#!/usr/bin/env python
# -*- coding: utf-8 -*-
# File:                ampel/contrib/hu/t2/xgb_trees.py
# License:             BSD-3-Clause
# Author:              jnordin@physik.hu-berlin.de
# Date:                06.04.2020
# Last Modified Date:  06.04.2020
# Last Modified By:    jnordin@physik.hu-berlin.de

# ruff: noqa

import numpy as np


class xgboost_tree:
    """
    Explicit python recording of xgboost tree.
    The parameter lists of the init function have to correspond to the order of the fits done.
    """

    def predict_risedecline(self, featuredict, ndet, max_trees=100):
        """
        Perform tree prediction based on dictionary with feature properties.
        """

        # Initial prediction (base score)
        predict = 0.5
        # Loop through all trees
        treemethod = eval("xgb_tree_" + str(ndet))
        for i in range(max_trees):
            predict = predict + treemethod(featuredict, i)
        return predict


def xgb_tree_2(x, num_booster):
    if num_booster == 0:
        state = 0
        if state == 0:
            state = 1 if x["magnr_med"] < 17.0195007 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.95450002)
                    else 4
                )
                if state == 3:
                    return -0.749048293
                if state == 4:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.9822278) else 8
                    if state == 7:
                        state = 13 if x["distnr_med"] < 7.95366764 else 14
                        if state == 13:
                            return -0.728509068
                        if state == 14:
                            state = 23 if x["magnr_med"] < 16.2384987 else 24
                            if state == 23:
                                return 0.499967992
                            if state == 24:
                                return -0.252000004
                    if state == 8:
                        state = 15 if x["distnr_med"] < 0.658522487 else 16
                        if state == 15:
                            state = 25 if x["magnr_med"] < 14.470499 else 26
                            if state == 25:
                                return -0.504000008
                            if state == 26:
                                state = 37 if x["maggaia_med"] < 16.0956631 else 38
                                if state == 37:
                                    return -0.252000004
                                if state == 38:
                                    return 0.601887643
                        if state == 16:
                            return -0.635039985
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.863000035)
                    else 6
                )
                if state == 5:
                    state = (
                        9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.00137155014) else 10
                    )
                    if state == 9:
                        return -0.737783134
                    if state == 10:
                        state = 17 if x["distnr_med"] < 6.27388191 else 18
                        if state == 17:
                            state = 27 if x["magnr_med"] < 20.6984997 else 28
                            if state == 27:
                                state = 39 if x["maggaia_med"] < 19.3743763 else 40
                                if state == 39:
                                    state = (
                                        51
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 3.03673601)
                                        else 52
                                    )
                                    if state == 51:
                                        state = (
                                            63 if x["magnr_med"] < 18.0582504 else 64
                                        )
                                        if state == 63:
                                            state = (
                                                73 if x["magnr_med"] < 17.682251 else 74
                                            )
                                            if state == 73:
                                                state = (
                                                    85
                                                    if x["distpsnr1_med"] < 0.69568944
                                                    else 86
                                                )
                                                if state == 85:
                                                    return -0.504000008
                                                if state == 86:
                                                    state = (
                                                        101
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 0.0780034959)
                                                        else 102
                                                    )
                                                    if state == 101:
                                                        return -0.252000004
                                                    if state == 102:
                                                        return 0.507586002
                                            if state == 74:
                                                return -0.554400027
                                        if state == 64:
                                            state = (
                                                75
                                                if x["magnr_med"] < 18.8052502
                                                else 76
                                            )
                                            if state == 75:
                                                state = (
                                                    87
                                                    if x["distpsnr1_med"] < 0.488713324
                                                    else 88
                                                )
                                                if state == 87:
                                                    return -0.453600019
                                                if state == 88:
                                                    return 0.650646627
                                            if state == 76:
                                                state = (
                                                    89
                                                    if x["distpsnr1_med"] < 1.28214347
                                                    else 90
                                                )
                                                if state == 89:
                                                    state = (
                                                        103
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 3.0015626)
                                                        else 104
                                                    )
                                                    if state == 103:
                                                        return -0.624521732
                                                    if state == 104:
                                                        state = (
                                                            119
                                                            if x["distpsnr1_med"]
                                                            < 0.284830689
                                                            else 120
                                                        )
                                                        if state == 119:
                                                            return 0.499967992
                                                        if state == 120:
                                                            return -0.252000004
                                                if state == 90:
                                                    state = (
                                                        105
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 2.88651609)
                                                        else 106
                                                    )
                                                    if state == 105:
                                                        return 0.588618279
                                                    if state == 106:
                                                        state = (
                                                            121
                                                            if x["distpsnr1_med"]
                                                            < 2.18345737
                                                            else 122
                                                        )
                                                        if state == 121:
                                                            return 0.245569378
                                                        if state == 122:
                                                            return -0.504000008
                                    if state == 52:
                                        return -0.481090903
                                if state == 40:
                                    state = (
                                        53
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 2.99189234)
                                        else 54
                                    )
                                    if state == 53:
                                        state = (
                                            65 if x["magnr_med"] < 20.3062515 else 66
                                        )
                                        if state == 65:
                                            state = (
                                                77
                                                if x["magnr_med"] < 18.0335007
                                                else 78
                                            )
                                            if state == 77:
                                                return -0.420000017
                                            if state == 78:
                                                state = (
                                                    91
                                                    if x["distpsnr1_med"] < 1.49141407
                                                    else 92
                                                )
                                                if state == 91:
                                                    return -0.624521732
                                                if state == 92:
                                                    state = (
                                                        107
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 0.989022017)
                                                        else 108
                                                    )
                                                    if state == 107:
                                                        state = (
                                                            123
                                                            if x["distpsnr1_med"]
                                                            < 8.49810123
                                                            else 124
                                                        )
                                                        if state == 123:
                                                            return -0.420000017
                                                        if state == 124:
                                                            return 0.438281804
                                                    if state == 108:
                                                        return 0.590652108
                                        if state == 66:
                                            return -0.540000021
                                    if state == 54:
                                        return -0.671999991
                            if state == 28:
                                state = (
                                    41
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.5813828)
                                    else 42
                                )
                                if state == 41:
                                    state = (
                                        55
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 0.0443113521)
                                        else 56
                                    )
                                    if state == 55:
                                        return -0.688799977
                                    if state == 56:
                                        state = (
                                            67 if x["magnr_med"] < 21.4202499 else 68
                                        )
                                        if state == 67:
                                            return -0.655200005
                                        if state == 68:
                                            state = (
                                                79
                                                if x["magnr_med"] < 22.7962494
                                                else 80
                                            )
                                            if state == 79:
                                                state = (
                                                    93
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (
                                                        x["distpsnr1_med"] < 0.155175447
                                                    )
                                                    else 94
                                                )
                                                if state == 93:
                                                    state = (
                                                        109
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 0.0776504502)
                                                        else 110
                                                    )
                                                    if state == 109:
                                                        return 0.645768046
                                                    if state == 110:
                                                        return -0.540000021
                                                if state == 94:
                                                    state = (
                                                        111
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 0.0505556017)
                                                        else 112
                                                    )
                                                    if state == 111:
                                                        return 0.401929915
                                                    if state == 112:
                                                        state = (
                                                            125
                                                            if x["distpsnr1_med"]
                                                            < 4.67712355
                                                            else 126
                                                        )
                                                        if state == 125:
                                                            return 0.0325943939
                                                        if state == 126:
                                                            return -0.540000021
                                            if state == 80:
                                                state = (
                                                    95
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 12.2965326)
                                                    else 96
                                                )
                                                if state == 95:
                                                    state = (
                                                        113
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 1.95106483)
                                                        else 114
                                                    )
                                                    if state == 113:
                                                        return -0.324000001
                                                    if state == 114:
                                                        state = (
                                                            127
                                                            if x["distpsnr1_med"]
                                                            < 8.59187317
                                                            else 128
                                                        )
                                                        if state == 127:
                                                            return 0.53604126
                                                        if state == 128:
                                                            return -0.252000004
                                                if state == 96:
                                                    return 0.550516844
                                if state == 42:
                                    return -0.69165957
                        if state == 18:
                            state = 29 if x["magnr_med"] < 19.1669998 else 30
                            if state == 29:
                                state = (
                                    43
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.8858681)
                                    else 44
                                )
                                if state == 43:
                                    return -0.523384631
                                if state == 44:
                                    return 0.499967992
                            if state == 30:
                                state = 45 if x["maggaia_med"] < 14.3526831 else 46
                                if state == 45:
                                    return 0.401929915
                                if state == 46:
                                    return -0.636186182
                if state == 6:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.00391784962) else 12
                    )
                    if state == 11:
                        state = 19 if x["distnr_med"] < 1.49187016 else 20
                        if state == 19:
                            state = 31 if x["magnr_med"] < 20.8937492 else 32
                            if state == 31:
                                return 0.550516844
                            if state == 32:
                                return -0.420000017
                        if state == 20:
                            return -0.743504107
                    if state == 12:
                        state = 21 if x["distnr_med"] < 0.550524235 else 22
                        if state == 21:
                            state = 33 if x["magnr_med"] < 20.6875 else 34
                            if state == 33:
                                state = (
                                    47
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.7718773)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        57
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 0.0346470028)
                                        else 58
                                    )
                                    if state == 57:
                                        return -0.377999991
                                    if state == 58:
                                        state = (
                                            69 if x["magnr_med"] < 17.8500004 else 70
                                        )
                                        if state == 69:
                                            state = (
                                                81
                                                if x["magnr_med"] < 17.5900002
                                                else 82
                                            )
                                            if state == 81:
                                                state = (
                                                    97
                                                    if x["distpsnr1_med"] < 0.135641724
                                                    else 98
                                                )
                                                if state == 97:
                                                    return 0.499967992
                                                if state == 98:
                                                    state = (
                                                        115
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 1.50262725)
                                                        else 116
                                                    )
                                                    if state == 115:
                                                        state = (
                                                            129
                                                            if x["distpsnr1_med"]
                                                            < 0.312010348
                                                            else 130
                                                        )
                                                        if state == 129:
                                                            return -0.252000004
                                                        if state == 130:
                                                            return 0.499967992
                                                    if state == 116:
                                                        return -0.252000004
                                            if state == 82:
                                                return -0.324000001
                                        if state == 70:
                                            return 0.634498775
                                if state == 48:
                                    return -0.377999991
                            if state == 34:
                                return -0.648000002
                        if state == 22:
                            state = 35 if x["magnr_med"] < 21.4449997 else 36
                            if state == 35:
                                return 0.69238615
                            if state == 36:
                                state = (
                                    49
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.6311378)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        59
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 0.018020751)
                                        else 60
                                    )
                                    if state == 59:
                                        return -0.324000001
                                    if state == 60:
                                        state = (
                                            71 if x["magnr_med"] < 23.0542507 else 72
                                        )
                                        if state == 71:
                                            state = (
                                                83 if x["magnr_med"] < 21.581749 else 84
                                            )
                                            if state == 83:
                                                return -0.252000004
                                            if state == 84:
                                                state = (
                                                    99
                                                    if x["distpsnr1_med"] < 0.213159144
                                                    else 100
                                                )
                                                if state == 99:
                                                    return -0.481090903
                                                if state == 100:
                                                    state = (
                                                        117
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 1.93774307)
                                                        else 118
                                                    )
                                                    if state == 117:
                                                        state = (
                                                            131
                                                            if x["distpsnr1_med"]
                                                            < 3.44711828
                                                            else 132
                                                        )
                                                        if state == 131:
                                                            return -0.252000004
                                                        if state == 132:
                                                            return 0.439581215
                                                    if state == 118:
                                                        return 0.59184885
                                        if state == 72:
                                            return -0.420000017
                                if state == 50:
                                    state = (
                                        61
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 1.98170722)
                                        else 62
                                    )
                                    if state == 61:
                                        return -0.578117669
                                    if state == 62:
                                        return 0.318088919
    elif num_booster == 1:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 10.7389936)
                else 2
            )
            if state == 1:
                state = 3 if x["neargaia_med"] < 2.48170805 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.9760513)
                        else 8
                    )
                    if state == 7:
                        return -0.535633028
                    if state == 8:
                        state = 15 if x["col_det"] < 0.526902199 else 16
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.148517996)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    43
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0364987999)
                                    else 44
                                )
                                if state == 43:
                                    return -0.390822232
                                if state == 44:
                                    state = (
                                        65 if x["distpsnr1_med"] < 0.963503003 else 66
                                    )
                                    if state == 65:
                                        state = (
                                            83
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 0.0385706015)
                                            else 84
                                        )
                                        if state == 83:
                                            return 0.369502753
                                        if state == 84:
                                            return -0.417606145
                                    if state == 66:
                                        state = (
                                            85
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 0.0384375006)
                                            else 86
                                        )
                                        if state == 85:
                                            return 0.440335453
                                        if state == 86:
                                            state = (
                                                109
                                                if x["sgscore1_med"] < 0.0384791493
                                                else 110
                                            )
                                            if state == 109:
                                                return 0.359871358
                                            if state == 110:
                                                return -0.302940011
                            if state == 28:
                                state = (
                                    45
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0412094966)
                                    else 46
                                )
                                if state == 45:
                                    return -0.297750324
                                if state == 46:
                                    return 0.594573557
                        if state == 16:
                            state = (
                                29
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0493124984)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    47
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.8958621)
                                    else 48
                                )
                                if state == 47:
                                    return -0.422015518
                                if state == 48:
                                    state = (
                                        67 if x["distpsnr1_med"] < 0.558903575 else 68
                                    )
                                    if state == 67:
                                        state = (
                                            87
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 2.96806717)
                                            else 88
                                        )
                                        if state == 87:
                                            state = (
                                                111
                                                if x["sgscore1_med"] < 0.010770835
                                                else 112
                                            )
                                            if state == 111:
                                                return 0.39311713
                                            if state == 112:
                                                return -0.253452152
                                        if state == 88:
                                            return -0.2821908
                                    if state == 68:
                                        state = (
                                            89
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 2.9588542)
                                            else 90
                                        )
                                        if state == 89:
                                            return 0.593906224
                                        if state == 90:
                                            return -0.233512312
                            if state == 30:
                                state = (
                                    49
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.00618649)
                                    else 50
                                )
                                if state == 49:
                                    return -0.574443102
                                if state == 50:
                                    state = (
                                        69 if x["distpsnr1_med"] < 0.970984042 else 70
                                    )
                                    if state == 69:
                                        return -0.491933763
                                    if state == 70:
                                        state = (
                                            91
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 3.0221529)
                                            else 92
                                        )
                                        if state == 91:
                                            return 0.391730934
                                        if state == 92:
                                            return -0.379671365
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1842499)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["col_det"] < 0.658545494 else 18
                        if state == 17:
                            state = (
                                31
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.587190509)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    51
                                    if np.isnan(x["t_lc"])
                                    or (x["t_lc"] < 0.00960070081)
                                    else 52
                                )
                                if state == 51:
                                    return -0.425513834
                                if state == 52:
                                    state = (
                                        71 if x["distpsnr1_med"] < 0.462724984 else 72
                                    )
                                    if state == 71:
                                        state = (
                                            93
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 0.0639988482)
                                            else 94
                                        )
                                        if state == 93:
                                            return -0.537527025
                                        if state == 94:
                                            state = (
                                                113
                                                if x["sgscore1_med"] < 0.0127083361
                                                else 114
                                            )
                                            if state == 113:
                                                return 0.257109374
                                            if state == 114:
                                                return -0.344103932
                                    if state == 72:
                                        return 0.502095938
                            if state == 32:
                                state = (
                                    53
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.107297495)
                                    else 54
                                )
                                if state == 53:
                                    return -0.616161764
                                if state == 54:
                                    return 0.288639754
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.563592494)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    55
                                    if np.isnan(x["t_lc"])
                                    or (x["t_lc"] < 0.00137730013)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        73 if x["distpsnr1_med"] < 0.735778034 else 74
                                    )
                                    if state == 73:
                                        state = (
                                            95
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 0.000457199989)
                                            else 96
                                        )
                                        if state == 95:
                                            return 0.316159457
                                        if state == 96:
                                            return -0.170104906
                                    if state == 74:
                                        return -0.524500489
                                if state == 56:
                                    state = (
                                        75
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.199287385)
                                        else 76
                                    )
                                    if state == 75:
                                        state = (
                                            97
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 2.98338556)
                                            else 98
                                        )
                                        if state == 97:
                                            state = (
                                                115
                                                if x["sgscore1_med"] < 1.00000095
                                                else 116
                                            )
                                            if state == 115:
                                                return -0.413392961
                                            if state == 116:
                                                state = (
                                                    131
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.63499999)
                                                    else 132
                                                )
                                                if state == 131:
                                                    state = (
                                                        151
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.455833256)
                                                        else 152
                                                    )
                                                    if state == 151:
                                                        return -0.511733949
                                                    if state == 152:
                                                        return -0.148877919
                                                if state == 132:
                                                    return 0.440335453
                                        if state == 98:
                                            state = (
                                                117
                                                if x["sgscore1_med"] < 1.00000095
                                                else 118
                                            )
                                            if state == 117:
                                                return -0.443845093
                                            if state == 118:
                                                state = (
                                                    133
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.517499983)
                                                    else 134
                                                )
                                                if state == 133:
                                                    return -0.265842468
                                                if state == 134:
                                                    return 0.445554793
                                    if state == 76:
                                        state = (
                                            99
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 0.922540545)
                                            else 100
                                        )
                                        if state == 99:
                                            state = (
                                                119
                                                if x["sgscore1_med"] < 0.0234375
                                                else 120
                                            )
                                            if state == 119:
                                                state = (
                                                    135
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.656428576)
                                                    else 136
                                                )
                                                if state == 135:
                                                    state = (
                                                        153
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.427262098)
                                                        else 154
                                                    )
                                                    if state == 153:
                                                        return 0.332560956
                                                    if state == 154:
                                                        return -0.266002953
                                                if state == 136:
                                                    return 0.516921341
                                            if state == 120:
                                                state = (
                                                    137
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.927857161)
                                                    else 138
                                                )
                                                if state == 137:
                                                    return -0.491098195
                                                if state == 138:
                                                    return 0.359871358
                                        if state == 100:
                                            state = (
                                                121
                                                if x["sgscore1_med"] < 0.503708482
                                                else 122
                                            )
                                            if state == 121:
                                                state = (
                                                    139
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.46416685)
                                                    else 140
                                                )
                                                if state == 139:
                                                    return -0.52379334
                                                if state == 140:
                                                    state = (
                                                        155
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.606666744)
                                                        else 156
                                                    )
                                                    if state == 155:
                                                        return 0.341856807
                                                    if state == 156:
                                                        return 0.479655385
                                            if state == 122:
                                                state = (
                                                    141
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.693333387)
                                                    else 142
                                                )
                                                if state == 141:
                                                    state = (
                                                        157
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.375833154)
                                                        else 158
                                                    )
                                                    if state == 157:
                                                        return -0.275078177
                                                    if state == 158:
                                                        return 0.367100894
                                                if state == 142:
                                                    return -0.4653337
                            if state == 34:
                                state = (
                                    57
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 1.00771999)
                                    else 58
                                )
                                if state == 57:
                                    return -0.553363681
                                if state == 58:
                                    state = (
                                        77 if x["distpsnr1_med"] < 7.74134445 else 78
                                    )
                                    if state == 77:
                                        return -0.562971115
                                    if state == 78:
                                        state = (
                                            101
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 1.52601278)
                                            else 102
                                        )
                                        if state == 101:
                                            return 0.39311713
                                        if state == 102:
                                            state = (
                                                123
                                                if x["sgscore1_med"] < 0.860895991
                                                else 124
                                            )
                                            if state == 123:
                                                return -0.336394221
                                            if state == 124:
                                                state = (
                                                    143
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.692142904)
                                                    else 144
                                                )
                                                if state == 143:
                                                    return -0.201129079
                                                if state == 144:
                                                    return 0.265402287
                    if state == 10:
                        state = 19 if x["col_det"] < -0.262050629 else 20
                        if state == 19:
                            return -0.489255905
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.848304033)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    59
                                    if np.isnan(x["t_lc"])
                                    or (x["t_lc"] < 0.00137155014)
                                    else 60
                                )
                                if state == 59:
                                    return -0.517009616
                                if state == 60:
                                    state = (
                                        79
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 1.49141407)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            103
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 2.91961217)
                                            else 104
                                        )
                                        if state == 103:
                                            state = (
                                                125
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.207901508)
                                                else 126
                                            )
                                            if state == 125:
                                                state = (
                                                    145
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.350357234)
                                                    else 146
                                                )
                                                if state == 145:
                                                    return -0.475341737
                                                if state == 146:
                                                    state = (
                                                        159
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.436666727)
                                                        else 160
                                                    )
                                                    if state == 159:
                                                        return 0.429345429
                                                    if state == 160:
                                                        state = (
                                                            163
                                                            if x["col_det"] < 2.40114307
                                                            else 164
                                                        )
                                                        if state == 163:
                                                            return -0.57329154
                                                        if state == 164:
                                                            return 0.440005839
                                            if state == 126:
                                                return -0.437939525
                                        if state == 104:
                                            return -0.62801671
                                    if state == 80:
                                        state = (
                                            105
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 0.0129282493)
                                            else 106
                                        )
                                        if state == 105:
                                            return -0.436141521
                                        if state == 106:
                                            state = (
                                                127
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.000729166495)
                                                else 128
                                            )
                                            if state == 127:
                                                return -0.457285643
                                            if state == 128:
                                                state = (
                                                    147
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.330357194)
                                                    else 148
                                                )
                                                if state == 147:
                                                    return -0.550228179
                                                if state == 148:
                                                    state = (
                                                        161
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.507500052)
                                                        else 162
                                                    )
                                                    if state == 161:
                                                        state = (
                                                            165
                                                            if x["col_det"] < 1.05581379
                                                            else 166
                                                        )
                                                        if state == 165:
                                                            return -0.380349219
                                                        if state == 166:
                                                            return 0.245471388
                                                    if state == 162:
                                                        state = (
                                                            167
                                                            if np.isnan(x["col_det"])
                                                            or (
                                                                x["col_det"]
                                                                < 0.141078949
                                                            )
                                                            else 168
                                                        )
                                                        if state == 167:
                                                            return 0.469812363
                                                        if state == 168:
                                                            return 0.20466207
                            if state == 36:
                                return -0.580312967
            if state == 2:
                state = (
                    5
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 11.3691196)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3176498)
                        else 12
                    )
                    if state == 11:
                        state = 21 if x["col_det"] < 1.30564213 else 22
                        if state == 21:
                            return -0.344957739
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.999374986)
                                else 38
                            )
                            if state == 37:
                                return -0.42882362
                            if state == 38:
                                return 0.359871358
                    if state == 12:
                        state = 23 if x["col_det"] < 0.35346508 else 24
                        if state == 23:
                            return 0.507050335
                        if state == 24:
                            return -0.361785233
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4557495)
                        else 14
                    )
                    if state == 13:
                        state = 25 if x["col_det"] < 0.0680055618 else 26
                        if state == 25:
                            state = 39 if x["sgscore1_med"] < 0.402020991 else 40
                            if state == 39:
                                return -0.292979509
                            if state == 40:
                                state = (
                                    61
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0436457992)
                                    else 62
                                )
                                if state == 61:
                                    return -0.32292369
                                if state == 62:
                                    return 0.467085272
                        if state == 26:
                            state = 41 if x["sgscore1_med"] < 0.542050481 else 42
                            if state == 41:
                                state = (
                                    63
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.51039356)
                                    else 64
                                )
                                if state == 63:
                                    return -0.539111912
                                if state == 64:
                                    state = (
                                        81 if x["distpsnr1_med"] < 13.8621807 else 82
                                    )
                                    if state == 81:
                                        return -0.231517017
                                    if state == 82:
                                        state = (
                                            107
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 2.98704863)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                129
                                                if x["sgscore1_med"] < 0.0107143
                                                else 130
                                            )
                                            if state == 129:
                                                state = (
                                                    149
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.49964273)
                                                    else 150
                                                )
                                                if state == 149:
                                                    return -0.185068339
                                                if state == 150:
                                                    return 0.3840321
                                            if state == 130:
                                                return 0.648638844
                                        if state == 108:
                                            return -0.180126801
                            if state == 42:
                                return -0.549663782
                    if state == 14:
                        return -0.547733188
    elif num_booster == 2:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.583698988)
                else 2
            )
            if state == 1:
                state = 3 if x["neargaia_med"] < 1.4944241 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.769249976)
                        else 8
                    )
                    if state == 7:
                        return -0.48369965
                    if state == 8:
                        state = 15 if x["distnr_med"] < 0.217259735 else 16
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.968999982)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    41
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.6214314)
                                    else 42
                                )
                                if state == 41:
                                    return 0.279071003
                                if state == 42:
                                    return -0.356589079
                            if state == 26:
                                return 0.479248554
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.989249945)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    43
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.0600243)
                                    else 44
                                )
                                if state == 43:
                                    return -0.430574983
                                if state == 44:
                                    state = 65 if x["maggaia_med"] < 17.3263988 else 66
                                    if state == 65:
                                        return -0.410596788
                                    if state == 66:
                                        state = (
                                            91
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.935500026)
                                            else 92
                                        )
                                        if state == 91:
                                            state = (
                                                119
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.7539902)
                                                else 120
                                            )
                                            if state == 119:
                                                state = (
                                                    147
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.861999989)
                                                    else 148
                                                )
                                                if state == 147:
                                                    state = (
                                                        169
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.790000021
                                                        )
                                                        else 170
                                                    )
                                                    if state == 169:
                                                        return 0.3821913
                                                    if state == 170:
                                                        state = (
                                                            185
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.630833268
                                                            )
                                                            else 186
                                                        )
                                                        if state == 185:
                                                            return -0.165804729
                                                        if state == 186:
                                                            return 0.280249
                                                if state == 148:
                                                    state = (
                                                        171
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.888999999
                                                        )
                                                        else 172
                                                    )
                                                    if state == 171:
                                                        return -0.373289376
                                                    if state == 172:
                                                        return 0.224609002
                                            if state == 120:
                                                return -0.484253049
                                        if state == 92:
                                            return 0.469139636
                            if state == 28:
                                return -0.419505149
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.862749994)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["distnr_med"] < 5.28807306 else 18
                        if state == 17:
                            state = (
                                29
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.704750001)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    45
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 20.0196495)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        67
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 17.8064156)
                                        else 68
                                    )
                                    if state == 67:
                                        return -0.488439351
                                    if state == 68:
                                        state = (
                                            93
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.471249998)
                                            else 94
                                        )
                                        if state == 93:
                                            return -0.433434516
                                        if state == 94:
                                            state = (
                                                121
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.0614109)
                                                else 122
                                            )
                                            if state == 121:
                                                return -0.390933573
                                            if state == 122:
                                                return 0.540315568
                                if state == 46:
                                    state = 69 if x["maggaia_med"] < 41.6919403 else 70
                                    if state == 69:
                                        return -0.546432674
                                    if state == 70:
                                        state = (
                                            95
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.644250035)
                                            else 96
                                        )
                                        if state == 95:
                                            return -0.49246031
                                        if state == 96:
                                            state = (
                                                123
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.6267509)
                                                else 124
                                            )
                                            if state == 123:
                                                return -0.254322559
                                            if state == 124:
                                                state = (
                                                    149
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.656499982)
                                                    else 150
                                                )
                                                if state == 149:
                                                    return 0.302703917
                                                if state == 150:
                                                    return -0.18563351
                            if state == 30:
                                state = (
                                    47
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 20.1041756)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        71
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 14.3206472)
                                        else 72
                                    )
                                    if state == 71:
                                        state = (
                                            97
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.726750016)
                                            else 98
                                        )
                                        if state == 97:
                                            return 0.398385406
                                        if state == 98:
                                            state = (
                                                125
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.9782143)
                                                else 126
                                            )
                                            if state == 125:
                                                return -0.471193224
                                            if state == 126:
                                                return 0.365389973
                                    if state == 72:
                                        state = (
                                            99
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.854249954)
                                            else 100
                                        )
                                        if state == 99:
                                            state = (
                                                127
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.981039)
                                                else 128
                                            )
                                            if state == 127:
                                                return -0.302089602
                                            if state == 128:
                                                return 0.461247653
                                        if state == 100:
                                            return -0.177819595
                                if state == 48:
                                    state = 73 if x["maggaia_med"] < 18.5569992 else 74
                                    if state == 73:
                                        return -0.515016079
                                    if state == 74:
                                        state = (
                                            101
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.713249981)
                                            else 102
                                        )
                                        if state == 101:
                                            return 0.329733968
                                        if state == 102:
                                            state = (
                                                129
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.4561672)
                                                else 130
                                            )
                                            if state == 129:
                                                state = (
                                                    151
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.777500033)
                                                    else 152
                                                )
                                                if state == 151:
                                                    return -0.395697683
                                                if state == 152:
                                                    state = (
                                                        173
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.797250032
                                                        )
                                                        else 174
                                                    )
                                                    if state == 173:
                                                        return 0.319924682
                                                    if state == 174:
                                                        state = (
                                                            187
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.489285588
                                                            )
                                                            else 188
                                                        )
                                                        if state == 187:
                                                            return 0.157753184
                                                        if state == 188:
                                                            return -0.298433125
                                            if state == 130:
                                                return -0.482771307
                        if state == 18:
                            state = (
                                31
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.605250001)
                                else 32
                            )
                            if state == 31:
                                return -0.50653553
                            if state == 32:
                                state = (
                                    49
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.6690216)
                                    else 50
                                )
                                if state == 49:
                                    return 0.496867776
                                if state == 50:
                                    state = (
                                        75
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 19.9962044)
                                        else 76
                                    )
                                    if state == 75:
                                        state = (
                                            103
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.621250033)
                                            else 104
                                        )
                                        if state == 103:
                                            return 0.292236894
                                        if state == 104:
                                            state = (
                                                131
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.1618195)
                                                else 132
                                            )
                                            if state == 131:
                                                state = (
                                                    153
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.790750027)
                                                    else 154
                                                )
                                                if state == 153:
                                                    return -0.382464051
                                                if state == 154:
                                                    state = (
                                                        175
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.800499976
                                                        )
                                                        else 176
                                                    )
                                                    if state == 175:
                                                        return 0.326271355
                                                    if state == 176:
                                                        return -0.395097762
                                            if state == 132:
                                                return -0.519704998
                                    if state == 76:
                                        state = (
                                            105
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.634000003)
                                            else 106
                                        )
                                        if state == 105:
                                            return 0.543941021
                                        if state == 106:
                                            return -0.38154757
                    if state == 10:
                        state = 19 if x["distnr_med"] < 5.37503242 else 20
                        if state == 19:
                            state = (
                                33
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.991750002)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    51
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 20.0568619)
                                    else 52
                                )
                                if state == 51:
                                    state = 77 if x["maggaia_med"] < 13.3895779 else 78
                                    if state == 77:
                                        return -0.196859151
                                    if state == 78:
                                        state = (
                                            107
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.925249994)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                133
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.0563507)
                                                else 134
                                            )
                                            if state == 133:
                                                return -0.280854464
                                            if state == 134:
                                                return 0.477373064
                                        if state == 108:
                                            state = (
                                                135
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.9009285)
                                                else 136
                                            )
                                            if state == 135:
                                                state = (
                                                    155
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.959250033)
                                                    else 156
                                                )
                                                if state == 155:
                                                    state = (
                                                        177
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.935249984
                                                        )
                                                        else 178
                                                    )
                                                    if state == 177:
                                                        state = (
                                                            189
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.541547656
                                                            )
                                                            else 190
                                                        )
                                                        if state == 189:
                                                            return 0.212715566
                                                        if state == 190:
                                                            return -0.322183371
                                                    if state == 178:
                                                        state = (
                                                            191
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.492619216
                                                            )
                                                            else 192
                                                        )
                                                        if state == 191:
                                                            return -0.285706043
                                                        if state == 192:
                                                            return 0.283897012
                                                if state == 156:
                                                    return 0.431718498
                                            if state == 136:
                                                state = (
                                                    157
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.966749966)
                                                    else 158
                                                )
                                                if state == 157:
                                                    state = (
                                                        179
                                                        if np.isnan(x["classtar_med"])
                                                        or (x["classtar_med"] < 0.963)
                                                        else 180
                                                    )
                                                    if state == 179:
                                                        state = (
                                                            193
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.539880872
                                                            )
                                                            else 194
                                                        )
                                                        if state == 193:
                                                            return 0.234962106
                                                        if state == 194:
                                                            return -0.454740763
                                                    if state == 180:
                                                        return 0.286736727
                                                if state == 158:
                                                    return -0.434928268
                                if state == 52:
                                    state = (
                                        79
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 15.8687744)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            109
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.966750026)
                                            else 110
                                        )
                                        if state == 109:
                                            state = (
                                                137
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.2963715)
                                                else 138
                                            )
                                            if state == 137:
                                                return -0.802166283
                                            if state == 138:
                                                state = (
                                                    159
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.919749975)
                                                    else 160
                                                )
                                                if state == 159:
                                                    return -0.398995757
                                                if state == 160:
                                                    return 0.184045523
                                        if state == 110:
                                            state = (
                                                139
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.2140579)
                                                else 140
                                            )
                                            if state == 139:
                                                return 0.235714212
                                            if state == 140:
                                                return -0.288385838
                                    if state == 80:
                                        state = (
                                            111
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.973999977)
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                141
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.2123146)
                                                else 142
                                            )
                                            if state == 141:
                                                state = (
                                                    161
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.918750048)
                                                    else 162
                                                )
                                                if state == 161:
                                                    state = (
                                                        181
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.910000026
                                                        )
                                                        else 182
                                                    )
                                                    if state == 181:
                                                        return -0.437346369
                                                    if state == 182:
                                                        return 0.286736727
                                                if state == 162:
                                                    return -0.388287753
                                            if state == 142:
                                                state = (
                                                    163
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.904999971)
                                                    else 164
                                                )
                                                if state == 163:
                                                    return 0.398887068
                                                if state == 164:
                                                    return -0.332234383
                                        if state == 112:
                                            return 0.455755293
                            if state == 34:
                                state = (
                                    53
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 17.9159546)
                                    else 54
                                )
                                if state == 53:
                                    return -0.434257925
                                if state == 54:
                                    state = 81 if x["maggaia_med"] < 18.0728722 else 82
                                    if state == 81:
                                        return 0.289860636
                                    if state == 82:
                                        return -0.269446254
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.958500028)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    55
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.2435646)
                                    else 56
                                )
                                if state == 55:
                                    return 0.227804258
                                if state == 56:
                                    return -0.474656612
                            if state == 36:
                                state = (
                                    57
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 20.0351467)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        83
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 16.1673222)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            113
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.989499986)
                                            else 114
                                        )
                                        if state == 113:
                                            return 0.258677781
                                        if state == 114:
                                            return -0.258484125
                                    if state == 84:
                                        state = (
                                            115
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.962749958)
                                            else 116
                                        )
                                        if state == 115:
                                            state = (
                                                143
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.5403042)
                                                else 144
                                            )
                                            if state == 143:
                                                return 0.286736727
                                            if state == 144:
                                                return -0.163997591
                                        if state == 116:
                                            return -0.500629425
                                if state == 58:
                                    state = 85 if x["maggaia_med"] < 41.4342422 else 86
                                    if state == 85:
                                        return -0.123935089
                                    if state == 86:
                                        return 0.433203042
            if state == 2:
                state = 5 if x["neargaia_med"] < 175.897018 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.694499969)
                        else 12
                    )
                    if state == 11:
                        return -0.497782886
                    if state == 12:
                        state = 21 if x["distnr_med"] < 3.12265515 else 22
                        if state == 21:
                            return -0.488063544
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.734500051)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    59
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.5992508)
                                    else 60
                                )
                                if state == 59:
                                    return 0.436408252
                                if state == 60:
                                    state = 87 if x["maggaia_med"] < 14.8100414 else 88
                                    if state == 87:
                                        return 0.310672551
                                    if state == 88:
                                        return -0.360757411
                            if state == 38:
                                state = (
                                    61
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.8240395)
                                    else 62
                                )
                                if state == 61:
                                    state = 89 if x["maggaia_med"] < 18.0131149 else 90
                                    if state == 89:
                                        state = (
                                            117
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.980750024)
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                145
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6159401)
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    165
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.979750037)
                                                    else 166
                                                )
                                                if state == 165:
                                                    return -0.348838538
                                                if state == 166:
                                                    return 0.333974898
                                            if state == 146:
                                                state = (
                                                    167
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.933000028)
                                                    else 168
                                                )
                                                if state == 167:
                                                    return 0.528515875
                                                if state == 168:
                                                    state = (
                                                        183
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.952000022
                                                        )
                                                        else 184
                                                    )
                                                    if state == 183:
                                                        return -0.121522956
                                                    if state == 184:
                                                        return 0.279348522
                                        if state == 118:
                                            return -0.284214467
                                    if state == 90:
                                        return -0.487477481
                                if state == 62:
                                    return -0.478948772
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.863749981)
                        else 14
                    )
                    if state == 13:
                        return -0.389056921
                    if state == 14:
                        state = 23 if x["distnr_med"] < 4.65449381 else 24
                        if state == 23:
                            return -0.282101244
                        if state == 24:
                            state = (
                                39
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.898000002)
                                else 40
                            )
                            if state == 39:
                                return 0.320778906
                            if state == 40:
                                state = (
                                    63
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.2767391)
                                    else 64
                                )
                                if state == 63:
                                    return 0.240317553
                                if state == 64:
                                    return -0.290786207
    elif num_booster == 3:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.583467007)
                else 2
            )
            if state == 1:
                state = 3 if x["sgscore1_med"] < 0.0677321479 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"])
                        or (x["t_predetect"] < 0.904681683)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7026329)
                            else 16
                        )
                        if state == 15:
                            state = 27 if x["sgscore1_med"] < 0.046583347 else 28
                            if state == 27:
                                return 0.432207823
                            if state == 28:
                                return -0.294790924
                        if state == 16:
                            state = 29 if x["sgscore1_med"] < 0.00760417012 else 30
                            if state == 29:
                                return -0.498312742
                            if state == 30:
                                state = (
                                    47
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.0200636983)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        71
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.0331402)
                                        else 72
                                    )
                                    if state == 71:
                                        return 0.214094326
                                    if state == 72:
                                        return -0.235890627
                                if state == 48:
                                    state = (
                                        73
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.8961201)
                                        else 74
                                    )
                                    if state == 73:
                                        state = (
                                            103
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.900500059)
                                            else 104
                                        )
                                        if state == 103:
                                            return 0.064586401
                                        if state == 104:
                                            return -0.203075334
                                    if state == 74:
                                        return -0.470141619
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.2238445)
                            else 18
                        )
                        if state == 17:
                            state = 31 if x["sgscore1_med"] < 0.0314582996 else 32
                            if state == 31:
                                state = (
                                    49
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.87614584)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        75
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.8596764)
                                        else 76
                                    )
                                    if state == 75:
                                        state = (
                                            105
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.819500029)
                                            else 106
                                        )
                                        if state == 105:
                                            return -0.226859868
                                        if state == 106:
                                            state = (
                                                137 if x["col_det"] < 0.000001 else 138
                                            )
                                            if state == 137:
                                                return 0.069418028
                                            if state == 138:
                                                state = (
                                                    163
                                                    if x["magnr_med"] < 18.6407509
                                                    else 164
                                                )
                                                if state == 163:
                                                    return -0.149570301
                                                if state == 164:
                                                    return 0.334182233
                                    if state == 76:
                                        return -0.341763347
                                if state == 50:
                                    state = (
                                        77
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.1008663)
                                        else 78
                                    )
                                    if state == 77:
                                        state = (
                                            107
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.740750015)
                                            else 108
                                        )
                                        if state == 107:
                                            return -0.306616277
                                        if state == 108:
                                            return 0.371135443
                                    if state == 78:
                                        state = (
                                            109
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.818000019)
                                            else 110
                                        )
                                        if state == 109:
                                            state = (
                                                139
                                                if x["col_det"] < 0.268312454
                                                else 140
                                            )
                                            if state == 139:
                                                return 0.23346813
                                            if state == 140:
                                                return -0.213721216
                                        if state == 110:
                                            return -0.373474807
                            if state == 32:
                                state = (
                                    51
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.98637152)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        79
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.2494755)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            111
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.870249987)
                                            else 112
                                        )
                                        if state == 111:
                                            return -0.178031474
                                        if state == 112:
                                            return 0.241712645
                                    if state == 80:
                                        state = (
                                            113
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.659250021)
                                            else 114
                                        )
                                        if state == 113:
                                            state = (
                                                141
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.28326416)
                                                else 142
                                            )
                                            if state == 141:
                                                return -0.146526113
                                            if state == 142:
                                                return 0.330199957
                                        if state == 114:
                                            return 0.529327154
                                if state == 52:
                                    state = (
                                        81
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.2931061)
                                        else 82
                                    )
                                    if state == 81:
                                        return -0.201893777
                                    if state == 82:
                                        state = (
                                            115
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.975499988)
                                            else 116
                                        )
                                        if state == 115:
                                            state = (
                                                143
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.219976425)
                                                else 144
                                            )
                                            if state == 143:
                                                return 0.451895565
                                            if state == 144:
                                                return -0.28677243
                                        if state == 116:
                                            state = (
                                                145 if x["col_det"] < 0.000001 else 146
                                            )
                                            if state == 145:
                                                return -0.272070527
                                            if state == 146:
                                                return 0.236684322
                        if state == 18:
                            state = 33 if x["sgscore1_med"] < 0.01672915 else 34
                            if state == 33:
                                return -0.487785399
                            if state == 34:
                                state = (
                                    53
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.954427)
                                    else 54
                                )
                                if state == 53:
                                    return -0.343664527
                                if state == 54:
                                    state = (
                                        83
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.4765472)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            117
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.852999926)
                                            else 118
                                        )
                                        if state == 117:
                                            return -0.280433863
                                        if state == 118:
                                            return 0.326037675
                                    if state == 84:
                                        return -0.24800846
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.83414364)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5829639)
                            else 20
                        )
                        if state == 19:
                            state = 35 if x["sgscore1_med"] < 0.147565514 else 36
                            if state == 35:
                                state = (
                                    55
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.00159724988)
                                    else 56
                                )
                                if state == 55:
                                    return 0.264061213
                                if state == 56:
                                    return -0.347535908
                            if state == 36:
                                state = (
                                    57
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 1.93331599)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        85
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 16.85532)
                                        else 86
                                    )
                                    if state == 85:
                                        return -0.360254318
                                    if state == 86:
                                        state = (
                                            119
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.696500063)
                                            else 120
                                        )
                                        if state == 119:
                                            state = (
                                                147
                                                if x["col_det"] < 5.69426823
                                                else 148
                                            )
                                            if state == 147:
                                                return -0.197562084
                                            if state == 148:
                                                state = (
                                                    165
                                                    if x["magnr_med"] < 18.444252
                                                    else 166
                                                )
                                                if state == 165:
                                                    return -0.236365288
                                                if state == 166:
                                                    return 0.103214748
                                        if state == 120:
                                            return 0.399631858
                                if state == 58:
                                    return -0.366270751
                        if state == 20:
                            state = 37 if x["sgscore1_med"] < 1.15911508 else 38
                            if state == 37:
                                return -0.504573882
                            if state == 38:
                                state = (
                                    59
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.0671122968)
                                    else 60
                                )
                                if state == 59:
                                    return -0.500901103
                                if state == 60:
                                    state = (
                                        87
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.4715996)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            121
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.722249985)
                                            else 122
                                        )
                                        if state == 121:
                                            return 0.327543885
                                        if state == 122:
                                            return -0.246596009
                                    if state == 88:
                                        return -0.33244732
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.3611679)
                            else 22
                        )
                        if state == 21:
                            state = (
                                39
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.145294502)
                                else 40
                            )
                            if state == 39:
                                return -0.504649162
                            if state == 40:
                                state = (
                                    61
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.01383686)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        89
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 16.7984676)
                                        else 90
                                    )
                                    if state == 89:
                                        state = (
                                            123
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.99000001)
                                            else 124
                                        )
                                        if state == 123:
                                            state = (
                                                149
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.0304689407)
                                                else 150
                                            )
                                            if state == 149:
                                                state = (
                                                    167
                                                    if x["magnr_med"] < 16.3285007
                                                    else 168
                                                )
                                                if state == 167:
                                                    return -0.300522268
                                                if state == 168:
                                                    return 0.301174164
                                            if state == 150:
                                                return -0.297624409
                                        if state == 124:
                                            return -0.356684119
                                    if state == 90:
                                        return -0.45812127
                                if state == 62:
                                    state = (
                                        91
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 17.2647095)
                                        else 92
                                    )
                                    if state == 91:
                                        return -0.321961284
                                    if state == 92:
                                        state = (
                                            125
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.754000008)
                                            else 126
                                        )
                                        if state == 125:
                                            return -0.128818929
                                        if state == 126:
                                            return 0.473211735
                        if state == 22:
                            state = 41 if x["sgscore1_med"] < 0.412187517 else 42
                            if state == 41:
                                state = (
                                    63
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.97938657)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        93
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.1524239)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            127
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.962499976)
                                            else 128
                                        )
                                        if state == 127:
                                            state = (
                                                151
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.159308434)
                                                else 152
                                            )
                                            if state == 151:
                                                return -0.435912222
                                            if state == 152:
                                                state = (
                                                    169
                                                    if x["magnr_med"] < 18.3069992
                                                    else 170
                                                )
                                                if state == 169:
                                                    return -0.287729532
                                                if state == 170:
                                                    return 0.218708515
                                        if state == 128:
                                            state = (
                                                153
                                                if x["col_det"] < 0.620513916
                                                else 154
                                            )
                                            if state == 153:
                                                state = (
                                                    171
                                                    if x["magnr_med"] < 20.7407494
                                                    else 172
                                                )
                                                if state == 171:
                                                    return 0.392789781
                                                if state == 172:
                                                    return -0.25500387
                                            if state == 154:
                                                state = (
                                                    173
                                                    if x["magnr_med"] < 17.7905006
                                                    else 174
                                                )
                                                if state == 173:
                                                    return -0.298990607
                                                if state == 174:
                                                    state = (
                                                        185
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.95905662
                                                        )
                                                        else 186
                                                    )
                                                    if state == 185:
                                                        return -0.163357377
                                                    if state == 186:
                                                        return 0.198489815
                                    if state == 94:
                                        state = (
                                            129
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.628499985)
                                            else 130
                                        )
                                        if state == 129:
                                            return -0.248671085
                                        if state == 130:
                                            state = (
                                                155
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.181976318)
                                                else 156
                                            )
                                            if state == 155:
                                                return -0.217910692
                                            if state == 156:
                                                state = (
                                                    175
                                                    if x["magnr_med"] < 20.4125004
                                                    else 176
                                                )
                                                if state == 175:
                                                    return 0.55056417
                                                if state == 176:
                                                    return 0.163156867
                                if state == 64:
                                    state = (
                                        95
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.8725662)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            131
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.940750003)
                                            else 132
                                        )
                                        if state == 131:
                                            return -0.435085565
                                        if state == 132:
                                            return 0.383871645
                                    if state == 96:
                                        return -0.38883394
                            if state == 42:
                                state = (
                                    65
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.87331009)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        97
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.3943825)
                                        else 98
                                    )
                                    if state == 97:
                                        return 0.436977595
                                    if state == 98:
                                        return -0.13436158
                                if state == 66:
                                    state = (
                                        99
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.4551353)
                                        else 100
                                    )
                                    if state == 99:
                                        state = (
                                            133
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.828249991)
                                            else 134
                                        )
                                        if state == 133:
                                            state = (
                                                157
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.0390138626)
                                                else 158
                                            )
                                            if state == 157:
                                                state = (
                                                    177
                                                    if x["magnr_med"] < 20.0929985
                                                    else 178
                                                )
                                                if state == 177:
                                                    state = (
                                                        187
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.94005799
                                                        )
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        return 0.331872493
                                                    if state == 188:
                                                        return -0.317463934
                                                if state == 178:
                                                    return -0.356918722
                                            if state == 158:
                                                state = (
                                                    179
                                                    if x["magnr_med"] < 20.6167507
                                                    else 180
                                                )
                                                if state == 179:
                                                    state = (
                                                        189
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.95507526
                                                        )
                                                        else 190
                                                    )
                                                    if state == 189:
                                                        return -0.236327931
                                                    if state == 190:
                                                        return 0.380802929
                                                if state == 180:
                                                    state = (
                                                        191
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.98032403
                                                        )
                                                        else 192
                                                    )
                                                    if state == 191:
                                                        return 0.208606854
                                                    if state == 192:
                                                        return -0.167195573
                                        if state == 134:
                                            state = (
                                                159
                                                if x["col_det"] < 0.546753883
                                                else 160
                                            )
                                            if state == 159:
                                                state = (
                                                    181
                                                    if x["magnr_med"] < 21.1362495
                                                    else 182
                                                )
                                                if state == 181:
                                                    state = (
                                                        193
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 3.04462385
                                                        )
                                                        else 194
                                                    )
                                                    if state == 193:
                                                        return 0.411220759
                                                    if state == 194:
                                                        return 0.101614833
                                                if state == 182:
                                                    state = (
                                                        195
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.91370964
                                                        )
                                                        else 196
                                                    )
                                                    if state == 195:
                                                        return -0.342163324
                                                    if state == 196:
                                                        state = (
                                                            199
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.52501899
                                                            )
                                                            else 200
                                                        )
                                                        if state == 199:
                                                            return 0.388602972
                                                        if state == 200:
                                                            return -0.150871664
                                            if state == 160:
                                                state = (
                                                    183
                                                    if x["magnr_med"] < 20.8027496
                                                    else 184
                                                )
                                                if state == 183:
                                                    return 0.333280027
                                                if state == 184:
                                                    state = (
                                                        197
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.92668986
                                                        )
                                                        else 198
                                                    )
                                                    if state == 197:
                                                        return -0.419950575
                                                    if state == 198:
                                                        state = (
                                                            201
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.48990202
                                                            )
                                                            else 202
                                                        )
                                                        if state == 201:
                                                            return -0.159441903
                                                        if state == 202:
                                                            return 0.103247404
                                    if state == 100:
                                        state = (
                                            135
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.656499982)
                                            else 136
                                        )
                                        if state == 135:
                                            state = (
                                                161
                                                if x["col_det"] < -0.181599617
                                                else 162
                                            )
                                            if state == 161:
                                                return 0.307657689
                                            if state == 162:
                                                return -0.337374181
                                        if state == 136:
                                            return -0.446035594
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.873729467 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.40126157)
                        else 12
                    )
                    if state == 11:
                        return -0.429320902
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4309006)
                            else 24
                        )
                        if state == 23:
                            state = 43 if x["sgscore1_med"] < 0.842774034 else 44
                            if state == 43:
                                state = (
                                    67
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.8495717)
                                    else 68
                                )
                                if state == 67:
                                    return 0.394397378
                                if state == 68:
                                    return -0.381542981
                            if state == 44:
                                return 0.378758729
                        if state == 24:
                            return -0.365785778
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["t_predetect"])
                        or (x["t_predetect"] < 0.0386458486)
                        else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.168869)
                            else 26
                        )
                        if state == 25:
                            state = 45 if x["sgscore1_med"] < 0.985520959 else 46
                            if state == 45:
                                state = (
                                    69
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.0385879502)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        101
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.1636658)
                                        else 102
                                    )
                                    if state == 101:
                                        return -0.276668668
                                    if state == 102:
                                        return 0.277325392
                                if state == 70:
                                    return 0.289631426
                            if state == 46:
                                return -0.312166512
                        if state == 26:
                            return -0.382059872
                    if state == 14:
                        return -0.434543401
    elif num_booster == 4:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.79261589)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 5.22621965)
                    else 4
                )
                if state == 3:
                    state = 7 if x["col_det"] < -0.0380010605 else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.4795494)
                            else 16
                        )
                        if state == 15:
                            state = 29 if x["distpsnr1_med"] < 4.03579187 else 30
                            if state == 29:
                                return -0.111925222
                            if state == 30:
                                return 0.190693349
                        if state == 16:
                            return -0.509129465
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.917099)
                            else 18
                        )
                        if state == 17:
                            return -0.380851865
                        if state == 18:
                            state = 31 if x["distpsnr1_med"] < 2.47215748 else 32
                            if state == 31:
                                state = 45 if x["sgscore1_med"] < 0.0395833477 else 46
                                if state == 45:
                                    state = 67 if x["distpsnr1_med"] < 2.122648 else 68
                                    if state == 67:
                                        state = (
                                            87
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.0437673479)
                                            else 88
                                        )
                                        if state == 87:
                                            state = (
                                                113
                                                if x["maggaia_med"] < 19.0309105
                                                else 114
                                            )
                                            if state == 113:
                                                return 0.364648998
                                            if state == 114:
                                                return -0.0888921618
                                        if state == 88:
                                            state = (
                                                115
                                                if x["maggaia_med"] < 18.7192249
                                                else 116
                                            )
                                            if state == 115:
                                                return 0.188443512
                                            if state == 116:
                                                return -0.372982115
                                    if state == 68:
                                        return -0.173631638
                                if state == 46:
                                    state = (
                                        69 if x["distpsnr1_med"] < 0.257383138 else 70
                                    )
                                    if state == 69:
                                        state = (
                                            89
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.0227604508)
                                            else 90
                                        )
                                        if state == 89:
                                            return 0.429217607
                                        if state == 90:
                                            state = (
                                                117
                                                if x["maggaia_med"] < 41.0752945
                                                else 118
                                            )
                                            if state == 117:
                                                return -0.310581535
                                            if state == 118:
                                                return 0.0840574726
                                    if state == 70:
                                        state = (
                                            91
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.937314808)
                                            else 92
                                        )
                                        if state == 91:
                                            state = (
                                                119
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 20.3302193)
                                                else 120
                                            )
                                            if state == 119:
                                                return -0.470925868
                                            if state == 120:
                                                return 0.192394421
                                        if state == 92:
                                            state = (
                                                121
                                                if x["maggaia_med"] < 18.9771423
                                                else 122
                                            )
                                            if state == 121:
                                                return -0.378786802
                                            if state == 122:
                                                return 0.197467297
                            if state == 32:
                                state = (
                                    47
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.525550485)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        71 if x["distpsnr1_med"] < 2.75047493 else 72
                                    )
                                    if state == 71:
                                        return 0.336949587
                                    if state == 72:
                                        state = (
                                            93
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.565069437)
                                            else 94
                                        )
                                        if state == 93:
                                            state = (
                                                123
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 19.3522797)
                                                else 124
                                            )
                                            if state == 123:
                                                return 0.275598139
                                            if state == 124:
                                                return -0.241641313
                                        if state == 94:
                                            state = (
                                                125
                                                if x["maggaia_med"] < 18.848011
                                                else 126
                                            )
                                            if state == 125:
                                                return 0.193309933
                                            if state == 126:
                                                return -0.469498277
                                if state == 48:
                                    return -0.294958979
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["col_det"]) or (x["col_det"] < 0.202965736)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8490505)
                            else 20
                        )
                        if state == 19:
                            return -0.432072431
                        if state == 20:
                            state = 33 if x["distpsnr1_med"] < 10.3451653 else 34
                            if state == 33:
                                state = 49 if x["sgscore1_med"] < 0.982396007 else 50
                                if state == 49:
                                    state = (
                                        73 if x["distpsnr1_med"] < 7.96378994 else 74
                                    )
                                    if state == 73:
                                        state = (
                                            95
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.532592535)
                                            else 96
                                        )
                                        if state == 95:
                                            return -0.409516126
                                        if state == 96:
                                            state = (
                                                127
                                                if x["maggaia_med"] < 17.4416676
                                                else 128
                                            )
                                            if state == 127:
                                                return 0.19449231
                                            if state == 128:
                                                return -0.182614028
                                    if state == 74:
                                        state = (
                                            97
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.476313591)
                                            else 98
                                        )
                                        if state == 97:
                                            state = (
                                                129
                                                if x["maggaia_med"] < 19.102169
                                                else 130
                                            )
                                            if state == 129:
                                                return 0.320985287
                                            if state == 130:
                                                return -0.337549299
                                        if state == 98:
                                            return -0.264003664
                                if state == 50:
                                    return -0.357474059
                            if state == 34:
                                return -0.349092662
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3627892)
                            else 22
                        )
                        if state == 21:
                            return -0.158335075
                        if state == 22:
                            return 0.264921039
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.407602638 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["col_det"]) or (x["col_det"] < -0.054444313)
                        else 12
                    )
                    if state == 11:
                        return -0.433628172
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.6170502)
                            else 24
                        )
                        if state == 23:
                            state = 35 if x["distpsnr1_med"] < 0.105146483 else 36
                            if state == 35:
                                return -0.330286145
                            if state == 36:
                                state = (
                                    51
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.0336041972)
                                    else 52
                                )
                                if state == 51:
                                    return 0.443839461
                                if state == 52:
                                    return -0.310064226
                        if state == 24:
                            return -0.359846801
                if state == 6:
                    state = 13 if x["col_det"] < 0.460152626 else 14
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.2626495)
                            else 26
                        )
                        if state == 25:
                            state = (
                                37
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 5.46097565)
                                else 38
                            )
                            if state == 37:
                                return -0.384784222
                            if state == 38:
                                state = 53 if x["sgscore1_med"] < 0.621708512 else 54
                                if state == 53:
                                    return 0.172272652
                                if state == 54:
                                    return -0.252646565
                        if state == 26:
                            state = 39 if x["distpsnr1_med"] < 5.57307434 else 40
                            if state == 39:
                                state = (
                                    55
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.64796102)
                                    else 56
                                )
                                if state == 55:
                                    state = 77 if x["distpsnr1_med"] < 1.3105793 else 78
                                    if state == 77:
                                        state = (
                                            99
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 3.0158565)
                                            else 100
                                        )
                                        if state == 99:
                                            state = (
                                                131
                                                if x["maggaia_med"] < 17.7026653
                                                else 132
                                            )
                                            if state == 131:
                                                state = (
                                                    151
                                                    if x["col_det"] < 0.000515937805
                                                    else 152
                                                )
                                                if state == 151:
                                                    state = (
                                                        167
                                                        if x["distpsnr1_med"]
                                                        < 0.917149544
                                                        else 168
                                                    )
                                                    if state == 167:
                                                        return 0.172690406
                                                    if state == 168:
                                                        return -0.143678039
                                                if state == 152:
                                                    return -0.304304898
                                            if state == 132:
                                                return 0.350381464
                                        if state == 100:
                                            return -0.0160259288
                                    if state == 78:
                                        return 0.364842832
                                if state == 56:
                                    return -0.147250652
                            if state == 40:
                                state = (
                                    57
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.843657494)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        79
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 8.48143768)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            101
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 3.02112865)
                                            else 102
                                        )
                                        if state == 101:
                                            state = (
                                                133
                                                if x["maggaia_med"] < 17.7910748
                                                else 134
                                            )
                                            if state == 133:
                                                return -0.331439912
                                            if state == 134:
                                                state = (
                                                    153
                                                    if x["col_det"] < -0.562947273
                                                    else 154
                                                )
                                                if state == 153:
                                                    return -0.235516042
                                                if state == 154:
                                                    state = (
                                                        169
                                                        if x["distpsnr1_med"]
                                                        < 5.89941406
                                                        else 170
                                                    )
                                                    if state == 169:
                                                        return -0.344584733
                                                    if state == 170:
                                                        state = (
                                                            183
                                                            if x["distnr_med"]
                                                            < 0.754777491
                                                            else 184
                                                        )
                                                        if state == 183:
                                                            return 0.088496238
                                                        if state == 184:
                                                            return 0.269196212
                                        if state == 102:
                                            return -0.370423168
                                    if state == 80:
                                        state = (
                                            103
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.98225689)
                                            else 104
                                        )
                                        if state == 103:
                                            state = (
                                                135
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 19.2002468)
                                                else 136
                                            )
                                            if state == 135:
                                                return 0.403344125
                                            if state == 136:
                                                return -0.290210545
                                        if state == 104:
                                            state = (
                                                137
                                                if x["maggaia_med"] < 17.4395409
                                                else 138
                                            )
                                            if state == 137:
                                                return 0.183807746
                                            if state == 138:
                                                return -0.178610623
                                if state == 58:
                                    return -0.32753852
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.4298496)
                            else 28
                        )
                        if state == 27:
                            state = (
                                41
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 3.13899136)
                                else 42
                            )
                            if state == 41:
                                state = 59 if x["sgscore1_med"] < 0.0390208513 else 60
                                if state == 59:
                                    return 0.192107841
                                if state == 60:
                                    state = (
                                        81 if x["distpsnr1_med"] < 0.692079663 else 82
                                    )
                                    if state == 81:
                                        state = (
                                            105
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.91653943)
                                            else 106
                                        )
                                        if state == 105:
                                            return 0.203371972
                                        if state == 106:
                                            return -0.324404359
                                    if state == 82:
                                        return -0.418171078
                            if state == 42:
                                state = 61 if x["sgscore1_med"] < 0.738208532 else 62
                                if state == 61:
                                    return 0.242156446
                                if state == 62:
                                    return -0.145850599
                        if state == 28:
                            state = (
                                43
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 7.63257885)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    63
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.854720473)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        83 if x["distpsnr1_med"] < 3.64256001 else 84
                                    )
                                    if state == 83:
                                        state = (
                                            107
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.9408679)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                139
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 17.1634712)
                                                else 140
                                            )
                                            if state == 139:
                                                return 0.325144917
                                            if state == 140:
                                                state = (
                                                    157
                                                    if np.isnan(x["col_det"])
                                                    or (x["col_det"] < 0.586990356)
                                                    else 158
                                                )
                                                if state == 157:
                                                    state = (
                                                        171
                                                        if x["distpsnr1_med"]
                                                        < 1.49424827
                                                        else 172
                                                    )
                                                    if state == 171:
                                                        state = (
                                                            185
                                                            if x["distnr_med"]
                                                            < 0.796085119
                                                            else 186
                                                        )
                                                        if state == 185:
                                                            return -0.195164084
                                                        if state == 186:
                                                            return 0.0210156832
                                                    if state == 172:
                                                        state = (
                                                            187
                                                            if x["distnr_med"]
                                                            < 1.68060458
                                                            else 188
                                                        )
                                                        if state == 187:
                                                            return -0.190356001
                                                        if state == 188:
                                                            return 0.267307192
                                                if state == 158:
                                                    return -0.144087017
                                        if state == 108:
                                            state = (
                                                141
                                                if x["maggaia_med"] < 18.0747528
                                                else 142
                                            )
                                            if state == 141:
                                                return -0.258805841
                                            if state == 142:
                                                state = (
                                                    159
                                                    if x["col_det"] < 1.32318211
                                                    else 160
                                                )
                                                if state == 159:
                                                    return -0.155406773
                                                if state == 160:
                                                    state = (
                                                        173
                                                        if x["distpsnr1_med"]
                                                        < 1.26598525
                                                        else 174
                                                    )
                                                    if state == 173:
                                                        state = (
                                                            189
                                                            if x["distnr_med"]
                                                            < 0.61712265
                                                            else 190
                                                        )
                                                        if state == 189:
                                                            return -0.193637282
                                                        if state == 190:
                                                            return 0.0535406768
                                                    if state == 174:
                                                        state = (
                                                            191
                                                            if x["distnr_med"]
                                                            < 1.88039935
                                                            else 192
                                                        )
                                                        if state == 191:
                                                            return 0.0307662021
                                                        if state == 192:
                                                            return 0.314230442
                                    if state == 84:
                                        state = (
                                            109
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.96769094)
                                            else 110
                                        )
                                        if state == 109:
                                            state = (
                                                143
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 16.6067467)
                                                else 144
                                            )
                                            if state == 143:
                                                state = (
                                                    161
                                                    if x["col_det"] < 1.3720026
                                                    else 162
                                                )
                                                if state == 161:
                                                    return -0.29469192
                                                if state == 162:
                                                    state = (
                                                        175
                                                        if x["distpsnr1_med"]
                                                        < 14.5652561
                                                        else 176
                                                    )
                                                    if state == 175:
                                                        return -0.19228971
                                                    if state == 176:
                                                        state = (
                                                            193
                                                            if x["distnr_med"]
                                                            < 1.37050676
                                                            else 194
                                                        )
                                                        if state == 193:
                                                            return -0.136763573
                                                        if state == 194:
                                                            return 0.211340398
                                            if state == 144:
                                                state = (
                                                    163
                                                    if x["col_det"] < 0.643917084
                                                    else 164
                                                )
                                                if state == 163:
                                                    return 0.352680326
                                                if state == 164:
                                                    state = (
                                                        177
                                                        if x["distpsnr1_med"]
                                                        < 4.93061018
                                                        else 178
                                                    )
                                                    if state == 177:
                                                        state = (
                                                            195
                                                            if x["distnr_med"]
                                                            < 3.90550947
                                                            else 196
                                                        )
                                                        if state == 195:
                                                            return -0.132729828
                                                        if state == 196:
                                                            return 0.235039219
                                                    if state == 178:
                                                        return -0.302381843
                                        if state == 110:
                                            state = (
                                                145
                                                if x["maggaia_med"] < 17.8998642
                                                else 146
                                            )
                                            if state == 145:
                                                return -0.128264666
                                            if state == 146:
                                                state = (
                                                    165
                                                    if x["col_det"] < 1.94480228
                                                    else 166
                                                )
                                                if state == 165:
                                                    state = (
                                                        179
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 6.3233881
                                                        )
                                                        else 180
                                                    )
                                                    if state == 179:
                                                        return -0.157433748
                                                    if state == 180:
                                                        return 0.223519146
                                                if state == 166:
                                                    state = (
                                                        181
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 6.70302534
                                                        )
                                                        else 182
                                                    )
                                                    if state == 181:
                                                        return 0.395800829
                                                    if state == 182:
                                                        state = (
                                                            197
                                                            if x["distnr_med"]
                                                            < 2.92643404
                                                            else 198
                                                        )
                                                        if state == 197:
                                                            return 0.209749281
                                                        if state == 198:
                                                            return -0.176887348
                                if state == 64:
                                    return -0.373384953
                            if state == 44:
                                state = (
                                    65
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.999166489)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        85 if x["distpsnr1_med"] < 14.9472198 else 86
                                    )
                                    if state == 85:
                                        return -0.449223638
                                    if state == 86:
                                        state = (
                                            111
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.87390614)
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                147
                                                if x["maggaia_med"] < 19.782486
                                                else 148
                                            )
                                            if state == 147:
                                                return -0.110829502
                                            if state == 148:
                                                return 0.33428362
                                        if state == 112:
                                            state = (
                                                149
                                                if x["maggaia_med"] < 15.6595058
                                                else 150
                                            )
                                            if state == 149:
                                                return 0.0798994377
                                            if state == 150:
                                                return -0.274499685
                                if state == 66:
                                    return 0.230077103
    elif num_booster == 5:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0105786994) else 2
            if state == 1:
                state = 3 if x["maggaia_med"] < 19.9310112 else 4
                if state == 3:
                    state = 7 if x["distpsnr1_med"] < 0.739422321 else 8
                    if state == 7:
                        state = 15 if x["distpsnr1_med"] < 0.593342483 else 16
                        if state == 15:
                            return -0.302688569
                        if state == 16:
                            return 0.278971225
                    if state == 8:
                        return -0.431815743
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 2.39442515)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["distpsnr1_med"] < 0.573653936 else 18
                        if state == 17:
                            return -0.158081889
                        if state == 18:
                            state = (
                                25
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.64857173)
                                else 26
                            )
                            if state == 25:
                                return -0.337649912
                            if state == 26:
                                return 0.298137426
                    if state == 10:
                        state = 19 if x["distpsnr1_med"] < 9.24009705 else 20
                        if state == 19:
                            state = (
                                27
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.427262098)
                                else 28
                            )
                            if state == 27:
                                return 0.238303661
                            if state == 28:
                                return -0.342467815
                        if state == 20:
                            return -0.348692596
            if state == 2:
                state = 5 if x["maggaia_med"] < 15.077879 else 6
                if state == 5:
                    state = 11 if x["distpsnr1_med"] < 10.1726599 else 12
                    if state == 11:
                        return -0.323596656
                    if state == 12:
                        state = 21 if x["distpsnr1_med"] < 10.5090542 else 22
                        if state == 21:
                            return 0.244737506
                        if state == 22:
                            state = (
                                29
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.639642715)
                                else 30
                            )
                            if state == 29:
                                return -0.283578485
                            if state == 30:
                                return 0.264992595
                if state == 6:
                    state = 13 if x["distpsnr1_med"] < 0.0847772956 else 14
                    if state == 13:
                        return -0.405101091
                    if state == 14:
                        state = 23 if x["distpsnr1_med"] < 0.0880597755 else 24
                        if state == 23:
                            return 0.607768953
                        if state == 24:
                            state = (
                                31
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.512499988)
                                else 32
                            )
                            if state == 31:
                                state = 33 if x["distpsnr1_med"] < 4.21035051 else 34
                                if state == 33:
                                    state = 37 if x["magnr_med"] < 21.3964996 else 38
                                    if state == 37:
                                        return -0.470181912
                                    if state == 38:
                                        state = (
                                            45 if x["maggaia_med"] < 16.9403152 else 46
                                        )
                                        if state == 45:
                                            return 0.13515538
                                        if state == 46:
                                            state = (
                                                57
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 1.05361116)
                                                else 58
                                            )
                                            if state == 57:
                                                state = (
                                                    71
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.00829268)
                                                    else 72
                                                )
                                                if state == 71:
                                                    return -0.254483312
                                                if state == 72:
                                                    return 0.1685711
                                            if state == 58:
                                                return -0.267606229
                                if state == 34:
                                    state = 39 if x["magnr_med"] < 20.2122498 else 40
                                    if state == 39:
                                        state = (
                                            47
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.8577118)
                                            else 48
                                        )
                                        if state == 47:
                                            state = (
                                                59
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.0266261511)
                                                else 60
                                            )
                                            if state == 59:
                                                return 0.326895475
                                            if state == 60:
                                                state = (
                                                    73
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.0026679)
                                                    else 74
                                                )
                                                if state == 73:
                                                    state = (
                                                        87
                                                        if x["magnr_med"] < 19.8307495
                                                        else 88
                                                    )
                                                    if state == 87:
                                                        state = (
                                                            105
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 3.00268507)
                                                            else 106
                                                        )
                                                        if state == 105:
                                                            return -0.405468255
                                                        if state == 106:
                                                            return 0.0648396611
                                                    if state == 88:
                                                        state = (
                                                            107
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 0.472789347)
                                                            else 108
                                                        )
                                                        if state == 107:
                                                            return 0.197523102
                                                        if state == 108:
                                                            return -0.150954679
                                                if state == 74:
                                                    state = (
                                                        89
                                                        if x["magnr_med"] < 18.14575
                                                        else 90
                                                    )
                                                    if state == 89:
                                                        return -0.222822204
                                                    if state == 90:
                                                        return 0.398768604
                                        if state == 48:
                                            return 0.323851228
                                    if state == 40:
                                        state = (
                                            49
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.1942406)
                                            else 50
                                        )
                                        if state == 49:
                                            state = (
                                                61
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.0609085485)
                                                else 62
                                            )
                                            if state == 61:
                                                state = (
                                                    75
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.9031713)
                                                    else 76
                                                )
                                                if state == 75:
                                                    state = (
                                                        91
                                                        if x["magnr_med"] < 22.5680008
                                                        else 92
                                                    )
                                                    if state == 91:
                                                        return -0.270451963
                                                    if state == 92:
                                                        return 0.164569914
                                                if state == 76:
                                                    state = (
                                                        93
                                                        if x["magnr_med"] < 22.630249
                                                        else 94
                                                    )
                                                    if state == 93:
                                                        state = (
                                                            109
                                                            if np.isnan(x["t_lc"])
                                                            or (
                                                                x["t_lc"] < 0.0449769013
                                                            )
                                                            else 110
                                                        )
                                                        if state == 109:
                                                            return 0.00927013904
                                                        if state == 110:
                                                            return 0.277634919
                                                    if state == 94:
                                                        state = (
                                                            111
                                                            if np.isnan(x["t_lc"])
                                                            or (
                                                                x["t_lc"] < 0.0475983471
                                                            )
                                                            else 112
                                                        )
                                                        if state == 111:
                                                            return 0.0596530735
                                                        if state == 112:
                                                            return -0.147492096
                                            if state == 62:
                                                state = (
                                                    77
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.870057821)
                                                    else 78
                                                )
                                                if state == 77:
                                                    return -0.403811455
                                                if state == 78:
                                                    state = (
                                                        95
                                                        if x["magnr_med"] < 21.654501
                                                        else 96
                                                    )
                                                    if state == 95:
                                                        state = (
                                                            113
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 0.529340267)
                                                            else 114
                                                        )
                                                        if state == 113:
                                                            return -0.248978719
                                                        if state == 114:
                                                            return 0.267362922
                                                    if state == 96:
                                                        return -0.46405527
                                        if state == 50:
                                            return -0.391745746
                            if state == 32:
                                state = 35 if x["distpsnr1_med"] < 0.492864847 else 36
                                if state == 35:
                                    state = 41 if x["magnr_med"] < 20.5734997 else 42
                                    if state == 41:
                                        state = (
                                            51
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.1317863)
                                            else 52
                                        )
                                        if state == 51:
                                            state = (
                                                63
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 2.98267937)
                                                else 64
                                            )
                                            if state == 63:
                                                return -0.37976566
                                            if state == 64:
                                                state = (
                                                    79
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0266667008)
                                                    else 80
                                                )
                                                if state == 79:
                                                    return 0.39759323
                                                if state == 80:
                                                    return -0.323286414
                                        if state == 52:
                                            state = (
                                                65
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.0365104005)
                                                else 66
                                            )
                                            if state == 65:
                                                return -0.294412225
                                            if state == 66:
                                                state = (
                                                    81
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.97891784)
                                                    else 82
                                                )
                                                if state == 81:
                                                    state = (
                                                        97
                                                        if x["magnr_med"] < 17.3139992
                                                        else 98
                                                    )
                                                    if state == 97:
                                                        return -0.135693565
                                                    if state == 98:
                                                        return 0.267786384
                                                if state == 82:
                                                    state = (
                                                        99
                                                        if x["magnr_med"] < 19.0740013
                                                        else 100
                                                    )
                                                    if state == 99:
                                                        return -0.26589641
                                                    if state == 100:
                                                        state = (
                                                            115
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 2.94087958)
                                                            else 116
                                                        )
                                                        if state == 115:
                                                            return 0.1943506
                                                        if state == 116:
                                                            return -0.11559511
                                    if state == 42:
                                        return -0.440807253
                                if state == 36:
                                    state = 43 if x["magnr_med"] < 16.5545006 else 44
                                    if state == 43:
                                        state = (
                                            53
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 15.6086617)
                                            else 54
                                        )
                                        if state == 53:
                                            state = (
                                                67
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.990480304)
                                                else 68
                                            )
                                            if state == 67:
                                                return -0.258751392
                                            if state == 68:
                                                state = (
                                                    83
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.01285291)
                                                    else 84
                                                )
                                                if state == 83:
                                                    state = (
                                                        101
                                                        if x["magnr_med"] < 16.0802498
                                                        else 102
                                                    )
                                                    if state == 101:
                                                        return -0.224419966
                                                    if state == 102:
                                                        return 0.19685173
                                                if state == 84:
                                                    return 0.302986503
                                        if state == 54:
                                            return -0.387585431
                                    if state == 44:
                                        state = (
                                            55
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 20.9524651)
                                            else 56
                                        )
                                        if state == 55:
                                            state = (
                                                69
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 3.03744221)
                                                else 70
                                            )
                                            if state == 69:
                                                state = (
                                                    85
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.02426505)
                                                    else 86
                                                )
                                                if state == 85:
                                                    state = (
                                                        103
                                                        if x["magnr_med"] < 17.3614998
                                                        else 104
                                                    )
                                                    if state == 103:
                                                        state = (
                                                            117
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 1.49795711)
                                                            else 118
                                                        )
                                                        if state == 117:
                                                            return -0.244644314
                                                        if state == 118:
                                                            return -0.0462127328
                                                    if state == 104:
                                                        state = (
                                                            119
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 3.02725124)
                                                            else 120
                                                        )
                                                        if state == 119:
                                                            return 0.272705793
                                                        if state == 120:
                                                            return -0.358521998
                                                if state == 86:
                                                    return 0.384853691
                                            if state == 70:
                                                return -0.315166205
                                        if state == 56:
                                            return -0.151143894
    elif num_booster == 6:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 0.0862373039 else 2
            if state == 1:
                return -0.391920179
            if state == 2:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.635714352) else 4
                if state == 3:
                    state = 5 if x["col_det"] < 0.286049843 else 6
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.605250001)
                            else 10
                        )
                        if state == 9:
                            return -0.352783173
                        if state == 10:
                            state = (
                                17
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.966321468)
                                else 18
                            )
                            if state == 17:
                                state = 29 if x["col_det"] < -0.470607758 else 30
                                if state == 29:
                                    return -0.27676782
                                if state == 30:
                                    state = (
                                        45 if x["distpsnr1_med"] < 1.04639935 else 46
                                    )
                                    if state == 45:
                                        return -0.279807448
                                    if state == 46:
                                        state = (
                                            67
                                            if np.isnan(x["distpsnr1_med"])
                                            or (x["distpsnr1_med"] < 1.79006326)
                                            else 68
                                        )
                                        if state == 67:
                                            state = (
                                                87
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.0346933007)
                                                else 88
                                            )
                                            if state == 87:
                                                return -0.517807424
                                            if state == 88:
                                                state = (
                                                    109
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.983749986)
                                                    else 110
                                                )
                                                if state == 109:
                                                    state = (
                                                        125
                                                        if x["distnr_med"] < 6.40294266
                                                        else 126
                                                    )
                                                    if state == 125:
                                                        state = (
                                                            143
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.4259987
                                                            )
                                                            else 144
                                                        )
                                                        if state == 143:
                                                            return 0.320546478
                                                        if state == 144:
                                                            return -0.161966711
                                                    if state == 126:
                                                        return -0.107009232
                                                if state == 110:
                                                    return -0.00486166263
                                        if state == 68:
                                            state = (
                                                89
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.0333738476)
                                                else 90
                                            )
                                            if state == 89:
                                                return 0.431069136
                                            if state == 90:
                                                state = (
                                                    111
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982749999)
                                                    else 112
                                                )
                                                if state == 111:
                                                    state = (
                                                        127
                                                        if x["distnr_med"] < 8.88732719
                                                        else 128
                                                    )
                                                    if state == 127:
                                                        state = (
                                                            145
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.4417992
                                                            )
                                                            else 146
                                                        )
                                                        if state == 145:
                                                            return 0.281309664
                                                        if state == 146:
                                                            return -0.339604169
                                                    if state == 128:
                                                        return -0.192067489
                                                if state == 112:
                                                    return -0.217208043
                            if state == 18:
                                return -0.302762091
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.954750001)
                            else 12
                        )
                        if state == 11:
                            state = 19 if x["sgscore1_med"] < 0.0226458013 else 20
                            if state == 19:
                                state = 31 if x["col_det"] < 2.05903339 else 32
                                if state == 31:
                                    return -0.229152039
                                if state == 32:
                                    state = (
                                        47 if x["distpsnr1_med"] < 9.29355145 else 48
                                    )
                                    if state == 47:
                                        state = (
                                            69
                                            if x["distpsnr1_med"] < 0.161489516
                                            else 70
                                        )
                                        if state == 69:
                                            return 0.259087831
                                        if state == 70:
                                            state = (
                                                91
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.00138889998)
                                                else 92
                                            )
                                            if state == 91:
                                                return -0.27505517
                                            if state == 92:
                                                state = (
                                                    113
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.725749969)
                                                    else 114
                                                )
                                                if state == 113:
                                                    return -0.265912831
                                                if state == 114:
                                                    state = (
                                                        129
                                                        if x["distnr_med"] < 0.933472693
                                                        else 130
                                                    )
                                                    if state == 129:
                                                        return -0.155795142
                                                    if state == 130:
                                                        state = (
                                                            147
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.6207504
                                                            )
                                                            else 148
                                                        )
                                                        if state == 147:
                                                            return 0.309304833
                                                        if state == 148:
                                                            return -0.181916058
                                    if state == 48:
                                        return -0.304469168
                            if state == 20:
                                state = 33 if x["col_det"] < 0.398426056 else 34
                                if state == 33:
                                    state = (
                                        49
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 5.4701519)
                                        else 50
                                    )
                                    if state == 49:
                                        return -0.281177014
                                    if state == 50:
                                        state = (
                                            71
                                            if x["distpsnr1_med"] < 9.06550026
                                            else 72
                                        )
                                        if state == 71:
                                            return 0.255754709
                                        if state == 72:
                                            return -0.134096846
                                if state == 34:
                                    state = (
                                        51 if x["distpsnr1_med"] < 14.0661316 else 52
                                    )
                                    if state == 51:
                                        return -0.353906602
                                    if state == 52:
                                        state = (
                                            73
                                            if x["distpsnr1_med"] < 14.0994663
                                            else 74
                                        )
                                        if state == 73:
                                            return 0.405182689
                                        if state == 74:
                                            state = (
                                                93
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.0219270494)
                                                else 94
                                            )
                                            if state == 93:
                                                return -0.368829668
                                            if state == 94:
                                                state = (
                                                    115
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.760749996)
                                                    else 116
                                                )
                                                if state == 115:
                                                    state = (
                                                        131
                                                        if x["distnr_med"] < 1.96997738
                                                        else 132
                                                    )
                                                    if state == 131:
                                                        state = (
                                                            149
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.8016014
                                                            )
                                                            else 150
                                                        )
                                                        if state == 149:
                                                            return -0.192832798
                                                        if state == 150:
                                                            return 0.0154514657
                                                    if state == 132:
                                                        return -0.353387266
                                                if state == 116:
                                                    state = (
                                                        133
                                                        if x["distnr_med"] < 1.68981504
                                                        else 134
                                                    )
                                                    if state == 133:
                                                        state = (
                                                            151
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.0382996
                                                            )
                                                            else 152
                                                        )
                                                        if state == 151:
                                                            return -0.273952186
                                                        if state == 152:
                                                            return 0.311370343
                                                    if state == 134:
                                                        return -0.354555488
                        if state == 12:
                            state = (
                                21
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0309791509)
                                else 22
                            )
                            if state == 21:
                                state = 35 if x["col_det"] < 2.40139866 else 36
                                if state == 35:
                                    return -0.200342059
                                if state == 36:
                                    state = (
                                        53 if x["distpsnr1_med"] < 50.1279526 else 54
                                    )
                                    if state == 53:
                                        return -0.323724627
                                    if state == 54:
                                        return 0.138903752
                            if state == 22:
                                state = (
                                    37
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.586455345)
                                    else 38
                                )
                                if state == 37:
                                    state = (
                                        55 if x["distpsnr1_med"] < 1.26502085 else 56
                                    )
                                    if state == 55:
                                        state = (
                                            75
                                            if x["distpsnr1_med"] < 0.269577146
                                            else 76
                                        )
                                        if state == 75:
                                            return 0.288623095
                                        if state == 76:
                                            state = (
                                                95
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.101765007)
                                                else 96
                                            )
                                            if state == 95:
                                                state = (
                                                    117
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.971249998)
                                                    else 118
                                                )
                                                if state == 117:
                                                    return 0.131548822
                                                if state == 118:
                                                    state = (
                                                        135
                                                        if x["distnr_med"] < 1.06235504
                                                        else 136
                                                    )
                                                    if state == 135:
                                                        return -0.120322034
                                                    if state == 136:
                                                        return 0.0988391265
                                            if state == 96:
                                                return -0.317294747
                                    if state == 56:
                                        state = (
                                            77
                                            if x["distpsnr1_med"] < 8.82079506
                                            else 78
                                        )
                                        if state == 77:
                                            state = (
                                                97
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.107500046)
                                                else 98
                                            )
                                            if state == 97:
                                                return -0.280637175
                                            if state == 98:
                                                state = (
                                                    119
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.992250025)
                                                    else 120
                                                )
                                                if state == 119:
                                                    state = (
                                                        137
                                                        if x["distnr_med"] < 1.44895756
                                                        else 138
                                                    )
                                                    if state == 137:
                                                        state = (
                                                            153
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.3342113
                                                            )
                                                            else 154
                                                        )
                                                        if state == 153:
                                                            return -0.132443309
                                                        if state == 154:
                                                            return 0.276302278
                                                    if state == 138:
                                                        state = (
                                                            155
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 17.9970016
                                                            )
                                                            else 156
                                                        )
                                                        if state == 155:
                                                            return 0.0441935174
                                                        if state == 156:
                                                            return 0.421499789
                                                if state == 120:
                                                    return -0.101599298
                                        if state == 78:
                                            state = (
                                                99
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 1.48827541)
                                                else 100
                                            )
                                            if state == 99:
                                                return -0.229167566
                                            if state == 100:
                                                return 0.250344783
                                if state == 38:
                                    return -0.232357889
                if state == 4:
                    state = 7 if x["col_det"] < 0.657653809 else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.620500028)
                            else 14
                        )
                        if state == 13:
                            return -0.30654186
                        if state == 14:
                            state = 23 if x["sgscore1_med"] < 0.0175625011 else 24
                            if state == 23:
                                state = 39 if x["col_det"] < 0.195489883 else 40
                                if state == 39:
                                    state = (
                                        57 if x["distpsnr1_med"] < 1.17838609 else 58
                                    )
                                    if state == 57:
                                        return 0.261474848
                                    if state == 58:
                                        state = (
                                            79
                                            if x["distpsnr1_med"] < 7.73736095
                                            else 80
                                        )
                                        if state == 79:
                                            return -0.490458369
                                        if state == 80:
                                            return -0.042233713
                                if state == 40:
                                    return -0.471111149
                            if state == 24:
                                state = 41 if x["col_det"] < -0.366446495 else 42
                                if state == 41:
                                    state = (
                                        59 if x["distpsnr1_med"] < 1.31813514 else 60
                                    )
                                    if state == 59:
                                        return 0.258421421
                                    if state == 60:
                                        return -0.402766198
                                if state == 42:
                                    state = (
                                        61 if x["distpsnr1_med"] < 0.513632059 else 62
                                    )
                                    if state == 61:
                                        state = (
                                            81
                                            if x["distpsnr1_med"] < 0.107469335
                                            else 82
                                        )
                                        if state == 81:
                                            state = (
                                                101
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.0550694503)
                                                else 102
                                            )
                                            if state == 101:
                                                return 0.461025864
                                            if state == 102:
                                                return -0.17365934
                                        if state == 82:
                                            return -0.368688643
                                    if state == 62:
                                        return 0.322237104
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.739249945)
                            else 16
                        )
                        if state == 15:
                            state = 25 if x["sgscore1_med"] < 2.00000095 else 26
                            if state == 25:
                                return -0.421154618
                            if state == 26:
                                return -0.121094629
                        if state == 16:
                            state = 27 if x["sgscore1_med"] < 0.507874966 else 28
                            if state == 27:
                                state = 43 if x["col_det"] < 1.14725685 else 44
                                if state == 43:
                                    state = (
                                        63 if x["distpsnr1_med"] < 3.98295689 else 64
                                    )
                                    if state == 63:
                                        return -0.112387851
                                    if state == 64:
                                        return 0.115345225
                                if state == 44:
                                    state = (
                                        65 if x["distpsnr1_med"] < 0.235143214 else 66
                                    )
                                    if state == 65:
                                        state = (
                                            83
                                            if x["distpsnr1_med"] < 0.133896172
                                            else 84
                                        )
                                        if state == 83:
                                            state = (
                                                103
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 2.96769667)
                                                else 104
                                            )
                                            if state == 103:
                                                return 0.150596961
                                            if state == 104:
                                                return -0.143707931
                                        if state == 84:
                                            return -0.275676489
                                    if state == 66:
                                        state = (
                                            85
                                            if x["distpsnr1_med"] < 3.89186144
                                            else 86
                                        )
                                        if state == 85:
                                            state = (
                                                105
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 2.44101858)
                                                else 106
                                            )
                                            if state == 105:
                                                state = (
                                                    121
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.97874999)
                                                    else 122
                                                )
                                                if state == 121:
                                                    state = (
                                                        139
                                                        if x["distnr_med"] < 2.74023008
                                                        else 140
                                                    )
                                                    if state == 139:
                                                        return -0.33064279
                                                    if state == 140:
                                                        state = (
                                                            157
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.9067993
                                                            )
                                                            else 158
                                                        )
                                                        if state == 157:
                                                            return 0.119958296
                                                        if state == 158:
                                                            return -0.182650506
                                                if state == 122:
                                                    return 0.285452276
                                            if state == 106:
                                                state = (
                                                    123
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.978500009)
                                                    else 124
                                                )
                                                if state == 123:
                                                    state = (
                                                        141
                                                        if x["distnr_med"] < 0.558533192
                                                        else 142
                                                    )
                                                    if state == 141:
                                                        state = (
                                                            159
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.8711739
                                                            )
                                                            else 160
                                                        )
                                                        if state == 159:
                                                            return -0.0254041087
                                                        if state == 160:
                                                            return -0.350124061
                                                    if state == 142:
                                                        state = (
                                                            161
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.9071999
                                                            )
                                                            else 162
                                                        )
                                                        if state == 161:
                                                            return -0.191861778
                                                        if state == 162:
                                                            return 0.269605041
                                                if state == 124:
                                                    return 0.399430573
                                        if state == 86:
                                            state = (
                                                107
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.929872632)
                                                else 108
                                            )
                                            if state == 107:
                                                return -0.224589601
                                            if state == 108:
                                                return 0.358931571
                            if state == 28:
                                return -0.143849984
    elif num_booster == 7:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 0.0862373039 else 2
            if state == 1:
                return -0.360514343
            if state == 2:
                state = 3 if x["distpsnr1_med"] < 0.262022376 else 4
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1665497)
                        else 6
                    )
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.264091998)
                            else 10
                        )
                        if state == 9:
                            state = 17 if x["sgscore1_med"] < 0.168919504 else 18
                            if state == 17:
                                state = 27 if x["distpsnr1_med"] < 0.214745671 else 28
                                if state == 27:
                                    state = (
                                        39 if x["distpsnr1_med"] < 0.0942226201 else 40
                                    )
                                    if state == 39:
                                        return 0.38567242
                                    if state == 40:
                                        state = (
                                            49 if x["magnr_med"] < 18.7625008 else 50
                                        )
                                        if state == 49:
                                            state = (
                                                63
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0450694486)
                                                else 64
                                            )
                                            if state == 63:
                                                return 0.11357113
                                            if state == 64:
                                                return -0.196307391
                                        if state == 50:
                                            return 0.246992052
                                if state == 28:
                                    return -0.142335385
                            if state == 18:
                                return 0.520125389
                        if state == 10:
                            state = 19 if x["sgscore1_med"] < 0.508413494 else 20
                            if state == 19:
                                state = 29 if x["distpsnr1_med"] < 0.244786352 else 30
                                if state == 29:
                                    return -0.330783546
                                if state == 30:
                                    return 0.319171935
                            if state == 20:
                                return -0.227665454
                    if state == 6:
                        state = 11 if x["sgscore1_med"] < 0.0190417003 else 12
                        if state == 11:
                            state = 21 if x["sgscore1_med"] < 0.016104199 else 22
                            if state == 21:
                                state = 31 if x["distpsnr1_med"] < 0.0976075828 else 32
                                if state == 31:
                                    return 0.107911855
                                if state == 32:
                                    return -0.222198293
                            if state == 22:
                                return 0.221741617
                        if state == 12:
                            return -0.288175642
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.1368999)
                        else 8
                    )
                    if state == 7:
                        state = 13 if x["sgscore1_med"] < 0.243693501 else 14
                        if state == 13:
                            state = 23 if x["sgscore1_med"] < 0.0270000007 else 24
                            if state == 23:
                                return -0.392989427
                            if state == 24:
                                state = 33 if x["distpsnr1_med"] < 2.72817302 else 34
                                if state == 33:
                                    return -0.19558613
                                if state == 34:
                                    return 0.222806484
                        if state == 14:
                            return -0.392004222
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.874173045)
                            else 16
                        )
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0141874999)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    35
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 1.22095239)
                                    else 36
                                )
                                if state == 35:
                                    state = (
                                        41
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.486712039)
                                        else 42
                                    )
                                    if state == 41:
                                        state = (
                                            51 if x["magnr_med"] < 20.1642494 else 52
                                        )
                                        if state == 51:
                                            state = (
                                                65
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.622806787)
                                                else 66
                                            )
                                            if state == 65:
                                                state = (
                                                    81
                                                    if x["magnr_med"] < 18.2815018
                                                    else 82
                                                )
                                                if state == 81:
                                                    return 0.0396150164
                                                if state == 82:
                                                    state = (
                                                        105
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 0.0607060492
                                                        )
                                                        else 106
                                                    )
                                                    if state == 105:
                                                        state = (
                                                            123
                                                            if x["magnr_med"]
                                                            < 19.043251
                                                            else 124
                                                        )
                                                        if state == 123:
                                                            return -0.126453862
                                                        if state == 124:
                                                            return 0.265259594
                                                    if state == 106:
                                                        return 0.346167952
                                            if state == 66:
                                                state = (
                                                    83
                                                    if x["magnr_med"] < 17.9570007
                                                    else 84
                                                )
                                                if state == 83:
                                                    return -0.22144717
                                                if state == 84:
                                                    state = (
                                                        107
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.98845482
                                                        )
                                                        else 108
                                                    )
                                                    if state == 107:
                                                        state = (
                                                            125
                                                            if x["magnr_med"]
                                                            < 19.2552509
                                                            else 126
                                                        )
                                                        if state == 125:
                                                            return -0.097831592
                                                        if state == 126:
                                                            return 0.148037612
                                                    if state == 108:
                                                        return 0.268965095
                                        if state == 52:
                                            state = (
                                                67
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.86568284)
                                                else 68
                                            )
                                            if state == 67:
                                                return -0.378543556
                                            if state == 68:
                                                state = (
                                                    85
                                                    if x["magnr_med"] < 22.2819996
                                                    else 86
                                                )
                                                if state == 85:
                                                    state = (
                                                        109
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.97884846
                                                        )
                                                        else 110
                                                    )
                                                    if state == 109:
                                                        state = (
                                                            129
                                                            if x["magnr_med"]
                                                            < 21.9362507
                                                            else 130
                                                        )
                                                        if state == 129:
                                                            return -0.043362122
                                                        if state == 130:
                                                            return 0.238586947
                                                    if state == 110:
                                                        return -0.306122065
                                                if state == 86:
                                                    return -0.390035242
                                    if state == 42:
                                        state = 53 if x["magnr_med"] < 21.970499 else 54
                                        if state == 53:
                                            state = (
                                                69
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.545966506)
                                                else 70
                                            )
                                            if state == 69:
                                                state = (
                                                    87
                                                    if x["magnr_med"] < 18.65625
                                                    else 88
                                                )
                                                if state == 87:
                                                    return 0.212179288
                                                if state == 88:
                                                    return -0.292824715
                                            if state == 70:
                                                state = (
                                                    89
                                                    if x["magnr_med"] < 18.4347496
                                                    else 90
                                                )
                                                if state == 89:
                                                    state = (
                                                        111
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 1.99067712
                                                        )
                                                        else 112
                                                    )
                                                    if state == 111:
                                                        return 0.146412745
                                                    if state == 112:
                                                        return -0.0737297907
                                                if state == 90:
                                                    return 0.321946561
                                        if state == 54:
                                            return -0.156410977
                                if state == 36:
                                    state = (
                                        43 if x["distpsnr1_med"] < 1.39764833 else 44
                                    )
                                    if state == 43:
                                        return -0.453205228
                                    if state == 44:
                                        state = (
                                            55 if x["magnr_med"] < 21.2242508 else 56
                                        )
                                        if state == 55:
                                            state = (
                                                71
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.9886806)
                                                else 72
                                            )
                                            if state == 71:
                                                state = (
                                                    91
                                                    if x["magnr_med"] < 19.4899998
                                                    else 92
                                                )
                                                if state == 91:
                                                    return 0.20569405
                                                if state == 92:
                                                    state = (
                                                        113
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"] < 2.9786284
                                                        )
                                                        else 114
                                                    )
                                                    if state == 113:
                                                        state = (
                                                            131
                                                            if x["magnr_med"]
                                                            < 20.605751
                                                            else 132
                                                        )
                                                        if state == 131:
                                                            return -0.119458094
                                                        if state == 132:
                                                            return 0.0982906371
                                                    if state == 114:
                                                        return 0.176074058
                                            if state == 72:
                                                return -0.219329417
                                        if state == 56:
                                            state = (
                                                73
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.99934602)
                                                else 74
                                            )
                                            if state == 73:
                                                state = (
                                                    95
                                                    if x["magnr_med"] < 22.8260002
                                                    else 96
                                                )
                                                if state == 95:
                                                    return -0.384720176
                                                if state == 96:
                                                    state = (
                                                        115
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 1.01372695
                                                        )
                                                        else 116
                                                    )
                                                    if state == 115:
                                                        state = (
                                                            133
                                                            if x["magnr_med"]
                                                            < 22.8304996
                                                            else 134
                                                        )
                                                        if state == 133:
                                                            return 0.267058313
                                                        if state == 134:
                                                            return -0.192694515
                                                    if state == 116:
                                                        return -0.240105778
                                            if state == 74:
                                                state = (
                                                    97
                                                    if x["magnr_med"] < 22.1417503
                                                    else 98
                                                )
                                                if state == 97:
                                                    return -0.223493576
                                                if state == 98:
                                                    return 0.205355555
                            if state == 26:
                                state = 37 if x["distpsnr1_med"] < 0.511591196 else 38
                                if state == 37:
                                    state = (
                                        45 if x["distpsnr1_med"] < 0.374550372 else 46
                                    )
                                    if state == 45:
                                        return -0.293281734
                                    if state == 46:
                                        state = 57 if x["magnr_med"] < 17.762001 else 58
                                        if state == 57:
                                            return -0.263895899
                                        if state == 58:
                                            state = (
                                                75
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0436805487)
                                                else 76
                                            )
                                            if state == 75:
                                                return 0.210398123
                                            if state == 76:
                                                state = (
                                                    99
                                                    if x["magnr_med"] < 19.0030003
                                                    else 100
                                                )
                                                if state == 99:
                                                    return -0.192089334
                                                if state == 100:
                                                    state = (
                                                        117
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 3.06954861
                                                        )
                                                        else 118
                                                    )
                                                    if state == 117:
                                                        return -0.0469725654
                                                    if state == 118:
                                                        return 0.137214497
                                if state == 38:
                                    state = (
                                        47 if x["distpsnr1_med"] < 23.1877861 else 48
                                    )
                                    if state == 47:
                                        state = (
                                            59 if x["magnr_med"] < 16.5540009 else 60
                                        )
                                        if state == 59:
                                            state = (
                                                77
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 3.01087952)
                                                else 78
                                            )
                                            if state == 77:
                                                return -0.338190526
                                            if state == 78:
                                                state = (
                                                    101
                                                    if x["magnr_med"] < 15.835
                                                    else 102
                                                )
                                                if state == 101:
                                                    return 0.219817266
                                                if state == 102:
                                                    return -0.163784876
                                        if state == 60:
                                            state = (
                                                79
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 3.02508688)
                                                else 80
                                            )
                                            if state == 79:
                                                state = (
                                                    103
                                                    if x["magnr_med"] < 20.8082504
                                                    else 104
                                                )
                                                if state == 103:
                                                    state = (
                                                        119
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 3.00483799
                                                        )
                                                        else 120
                                                    )
                                                    if state == 119:
                                                        state = (
                                                            137
                                                            if x["magnr_med"]
                                                            < 17.019249
                                                            else 138
                                                        )
                                                        if state == 137:
                                                            return -0.18534337
                                                        if state == 138:
                                                            return 0.24545604
                                                    if state == 120:
                                                        state = (
                                                            139
                                                            if x["magnr_med"]
                                                            < 19.2905006
                                                            else 140
                                                        )
                                                        if state == 139:
                                                            return 0.0226911288
                                                        if state == 140:
                                                            return -0.440095186
                                                if state == 104:
                                                    state = (
                                                        121
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 0.990983844
                                                        )
                                                        else 122
                                                    )
                                                    if state == 121:
                                                        state = (
                                                            141
                                                            if x["magnr_med"]
                                                            < 22.8730011
                                                            else 142
                                                        )
                                                        if state == 141:
                                                            return -0.290517002
                                                        if state == 142:
                                                            return -0.0294766948
                                                    if state == 122:
                                                        state = (
                                                            143
                                                            if x["magnr_med"]
                                                            < 22.5834999
                                                            else 144
                                                        )
                                                        if state == 143:
                                                            return -0.082209751
                                                        if state == 144:
                                                            return 0.144075438
                                            if state == 80:
                                                return 0.323155582
                                    if state == 48:
                                        state = (
                                            61 if x["magnr_med"] < 22.2735004 else 62
                                        )
                                        if state == 61:
                                            return 0.747397304
                                        if state == 62:
                                            return -0.16738826
                        if state == 16:
                            return -0.330967128
    elif num_booster == 8:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 13.7891951 else 2
            if state == 1:
                state = 3 if x["col_det"] < 0.162837029 else 4
                if state == 3:
                    state = 7 if x["distpsnr1_med"] < 9.42046261 else 8
                    if state == 7:
                        return -0.143971622
                    if state == 8:
                        return 0.16255109
                if state == 4:
                    return -0.393435895
            if state == 2:
                state = 5 if x["col_det"] < 0.427095413 else 6
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 0.0862373039)
                        else 10
                    )
                    if state == 9:
                        state = 13 if x["maggaia_med"] < 42.018074 else 14
                        if state == 13:
                            return -0.290444613
                        if state == 14:
                            state = (
                                21
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.908749998)
                                else 22
                            )
                            if state == 21:
                                return -0.162606731
                            if state == 22:
                                return 0.0817219466
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 19.4253502)
                            else 16
                        )
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.617750049)
                                else 24
                            )
                            if state == 23:
                                return -0.222293034
                            if state == 24:
                                state = 33 if x["neargaia_med"] < 0.260023832 else 34
                                if state == 33:
                                    return 0.412651539
                                if state == 34:
                                    state = (
                                        47
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.504166603)
                                        else 48
                                    )
                                    if state == 47:
                                        state = (
                                            65 if x["neargaia_med"] < 23.1565666 else 66
                                        )
                                        if state == 65:
                                            state = (
                                                85
                                                if x["col_det"] < -0.321071625
                                                else 86
                                            )
                                            if state == 85:
                                                return 0.0919198692
                                            if state == 86:
                                                return -0.287837476
                                        if state == 66:
                                            state = (
                                                87
                                                if x["col_det"] < -0.0512733459
                                                else 88
                                            )
                                            if state == 87:
                                                state = (
                                                    101
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.92018509)
                                                    else 102
                                                )
                                                if state == 101:
                                                    return 0.176222578
                                                if state == 102:
                                                    return -0.178610504
                                            if state == 88:
                                                return 0.27586934
                                    if state == 48:
                                        state = (
                                            67 if x["neargaia_med"] < 8.68958664 else 68
                                        )
                                        if state == 67:
                                            state = (
                                                89
                                                if x["col_det"] < -0.00802612305
                                                else 90
                                            )
                                            if state == 89:
                                                state = (
                                                    105
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.93208933)
                                                    else 106
                                                )
                                                if state == 105:
                                                    state = (
                                                        119
                                                        if x["col_det"] < -0.0868091583
                                                        else 120
                                                    )
                                                    if state == 119:
                                                        return 0.311695933
                                                    if state == 120:
                                                        return 0.0330838822
                                                if state == 106:
                                                    state = (
                                                        121
                                                        if x["col_det"] < -0.107714653
                                                        else 122
                                                    )
                                                    if state == 121:
                                                        state = (
                                                            133
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 0.103854254)
                                                            else 134
                                                        )
                                                        if state == 133:
                                                            return -0.293888301
                                                        if state == 134:
                                                            return 0.144273221
                                                    if state == 122:
                                                        return 0.224642366
                                            if state == 90:
                                                state = (
                                                    107
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.88759851)
                                                    else 108
                                                )
                                                if state == 107:
                                                    return 0.103051662
                                                if state == 108:
                                                    return -0.298566729
                                        if state == 68:
                                            state = (
                                                91 if x["col_det"] < 0.238675117 else 92
                                            )
                                            if state == 91:
                                                state = (
                                                    109
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.02963543)
                                                    else 110
                                                )
                                                if state == 109:
                                                    state = (
                                                        123
                                                        if x["col_det"] < -0.375477791
                                                        else 124
                                                    )
                                                    if state == 123:
                                                        return 0.0729913637
                                                    if state == 124:
                                                        return 0.352170974
                                                if state == 110:
                                                    return 0.000384660205
                                            if state == 92:
                                                state = (
                                                    111
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.90708923)
                                                    else 112
                                                )
                                                if state == 111:
                                                    return 0.351238161
                                                if state == 112:
                                                    state = (
                                                        125
                                                        if x["col_det"] < 0.376420975
                                                        else 126
                                                    )
                                                    if state == 125:
                                                        state = (
                                                            135
                                                            if np.isnan(x["t_lc"])
                                                            or (
                                                                x["t_lc"] < 0.0405150503
                                                            )
                                                            else 136
                                                        )
                                                        if state == 135:
                                                            return -0.398740143
                                                        if state == 136:
                                                            return 0.093623288
                                                    if state == 126:
                                                        return 0.115686789
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.97724998)
                                else 26
                            )
                            if state == 25:
                                state = 35 if x["neargaia_med"] < 10.2711601 else 36
                                if state == 35:
                                    state = (
                                        49
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.727500021)
                                        else 50
                                    )
                                    if state == 49:
                                        state = (
                                            69 if x["neargaia_med"] < 1.52299547 else 70
                                        )
                                        if state == 69:
                                            return -0.0353001431
                                        if state == 70:
                                            return -0.428333938
                                    if state == 50:
                                        return 0.0396302976
                                if state == 36:
                                    state = (
                                        51
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.784523726)
                                        else 52
                                    )
                                    if state == 51:
                                        state = (
                                            71 if x["neargaia_med"] < 39.2397842 else 72
                                        )
                                        if state == 71:
                                            state = (
                                                93 if x["col_det"] < 0.299508095 else 94
                                            )
                                            if state == 93:
                                                state = (
                                                    113
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.96785307)
                                                    else 114
                                                )
                                                if state == 113:
                                                    state = (
                                                        127
                                                        if x["col_det"] < 0.281560898
                                                        else 128
                                                    )
                                                    if state == 127:
                                                        return -0.228412241
                                                    if state == 128:
                                                        return 0.166892081
                                                if state == 114:
                                                    return 0.274411708
                                            if state == 94:
                                                return -0.13321878
                                        if state == 72:
                                            return -0.122787558
                                    if state == 52:
                                        return -0.291952997
                            if state == 26:
                                state = 37 if x["neargaia_med"] < 11.1304836 else 38
                                if state == 37:
                                    return 0.220905542
                                if state == 38:
                                    state = (
                                        53
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.88500005)
                                        else 54
                                    )
                                    if state == 53:
                                        return 0.164135337
                                    if state == 54:
                                        return -0.193450078
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 23.1376495)
                        else 12
                    )
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 18.3137169)
                            else 18
                        )
                        if state == 17:
                            state = (
                                27
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.734000027)
                                else 28
                            )
                            if state == 27:
                                return -0.299335986
                            if state == 28:
                                state = 39 if x["neargaia_med"] < 1.49824727 else 40
                                if state == 39:
                                    state = (
                                        55
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.859285712)
                                        else 56
                                    )
                                    if state == 55:
                                        state = (
                                            73
                                            if x["neargaia_med"] < 0.621789873
                                            else 74
                                        )
                                        if state == 73:
                                            return -0.106404826
                                        if state == 74:
                                            state = (
                                                95 if x["col_det"] < 0.490218163 else 96
                                            )
                                            if state == 95:
                                                return 0.0959294736
                                            if state == 96:
                                                return -0.353973806
                                    if state == 56:
                                        return 0.131741852
                                if state == 40:
                                    state = (
                                        57
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.457499743)
                                        else 58
                                    )
                                    if state == 57:
                                        return -0.299095273
                                    if state == 58:
                                        state = (
                                            75
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 60.9836769)
                                            else 76
                                        )
                                        if state == 75:
                                            state = (
                                                97
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.80010891)
                                                else 98
                                            )
                                            if state == 97:
                                                state = (
                                                    115
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.04432297)
                                                    else 116
                                                )
                                                if state == 115:
                                                    return 0.167112336
                                                if state == 116:
                                                    return 0.34531036
                                            if state == 98:
                                                return -0.235309437
                                        if state == 76:
                                            return -0.247717187
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.973749995)
                                else 30
                            )
                            if state == 29:
                                state = 41 if x["neargaia_med"] < 26.2820854 else 42
                                if state == 41:
                                    state = (
                                        59
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.422499895)
                                        else 60
                                    )
                                    if state == 59:
                                        state = (
                                            77 if x["neargaia_med"] < 7.28698444 else 78
                                        )
                                        if state == 77:
                                            return 0.19957687
                                        if state == 78:
                                            return -0.293204099
                                    if state == 60:
                                        state = (
                                            79 if x["neargaia_med"] < 0.14541626 else 80
                                        )
                                        if state == 79:
                                            return 0.00180799013
                                        if state == 80:
                                            return -0.369976133
                                if state == 42:
                                    state = (
                                        61
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.574999928)
                                        else 62
                                    )
                                    if state == 61:
                                        state = (
                                            81 if x["neargaia_med"] < 32.052494 else 82
                                        )
                                        if state == 81:
                                            return -0.0697134733
                                        if state == 82:
                                            return -0.330246568
                                    if state == 62:
                                        state = (
                                            83 if x["neargaia_med"] < 36.2926254 else 84
                                        )
                                        if state == 83:
                                            return 0.257976472
                                        if state == 84:
                                            state = (
                                                99
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 1.0031147)
                                                else 100
                                            )
                                            if state == 99:
                                                state = (
                                                    117
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.96192694)
                                                    else 118
                                                )
                                                if state == 117:
                                                    state = (
                                                        129
                                                        if x["col_det"] < 1.63869572
                                                        else 130
                                                    )
                                                    if state == 129:
                                                        return -0.0158657748
                                                    if state == 130:
                                                        state = (
                                                            137
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 1.45331025)
                                                            else 138
                                                        )
                                                        if state == 137:
                                                            return -0.133283436
                                                        if state == 138:
                                                            return 0.192254335
                                                if state == 118:
                                                    return -0.223848253
                                            if state == 100:
                                                return 0.119162306
                            if state == 30:
                                state = 43 if x["neargaia_med"] < 11.247591 else 44
                                if state == 43:
                                    return -0.252721012
                                if state == 44:
                                    state = (
                                        63
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.517023802)
                                        else 64
                                    )
                                    if state == 63:
                                        return 0.00663087144
                                    if state == 64:
                                        return 0.278775454
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 20.1201591)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.917250037)
                                else 32
                            )
                            if state == 31:
                                return -0.171071589
                            if state == 32:
                                state = 45 if x["neargaia_med"] < 26.6432114 else 46
                                if state == 45:
                                    return 0.129527062
                                if state == 46:
                                    return -0.156247929
                        if state == 20:
                            return 0.440148145
    elif num_booster == 9:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.3241501) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.3899384)
                    else 4
                )
                if state == 3:
                    return -0.391312391
                if state == 4:
                    return 0.124990337
            if state == 2:
                state = (
                    5
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.4055023)
                    else 6
                )
                if state == 5:
                    state = 7 if x["maggaia_med"] < 17.3329906 else 8
                    if state == 7:
                        state = 11 if x["distnr_med"] < 9.40089798 else 12
                        if state == 11:
                            state = (
                                17
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.0244733989)
                                else 18
                            )
                            if state == 17:
                                return 0.194206417
                            if state == 18:
                                state = 27 if x["col_det"] < 0.427095413 else 28
                                if state == 27:
                                    state = (
                                        41
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 0.0719559938)
                                        else 42
                                    )
                                    if state == 41:
                                        state = (
                                            61 if x["col_det"] < -0.195786476 else 62
                                        )
                                        if state == 61:
                                            return -0.244724527
                                        if state == 62:
                                            state = (
                                                77
                                                if x["maggaia_med"] < 16.7729797
                                                else 78
                                            )
                                            if state == 77:
                                                state = (
                                                    97
                                                    if x["distnr_med"] < 2.77071095
                                                    else 98
                                                )
                                                if state == 97:
                                                    state = (
                                                        117
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.456666589)
                                                        else 118
                                                    )
                                                    if state == 117:
                                                        return 0.117291257
                                                    if state == 118:
                                                        state = (
                                                            139
                                                            if x["col_det"]
                                                            < -0.162604332
                                                            else 140
                                                        )
                                                        if state == 139:
                                                            return 0.129980296
                                                        if state == 140:
                                                            return -0.250142723
                                                if state == 98:
                                                    return 0.254674345
                                            if state == 78:
                                                return -0.21655567
                                    if state == 42:
                                        return 0.225756764
                                if state == 28:
                                    state = (
                                        43
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 0.980347157)
                                        else 44
                                    )
                                    if state == 43:
                                        return -0.231857553
                                    if state == 44:
                                        return -0.0565246455
                        if state == 12:
                            return -0.322840482
                    if state == 8:
                        state = 13 if x["distnr_med"] < 5.0004096 else 14
                        if state == 13:
                            state = (
                                19
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.98130798)
                                else 20
                            )
                            if state == 19:
                                state = 29 if x["col_det"] < 0.236618042 else 30
                                if state == 29:
                                    state = (
                                        45
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 0.0752199441)
                                        else 46
                                    )
                                    if state == 45:
                                        state = (
                                            63 if x["col_det"] < 0.0726747513 else 64
                                        )
                                        if state == 63:
                                            state = (
                                                79
                                                if x["maggaia_med"] < 17.9289703
                                                else 80
                                            )
                                            if state == 79:
                                                state = (
                                                    99
                                                    if x["distnr_med"] < 1.17594767
                                                    else 100
                                                )
                                                if state == 99:
                                                    return -0.151035354
                                                if state == 100:
                                                    state = (
                                                        119
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.698690534)
                                                        else 120
                                                    )
                                                    if state == 119:
                                                        return 0.14142777
                                                    if state == 120:
                                                        return -0.144080728
                                            if state == 80:
                                                state = (
                                                    101
                                                    if x["distnr_med"] < 0.253441006
                                                    else 102
                                                )
                                                if state == 101:
                                                    return -0.0993236676
                                                if state == 102:
                                                    state = (
                                                        121
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.521666646)
                                                        else 122
                                                    )
                                                    if state == 121:
                                                        state = (
                                                            141
                                                            if x["col_det"]
                                                            < -0.26115036
                                                            else 142
                                                        )
                                                        if state == 141:
                                                            return -0.159975037
                                                        if state == 142:
                                                            return 0.159583375
                                                    if state == 122:
                                                        return 0.239545897
                                        if state == 64:
                                            state = (
                                                81
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 19.0191917)
                                                else 82
                                            )
                                            if state == 81:
                                                return 0.335113972
                                            if state == 82:
                                                return -0.0327994265
                                    if state == 46:
                                        state = (
                                            65 if x["col_det"] < -0.298700333 else 66
                                        )
                                        if state == 65:
                                            return -0.238234133
                                        if state == 66:
                                            state = (
                                                83
                                                if x["maggaia_med"] < 18.5708237
                                                else 84
                                            )
                                            if state == 83:
                                                return 0.170106545
                                            if state == 84:
                                                state = (
                                                    103
                                                    if x["distnr_med"] < 3.06433988
                                                    else 104
                                                )
                                                if state == 103:
                                                    return 0.136216477
                                                if state == 104:
                                                    return -0.206539631
                                if state == 30:
                                    state = (
                                        47
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 2.99758673)
                                        else 48
                                    )
                                    if state == 47:
                                        state = 67 if x["col_det"] < 0.326242447 else 68
                                        if state == 67:
                                            state = (
                                                85
                                                if x["maggaia_med"] < 18.8294353
                                                else 86
                                            )
                                            if state == 85:
                                                return 0.144141749
                                            if state == 86:
                                                return -0.33625257
                                        if state == 68:
                                            state = (
                                                87
                                                if x["maggaia_med"] < 19.3316917
                                                else 88
                                            )
                                            if state == 87:
                                                state = (
                                                    105
                                                    if x["distnr_med"] < 1.72137177
                                                    else 106
                                                )
                                                if state == 105:
                                                    state = (
                                                        125
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.623928547)
                                                        else 126
                                                    )
                                                    if state == 125:
                                                        return -0.208143234
                                                    if state == 126:
                                                        state = (
                                                            145
                                                            if x["col_det"]
                                                            < 0.356444359
                                                            else 146
                                                        )
                                                        if state == 145:
                                                            return 0.234771162
                                                        if state == 146:
                                                            return -0.00751722045
                                                if state == 106:
                                                    state = (
                                                        127
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.569285631)
                                                        else 128
                                                    )
                                                    if state == 127:
                                                        return 0.0913822278
                                                    if state == 128:
                                                        return 0.287899226
                                            if state == 88:
                                                state = (
                                                    107
                                                    if x["distnr_med"] < 1.92370176
                                                    else 108
                                                )
                                                if state == 107:
                                                    state = (
                                                        129
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.842381001)
                                                        else 130
                                                    )
                                                    if state == 129:
                                                        return 0.0992467999
                                                    if state == 130:
                                                        return -0.317881674
                                                if state == 108:
                                                    return -0.352471322
                                    if state == 48:
                                        return 0.236584872
                            if state == 20:
                                state = (
                                    31
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.44380188)
                                    else 32
                                )
                                if state == 31:
                                    state = (
                                        49
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 2.94190979)
                                        else 50
                                    )
                                    if state == 49:
                                        state = (
                                            69
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < 0.0241727829)
                                            else 70
                                        )
                                        if state == 69:
                                            state = (
                                                89
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 18.5707359)
                                                else 90
                                            )
                                            if state == 89:
                                                state = (
                                                    109
                                                    if x["distnr_med"] < 0.348801315
                                                    else 110
                                                )
                                                if state == 109:
                                                    return -0.187221214
                                                if state == 110:
                                                    return 0.275267929
                                            if state == 90:
                                                state = (
                                                    111
                                                    if x["distnr_med"] < 1.80617881
                                                    else 112
                                                )
                                                if state == 111:
                                                    return -0.321844071
                                                if state == 112:
                                                    return 0.123435415
                                        if state == 70:
                                            return -0.286159873
                                    if state == 50:
                                        return -0.222227514
                                if state == 32:
                                    return 0.216617957
                        if state == 14:
                            state = (
                                21
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.124745294)
                                else 22
                            )
                            if state == 21:
                                return -0.349275887
                            if state == 22:
                                state = 33 if x["col_det"] < -0.20759964 else 34
                                if state == 33:
                                    state = (
                                        51
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 0.0633738488)
                                        else 52
                                    )
                                    if state == 51:
                                        return -0.0103086857
                                    if state == 52:
                                        return 0.304096818
                                if state == 34:
                                    state = (
                                        53
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 2.95272565)
                                        else 54
                                    )
                                    if state == 53:
                                        state = (
                                            71
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < -0.13955307)
                                            else 72
                                        )
                                        if state == 71:
                                            return -0.334248573
                                        if state == 72:
                                            state = (
                                                91
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 18.329298)
                                                else 92
                                            )
                                            if state == 91:
                                                state = (
                                                    113
                                                    if x["distnr_med"] < 7.14109421
                                                    else 114
                                                )
                                                if state == 113:
                                                    state = (
                                                        135
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.50666666)
                                                        else 136
                                                    )
                                                    if state == 135:
                                                        return -0.0345116965
                                                    if state == 136:
                                                        return 0.206537351
                                                if state == 114:
                                                    return -0.145103067
                                            if state == 92:
                                                return -0.129484221
                                    if state == 54:
                                        return 0.14726983
                if state == 6:
                    state = 9 if x["maggaia_med"] < 19.5770149 else 10
                    if state == 9:
                        return -0.394391418
                    if state == 10:
                        state = 15 if x["distnr_med"] < 2.59481144 else 16
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.0441377498)
                                else 24
                            )
                            if state == 23:
                                return 0.153194681
                            if state == 24:
                                state = 35 if x["col_det"] < -0.0528821945 else 36
                                if state == 35:
                                    state = (
                                        55
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 0.063350752)
                                        else 56
                                    )
                                    if state == 55:
                                        state = (
                                            73 if x["col_det"] < -0.301325798 else 74
                                        )
                                        if state == 73:
                                            return 0.159578189
                                        if state == 74:
                                            return -0.255875498
                                    if state == 56:
                                        return -0.321978331
                                if state == 36:
                                    state = (
                                        57
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 0.543153942)
                                        else 58
                                    )
                                    if state == 57:
                                        state = (
                                            75
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < 0.308117867)
                                            else 76
                                        )
                                        if state == 75:
                                            state = (
                                                93
                                                if x["maggaia_med"] < 19.9505882
                                                else 94
                                            )
                                            if state == 93:
                                                state = (
                                                    115
                                                    if x["distnr_med"] < 0.693750501
                                                    else 116
                                                )
                                                if state == 115:
                                                    return 0.163683727
                                                if state == 116:
                                                    return -0.0574509613
                                            if state == 94:
                                                return 0.175208688
                                        if state == 76:
                                            state = (
                                                95
                                                if x["maggaia_med"] < 20.1717758
                                                else 96
                                            )
                                            if state == 95:
                                                return -0.162290901
                                            if state == 96:
                                                return 0.100198187
                                    if state == 58:
                                        return -0.0321812071
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.96985531)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    37
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 1.10819912)
                                    else 38
                                )
                                if state == 37:
                                    return -0.455883652
                                if state == 38:
                                    return 0.101043977
                            if state == 26:
                                state = 39 if x["col_det"] < 0.00728130341 else 40
                                if state == 39:
                                    return -0.144112825
                                if state == 40:
                                    state = (
                                        59
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 0.00140045001)
                                        else 60
                                    )
                                    if state == 59:
                                        return -0.180428892
                                    if state == 60:
                                        return 0.27526325
    elif num_booster == 10:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.0562744) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.873729467)
                    else 4
                )
                if state == 3:
                    state = 7 if x["maggaia_med"] < 14.1992092 else 8
                    if state == 7:
                        state = 13 if x["col_det"] < 0.162837029 else 14
                        if state == 13:
                            return 0.138407528
                        if state == 14:
                            return -0.289355427
                    if state == 8:
                        state = 15 if x["col_det"] < -0.118923187 else 16
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.513333201)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    33
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.0894317031)
                                    else 34
                                )
                                if state == 33:
                                    return 0.202232689
                                if state == 34:
                                    return -0.128430635
                            if state == 24:
                                state = 35 if x["sgscore1_med"] < 0.0193332992 else 36
                                if state == 35:
                                    state = 51 if x["magnr_med"] < 21.4814987 else 52
                                    if state == 51:
                                        state = (
                                            71 if x["maggaia_med"] < 20.0147247 else 72
                                        )
                                        if state == 71:
                                            return -0.214544639
                                        if state == 72:
                                            return 0.132262096
                                    if state == 52:
                                        return -0.336470783
                                if state == 36:
                                    state = 53 if x["magnr_med"] < 21.1607513 else 54
                                    if state == 53:
                                        state = (
                                            73
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.6058693)
                                            else 74
                                        )
                                        if state == 73:
                                            return 0.182864547
                                        if state == 74:
                                            state = (
                                                89
                                                if x["distpsnr1_med"] < 2.69127035
                                                else 90
                                            )
                                            if state == 89:
                                                return -0.269715995
                                            if state == 90:
                                                state = (
                                                    101
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.9574814)
                                                    else 102
                                                )
                                                if state == 101:
                                                    return 0.19190073
                                                if state == 102:
                                                    return -0.107045688
                                    if state == 54:
                                        return -0.363455415
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.330357194)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    37
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.482782483)
                                    else 38
                                )
                                if state == 37:
                                    return -0.231082857
                                if state == 38:
                                    state = 55 if x["magnr_med"] < 20.6167507 else 56
                                    if state == 55:
                                        return 0.0660176724
                                    if state == 56:
                                        return -0.114612706
                            if state == 26:
                                state = 39 if x["sgscore1_med"] < 0.0171458013 else 40
                                if state == 39:
                                    state = 57 if x["magnr_med"] < 18.4347496 else 58
                                    if state == 57:
                                        state = (
                                            75 if x["maggaia_med"] < 18.6501007 else 76
                                        )
                                        if state == 75:
                                            return -0.323807567
                                        if state == 76:
                                            return 0.18434234
                                    if state == 58:
                                        state = (
                                            77 if x["maggaia_med"] < 19.10009 else 78
                                        )
                                        if state == 77:
                                            state = (
                                                91
                                                if x["distpsnr1_med"] < 0.0815681443
                                                else 92
                                            )
                                            if state == 91:
                                                return -0.17914702
                                            if state == 92:
                                                state = (
                                                    103
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.9484959)
                                                    else 104
                                                )
                                                if state == 103:
                                                    return 0.280472755
                                                if state == 104:
                                                    return -0.267410696
                                        if state == 78:
                                            state = (
                                                93
                                                if x["distpsnr1_med"] < 0.526782513
                                                else 94
                                            )
                                            if state == 93:
                                                return 0.00289796828
                                            if state == 94:
                                                return 0.410839677
                                if state == 40:
                                    state = (
                                        59
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 16.5540009)
                                        else 60
                                    )
                                    if state == 59:
                                        state = (
                                            79
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 16.421133)
                                            else 80
                                        )
                                        if state == 79:
                                            state = (
                                                95
                                                if x["distpsnr1_med"] < 0.250110954
                                                else 96
                                            )
                                            if state == 95:
                                                return 0.16196534
                                            if state == 96:
                                                state = (
                                                    105
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 17.8191566)
                                                    else 106
                                                )
                                                if state == 105:
                                                    return -0.272014588
                                                if state == 106:
                                                    state = (
                                                        113
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.39715)
                                                        else 114
                                                    )
                                                    if state == 113:
                                                        return -0.183633715
                                                    if state == 114:
                                                        return 0.0352847315
                                        if state == 80:
                                            return -0.314197421
                                    if state == 60:
                                        state = (
                                            81
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.4260025)
                                            else 82
                                        )
                                        if state == 81:
                                            state = (
                                                97
                                                if x["distpsnr1_med"] < 0.217205286
                                                else 98
                                            )
                                            if state == 97:
                                                state = (
                                                    107
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.9256554)
                                                    else 108
                                                )
                                                if state == 107:
                                                    return -0.297230214
                                                if state == 108:
                                                    return 0.208698869
                                            if state == 98:
                                                state = (
                                                    109
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.703371)
                                                    else 110
                                                )
                                                if state == 109:
                                                    state = (
                                                        115
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.8779106)
                                                        else 116
                                                    )
                                                    if state == 115:
                                                        state = (
                                                            123
                                                            if x["col_det"]
                                                            < 0.231146812
                                                            else 124
                                                        )
                                                        if state == 123:
                                                            return 0.302185714
                                                        if state == 124:
                                                            return 0.128992572
                                                    if state == 116:
                                                        state = (
                                                            125
                                                            if np.isnan(x["col_det"])
                                                            or (
                                                                x["col_det"]
                                                                < 0.457063675
                                                            )
                                                            else 126
                                                        )
                                                        if state == 125:
                                                            return 0.413189799
                                                        if state == 126:
                                                            return 0.0432157852
                                                if state == 110:
                                                    state = (
                                                        117
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.2395)
                                                        else 118
                                                    )
                                                    if state == 117:
                                                        state = (
                                                            127
                                                            if np.isnan(x["col_det"])
                                                            or (
                                                                x["col_det"]
                                                                < -0.0614147186
                                                            )
                                                            else 128
                                                        )
                                                        if state == 127:
                                                            return -0.189419553
                                                        if state == 128:
                                                            return 0.255528927
                                                    if state == 118:
                                                        return 0.304287821
                                        if state == 82:
                                            state = (
                                                99
                                                if np.isnan(x["distpsnr1_med"])
                                                or (x["distpsnr1_med"] < 0.684059858)
                                                else 100
                                            )
                                            if state == 99:
                                                return -0.285274863
                                            if state == 100:
                                                state = (
                                                    111
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.5233898)
                                                    else 112
                                                )
                                                if state == 111:
                                                    state = (
                                                        119
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.6555996)
                                                        else 120
                                                    )
                                                    if state == 119:
                                                        state = (
                                                            129
                                                            if x["col_det"]
                                                            < 0.471012115
                                                            else 130
                                                        )
                                                        if state == 129:
                                                            return 0.192318276
                                                        if state == 130:
                                                            return -0.0951137319
                                                    if state == 120:
                                                        return 0.320765108
                                                if state == 112:
                                                    state = (
                                                        121
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.0649872)
                                                        else 122
                                                    )
                                                    if state == 121:
                                                        return -0.327206671
                                                    if state == 122:
                                                        state = (
                                                            131
                                                            if x["col_det"]
                                                            < 0.203231812
                                                            else 132
                                                        )
                                                        if state == 131:
                                                            return 0.182161674
                                                        if state == 132:
                                                            return -0.227423921
                if state == 4:
                    return -0.315847307
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.119400002 else 6
                if state == 5:
                    state = 9 if x["maggaia_med"] < 18.4763603 else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.0781431198)
                            else 18
                        )
                        if state == 17:
                            return -0.28790912
                        if state == 18:
                            state = (
                                27
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.777499914)
                                else 28
                            )
                            if state == 27:
                                state = 41 if x["sgscore1_med"] < 0.00883333012 else 42
                                if state == 41:
                                    return 0.120726421
                                if state == 42:
                                    state = 61 if x["magnr_med"] < 19.6322498 else 62
                                    if state == 61:
                                        return 0.0938307643
                                    if state == 62:
                                        return -0.175430402
                            if state == 28:
                                return 0.175946698
                    if state == 10:
                        state = 19 if x["col_det"] < -0.00036907196 else 20
                        if state == 19:
                            return 0.00181703456
                        if state == 20:
                            return -0.466716617
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.0120583)
                        else 12
                    )
                    if state == 11:
                        state = 21 if x["col_det"] < 0.0816307068 else 22
                        if state == 21:
                            state = (
                                29
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.31892848)
                                else 30
                            )
                            if state == 29:
                                return -0.132061571
                            if state == 30:
                                state = 43 if x["sgscore1_med"] < 1.28216696 else 44
                                if state == 43:
                                    return 0.198530808
                                if state == 44:
                                    state = 63 if x["magnr_med"] < 22.1257496 else 64
                                    if state == 63:
                                        return 0.0748676062
                                    if state == 64:
                                        return -0.210559756
                        if state == 22:
                            state = (
                                31
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.53000015)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    45
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.180081487)
                                    else 46
                                )
                                if state == 45:
                                    state = 65 if x["magnr_med"] < 21.7877502 else 66
                                    if state == 65:
                                        state = (
                                            83
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 14.6634769)
                                            else 84
                                        )
                                        if state == 83:
                                            return -0.0215021688
                                        if state == 84:
                                            return 0.269461066
                                    if state == 66:
                                        return -0.208768412
                                if state == 46:
                                    state = 67 if x["magnr_med"] < 22.6172485 else 68
                                    if state == 67:
                                        return -0.305140585
                                    if state == 68:
                                        state = (
                                            85 if x["maggaia_med"] < 37.899559 else 86
                                        )
                                        if state == 85:
                                            return -0.198120907
                                        if state == 86:
                                            return 0.0866389126
                            if state == 32:
                                state = 47 if x["sgscore1_med"] < 0.169351012 else 48
                                if state == 47:
                                    return -0.0308337882
                                if state == 48:
                                    state = 69 if x["magnr_med"] < 19.9762497 else 70
                                    if state == 69:
                                        return -0.380355865
                                    if state == 70:
                                        state = (
                                            87 if x["maggaia_med"] < 37.7381516 else 88
                                        )
                                        if state == 87:
                                            return -0.264191091
                                        if state == 88:
                                            return 0.11152938
                    if state == 12:
                        return -0.343441576
    elif num_booster == 11:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.95839691)
                else 2
            )
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.559999943) else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 27.5614166)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0375867486)
                            else 16
                        )
                        if state == 15:
                            state = (
                                31
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.467500091)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    61
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.725749969)
                                    else 62
                                )
                                if state == 61:
                                    return -0.1712915
                                if state == 62:
                                    state = 89 if x["neargaia_med"] < 7.69453716 else 90
                                    if state == 89:
                                        return 0.148336619
                                    if state == 90:
                                        state = (
                                            123
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.0168402493)
                                            else 124
                                        )
                                        if state == 123:
                                            return 0.0499961004
                                        if state == 124:
                                            return -0.152655452
                            if state == 32:
                                state = (
                                    63
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.798500001)
                                    else 64
                                )
                                if state == 63:
                                    return -0.123594619
                                if state == 64:
                                    state = 91 if x["neargaia_med"] < 27.2490768 else 92
                                    if state == 91:
                                        return -0.0190469734
                                    if state == 92:
                                        return 0.238428175
                        if state == 16:
                            state = (
                                33
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.416666567)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    65
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.613749981)
                                    else 66
                                )
                                if state == 65:
                                    return -0.266265392
                                if state == 66:
                                    state = (
                                        93
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 16.3110161)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            125
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.90656829)
                                            else 126
                                        )
                                        if state == 125:
                                            return -0.295132041
                                        if state == 126:
                                            state = (
                                                163
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.0253353)
                                                else 164
                                            )
                                            if state == 163:
                                                return -0.0246382821
                                            if state == 164:
                                                return 0.179467708
                                    if state == 94:
                                        state = (
                                            127
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.56246525)
                                            else 128
                                        )
                                        if state == 127:
                                            return 0.218556434
                                        if state == 128:
                                            return -0.123046696
                            if state == 34:
                                state = (
                                    67
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.966250002)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        95
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 22.5734215)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            129
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.0648032501)
                                            else 130
                                        )
                                        if state == 129:
                                            state = (
                                                165
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.9464607)
                                                else 166
                                            )
                                            if state == 165:
                                                return 0.0397801399
                                            if state == 166:
                                                return -0.155050308
                                        if state == 130:
                                            return -0.341457963
                                    if state == 96:
                                        state = (
                                            131
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.8897512)
                                            else 132
                                        )
                                        if state == 131:
                                            return -0.105967671
                                        if state == 132:
                                            return 0.132290438
                                if state == 68:
                                    state = 97 if x["neargaia_med"] < 19.2157917 else 98
                                    if state == 97:
                                        return -0.200059339
                                    if state == 98:
                                        return 0.184395015
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0244676005)
                            else 18
                        )
                        if state == 17:
                            state = (
                                35
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.511666656)
                                else 36
                            )
                            if state == 35:
                                return -0.161614507
                            if state == 36:
                                return 0.0528373979
                        if state == 18:
                            return -0.326094717
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 0.960377634)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0426967517)
                            else 20
                        )
                        if state == 19:
                            state = (
                                37
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.620833397)
                                else 38
                            )
                            if state == 37:
                                return 0.24700512
                            if state == 38:
                                state = (
                                    71
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.898249984)
                                    else 72
                                )
                                if state == 71:
                                    return -0.264683336
                                if state == 72:
                                    return 0.240804359
                        if state == 20:
                            state = (
                                39
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.845714271)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    73
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.908749938)
                                    else 74
                                )
                                if state == 73:
                                    state = (
                                        99
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 0.767785728)
                                        else 100
                                    )
                                    if state == 99:
                                        state = (
                                            133
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.0692013949)
                                            else 134
                                        )
                                        if state == 133:
                                            state = (
                                                167
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.4465675)
                                                else 168
                                            )
                                            if state == 167:
                                                return -0.126529977
                                            if state == 168:
                                                return 0.0665756389
                                        if state == 134:
                                            state = (
                                                169
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6245232)
                                                else 170
                                            )
                                            if state == 169:
                                                return -0.0568351559
                                            if state == 170:
                                                return -0.373118639
                                    if state == 100:
                                        return 0.0516485535
                                if state == 74:
                                    state = (
                                        101
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 0.588193059)
                                        else 102
                                    )
                                    if state == 101:
                                        state = (
                                            135
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.94511557)
                                            else 136
                                        )
                                        if state == 135:
                                            state = (
                                                171
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.3292065)
                                                else 172
                                            )
                                            if state == 171:
                                                return -0.241550982
                                            if state == 172:
                                                return 0.191729099
                                        if state == 136:
                                            return -0.178608015
                                    if state == 102:
                                        return 0.13839829
                            if state == 40:
                                return -0.38192302
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.93641186)
                            else 22
                        )
                        if state == 21:
                            state = (
                                41
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.679166555)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    75
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.95450002)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        103 if x["neargaia_med"] < 34.8703346 else 104
                                    )
                                    if state == 103:
                                        state = (
                                            137
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.0341030508)
                                            else 138
                                        )
                                        if state == 137:
                                            state = (
                                                173
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.3955994)
                                                else 174
                                            )
                                            if state == 173:
                                                return 0.128730059
                                            if state == 174:
                                                return -0.17037113
                                        if state == 138:
                                            state = (
                                                175
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.7087631)
                                                else 176
                                            )
                                            if state == 175:
                                                state = (
                                                    197
                                                    if x["magnr_med"] < 17.0960007
                                                    else 198
                                                )
                                                if state == 197:
                                                    return -0.0952832848
                                                if state == 198:
                                                    return 0.293112665
                                            if state == 176:
                                                state = (
                                                    199
                                                    if x["magnr_med"] < 18.6040001
                                                    else 200
                                                )
                                                if state == 199:
                                                    return 0.173461512
                                                if state == 200:
                                                    return -0.298252821
                                    if state == 104:
                                        state = (
                                            139
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.54719907)
                                            else 140
                                        )
                                        if state == 139:
                                            return -0.306625932
                                        if state == 140:
                                            state = (
                                                177
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.9580154)
                                                else 178
                                            )
                                            if state == 177:
                                                return 0.0643802136
                                            if state == 178:
                                                return -0.112331048
                                if state == 76:
                                    state = (
                                        105 if x["neargaia_med"] < 15.5270853 else 106
                                    )
                                    if state == 105:
                                        return 0.264049321
                                    if state == 106:
                                        state = (
                                            141
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.45163774)
                                            else 142
                                        )
                                        if state == 141:
                                            return 0.0449019484
                                        if state == 142:
                                            return -0.321642488
                            if state == 42:
                                state = (
                                    77
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.976999998)
                                    else 78
                                )
                                if state == 77:
                                    state = (
                                        107 if x["neargaia_med"] < 23.2147026 else 108
                                    )
                                    if state == 107:
                                        state = (
                                            143
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.104722247)
                                            else 144
                                        )
                                        if state == 143:
                                            return -0.398587108
                                        if state == 144:
                                            state = (
                                                181
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.0991325)
                                                else 182
                                            )
                                            if state == 181:
                                                return 0.27782625
                                            if state == 182:
                                                return -0.185651496
                                    if state == 108:
                                        state = (
                                            145
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.86767364)
                                            else 146
                                        )
                                        if state == 145:
                                            state = (
                                                183
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.1510296)
                                                else 184
                                            )
                                            if state == 183:
                                                return -0.0603072345
                                            if state == 184:
                                                state = (
                                                    201
                                                    if x["magnr_med"] < 19.8197479
                                                    else 202
                                                )
                                                if state == 201:
                                                    return 0.365149498
                                                if state == 202:
                                                    return -0.13615495
                                        if state == 146:
                                            state = (
                                                185
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.7488422)
                                                else 186
                                            )
                                            if state == 185:
                                                return 0.109061673
                                            if state == 186:
                                                return -0.204762936
                                if state == 78:
                                    return 0.231626943
                        if state == 22:
                            state = (
                                43
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.69059515)
                                else 44
                            )
                            if state == 43:
                                return -0.347069621
                            if state == 44:
                                state = (
                                    79
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.898000002)
                                    else 80
                                )
                                if state == 79:
                                    state = (
                                        109 if x["neargaia_med"] < 27.8509407 else 110
                                    )
                                    if state == 109:
                                        state = (
                                            147
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.95020247)
                                            else 148
                                        )
                                        if state == 147:
                                            return -0.120950669
                                        if state == 148:
                                            return 0.075551711
                                    if state == 110:
                                        return 0.124054603
                                if state == 80:
                                    state = (
                                        111 if x["neargaia_med"] < 13.1537228 else 112
                                    )
                                    if state == 111:
                                        return 0.0162710268
                                    if state == 112:
                                        return -0.212162465
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.503333271) else 6
                if state == 5:
                    state = 11 if x["neargaia_med"] < 29.1880951 else 12
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.97370386)
                            else 24
                        )
                        if state == 23:
                            return 0.118801497
                        if state == 24:
                            state = (
                                47
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.354166508)
                                else 48
                            )
                            if state == 47:
                                return 0.00366948615
                            if state == 48:
                                return -0.279692203
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 3.01947355)
                            else 26
                        )
                        if state == 25:
                            state = (
                                49
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.452499837)
                                else 50
                            )
                            if state == 49:
                                state = (
                                    81
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.616999984)
                                    else 82
                                )
                                if state == 81:
                                    return -0.157901391
                                if state == 82:
                                    state = (
                                        113 if x["neargaia_med"] < 49.6701202 else 114
                                    )
                                    if state == 113:
                                        return 0.204786301
                                    if state == 114:
                                        return -0.117107362
                            if state == 50:
                                return -0.202511057
                        if state == 26:
                            state = (
                                51
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.419642866)
                                else 52
                            )
                            if state == 51:
                                return -0.112322897
                            if state == 52:
                                return 0.243253127
                if state == 6:
                    state = 13 if x["neargaia_med"] < 19.9994812 else 14
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.97368622)
                            else 28
                        )
                        if state == 27:
                            state = (
                                53
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.669166803)
                                else 54
                            )
                            if state == 53:
                                return -0.0949864984
                            if state == 54:
                                return 0.328193069
                        if state == 28:
                            state = (
                                55
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.5200001)
                                else 56
                            )
                            if state == 55:
                                return 0.268403769
                            if state == 56:
                                state = (
                                    83
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.942000031)
                                    else 84
                                )
                                if state == 83:
                                    state = (
                                        115 if x["neargaia_med"] < 0.556552172 else 116
                                    )
                                    if state == 115:
                                        state = (
                                            149
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 3.01721048)
                                            else 150
                                        )
                                        if state == 149:
                                            return -0.146191925
                                        if state == 150:
                                            return 0.0828808621
                                    if state == 116:
                                        return -0.320358008
                                if state == 84:
                                    state = (
                                        117 if x["neargaia_med"] < 11.8321075 else 118
                                    )
                                    if state == 117:
                                        state = (
                                            153
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 3.02593184)
                                            else 154
                                        )
                                        if state == 153:
                                            state = (
                                                189
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.6876259)
                                                else 190
                                            )
                                            if state == 189:
                                                return -0.161602005
                                            if state == 190:
                                                return 0.0879715756
                                        if state == 154:
                                            return 0.292537361
                                    if state == 118:
                                        state = (
                                            155
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 3.01822329)
                                            else 156
                                        )
                                        if state == 155:
                                            return -0.287236989
                                        if state == 156:
                                            state = (
                                                191
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.615181)
                                                else 192
                                            )
                                            if state == 191:
                                                return -0.139913902
                                            if state == 192:
                                                return 0.167558268
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 3.00790501)
                            else 30
                        )
                        if state == 29:
                            state = (
                                57
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.518333316)
                                else 58
                            )
                            if state == 57:
                                return 0.338348269
                            if state == 58:
                                state = (
                                    85
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.752499998)
                                    else 86
                                )
                                if state == 85:
                                    return -0.231650785
                                if state == 86:
                                    state = (
                                        119
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 42.0890503)
                                        else 120
                                    )
                                    if state == 119:
                                        state = (
                                            157
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 3.0022974)
                                            else 158
                                        )
                                        if state == 157:
                                            state = (
                                                193
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.106205)
                                                else 194
                                            )
                                            if state == 193:
                                                state = (
                                                    207
                                                    if x["magnr_med"] < 17.9292488
                                                    else 208
                                                )
                                                if state == 207:
                                                    return 0.00258283783
                                                if state == 208:
                                                    return 0.320792258
                                            if state == 194:
                                                state = (
                                                    209
                                                    if x["magnr_med"] < 18.0904999
                                                    else 210
                                                )
                                                if state == 209:
                                                    return 0.233069181
                                                if state == 210:
                                                    state = (
                                                        211
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.1048126)
                                                        else 212
                                                    )
                                                    if state == 211:
                                                        return 0.143905908
                                                    if state == 212:
                                                        return -0.225142717
                                        if state == 158:
                                            return -0.0112428861
                                    if state == 120:
                                        state = (
                                            159
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.96367478)
                                            else 160
                                        )
                                        if state == 159:
                                            return 0.113976061
                                        if state == 160:
                                            return -0.135178953
                        if state == 30:
                            state = (
                                59
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.580118895)
                                else 60
                            )
                            if state == 59:
                                return -0.121167161
                            if state == 60:
                                state = (
                                    87
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.824249983)
                                    else 88
                                )
                                if state == 87:
                                    return -0.262345761
                                if state == 88:
                                    state = (
                                        121 if x["neargaia_med"] < 63.4665375 else 122
                                    )
                                    if state == 121:
                                        state = (
                                            161
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 3.0244503)
                                            else 162
                                        )
                                        if state == 161:
                                            return -0.194613397
                                        if state == 162:
                                            return 0.200967163
                                    if state == 122:
                                        return 0.232778773
    elif num_booster == 12:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 15.5337496) else 2
            )
            if state == 1:
                return -0.338781267
            if state == 2:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7920418) else 4
                )
                if state == 3:
                    state = 5 if x["neargaia_med"] < 4.44630623 else 6
                    if state == 5:
                        state = 9 if x["distnr_med"] < 0.691525221 else 10
                        if state == 9:
                            state = 17 if x["magnr_med"] < 18.4632492 else 18
                            if state == 17:
                                state = 29 if x["col_det"] < 0.0990447998 else 30
                                if state == 29:
                                    return 0.325488269
                                if state == 30:
                                    state = (
                                        49 if x["distpsnr1_med"] < 0.552746177 else 50
                                    )
                                    if state == 49:
                                        state = (
                                            77 if x["magnr_med"] < 15.5342503 else 78
                                        )
                                        if state == 77:
                                            return 0.142794892
                                        if state == 78:
                                            return -0.108646132
                                    if state == 50:
                                        return 0.176195741
                            if state == 18:
                                return -0.105878308
                        if state == 10:
                            state = 19 if x["magnr_med"] < 16.5545006 else 20
                            if state == 19:
                                return -0.217628762
                            if state == 20:
                                state = (
                                    31
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.220357895)
                                    else 32
                                )
                                if state == 31:
                                    state = (
                                        51 if x["distpsnr1_med"] < 1.11264277 else 52
                                    )
                                    if state == 51:
                                        state = (
                                            79 if x["magnr_med"] < 18.0240002 else 80
                                        )
                                        if state == 79:
                                            return -0.216854572
                                        if state == 80:
                                            return 0.107718632
                                    if state == 52:
                                        state = (
                                            81 if x["magnr_med"] < 18.5142479 else 82
                                        )
                                        if state == 81:
                                            state = (
                                                107
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.6844139)
                                                else 108
                                            )
                                            if state == 107:
                                                return 0.132888868
                                            if state == 108:
                                                return -0.180965766
                                        if state == 82:
                                            return 0.18795605
                                if state == 32:
                                    state = (
                                        53 if x["distpsnr1_med"] < 1.90270615 else 54
                                    )
                                    if state == 53:
                                        return -0.244848624
                                    if state == 54:
                                        state = (
                                            83 if x["magnr_med"] < 18.1637497 else 84
                                        )
                                        if state == 83:
                                            return 0.11606852
                                        if state == 84:
                                            return -0.108655065
                    if state == 6:
                        state = 11 if x["distnr_med"] < 12.2598324 else 12
                        if state == 11:
                            state = 21 if x["magnr_med"] < 22.0662498 else 22
                            if state == 21:
                                state = (
                                    33
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.521520615)
                                    else 34
                                )
                                if state == 33:
                                    state = (
                                        55 if x["distpsnr1_med"] < 0.148055196 else 56
                                    )
                                    if state == 55:
                                        return -0.0980245396
                                    if state == 56:
                                        state = (
                                            85 if x["magnr_med"] < 17.5157509 else 86
                                        )
                                        if state == 85:
                                            state = (
                                                109
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.5035019)
                                                else 110
                                            )
                                            if state == 109:
                                                state = (
                                                    125
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.452003002)
                                                    else 126
                                                )
                                                if state == 125:
                                                    return -0.186849773
                                                if state == 126:
                                                    return 0.0976746231
                                            if state == 110:
                                                return 0.113976195
                                        if state == 86:
                                            state = (
                                                111
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6657715)
                                                else 112
                                            )
                                            if state == 111:
                                                state = (
                                                    127
                                                    if x["sgscore1_med"] < 0.57388401
                                                    else 128
                                                )
                                                if state == 127:
                                                    return 0.399844408
                                                if state == 128:
                                                    return 0.173329607
                                            if state == 112:
                                                state = (
                                                    129
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0386041999
                                                    )
                                                    else 130
                                                )
                                                if state == 129:
                                                    return 0.0969366208
                                                if state == 130:
                                                    return -0.15317215
                                if state == 34:
                                    state = (
                                        57
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 1.96097279)
                                        else 58
                                    )
                                    if state == 57:
                                        state = (
                                            87 if x["magnr_med"] < 21.1917496 else 88
                                        )
                                        if state == 87:
                                            state = (
                                                113
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.1472836)
                                                else 114
                                            )
                                            if state == 113:
                                                state = (
                                                    131
                                                    if x["sgscore1_med"] < 1.41863108
                                                    else 132
                                                )
                                                if state == 131:
                                                    state = (
                                                        141
                                                        if x["col_det"] < 0.17632103
                                                        else 142
                                                    )
                                                    if state == 141:
                                                        return -0.417964369
                                                    if state == 142:
                                                        return 0.0836978853
                                                if state == 132:
                                                    state = (
                                                        143
                                                        if x["col_det"] < -0.260450363
                                                        else 144
                                                    )
                                                    if state == 143:
                                                        return 0.14122805
                                                    if state == 144:
                                                        return -0.0640965402
                                            if state == 114:
                                                state = (
                                                    133
                                                    if x["sgscore1_med"] < 0.232387006
                                                    else 134
                                                )
                                                if state == 133:
                                                    state = (
                                                        145
                                                        if x["col_det"] < 0.217421532
                                                        else 146
                                                    )
                                                    if state == 145:
                                                        return 0.105543181
                                                    if state == 146:
                                                        state = (
                                                            149
                                                            if x["neargaia_med"]
                                                            < 42.2250328
                                                            else 150
                                                        )
                                                        if state == 149:
                                                            return 0.0744583905
                                                        if state == 150:
                                                            return -0.166529983
                                                if state == 134:
                                                    return 0.272237092
                                        if state == 88:
                                            return -0.451072127
                                    if state == 58:
                                        state = (
                                            89 if x["magnr_med"] < 21.2900009 else 90
                                        )
                                        if state == 89:
                                            return 0.246366277
                                        if state == 90:
                                            return -0.129195362
                            if state == 22:
                                state = (
                                    35
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.367570877)
                                    else 36
                                )
                                if state == 35:
                                    state = (
                                        59
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 4.14850712)
                                        else 60
                                    )
                                    if state == 59:
                                        return -0.27628994
                                    if state == 60:
                                        state = (
                                            91 if x["magnr_med"] < 22.6905003 else 92
                                        )
                                        if state == 91:
                                            state = (
                                                115
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 17.3204784)
                                                else 116
                                            )
                                            if state == 115:
                                                return 0.122903675
                                            if state == 116:
                                                state = (
                                                    135
                                                    if x["sgscore1_med"] < 0.00425000023
                                                    else 136
                                                )
                                                if state == 135:
                                                    return 0.0992800146
                                                if state == 136:
                                                    return -0.193965778
                                        if state == 92:
                                            return 0.23954542
                                if state == 36:
                                    return -0.406276911
                        if state == 12:
                            return -0.245113447
                if state == 4:
                    state = 7 if x["neargaia_med"] < 22.8072262 else 8
                    if state == 7:
                        state = 13 if x["distnr_med"] < 0.201410025 else 14
                        if state == 13:
                            return 0.0398421288
                        if state == 14:
                            state = 23 if x["magnr_med"] < 21.2145004 else 24
                            if state == 23:
                                state = 37 if x["col_det"] < -0.0165328979 else 38
                                if state == 37:
                                    state = (
                                        61 if x["distpsnr1_med"] < 0.855360627 else 62
                                    )
                                    if state == 61:
                                        return -0.103995025
                                    if state == 62:
                                        return 0.186291412
                                if state == 38:
                                    state = (
                                        63 if x["distpsnr1_med"] < 6.75426865 else 64
                                    )
                                    if state == 63:
                                        return -0.43351838
                                    if state == 64:
                                        return -0.0453331172
                            if state == 24:
                                state = (
                                    39
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.00648117065)
                                    else 40
                                )
                                if state == 39:
                                    return -0.323862284
                                if state == 40:
                                    state = (
                                        65 if x["distpsnr1_med"] < 14.8677473 else 66
                                    )
                                    if state == 65:
                                        return 0.199028343
                                    if state == 66:
                                        return -0.143294439
                    if state == 8:
                        state = 15 if x["distnr_med"] < 2.19575906 else 16
                        if state == 15:
                            state = 25 if x["magnr_med"] < 19.2777481 else 26
                            if state == 25:
                                state = 41 if x["col_det"] < 0.813950539 else 42
                                if state == 41:
                                    state = (
                                        67 if x["distpsnr1_med"] < 0.476442069 else 68
                                    )
                                    if state == 67:
                                        return -0.128562361
                                    if state == 68:
                                        state = (
                                            95 if x["magnr_med"] < 18.5272522 else 96
                                        )
                                        if state == 95:
                                            return 0.26609984
                                        if state == 96:
                                            state = (
                                                121
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.9331322)
                                                else 122
                                            )
                                            if state == 121:
                                                return 0.131555393
                                            if state == 122:
                                                return -0.205226496
                                if state == 42:
                                    state = (
                                        69 if x["distpsnr1_med"] < 3.64848089 else 70
                                    )
                                    if state == 69:
                                        return -0.316739172
                                    if state == 70:
                                        state = (
                                            97 if x["magnr_med"] < 18.6072502 else 98
                                        )
                                        if state == 97:
                                            return 0.0951290056
                                        if state == 98:
                                            return -0.218941525
                            if state == 26:
                                state = 43 if x["col_det"] < 0.426534653 else 44
                                if state == 43:
                                    state = (
                                        71 if x["distpsnr1_med"] < 0.535810471 else 72
                                    )
                                    if state == 71:
                                        return -0.116097011
                                    if state == 72:
                                        return 0.223213822
                                if state == 44:
                                    state = (
                                        73 if x["distpsnr1_med"] < 40.1616745 else 74
                                    )
                                    if state == 73:
                                        state = (
                                            99 if x["magnr_med"] < 19.6349983 else 100
                                        )
                                        if state == 99:
                                            return 0.0478193797
                                        if state == 100:
                                            return -0.307093352
                                    if state == 74:
                                        state = (
                                            101 if x["magnr_med"] < 20.1580009 else 102
                                        )
                                        if state == 101:
                                            state = (
                                                123
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.5244007)
                                                else 124
                                            )
                                            if state == 123:
                                                return 0.266405106
                                            if state == 124:
                                                return -0.138874158
                                        if state == 102:
                                            return -0.177427977
                        if state == 16:
                            state = 27 if x["magnr_med"] < 22.3155003 else 28
                            if state == 27:
                                state = (
                                    45
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.281193733)
                                    else 46
                                )
                                if state == 45:
                                    return -0.338018775
                                if state == 46:
                                    state = (
                                        75 if x["distpsnr1_med"] < 9.28799725 else 76
                                    )
                                    if state == 75:
                                        return 0.169634134
                                    if state == 76:
                                        state = (
                                            103 if x["magnr_med"] < 19.3217506 else 104
                                        )
                                        if state == 103:
                                            return 0.10327664
                                        if state == 104:
                                            return -0.106521584
                            if state == 28:
                                state = 47 if x["col_det"] < 0.25622654 else 48
                                if state == 47:
                                    return 0.311580718
                                if state == 48:
                                    return -0.333135337
    elif num_booster == 13:
        state = 0
        if state == 0:
            state = 1 if x["distnr_med"] < 12.2592449 else 2
            if state == 1:
                state = 3 if x["magnr_med"] < 15.5337496 else 4
                if state == 3:
                    return -0.316142052
                if state == 4:
                    state = (
                        5
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 7.86786699)
                        else 6
                    )
                    if state == 5:
                        state = (
                            7
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.733333409)
                            else 8
                        )
                        if state == 7:
                            state = 11 if x["magnr_med"] < 21.7092495 else 12
                            if state == 11:
                                state = (
                                    19
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.680357218)
                                    else 20
                                )
                                if state == 19:
                                    state = (
                                        31
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 3.0250001)
                                        else 32
                                    )
                                    if state == 31:
                                        state = (
                                            45
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4860001)
                                            else 46
                                        )
                                        if state == 45:
                                            state = (
                                                69
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.96976852)
                                                else 70
                                            )
                                            if state == 69:
                                                state = (
                                                    89
                                                    if x["neargaia_med"] < 1.22065973
                                                    else 90
                                                )
                                                if state == 89:
                                                    return -0.175459176
                                                if state == 90:
                                                    state = (
                                                        109
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 41.8243561
                                                        )
                                                        else 110
                                                    )
                                                    if state == 109:
                                                        state = (
                                                            117
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.0695992
                                                            )
                                                            else 118
                                                        )
                                                        if state == 117:
                                                            return 0.0497388765
                                                        if state == 118:
                                                            return 0.174148411
                                                    if state == 110:
                                                        return -0.154318631
                                            if state == 70:
                                                state = (
                                                    91
                                                    if x["neargaia_med"] < 31.9943962
                                                    else 92
                                                )
                                                if state == 91:
                                                    return -0.209497556
                                                if state == 92:
                                                    return 0.180168852
                                        if state == 46:
                                            state = (
                                                71
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.0336864)
                                                else 72
                                            )
                                            if state == 71:
                                                state = (
                                                    93
                                                    if x["neargaia_med"] < 48.6984138
                                                    else 94
                                                )
                                                if state == 93:
                                                    return -0.195050195
                                                if state == 94:
                                                    return 0.142718822
                                            if state == 72:
                                                return -0.297435254
                                    if state == 32:
                                        state = (
                                            47
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.4412994)
                                            else 48
                                        )
                                        if state == 47:
                                            return -0.0747481585
                                        if state == 48:
                                            return 0.184034929
                                if state == 20:
                                    state = (
                                        33
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 0.0322800986)
                                        else 34
                                    )
                                    if state == 33:
                                        return -0.132404327
                                    if state == 34:
                                        state = (
                                            49
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.9482498)
                                            else 50
                                        )
                                        if state == 49:
                                            return 0.293475568
                                        if state == 50:
                                            state = (
                                                73
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.9439292)
                                                else 74
                                            )
                                            if state == 73:
                                                state = (
                                                    95
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 3.40692806)
                                                    else 96
                                                )
                                                if state == 95:
                                                    state = (
                                                        113
                                                        if x["neargaia_med"]
                                                        < 0.959630132
                                                        else 114
                                                    )
                                                    if state == 113:
                                                        return 0.11806795
                                                    if state == 114:
                                                        state = (
                                                            121
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.4368496
                                                            )
                                                            else 122
                                                        )
                                                        if state == 121:
                                                            return -0.167150602
                                                        if state == 122:
                                                            return 0.137703598
                                                if state == 96:
                                                    return 0.190993071
                                            if state == 74:
                                                state = (
                                                    97
                                                    if x["neargaia_med"] < 38.0834656
                                                    else 98
                                                )
                                                if state == 97:
                                                    return 0.0518330634
                                                if state == 98:
                                                    return -0.149690613
                            if state == 12:
                                state = (
                                    21
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.65464282)
                                    else 22
                                )
                                if state == 21:
                                    state = (
                                        35
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 3.00225687)
                                        else 36
                                    )
                                    if state == 35:
                                        state = (
                                            51
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.15765)
                                            else 52
                                        )
                                        if state == 51:
                                            return -0.351303577
                                        if state == 52:
                                            state = (
                                                75
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.90758681)
                                                else 76
                                            )
                                            if state == 75:
                                                return -0.221479565
                                            if state == 76:
                                                state = (
                                                    99
                                                    if x["neargaia_med"] < 116.112091
                                                    else 100
                                                )
                                                if state == 99:
                                                    return -0.136985645
                                                if state == 100:
                                                    return 0.127001762
                                    if state == 36:
                                        return 0.0231221635
                                if state == 22:
                                    return 0.116037607
                        if state == 8:
                            state = 13 if x["magnr_med"] < 19.3732491 else 14
                            if state == 13:
                                state = (
                                    23
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.744404674)
                                    else 24
                                )
                                if state == 23:
                                    return -0.188493028
                                if state == 24:
                                    state = (
                                        37
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 0.191666663)
                                        else 38
                                    )
                                    if state == 37:
                                        state = (
                                            55
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.3899994)
                                            else 56
                                        )
                                        if state == 55:
                                            state = (
                                                77
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0227604508)
                                                else 78
                                            )
                                            if state == 77:
                                                return 0.120734915
                                            if state == 78:
                                                state = (
                                                    101
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 24.9171104)
                                                    else 102
                                                )
                                                if state == 101:
                                                    return -0.322303206
                                                if state == 102:
                                                    return 0.0374175943
                                        if state == 56:
                                            return 0.119518243
                                    if state == 38:
                                        state = (
                                            57
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.8684502)
                                            else 58
                                        )
                                        if state == 57:
                                            state = (
                                                81
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.01868057)
                                                else 82
                                            )
                                            if state == 81:
                                                return -0.000569163298
                                            if state == 82:
                                                return 0.303046614
                                        if state == 58:
                                            state = (
                                                83
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.95282412)
                                                else 84
                                            )
                                            if state == 83:
                                                return 0.108665511
                                            if state == 84:
                                                return -0.362345815
                            if state == 14:
                                state = (
                                    25
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.911785483)
                                    else 26
                                )
                                if state == 25:
                                    return -0.415424645
                                if state == 26:
                                    state = (
                                        39
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 2.96186352)
                                        else 40
                                    )
                                    if state == 39:
                                        state = (
                                            59
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.3064995)
                                            else 60
                                        )
                                        if state == 59:
                                            return 0.0159480572
                                        if state == 60:
                                            return -0.298014402
                                    if state == 40:
                                        state = (
                                            61
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.9053001)
                                            else 62
                                        )
                                        if state == 61:
                                            return -0.0643702224
                                        if state == 62:
                                            return 0.109620817
                    if state == 6:
                        state = (
                            9
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.496666521)
                            else 10
                        )
                        if state == 9:
                            state = 15 if x["magnr_med"] < 22.6417503 else 16
                            if state == 15:
                                state = (
                                    27
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.422500074)
                                    else 28
                                )
                                if state == 27:
                                    state = (
                                        41
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 0.124745294)
                                        else 42
                                    )
                                    if state == 41:
                                        return -0.0871188268
                                    if state == 42:
                                        state = (
                                            65
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.3346996)
                                            else 66
                                        )
                                        if state == 65:
                                            state = (
                                                85
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.9845891)
                                                else 86
                                            )
                                            if state == 85:
                                                return 0.372970194
                                            if state == 86:
                                                state = (
                                                    105
                                                    if x["neargaia_med"] < 30.3646622
                                                    else 106
                                                )
                                                if state == 105:
                                                    state = (
                                                        115
                                                        if x["neargaia_med"]
                                                        < 9.11329842
                                                        else 116
                                                    )
                                                    if state == 115:
                                                        return 0.130318508
                                                    if state == 116:
                                                        return -0.132948145
                                                if state == 106:
                                                    return 0.176617756
                                        if state == 66:
                                            return -0.187614799
                                if state == 28:
                                    return -0.216113627
                            if state == 16:
                                return -0.277825356
                        if state == 10:
                            state = 17 if x["magnr_med"] < 22.3227501 else 18
                            if state == 17:
                                return 0.27402854
                            if state == 18:
                                state = (
                                    29
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.498333335)
                                    else 30
                                )
                                if state == 29:
                                    return 0.251893014
                                if state == 30:
                                    state = (
                                        43
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 0.986487269)
                                        else 44
                                    )
                                    if state == 43:
                                        return -0.223250479
                                    if state == 44:
                                        state = (
                                            67
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.237999)
                                            else 68
                                        )
                                        if state == 67:
                                            state = (
                                                87
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.97181702)
                                                else 88
                                            )
                                            if state == 87:
                                                return -0.219660863
                                            if state == 88:
                                                return 0.00187688484
                                        if state == 68:
                                            return 0.227582395
            if state == 2:
                return -0.27447623
    elif num_booster == 14:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.396801) else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0325637013) else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.106433347)
                        else 8
                    )
                    if state == 7:
                        return 0.111145861
                    if state == 8:
                        return -0.177526265
                if state == 4:
                    state = 9 if x["sgscore1_med"] < 0.590795994 else 10
                    if state == 9:
                        state = 13 if x["neargaia_med"] < 130.080994 else 14
                        if state == 13:
                            state = 19 if x["magnr_med"] < 22.2600002 else 20
                            if state == 19:
                                return -0.199626356
                            if state == 20:
                                return 0.0316866189
                        if state == 14:
                            return 0.136446953
                    if state == 10:
                        return -0.339655071
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.00137155014) else 6
                if state == 5:
                    return -0.306022942
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.500625014)
                        else 12
                    )
                    if state == 11:
                        state = (
                            15
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 1.84909284)
                            else 16
                        )
                        if state == 15:
                            state = 21 if x["magnr_med"] < 17.993 else 22
                            if state == 21:
                                state = 29 if x["magnr_med"] < 16.7097492 else 30
                                if state == 29:
                                    state = (
                                        41
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.203494012)
                                        else 42
                                    )
                                    if state == 41:
                                        state = (
                                            53
                                            if np.isnan(x["distpsnr1_med"])
                                            or (x["distpsnr1_med"] < 1.50756574)
                                            else 54
                                        )
                                        if state == 53:
                                            return -0.211585209
                                        if state == 54:
                                            return 0.086914897
                                    if state == 42:
                                        return 0.148326278
                                if state == 30:
                                    state = (
                                        43
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.0874523968)
                                        else 44
                                    )
                                    if state == 43:
                                        return -0.313162923
                                    if state == 44:
                                        state = (
                                            55
                                            if x["distpsnr1_med"] < 1.08468556
                                            else 56
                                        )
                                        if state == 55:
                                            return -0.207660139
                                        if state == 56:
                                            return 0.120841168
                            if state == 22:
                                state = 31 if x["magnr_med"] < 18.4724998 else 32
                                if state == 31:
                                    state = (
                                        45
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.00354166515)
                                        else 46
                                    )
                                    if state == 45:
                                        return 0.29944402
                                    if state == 46:
                                        state = (
                                            57
                                            if x["distpsnr1_med"] < 0.118212685
                                            else 58
                                        )
                                        if state == 57:
                                            return 0.0927224979
                                        if state == 58:
                                            state = (
                                                71
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.9398499)
                                                else 72
                                            )
                                            if state == 71:
                                                return 0.0726406798
                                            if state == 72:
                                                return -0.155863538
                                if state == 32:
                                    state = (
                                        47
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.0077083353)
                                        else 48
                                    )
                                    if state == 47:
                                        state = (
                                            59
                                            if np.isnan(x["distpsnr1_med"])
                                            or (x["distpsnr1_med"] < 1.00581098)
                                            else 60
                                        )
                                        if state == 59:
                                            state = (
                                                73
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.5095997)
                                                else 74
                                            )
                                            if state == 73:
                                                state = (
                                                    85
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.90656829)
                                                    else 86
                                                )
                                                if state == 85:
                                                    state = (
                                                        97
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.4794502)
                                                        else 98
                                                    )
                                                    if state == 97:
                                                        return -0.156020299
                                                    if state == 98:
                                                        return 0.19184579
                                                if state == 86:
                                                    state = (
                                                        99
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.8790741)
                                                        else 100
                                                    )
                                                    if state == 99:
                                                        return 0.274873406
                                                    if state == 100:
                                                        return 0.074962683
                                            if state == 74:
                                                return -0.320900947
                                        if state == 60:
                                            state = (
                                                75
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.4990501)
                                                else 76
                                            )
                                            if state == 75:
                                                return 0.102266856
                                            if state == 76:
                                                return -0.361685127
                                    if state == 48:
                                        state = (
                                            61
                                            if x["distpsnr1_med"] < 0.530229807
                                            else 62
                                        )
                                        if state == 61:
                                            return -0.179176852
                                        if state == 62:
                                            state = (
                                                77
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.3931007)
                                                else 78
                                            )
                                            if state == 77:
                                                state = (
                                                    87
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.4488368)
                                                    else 88
                                                )
                                                if state == 87:
                                                    state = (
                                                        101
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.1676998)
                                                        else 102
                                                    )
                                                    if state == 101:
                                                        return -0.15047133
                                                    if state == 102:
                                                        return 0.106138371
                                                if state == 88:
                                                    return 0.257587016
                                            if state == 78:
                                                state = (
                                                    89
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 1.0106771)
                                                    else 90
                                                )
                                                if state == 89:
                                                    return 0.0842576697
                                                if state == 90:
                                                    return -0.18991746
                        if state == 16:
                            state = 23 if x["magnr_med"] < 22.3322506 else 24
                            if state == 23:
                                state = 33 if x["magnr_med"] < 16.7587509 else 34
                                if state == 33:
                                    return -0.160555512
                                if state == 34:
                                    state = (
                                        49
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.0141874999)
                                        else 50
                                    )
                                    if state == 49:
                                        state = (
                                            63
                                            if x["distpsnr1_med"] < 4.35730457
                                            else 64
                                        )
                                        if state == 63:
                                            state = (
                                                79
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.77635)
                                                else 80
                                            )
                                            if state == 79:
                                                state = (
                                                    91
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.00671291)
                                                    else 92
                                                )
                                                if state == 91:
                                                    state = (
                                                        105
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.7211494)
                                                        else 106
                                                    )
                                                    if state == 105:
                                                        return -0.0675413236
                                                    if state == 106:
                                                        state = (
                                                            113
                                                            if x["neargaia_med"]
                                                            < 25.120039
                                                            else 114
                                                        )
                                                        if state == 113:
                                                            return 0.179440975
                                                        if state == 114:
                                                            return 0.0329223163
                                                if state == 92:
                                                    return -0.240089566
                                            if state == 80:
                                                return -0.207304537
                                        if state == 64:
                                            return 0.150428027
                                    if state == 50:
                                        state = (
                                            65
                                            if x["distpsnr1_med"] < 9.00817108
                                            else 66
                                        )
                                        if state == 65:
                                            state = (
                                                81
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.4805984)
                                                else 82
                                            )
                                            if state == 81:
                                                state = (
                                                    93
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0338888504)
                                                    else 94
                                                )
                                                if state == 93:
                                                    return -0.0716487616
                                                if state == 94:
                                                    state = (
                                                        107
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.6975498)
                                                        else 108
                                                    )
                                                    if state == 107:
                                                        state = (
                                                            115
                                                            if x["neargaia_med"]
                                                            < 2.38972855
                                                            else 116
                                                        )
                                                        if state == 115:
                                                            return -0.00717836991
                                                        if state == 116:
                                                            return 0.272199959
                                                    if state == 108:
                                                        state = (
                                                            117
                                                            if x["neargaia_med"]
                                                            < 51.5619392
                                                            else 118
                                                        )
                                                        if state == 117:
                                                            return 0.155149668
                                                        if state == 118:
                                                            return -0.137786731
                                            if state == 82:
                                                state = (
                                                    95
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.02316546)
                                                    else 96
                                                )
                                                if state == 95:
                                                    state = (
                                                        109
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.5352001)
                                                        else 110
                                                    )
                                                    if state == 109:
                                                        return -0.201402262
                                                    if state == 110:
                                                        return -0.00967144687
                                                if state == 96:
                                                    return 0.125385776
                                        if state == 66:
                                            return 0.307097971
                            if state == 24:
                                state = 35 if x["magnr_med"] < 22.6940002 else 36
                                if state == 35:
                                    return -0.275381416
                                if state == 36:
                                    state = (
                                        51
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.344024003)
                                        else 52
                                    )
                                    if state == 51:
                                        state = (
                                            67
                                            if x["distpsnr1_med"] < 6.70453358
                                            else 68
                                        )
                                        if state == 67:
                                            return 0.0287456475
                                        if state == 68:
                                            return -0.208121404
                                    if state == 52:
                                        state = (
                                            69 if x["distpsnr1_med"] < 12.838953 else 70
                                        )
                                        if state == 69:
                                            state = (
                                                83
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.6687508)
                                                else 84
                                            )
                                            if state == 83:
                                                return -0.109315187
                                            if state == 84:
                                                return 0.26730001
                                        if state == 70:
                                            return 0.0122568728
                    if state == 12:
                        state = 17 if x["neargaia_med"] < 31.4047813 else 18
                        if state == 17:
                            state = 25 if x["magnr_med"] < 22.0267487 else 26
                            if state == 25:
                                return -0.306778938
                            if state == 26:
                                state = 37 if x["magnr_med"] < 22.6022491 else 38
                                if state == 37:
                                    return 0.0403892584
                                if state == 38:
                                    return -0.177729979
                        if state == 18:
                            state = 27 if x["magnr_med"] < 19.6549988 else 28
                            if state == 27:
                                return 0.150673375
                            if state == 28:
                                return -0.0550513901
    elif num_booster == 15:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.873729467)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["col_det"]) or (x["col_det"] < 0.655822754) else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.00137155014) else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.981750011)
                            else 16
                        )
                        if state == 15:
                            return -0.303124636
                        if state == 16:
                            return 0.0146701401
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.69174999)
                            else 18
                        )
                        if state == 17:
                            state = (
                                21
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.258095086)
                                else 22
                            )
                            if state == 21:
                                state = 25 if x["distnr_med"] < 5.51353455 else 26
                                if state == 25:
                                    return -0.125300676
                                if state == 26:
                                    return 0.0690477192
                            if state == 22:
                                state = 27 if x["distnr_med"] < 11.4715662 else 28
                                if state == 27:
                                    state = 33 if x["distnr_med"] < 0.122701108 else 34
                                    if state == 33:
                                        return 0.0701077208
                                    if state == 34:
                                        state = (
                                            43 if x["neargaia_med"] < 11.8054638 else 44
                                        )
                                        if state == 43:
                                            state = (
                                                55
                                                if x["distnr_med"] < 1.99890637
                                                else 56
                                            )
                                            if state == 55:
                                                return -0.262865305
                                            if state == 56:
                                                return 0.0771933869
                                        if state == 44:
                                            return -0.353652984
                                if state == 28:
                                    return 0.117066003
                        if state == 18:
                            state = (
                                23
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.731190503)
                                else 24
                            )
                            if state == 23:
                                state = 29 if x["distnr_med"] < 0.647312045 else 30
                                if state == 29:
                                    state = 35 if x["distnr_med"] < 0.427625775 else 36
                                    if state == 35:
                                        state = (
                                            45 if x["neargaia_med"] < 29.0862751 else 46
                                        )
                                        if state == 45:
                                            state = (
                                                57
                                                if x["distnr_med"] < 0.21513465
                                                else 58
                                            )
                                            if state == 57:
                                                state = (
                                                    69
                                                    if x["magnr_med"] < 17.0534992
                                                    else 70
                                                )
                                                if state == 69:
                                                    return 0.150929332
                                                if state == 70:
                                                    return -0.111374214
                                            if state == 58:
                                                return -0.193332344
                                        if state == 46:
                                            state = (
                                                59
                                                if x["distnr_med"] < 0.382870823
                                                else 60
                                            )
                                            if state == 59:
                                                state = (
                                                    71
                                                    if x["magnr_med"] < 21.573
                                                    else 72
                                                )
                                                if state == 71:
                                                    return -0.122086994
                                                if state == 72:
                                                    return 0.149128675
                                            if state == 60:
                                                return 0.211553007
                                    if state == 36:
                                        return -0.184582233
                                if state == 30:
                                    state = 37 if x["distnr_med"] < 9.34478569 else 38
                                    if state == 37:
                                        state = (
                                            47 if x["neargaia_med"] < 41.6847992 else 48
                                        )
                                        if state == 47:
                                            state = (
                                                61
                                                if x["distnr_med"] < 5.26359272
                                                else 62
                                            )
                                            if state == 61:
                                                state = (
                                                    73
                                                    if x["magnr_med"] < 16.52425
                                                    else 74
                                                )
                                                if state == 73:
                                                    return -0.164627731
                                                if state == 74:
                                                    state = (
                                                        87
                                                        if x["col_det"] < -0.109416962
                                                        else 88
                                                    )
                                                    if state == 87:
                                                        state = (
                                                            101
                                                            if x["neargaia_med"]
                                                            < 6.89260435
                                                            else 102
                                                        )
                                                        if state == 101:
                                                            return -0.167321146
                                                        if state == 102:
                                                            return 0.0305292346
                                                    if state == 88:
                                                        return 0.254667699
                                            if state == 62:
                                                state = (
                                                    75
                                                    if x["magnr_med"] < 20.8922501
                                                    else 76
                                                )
                                                if state == 75:
                                                    return -0.24223499
                                                if state == 76:
                                                    return 0.186816022
                                        if state == 48:
                                            state = (
                                                63
                                                if x["distnr_med"] < 0.954876423
                                                else 64
                                            )
                                            if state == 63:
                                                return -0.0886647031
                                            if state == 64:
                                                state = (
                                                    79
                                                    if x["magnr_med"] < 20.3037491
                                                    else 80
                                                )
                                                if state == 79:
                                                    state = (
                                                        89
                                                        if x["col_det"] < 0.294365883
                                                        else 90
                                                    )
                                                    if state == 89:
                                                        return 0.210063636
                                                    if state == 90:
                                                        state = (
                                                            103
                                                            if x["neargaia_med"]
                                                            < 127.104347
                                                            else 104
                                                        )
                                                        if state == 103:
                                                            return -0.0566744171
                                                        if state == 104:
                                                            return 0.10769967
                                                if state == 80:
                                                    state = (
                                                        91
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.364094734)
                                                        else 92
                                                    )
                                                    if state == 91:
                                                        return -0.111937992
                                                    if state == 92:
                                                        return 0.0494538248
                                    if state == 38:
                                        return -0.169680834
                            if state == 24:
                                state = 31 if x["distnr_med"] < 2.51209402 else 32
                                if state == 31:
                                    state = 39 if x["distnr_med"] < 1.89057672 else 40
                                    if state == 39:
                                        state = (
                                            49
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 63.658287)
                                            else 50
                                        )
                                        if state == 49:
                                            state = (
                                                65
                                                if x["distnr_med"] < 0.318104029
                                                else 66
                                            )
                                            if state == 65:
                                                state = (
                                                    81
                                                    if x["magnr_med"] < 18.8959999
                                                    else 82
                                                )
                                                if state == 81:
                                                    state = (
                                                        93
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.0157594681)
                                                        else 94
                                                    )
                                                    if state == 93:
                                                        return -0.15659909
                                                    if state == 94:
                                                        return 0.092633307
                                                if state == 82:
                                                    return -0.233082756
                                            if state == 66:
                                                state = (
                                                    83
                                                    if x["magnr_med"] < 19.3719997
                                                    else 84
                                                )
                                                if state == 83:
                                                    state = (
                                                        95
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.200656891)
                                                        else 96
                                                    )
                                                    if state == 95:
                                                        state = (
                                                            107
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 9.72846603
                                                            )
                                                            else 108
                                                        )
                                                        if state == 107:
                                                            return -0.0740445033
                                                        if state == 108:
                                                            return 0.0779106319
                                                    if state == 96:
                                                        state = (
                                                            109
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 41.9649811
                                                            )
                                                            else 110
                                                        )
                                                        if state == 109:
                                                            return 0.203597069
                                                        if state == 110:
                                                            return -0.0982049555
                                                if state == 84:
                                                    state = (
                                                        97
                                                        if x["col_det"] < -0.307743073
                                                        else 98
                                                    )
                                                    if state == 97:
                                                        return 0.151988149
                                                    if state == 98:
                                                        return -0.288243234
                                        if state == 50:
                                            return 0.21340023
                                    if state == 40:
                                        return 0.225833088
                                if state == 32:
                                    state = 41 if x["distnr_med"] < 6.78640652 else 42
                                    if state == 41:
                                        state = (
                                            51
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 15.4492884)
                                            else 52
                                        )
                                        if state == 51:
                                            state = (
                                                67
                                                if x["distnr_med"] < 3.12132573
                                                else 68
                                            )
                                            if state == 67:
                                                return -0.193861812
                                            if state == 68:
                                                state = (
                                                    85
                                                    if x["magnr_med"] < 22.3139992
                                                    else 86
                                                )
                                                if state == 85:
                                                    state = (
                                                        99
                                                        if x["col_det"] < -0.102819443
                                                        else 100
                                                    )
                                                    if state == 99:
                                                        return 0.0176748335
                                                    if state == 100:
                                                        return -0.202822104
                                                if state == 86:
                                                    return 0.137408197
                                        if state == 52:
                                            return -0.362589747
                                    if state == 42:
                                        return 0.034390416
                if state == 4:
                    return -0.187468573
            if state == 2:
                state = (
                    5 if np.isnan(x["col_det"]) or (x["col_det"] < 0.202965736) else 6
                )
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.97436905) else 12
                    )
                    if state == 11:
                        return -0.297804713
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.977999985)
                            else 20
                        )
                        if state == 19:
                            return -0.16179888
                        if state == 20:
                            return 0.0565541871
                if state == 6:
                    state = (
                        13 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0230497997) else 14
                    )
                    if state == 13:
                        return 0.0886262581
                    if state == 14:
                        return -0.123340182
    elif num_booster == 16:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 24.747303)
                else 2
            )
            if state == 1:
                state = 3 if x["col_det"] < -0.0222291946 else 4
                if state == 3:
                    state = 7 if x["neargaia_med"] < 10.2537451 else 8
                    if state == 7:
                        return 0.165288478
                    if state == 8:
                        state = 15 if x["neargaia_med"] < 15.0892315 else 16
                        if state == 15:
                            return -0.171119809
                        if state == 16:
                            state = 25 if x["maggaia_med"] < 19.9909878 else 26
                            if state == 25:
                                return 0.0774670839
                            if state == 26:
                                state = (
                                    43
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 10.4213562)
                                    else 44
                                )
                                if state == 43:
                                    state = (
                                        61
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.9148502)
                                        else 62
                                    )
                                    if state == 61:
                                        return 0.169340402
                                    if state == 62:
                                        return -0.129054949
                                if state == 44:
                                    return -0.115999937
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 8.04639721)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 4.61288738)
                            else 18
                        )
                        if state == 17:
                            state = 27 if x["maggaia_med"] < 16.3680305 else 28
                            if state == 27:
                                return -0.222080275
                            if state == 28:
                                state = 45 if x["distpsnr1_med"] < 1.94081187 else 46
                                if state == 45:
                                    state = (
                                        63
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.72295)
                                        else 64
                                    )
                                    if state == 63:
                                        return 0.142270461
                                    if state == 64:
                                        state = (
                                            87
                                            if x["distpsnr1_med"] < 1.51607084
                                            else 88
                                        )
                                        if state == 87:
                                            state = (
                                                111
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.8648224)
                                                else 112
                                            )
                                            if state == 111:
                                                state = (
                                                    135
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.731249988)
                                                    else 136
                                                )
                                                if state == 135:
                                                    return -0.157813549
                                                if state == 136:
                                                    state = (
                                                        151
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 3.01873255
                                                        )
                                                        else 152
                                                    )
                                                    if state == 151:
                                                        state = (
                                                            169
                                                            if x["magnr_med"]
                                                            < 17.425499
                                                            else 170
                                                        )
                                                        if state == 169:
                                                            return -0.139642864
                                                        if state == 170:
                                                            return 0.0631348044
                                                    if state == 152:
                                                        return 0.119011655
                                            if state == 112:
                                                state = (
                                                    137
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.842000008)
                                                    else 138
                                                )
                                                if state == 137:
                                                    return -0.221656933
                                                if state == 138:
                                                    state = (
                                                        153
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 0.0653240979
                                                        )
                                                        else 154
                                                    )
                                                    if state == 153:
                                                        return 0.141961917
                                                    if state == 154:
                                                        return -0.192978501
                                        if state == 88:
                                            return -0.312349737
                                if state == 46:
                                    state = (
                                        65
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.3709507)
                                        else 66
                                    )
                                    if state == 65:
                                        state = (
                                            89
                                            if x["distpsnr1_med"] < 2.62456656
                                            else 90
                                        )
                                        if state == 89:
                                            return 0.15711081
                                        if state == 90:
                                            state = (
                                                113
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.8012505)
                                                else 114
                                            )
                                            if state == 113:
                                                state = (
                                                    139
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.962249994)
                                                    else 140
                                                )
                                                if state == 139:
                                                    state = (
                                                        155
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 3.00205445
                                                        )
                                                        else 156
                                                    )
                                                    if state == 155:
                                                        return -0.144956797
                                                    if state == 156:
                                                        return 0.0546184294
                                                if state == 140:
                                                    return 0.119478039
                                            if state == 114:
                                                state = (
                                                    141
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.780250072)
                                                    else 142
                                                )
                                                if state == 141:
                                                    state = (
                                                        159
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.92981482
                                                        )
                                                        else 160
                                                    )
                                                    if state == 159:
                                                        return -0.129863024
                                                    if state == 160:
                                                        return 0.159603655
                                                if state == 142:
                                                    state = (
                                                        161
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 0.0423726998
                                                        )
                                                        else 162
                                                    )
                                                    if state == 161:
                                                        return 0.010889492
                                                    if state == 162:
                                                        state = (
                                                            171
                                                            if x["magnr_med"]
                                                            < 21.9547501
                                                            else 172
                                                        )
                                                        if state == 171:
                                                            return -0.348455787
                                                        if state == 172:
                                                            return 0.0953593552
                                    if state == 66:
                                        state = (
                                            91
                                            if np.isnan(x["distpsnr1_med"])
                                            or (x["distpsnr1_med"] < 4.99101019)
                                            else 92
                                        )
                                        if state == 91:
                                            state = (
                                                115
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.5250492)
                                                else 116
                                            )
                                            if state == 115:
                                                return 0.25537172
                                            if state == 116:
                                                state = (
                                                    143
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.777750015)
                                                    else 144
                                                )
                                                if state == 143:
                                                    state = (
                                                        163
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 0.0507175997
                                                        )
                                                        else 164
                                                    )
                                                    if state == 163:
                                                        return 0.0562087409
                                                    if state == 164:
                                                        return -0.17454645
                                                if state == 144:
                                                    return 0.150678605
                                        if state == 92:
                                            state = (
                                                117
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.3811989)
                                                else 118
                                            )
                                            if state == 117:
                                                return 0.0976833701
                                            if state == 118:
                                                return -0.112928651
                        if state == 18:
                            return -0.268980056
                    if state == 10:
                        state = 19 if x["neargaia_med"] < 22.4363441 else 20
                        if state == 19:
                            state = 29 if x["maggaia_med"] < 19.1441593 else 30
                            if state == 29:
                                state = 47 if x["distpsnr1_med"] < 6.67664814 else 48
                                if state == 47:
                                    state = (
                                        67
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.27565)
                                        else 68
                                    )
                                    if state == 67:
                                        state = (
                                            93
                                            if x["distpsnr1_med"] < 1.14297509
                                            else 94
                                        )
                                        if state == 93:
                                            return 0.0407018065
                                        if state == 94:
                                            state = (
                                                121
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.8055496)
                                                else 122
                                            )
                                            if state == 121:
                                                state = (
                                                    147
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982749999)
                                                    else 148
                                                )
                                                if state == 147:
                                                    return -0.0980747268
                                                if state == 148:
                                                    return 0.0755214393
                                            if state == 122:
                                                return -0.232512489
                                    if state == 68:
                                        return 0.17114307
                                if state == 48:
                                    state = (
                                        69
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.0335999)
                                        else 70
                                    )
                                    if state == 69:
                                        return -0.0662152842
                                    if state == 70:
                                        state = (
                                            97
                                            if x["distpsnr1_med"] < 8.96192169
                                            else 98
                                        )
                                        if state == 97:
                                            return 0.252468586
                                        if state == 98:
                                            state = (
                                                125
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.8667488)
                                                else 126
                                            )
                                            if state == 125:
                                                return 0.10840369
                                            if state == 126:
                                                state = (
                                                    149
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.796750009)
                                                    else 150
                                                )
                                                if state == 149:
                                                    return -0.133435652
                                                if state == 150:
                                                    state = (
                                                        167
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.43739605
                                                        )
                                                        else 168
                                                    )
                                                    if state == 167:
                                                        state = (
                                                            173
                                                            if x["magnr_med"]
                                                            < 22.7799988
                                                            else 174
                                                        )
                                                        if state == 173:
                                                            return -0.118834212
                                                        if state == 174:
                                                            return 0.0984947085
                                                    if state == 168:
                                                        return 0.0873889104
                            if state == 30:
                                state = 49 if x["distpsnr1_med"] < 7.00626755 else 50
                                if state == 49:
                                    state = (
                                        71
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.357151)
                                        else 72
                                    )
                                    if state == 71:
                                        return 0.0155808311
                                    if state == 72:
                                        return -0.196580261
                                if state == 50:
                                    state = (
                                        73
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.6786499)
                                        else 74
                                    )
                                    if state == 73:
                                        state = (
                                            99
                                            if x["distpsnr1_med"] < 7.39396954
                                            else 100
                                        )
                                        if state == 99:
                                            return 0.138442293
                                        if state == 100:
                                            return -0.195405453
                                    if state == 74:
                                        return 0.108503029
                        if state == 20:
                            state = 31 if x["maggaia_med"] < 19.9959221 else 32
                            if state == 31:
                                state = 51 if x["distpsnr1_med"] < 4.93379593 else 52
                                if state == 51:
                                    state = (
                                        75
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.9720001)
                                        else 76
                                    )
                                    if state == 75:
                                        return -0.0261523649
                                    if state == 76:
                                        return 0.219513714
                                if state == 52:
                                    return -0.150435939
                            if state == 32:
                                return 0.204829514
            if state == 2:
                state = 5 if x["col_det"] < -0.169613838 else 6
                if state == 5:
                    return -0.357830524
                if state == 6:
                    state = 13 if x["neargaia_med"] < 27.5280037 else 14
                    if state == 13:
                        state = 21 if x["neargaia_med"] < 26.3804588 else 22
                        if state == 21:
                            return -0.0167692695
                        if state == 22:
                            state = 35 if x["maggaia_med"] < 20.0357399 else 36
                            if state == 35:
                                return -0.317115039
                            if state == 36:
                                return 0.0317357108
                    if state == 14:
                        state = 23 if x["neargaia_med"] < 33.9673157 else 24
                        if state == 23:
                            state = 37 if x["maggaia_med"] < 19.10009 else 38
                            if state == 37:
                                return -0.0871213675
                            if state == 38:
                                state = 55 if x["distpsnr1_med"] < 2.40080881 else 56
                                if state == 55:
                                    return -0.0291184746
                                if state == 56:
                                    return 0.242042035
                        if state == 24:
                            state = 39 if x["maggaia_med"] < 17.7177315 else 40
                            if state == 39:
                                state = 57 if x["distpsnr1_med"] < 2.2735281 else 58
                                if state == 57:
                                    return 0.158297658
                                if state == 58:
                                    state = (
                                        81
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.6070499)
                                        else 82
                                    )
                                    if state == 81:
                                        return 0.067034319
                                    if state == 82:
                                        state = (
                                            105
                                            if np.isnan(x["distpsnr1_med"])
                                            or (x["distpsnr1_med"] < 9.54959297)
                                            else 106
                                        )
                                        if state == 105:
                                            return -0.194742963
                                        if state == 106:
                                            state = (
                                                131
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.9838486)
                                                else 132
                                            )
                                            if state == 131:
                                                return -0.13283208
                                            if state == 132:
                                                return 0.0458289459
                            if state == 40:
                                state = 59 if x["distpsnr1_med"] < 0.274308443 else 60
                                if state == 59:
                                    return 0.0647627711
                                if state == 60:
                                    state = (
                                        83
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.6921005)
                                        else 84
                                    )
                                    if state == 83:
                                        return -0.243147433
                                    if state == 84:
                                        state = (
                                            107
                                            if x["distpsnr1_med"] < 6.72001505
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                133
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.1356888)
                                                else 134
                                            )
                                            if state == 133:
                                                return 0.106068388
                                            if state == 134:
                                                return -0.088073656
                                        if state == 108:
                                            return -0.152742803
    elif num_booster == 17:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.3973007) else 2
            if state == 1:
                state = 3 if x["distnr_med"] < 0.283298135 else 4
                if state == 3:
                    return 0.0931645781
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.2481995)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 16.7905502)
                            else 14
                        )
                        if state == 13:
                            return -0.0796016827
                        if state == 14:
                            state = (
                                23
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0325637013)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    39
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.981249988)
                                    else 40
                                )
                                if state == 39:
                                    return -0.125300765
                                if state == 40:
                                    return 0.0404623784
                            if state == 24:
                                return -0.314511597
                    if state == 8:
                        return -0.0418896712
            if state == 2:
                state = 5 if x["distnr_med"] < 3.43950796 else 6
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4103508)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.9358749)
                            else 16
                        )
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.02119207)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    41
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.634250045)
                                    else 42
                                )
                                if state == 41:
                                    state = (
                                        55 if x["distpsnr1_med"] < 2.39251852 else 56
                                    )
                                    if state == 55:
                                        return -0.194772661
                                    if state == 56:
                                        return 0.124813274
                                if state == 42:
                                    state = (
                                        57 if x["distpsnr1_med"] < 0.0862373039 else 58
                                    )
                                    if state == 57:
                                        return -0.129569352
                                    if state == 58:
                                        state = (
                                            71
                                            if x["distpsnr1_med"] < 1.37765539
                                            else 72
                                        )
                                        if state == 71:
                                            state = (
                                                81
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.547807992)
                                                else 82
                                            )
                                            if state == 81:
                                                state = (
                                                    89
                                                    if x["distnr_med"] < 1.37838149
                                                    else 90
                                                )
                                                if state == 89:
                                                    state = (
                                                        95
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.213113785)
                                                        else 96
                                                    )
                                                    if state == 95:
                                                        state = (
                                                            103
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.632499933
                                                            )
                                                            else 104
                                                        )
                                                        if state == 103:
                                                            return 0.0544847138
                                                        if state == 104:
                                                            return 0.247415558
                                                    if state == 96:
                                                        return -0.043570634
                                                if state == 90:
                                                    state = (
                                                        97
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.269873619)
                                                        else 98
                                                    )
                                                    if state == 97:
                                                        return 0.0735328719
                                                    if state == 98:
                                                        return -0.177142099
                                            if state == 82:
                                                return -0.125539765
                                        if state == 72:
                                            state = (
                                                83
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.533294499)
                                                else 84
                                            )
                                            if state == 83:
                                                state = (
                                                    91
                                                    if x["distnr_med"] < 0.914159298
                                                    else 92
                                                )
                                                if state == 91:
                                                    state = (
                                                        99
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.234237671)
                                                        else 100
                                                    )
                                                    if state == 99:
                                                        return -0.128080428
                                                    if state == 100:
                                                        state = (
                                                            107
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.744047761
                                                            )
                                                            else 108
                                                        )
                                                        if state == 107:
                                                            return 0.134190828
                                                        if state == 108:
                                                            return -0.0505664125
                                                if state == 92:
                                                    return 0.302292794
                                            if state == 84:
                                                return 0.0391435288
                            if state == 26:
                                state = (
                                    43
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.979499996)
                                    else 44
                                )
                                if state == 43:
                                    state = (
                                        59 if x["distpsnr1_med"] < 2.53987765 else 60
                                    )
                                    if state == 59:
                                        state = (
                                            73
                                            if x["distpsnr1_med"] < 2.39943027
                                            else 74
                                        )
                                        if state == 73:
                                            return -0.120401002
                                        if state == 74:
                                            return 0.159630984
                                    if state == 60:
                                        return -0.260210782
                                if state == 44:
                                    return 0.156035647
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 1.03480911)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    45
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.800500035)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        61 if x["distpsnr1_med"] < 1.32661366 else 62
                                    )
                                    if state == 61:
                                        return -0.0410220884
                                    if state == 62:
                                        return 0.177124172
                                if state == 46:
                                    state = (
                                        63 if x["distpsnr1_med"] < 2.36746454 else 64
                                    )
                                    if state == 63:
                                        state = (
                                            77 if x["distpsnr1_med"] < 1.2988503 else 78
                                        )
                                        if state == 77:
                                            return -0.138542011
                                        if state == 78:
                                            return 0.187108085
                                    if state == 64:
                                        return -0.228862137
                            if state == 28:
                                return -0.283775836
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.0146484)
                            else 18
                        )
                        if state == 17:
                            state = (
                                29
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.41610527)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    47
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.749499977)
                                    else 48
                                )
                                if state == 47:
                                    return 0.0563091412
                                if state == 48:
                                    return -0.156477198
                            if state == 30:
                                state = (
                                    49
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.858749986)
                                    else 50
                                )
                                if state == 49:
                                    return 0.205196083
                                if state == 50:
                                    return -0.0324180797
                        if state == 18:
                            state = (
                                31
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.00251734979)
                                else 32
                            )
                            if state == 31:
                                return 0.119096726
                            if state == 32:
                                return -0.334876895
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.3282013)
                        else 12
                    )
                    if state == 11:
                        return -0.383292466
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6987076)
                            else 20
                        )
                        if state == 19:
                            state = (
                                33
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0104918508)
                                else 34
                            )
                            if state == 33:
                                return -0.239827082
                            if state == 34:
                                state = (
                                    51
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.730499983)
                                    else 52
                                )
                                if state == 51:
                                    return 0.0125063462
                                if state == 52:
                                    return 0.334853709
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0751099512)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    53
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.958500028)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        67
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 6.78743792)
                                        else 68
                                    )
                                    if state == 67:
                                        return -0.35037306
                                    if state == 68:
                                        state = (
                                            79
                                            if x["distpsnr1_med"] < 12.8561249
                                            else 80
                                        )
                                        if state == 79:
                                            state = (
                                                87
                                                if x["sgscore1_med"] < 0.648082972
                                                else 88
                                            )
                                            if state == 87:
                                                state = (
                                                    93
                                                    if x["distnr_med"] < 6.37311077
                                                    else 94
                                                )
                                                if state == 93:
                                                    return 0.192131028
                                                if state == 94:
                                                    state = (
                                                        101
                                                        if x["col_det"] < 0.22951889
                                                        else 102
                                                    )
                                                    if state == 101:
                                                        return 0.168946728
                                                    if state == 102:
                                                        return -0.124743685
                                            if state == 88:
                                                return -0.0556199998
                                        if state == 80:
                                            return -0.224334717
                                if state == 54:
                                    return 0.126245633
                            if state == 36:
                                return -0.293708444
    elif num_booster == 18:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0129282493) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.8864117) else 4
                )
                if state == 3:
                    return -0.0185907967
                if state == 4:
                    return -0.222379893
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8389549) else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.8145833)
                        else 10
                    )
                    if state == 9:
                        state = 13 if x["distnr_med"] < 1.86665654 else 14
                        if state == 13:
                            state = 21 if x["distnr_med"] < 0.839460969 else 22
                            if state == 21:
                                return 0.161692023
                            if state == 22:
                                state = (
                                    35
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.85479164)
                                    else 36
                                )
                                if state == 35:
                                    return -0.14566727
                                if state == 36:
                                    state = (
                                        51
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.3240509)
                                        else 52
                                    )
                                    if state == 51:
                                        state = (
                                            67
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 2.97726846)
                                            else 68
                                        )
                                        if state == 67:
                                            return 0.044026766
                                        if state == 68:
                                            return -0.129559934
                                    if state == 52:
                                        return 0.117563896
                        if state == 14:
                            return 0.295607269
                    if state == 10:
                        state = 15 if x["distnr_med"] < 0.645311594 else 16
                        if state == 15:
                            state = 23 if x["distnr_med"] < 0.361729145 else 24
                            if state == 23:
                                state = (
                                    37
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0646990538)
                                    else 38
                                )
                                if state == 37:
                                    state = (
                                        53
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.6641502)
                                        else 54
                                    )
                                    if state == 53:
                                        return 0.196542069
                                    if state == 54:
                                        return -0.151129708
                                if state == 38:
                                    return -0.0683881342
                            if state == 24:
                                return -0.219948962
                        if state == 16:
                            state = 25 if x["distnr_med"] < 4.50911522 else 26
                            if state == 25:
                                state = (
                                    39
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0614410006)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        55
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.0549011)
                                        else 56
                                    )
                                    if state == 55:
                                        state = (
                                            69
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 0.0424999967)
                                            else 70
                                        )
                                        if state == 69:
                                            state = (
                                                83
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981750011)
                                                else 84
                                            )
                                            if state == 83:
                                                return -0.13517952
                                            if state == 84:
                                                return 0.0938738137
                                        if state == 70:
                                            return 0.156736821
                                    if state == 56:
                                        state = (
                                            71
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 0.028333351)
                                            else 72
                                        )
                                        if state == 71:
                                            return 0.0999730751
                                        if state == 72:
                                            state = (
                                                85
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.986750007)
                                                else 86
                                            )
                                            if state == 85:
                                                return -0.268622607
                                            if state == 86:
                                                return 0.100129932
                                if state == 40:
                                    state = (
                                        57
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.6546001)
                                        else 58
                                    )
                                    if state == 57:
                                        state = (
                                            73
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 3.03552103)
                                            else 74
                                        )
                                        if state == 73:
                                            state = (
                                                87
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.894999981)
                                                else 88
                                            )
                                            if state == 87:
                                                return -0.206380263
                                            if state == 88:
                                                state = (
                                                    95
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.8986516)
                                                    else 96
                                                )
                                                if state == 95:
                                                    return -0.0262971055
                                                if state == 96:
                                                    state = (
                                                        99
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 16.7838707)
                                                        else 100
                                                    )
                                                    if state == 99:
                                                        return -0.0221730918
                                                    if state == 100:
                                                        return 0.255197614
                                        if state == 74:
                                            return -0.118088543
                                    if state == 58:
                                        return 0.298663884
                            if state == 26:
                                state = (
                                    41
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0477256998)
                                    else 42
                                )
                                if state == 41:
                                    state = (
                                        59
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.1309662)
                                        else 60
                                    )
                                    if state == 59:
                                        return -0.103699699
                                    if state == 60:
                                        return 0.125719741
                                if state == 42:
                                    state = (
                                        61
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.3282013)
                                        else 62
                                    )
                                    if state == 61:
                                        return -0.199155375
                                    if state == 62:
                                        state = (
                                            75
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 2.95733213)
                                            else 76
                                        )
                                        if state == 75:
                                            return -0.106089331
                                        if state == 76:
                                            return 0.157836094
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.8249073)
                        else 12
                    )
                    if state == 11:
                        state = 17 if x["distnr_med"] < 4.73093414 else 18
                        if state == 17:
                            return -0.29122588
                        if state == 18:
                            state = 27 if x["distnr_med"] < 4.83563805 else 28
                            if state == 27:
                                return 0.107002236
                            if state == 28:
                                return -0.18025969
                    if state == 12:
                        state = 19 if x["distnr_med"] < 6.26584625 else 20
                        if state == 19:
                            state = 29 if x["distnr_med"] < 1.0464623 else 30
                            if state == 29:
                                state = (
                                    43
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.04050925)
                                    else 44
                                )
                                if state == 43:
                                    return -0.120025255
                                if state == 44:
                                    state = (
                                        63
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.0858879)
                                        else 64
                                    )
                                    if state == 63:
                                        return 0.12927705
                                    if state == 64:
                                        state = (
                                            79
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 0.0417881496)
                                            else 80
                                        )
                                        if state == 79:
                                            return 0.155499801
                                        if state == 80:
                                            return -0.0763119757
                            if state == 30:
                                state = (
                                    45
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0376388989)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        65
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.3526497)
                                        else 66
                                    )
                                    if state == 65:
                                        state = (
                                            81
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 0.0205902494)
                                            else 82
                                        )
                                        if state == 81:
                                            return -0.0259510167
                                        if state == 82:
                                            state = (
                                                91
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.792000055)
                                                else 92
                                            )
                                            if state == 91:
                                                return 0.206028119
                                            if state == 92:
                                                state = (
                                                    97
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.9484663)
                                                    else 98
                                                )
                                                if state == 97:
                                                    return 0.0920196846
                                                if state == 98:
                                                    return -0.0852570608
                                    if state == 66:
                                        return -0.105174556
                                if state == 46:
                                    return -0.222323045
                        if state == 20:
                            state = 31 if x["distnr_med"] < 6.51303959 else 32
                            if state == 31:
                                return 0.15053457
                            if state == 32:
                                state = (
                                    47
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0166261494)
                                    else 48
                                )
                                if state == 47:
                                    return 0.15285404
                                if state == 48:
                                    return -0.112970859
    elif num_booster == 19:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.00137155014) else 2
            if state == 1:
                return -0.221684396
            if state == 2:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.97509837) else 4
                if state == 3:
                    state = 5 if x["magnr_med"] < 20.3037491 else 6
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.4773617)
                            else 10
                        )
                        if state == 9:
                            state = (
                                17
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.9757061)
                                else 18
                            )
                            if state == 17:
                                state = (
                                    29
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.0028858)
                                    else 30
                                )
                                if state == 29:
                                    state = 45 if x["magnr_med"] < 18.3269997 else 46
                                    if state == 45:
                                        state = (
                                            61 if x["distnr_med"] < 0.944565713 else 62
                                        )
                                        if state == 61:
                                            return 0.0491646007
                                        if state == 62:
                                            return -0.311108321
                                    if state == 46:
                                        return 0.172846526
                                if state == 30:
                                    state = 47 if x["magnr_med"] < 19.2405014 else 48
                                    if state == 47:
                                        state = (
                                            63 if x["distnr_med"] < 1.32205856 else 64
                                        )
                                        if state == 63:
                                            state = (
                                                75
                                                if x["distnr_med"] < 1.05953538
                                                else 76
                                            )
                                            if state == 75:
                                                state = (
                                                    91
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.744381)
                                                    else 92
                                                )
                                                if state == 91:
                                                    state = (
                                                        111
                                                        if x["maggaia_med"] < 17.7179337
                                                        else 112
                                                    )
                                                    if state == 111:
                                                        state = (
                                                            119
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 0.531365752)
                                                            else 120
                                                        )
                                                        if state == 119:
                                                            return -0.0990547761
                                                        if state == 120:
                                                            return 0.1460917
                                                    if state == 112:
                                                        return 0.212119609
                                                if state == 92:
                                                    return -0.172336146
                                            if state == 76:
                                                return -0.116953343
                                        if state == 64:
                                            state = (
                                                77
                                                if x["distnr_med"] < 3.68479061
                                                else 78
                                            )
                                            if state == 77:
                                                state = (
                                                    95
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 20.0301208)
                                                    else 96
                                                )
                                                if state == 95:
                                                    return 0.256797522
                                                if state == 96:
                                                    state = (
                                                        113
                                                        if x["maggaia_med"] < 19.1591167
                                                        else 114
                                                    )
                                                    if state == 113:
                                                        return 0.0959125832
                                                    if state == 114:
                                                        return -0.114085212
                                            if state == 78:
                                                state = (
                                                    97
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.6476784)
                                                    else 98
                                                )
                                                if state == 97:
                                                    return 0.171124473
                                                if state == 98:
                                                    return -0.18475379
                                    if state == 48:
                                        return 0.281781763
                            if state == 18:
                                state = (
                                    31
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 20.106205)
                                    else 32
                                )
                                if state == 31:
                                    state = 49 if x["magnr_med"] < 18.9220009 else 50
                                    if state == 49:
                                        state = (
                                            65 if x["distnr_med"] < 1.18646264 else 66
                                        )
                                        if state == 65:
                                            return -0.15542689
                                        if state == 66:
                                            state = (
                                                81
                                                if x["distnr_med"] < 1.19991624
                                                else 82
                                            )
                                            if state == 81:
                                                return 0.0997188613
                                            if state == 82:
                                                state = (
                                                    101
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.5474777)
                                                    else 102
                                                )
                                                if state == 101:
                                                    return 0.0764001459
                                                if state == 102:
                                                    return -0.125658318
                                    if state == 50:
                                        return 0.206814528
                                if state == 32:
                                    return -0.204287365
                        if state == 10:
                            return -0.23100026
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1090336)
                            else 12
                        )
                        if state == 11:
                            state = (
                                19
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.87641191)
                                else 20
                            )
                            if state == 19:
                                return 0.0831014886
                            if state == 20:
                                state = (
                                    35
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.8162766)
                                    else 36
                                )
                                if state == 35:
                                    state = 51 if x["magnr_med"] < 22.5662498 else 52
                                    if state == 51:
                                        return -0.329857051
                                    if state == 52:
                                        return 0.0101101873
                                if state == 36:
                                    return -0.0407798216
                        if state == 12:
                            state = (
                                21
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.97534132)
                                else 22
                            )
                            if state == 21:
                                state = (
                                    37
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 20.6436501)
                                    else 38
                                )
                                if state == 37:
                                    state = 53 if x["magnr_med"] < 22.6412506 else 54
                                    if state == 53:
                                        state = (
                                            67 if x["distnr_med"] < 0.711632729 else 68
                                        )
                                        if state == 67:
                                            state = (
                                                83
                                                if x["distnr_med"] < 0.454772294
                                                else 84
                                            )
                                            if state == 83:
                                                return -0.0894404203
                                            if state == 84:
                                                return 0.160558328
                                        if state == 68:
                                            state = (
                                                85
                                                if x["distnr_med"] < 4.71101141
                                                else 86
                                            )
                                            if state == 85:
                                                state = (
                                                    105
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.822052)
                                                    else 106
                                                )
                                                if state == 105:
                                                    return 0.0461676195
                                                if state == 106:
                                                    state = (
                                                        115
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 19.1715508
                                                        )
                                                        else 116
                                                    )
                                                    if state == 115:
                                                        return -0.290724158
                                                    if state == 116:
                                                        return 0.0625318214
                                            if state == 86:
                                                state = (
                                                    107
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 20.1118431)
                                                    else 108
                                                )
                                                if state == 107:
                                                    return -0.0885866359
                                                if state == 108:
                                                    return 0.117404923
                                    if state == 54:
                                        return -0.236613438
                                if state == 38:
                                    return 0.0637401715
                            if state == 22:
                                state = (
                                    39
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 20.0578136)
                                    else 40
                                )
                                if state == 39:
                                    state = 55 if x["magnr_med"] < 22.2767487 else 56
                                    if state == 55:
                                        return 0.217737138
                                    if state == 56:
                                        state = (
                                            69 if x["distnr_med"] < 3.47758412 else 70
                                        )
                                        if state == 69:
                                            return -0.0789207891
                                        if state == 70:
                                            return 0.117530666
                                if state == 40:
                                    state = 57 if x["magnr_med"] < 22.3134995 else 58
                                    if state == 57:
                                        return -0.123094097
                                    if state == 58:
                                        return 0.0817550346
                if state == 4:
                    state = 7 if x["magnr_med"] < 20.5212517 else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.521944)
                            else 14
                        )
                        if state == 13:
                            state = (
                                23
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.914184093)
                                else 24
                            )
                            if state == 23:
                                return 0.189442128
                            if state == 24:
                                state = (
                                    41
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.0734596)
                                    else 42
                                )
                                if state == 41:
                                    return -0.109617405
                                if state == 42:
                                    state = 59 if x["magnr_med"] < 18.1697502 else 60
                                    if state == 59:
                                        state = (
                                            71 if x["distnr_med"] < 0.643134892 else 72
                                        )
                                        if state == 71:
                                            return -0.151581779
                                        if state == 72:
                                            state = (
                                                87
                                                if x["distnr_med"] < 0.657836199
                                                else 88
                                            )
                                            if state == 87:
                                                return 0.102004163
                                            if state == 88:
                                                return -0.092014499
                                    if state == 60:
                                        return 0.140413254
                        if state == 14:
                            return -0.281567007
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7266846)
                            else 16
                        )
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.91226268)
                                else 28
                            )
                            if state == 27:
                                return -0.0346012898
                            if state == 28:
                                return 0.170558542
                        if state == 16:
                            return -0.201552212
    elif num_booster == 20:
        state = 0
        if state == 0:
            state = 1 if x["distnr_med"] < 4.83447599 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.956738472)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.3264008)
                        else 8
                    )
                    if state == 7:
                        return -0.168621898
                    if state == 8:
                        state = 13 if x["col_det"] < -0.430595398 else 14
                        if state == 13:
                            return -0.168935567
                        if state == 14:
                            state = 23 if x["magnr_med"] < 16.5545006 else 24
                            if state == 23:
                                return -0.208310708
                            if state == 24:
                                state = (
                                    35
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.5250492)
                                    else 36
                                )
                                if state == 35:
                                    state = 39 if x["magnr_med"] < 19.0865002 else 40
                                    if state == 39:
                                        state = (
                                            45
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < 0.0592536926)
                                            else 46
                                        )
                                        if state == 45:
                                            state = (
                                                51
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.91157389)
                                                else 52
                                            )
                                            if state == 51:
                                                state = (
                                                    57
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0327199027)
                                                    else 58
                                                )
                                                if state == 57:
                                                    return -0.243339822
                                                if state == 58:
                                                    state = (
                                                        67
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.0308125019
                                                        )
                                                        else 68
                                                    )
                                                    if state == 67:
                                                        state = (
                                                            79
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.7087631
                                                            )
                                                            else 80
                                                        )
                                                        if state == 79:
                                                            return 0.0813378841
                                                        if state == 80:
                                                            return -0.323233247
                                                    if state == 68:
                                                        state = (
                                                            81
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.9869747
                                                            )
                                                            else 82
                                                        )
                                                        if state == 81:
                                                            return -0.140368879
                                                        if state == 82:
                                                            return 0.147924677
                                            if state == 52:
                                                state = (
                                                    59
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.96220493)
                                                    else 60
                                                )
                                                if state == 59:
                                                    return 0.215130791
                                                if state == 60:
                                                    state = (
                                                        69
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.0221041497
                                                        )
                                                        else 70
                                                    )
                                                    if state == 69:
                                                        return -0.127453372
                                                    if state == 70:
                                                        state = (
                                                            83
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.4501915
                                                            )
                                                            else 84
                                                        )
                                                        if state == 83:
                                                            return 0.144077703
                                                        if state == 84:
                                                            return -0.018250173
                                        if state == 46:
                                            return 0.180411667
                                    if state == 40:
                                        state = (
                                            47
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < 0.478796959)
                                            else 48
                                        )
                                        if state == 47:
                                            state = (
                                                53
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.96062493)
                                                else 54
                                            )
                                            if state == 53:
                                                state = (
                                                    61
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.95615149)
                                                    else 62
                                                )
                                                if state == 61:
                                                    state = (
                                                        71
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.0201250017
                                                        )
                                                        else 72
                                                    )
                                                    if state == 71:
                                                        state = (
                                                            85
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.4008865
                                                            )
                                                            else 86
                                                        )
                                                        if state == 85:
                                                            return -0.119673871
                                                        if state == 86:
                                                            return 0.20390527
                                                    if state == 72:
                                                        state = (
                                                            87
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.3881187
                                                            )
                                                            else 88
                                                        )
                                                        if state == 87:
                                                            return 0.135018706
                                                        if state == 88:
                                                            return -0.0641628131
                                                if state == 62:
                                                    return -0.134608403
                                            if state == 54:
                                                state = (
                                                    63
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.99909711)
                                                    else 64
                                                )
                                                if state == 63:
                                                    return 0.225784302
                                                if state == 64:
                                                    state = (
                                                        75
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.0225833002
                                                        )
                                                        else 76
                                                    )
                                                    if state == 75:
                                                        return 0.125154838
                                                    if state == 76:
                                                        state = (
                                                            89
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.5109386
                                                            )
                                                            else 90
                                                        )
                                                        if state == 89:
                                                            return 0.105171576
                                                        if state == 90:
                                                            return -0.136590615
                                        if state == 48:
                                            return -0.153459355
                                if state == 36:
                                    state = 41 if x["magnr_med"] < 18.7000008 else 42
                                    if state == 41:
                                        return 0.149572879
                                    if state == 42:
                                        state = 49 if x["col_det"] < 1.07964134 else 50
                                        if state == 49:
                                            return -0.189959466
                                        if state == 50:
                                            state = (
                                                55
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.03097224)
                                                else 56
                                            )
                                            if state == 55:
                                                return 0.025354119
                                            if state == 56:
                                                return -0.13978
                if state == 4:
                    return -0.198802233
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.500625014 else 6
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7616501)
                        else 10
                    )
                    if state == 9:
                        state = 15 if x["col_det"] < 0.212258339 else 16
                        if state == 15:
                            return 0.0770823807
                        if state == 16:
                            return -0.231277317
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.02942276)
                            else 18
                        )
                        if state == 17:
                            state = 27 if x["magnr_med"] < 19.0004997 else 28
                            if state == 27:
                                return -0.117469519
                            if state == 28:
                                state = (
                                    37
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.3260002)
                                    else 38
                                )
                                if state == 37:
                                    return 0.183909684
                                if state == 38:
                                    return -0.0202047378
                        if state == 18:
                            state = 29 if x["magnr_med"] < 22.0087509 else 30
                            if state == 29:
                                return 0.0594463758
                            if state == 30:
                                return -0.121187598
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.3282013)
                        else 12
                    )
                    if state == 11:
                        return -0.38062641
                    if state == 12:
                        state = 19 if x["col_det"] < 0.233449936 else 20
                        if state == 19:
                            return 0.0985422507
                        if state == 20:
                            state = 33 if x["magnr_med"] < 19.5869999 else 34
                            if state == 33:
                                return 0.0869496316
                            if state == 34:
                                return -0.207193166
    elif num_booster == 21:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.04114585) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.796750009)
                    else 4
                )
                if state == 3:
                    state = 7 if x["col_det"] < 0.0544061661 else 8
                    if state == 7:
                        return -0.133424431
                    if state == 8:
                        state = 13 if x["magnr_med"] < 22.3322506 else 14
                        if state == 13:
                            state = (
                                23
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.7521992)
                                else 24
                            )
                            if state == 23:
                                return -0.107862592
                            if state == 24:
                                state = (
                                    33
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.360129356)
                                    else 34
                                )
                                if state == 33:
                                    return 0.182316467
                                if state == 34:
                                    return -0.0297848061
                        if state == 14:
                            return -0.148981586
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["col_det"]) or (x["col_det"] < -0.0301399231)
                        else 10
                    )
                    if state == 9:
                        state = 15 if x["magnr_med"] < 21.14575 else 16
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.7685337)
                                else 26
                            )
                            if state == 25:
                                return -0.192712158
                            if state == 26:
                                state = 37 if x["col_det"] < -0.0852718353 else 38
                                if state == 37:
                                    return 0.0744636282
                                if state == 38:
                                    state = (
                                        51
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.2622414)
                                        else 52
                                    )
                                    if state == 51:
                                        return 0.0860269666
                                    if state == 52:
                                        return -0.125603974
                        if state == 16:
                            return -0.313396811
                    if state == 10:
                        state = 17 if x["magnr_med"] < 18.3769989 else 18
                        if state == 17:
                            return 0.0718515068
                        if state == 18:
                            state = (
                                27
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.8917351)
                                else 28
                            )
                            if state == 27:
                                state = 39 if x["col_det"] < 0.215722084 else 40
                                if state == 39:
                                    return 0.0990877002
                                if state == 40:
                                    return -0.123634122
                            if state == 28:
                                return -0.126497865
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.630250037)
                    else 6
                )
                if state == 5:
                    return -0.230775699
                if state == 6:
                    state = 11 if x["col_det"] < 0.131872177 else 12
                    if state == 11:
                        state = 19 if x["magnr_med"] < 20.7550011 else 20
                        if state == 19:
                            return 0.198610768
                        if state == 20:
                            state = (
                                29
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 20.0211029)
                                else 30
                            )
                            if state == 29:
                                state = 43 if x["col_det"] < -0.21169281 else 44
                                if state == 43:
                                    return 0.0839954987
                                if state == 44:
                                    state = (
                                        57
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.6964321)
                                        else 58
                                    )
                                    if state == 57:
                                        state = (
                                            63
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.0041504)
                                            else 64
                                        )
                                        if state == 63:
                                            return -0.120862238
                                        if state == 64:
                                            return 0.0795592964
                                    if state == 58:
                                        return -0.160507277
                            if state == 30:
                                return 0.149771377
                    if state == 12:
                        state = 21 if x["magnr_med"] < 15.5297499 else 22
                        if state == 21:
                            return -0.193775237
                        if state == 22:
                            state = (
                                31
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.7403603)
                                else 32
                            )
                            if state == 31:
                                state = 45 if x["col_det"] < 1.1651783 else 46
                                if state == 45:
                                    state = (
                                        59
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.5223007)
                                        else 60
                                    )
                                    if state == 59:
                                        return -0.112695552
                                    if state == 60:
                                        return 0.0575839654
                                if state == 46:
                                    state = (
                                        61
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 16.7838707)
                                        else 62
                                    )
                                    if state == 61:
                                        return -0.0570692532
                                    if state == 62:
                                        state = (
                                            67
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.6664734)
                                            else 68
                                        )
                                        if state == 67:
                                            state = (
                                                71
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.819285631)
                                                else 72
                                            )
                                            if state == 71:
                                                state = (
                                                    73
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0236226507)
                                                    else 74
                                                )
                                                if state == 73:
                                                    return -0.0275907628
                                                if state == 74:
                                                    state = (
                                                        77
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.488333255)
                                                        else 78
                                                    )
                                                    if state == 77:
                                                        state = (
                                                            81
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.879750013
                                                            )
                                                            else 82
                                                        )
                                                        if state == 81:
                                                            return 0.111300647
                                                        if state == 82:
                                                            return -0.0624714829
                                                    if state == 78:
                                                        return 0.271586537
                                            if state == 72:
                                                state = (
                                                    75
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0227604508)
                                                    else 76
                                                )
                                                if state == 75:
                                                    return 0.140882194
                                                if state == 76:
                                                    state = (
                                                        79
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.888214111)
                                                        else 80
                                                    )
                                                    if state == 79:
                                                        state = (
                                                            83
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.93324995
                                                            )
                                                            else 84
                                                        )
                                                        if state == 83:
                                                            return 0.0867896527
                                                        if state == 84:
                                                            return -0.269543022
                                                    if state == 80:
                                                        state = (
                                                            85
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.978500009
                                                            )
                                                            else 86
                                                        )
                                                        if state == 85:
                                                            return 0.135472849
                                                        if state == 86:
                                                            return -0.0927039385
                                        if state == 68:
                                            return 0.0160714891
                            if state == 32:
                                state = (
                                    47
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.277019501)
                                    else 48
                                )
                                if state == 47:
                                    return -0.305983394
                                if state == 48:
                                    return 0.14633061
    elif num_booster == 22:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 7.11181116 else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.9518471) else 4
                )
                if state == 3:
                    return -0.188001245
                if state == 4:
                    state = 7 if x["maggaia_med"] < 18.8394794 else 8
                    if state == 7:
                        state = 13 if x["magnr_med"] < 17.5214996 else 14
                        if state == 13:
                            state = (
                                25
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.0250397)
                                else 26
                            )
                            if state == 25:
                                return 0.0426266342
                            if state == 26:
                                return -0.140847519
                        if state == 14:
                            state = (
                                27
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.9557343)
                                else 28
                            )
                            if state == 27:
                                return 0.158448204
                            if state == 28:
                                return -0.128204077
                    if state == 8:
                        state = 15 if x["magnr_med"] < 20.8800011 else 16
                        if state == 15:
                            return -0.153848857
                        if state == 16:
                            return 0.0484779328
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8197956) else 6
                )
                if state == 5:
                    state = 9 if x["maggaia_med"] < 20.6145039 else 10
                    if state == 9:
                        state = 17 if x["magnr_med"] < 17.3167496 else 18
                        if state == 17:
                            state = (
                                29
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.319458)
                                else 30
                            )
                            if state == 29:
                                return -0.160018429
                            if state == 30:
                                return 0.0638946667
                        if state == 18:
                            state = (
                                31
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.1968307)
                                else 32
                            )
                            if state == 31:
                                return 0.0202173069
                            if state == 32:
                                state = (
                                    47
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.8012505)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        59
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.6892891)
                                        else 60
                                    )
                                    if state == 59:
                                        state = (
                                            69
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.1837006)
                                            else 70
                                        )
                                        if state == 69:
                                            state = (
                                                77
                                                if x["maggaia_med"] < 15.985651
                                                else 78
                                            )
                                            if state == 77:
                                                return -0.0136812134
                                            if state == 78:
                                                state = (
                                                    85
                                                    if x["neargaia_med"] < 11.7040405
                                                    else 86
                                                )
                                                if state == 85:
                                                    return 0.00841246359
                                                if state == 86:
                                                    state = (
                                                        93
                                                        if x["distnr_med"] < 3.1669023
                                                        else 94
                                                    )
                                                    if state == 93:
                                                        return 0.206611484
                                                    if state == 94:
                                                        return -0.0795272067
                                        if state == 70:
                                            state = (
                                                79
                                                if x["maggaia_med"] < 18.5660973
                                                else 80
                                            )
                                            if state == 79:
                                                return 0.0733410046
                                            if state == 80:
                                                state = (
                                                    89
                                                    if x["neargaia_med"] < 29.9958344
                                                    else 90
                                                )
                                                if state == 89:
                                                    state = (
                                                        95
                                                        if x["distnr_med"] < 2.38169384
                                                        else 96
                                                    )
                                                    if state == 95:
                                                        return 0.0793423057
                                                    if state == 96:
                                                        return -0.087308839
                                                if state == 90:
                                                    return -0.114809804
                                    if state == 60:
                                        return -0.24289979
                                if state == 48:
                                    return 0.269987792
                    if state == 10:
                        state = 19 if x["magnr_med"] < 21.2177505 else 20
                        if state == 19:
                            state = (
                                33
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.3991013)
                                else 34
                            )
                            if state == 33:
                                return -0.0631036386
                            if state == 34:
                                return 0.166822612
                        if state == 20:
                            return -0.302712262
                if state == 6:
                    state = 11 if x["maggaia_med"] < 16.0724144 else 12
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 23.0507507)
                            else 22
                        )
                        if state == 21:
                            return -0.218908861
                        if state == 22:
                            return 0.0548299327
                    if state == 12:
                        state = 23 if x["magnr_med"] < 21.3969994 else 24
                        if state == 23:
                            state = (
                                35
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 20.4765472)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    51
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.4983997)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        63
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.1842499)
                                        else 64
                                    )
                                    if state == 63:
                                        state = (
                                            71
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.1569004)
                                            else 72
                                        )
                                        if state == 71:
                                            state = (
                                                81
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 16.5126724)
                                                else 82
                                            )
                                            if state == 81:
                                                return -0.140637487
                                            if state == 82:
                                                state = (
                                                    91
                                                    if x["neargaia_med"] < 29.0819874
                                                    else 92
                                                )
                                                if state == 91:
                                                    return -0.117683716
                                                if state == 92:
                                                    return 0.140684247
                                        if state == 72:
                                            return 0.12987709
                                    if state == 64:
                                        return -0.152705655
                                if state == 52:
                                    state = (
                                        65
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.6025505)
                                        else 66
                                    )
                                    if state == 65:
                                        return 0.156167388
                                    if state == 66:
                                        return -0.127354577
                            if state == 36:
                                return -0.183196649
                        if state == 24:
                            state = (
                                37
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 20.0002213)
                                else 38
                            )
                            if state == 37:
                                return -0.125945464
                            if state == 38:
                                state = (
                                    55
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.7505493)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        67
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.3199501)
                                        else 68
                                    )
                                    if state == 67:
                                        state = (
                                            73
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.0764599)
                                            else 74
                                        )
                                        if state == 73:
                                            return 0.0507876128
                                        if state == 74:
                                            return -0.128896818
                                    if state == 68:
                                        return 0.170203328
                                if state == 56:
                                    return -0.0958291665
    elif num_booster == 23:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.97509837) else 2
            if state == 1:
                state = 3 if x["magnr_med"] < 20.3295002 else 4
                if state == 3:
                    state = 7 if x["magnr_med"] < 15.7934999 else 8
                    if state == 7:
                        return -0.176320657
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1996994)
                            else 14
                        )
                        if state == 13:
                            state = 23 if x["magnr_med"] < 17.3392506 else 24
                            if state == 23:
                                state = (
                                    37
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.9580152)
                                    else 38
                                )
                                if state == 37:
                                    state = (
                                        59
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.6137581)
                                        else 60
                                    )
                                    if state == 59:
                                        state = (
                                            73
                                            if x["distpsnr1_med"] < 0.190212667
                                            else 74
                                        )
                                        if state == 73:
                                            return 0.079063639
                                        if state == 74:
                                            return -0.140948936
                                    if state == 60:
                                        return 0.0290674102
                                if state == 38:
                                    return 0.0790153295
                            if state == 24:
                                state = (
                                    39
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.91157389)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        61
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.6701927)
                                        else 62
                                    )
                                    if state == 61:
                                        return -0.207449779
                                    if state == 62:
                                        state = (
                                            75
                                            if np.isnan(x["distpsnr1_med"])
                                            or (x["distpsnr1_med"] < 1.17688298)
                                            else 76
                                        )
                                        if state == 75:
                                            return 0.198176786
                                        if state == 76:
                                            state = (
                                                83
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.93599999)
                                                else 84
                                            )
                                            if state == 83:
                                                state = (
                                                    87
                                                    if x["magnr_med"] < 19.2195015
                                                    else 88
                                                )
                                                if state == 87:
                                                    return -0.195029482
                                                if state == 88:
                                                    return 0.0598819591
                                            if state == 84:
                                                return 0.00881775841
                                if state == 40:
                                    return 0.190242738
                        if state == 14:
                            state = 25 if x["magnr_med"] < 19.4407501 else 26
                            if state == 25:
                                state = (
                                    41
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.540358782)
                                    else 42
                                )
                                if state == 41:
                                    state = (
                                        63
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.7216187)
                                        else 64
                                    )
                                    if state == 63:
                                        return 0.151594684
                                    if state == 64:
                                        return -0.130543619
                                if state == 42:
                                    return -0.190047547
                            if state == 26:
                                return 0.095076941
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.5982513)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1816998)
                            else 16
                        )
                        if state == 15:
                            state = 27 if x["magnr_med"] < 21.618 else 28
                            if state == 27:
                                state = (
                                    45
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.93817711)
                                    else 46
                                )
                                if state == 45:
                                    return -0.146087512
                                if state == 46:
                                    state = (
                                        65
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.9550514)
                                        else 66
                                    )
                                    if state == 65:
                                        return 0.122147523
                                    if state == 66:
                                        return -0.0915150344
                            if state == 28:
                                return -0.293214858
                        if state == 16:
                            state = 29 if x["magnr_med"] < 21.4377518 else 30
                            if state == 29:
                                return -0.0968695357
                            if state == 30:
                                return 0.124081783
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4568005)
                            else 18
                        )
                        if state == 17:
                            state = 31 if x["magnr_med"] < 22.8502502 else 32
                            if state == 31:
                                return 0.125513196
                            if state == 32:
                                state = (
                                    53
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.992419)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        71
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.3467751)
                                        else 72
                                    )
                                    if state == 71:
                                        return -0.148566484
                                    if state == 72:
                                        return 0.0665018633
                                if state == 54:
                                    return 0.0568990186
                        if state == 18:
                            return -0.116413325
            if state == 2:
                state = 5 if x["magnr_med"] < 15.5529995 else 6
                if state == 5:
                    return 0.0602087304
                if state == 6:
                    state = 11 if x["magnr_med"] < 20.3102493 else 12
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.2987995)
                            else 20
                        )
                        if state == 19:
                            return -0.243444458
                        if state == 20:
                            return 0.0435563102
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9982986)
                            else 22
                        )
                        if state == 21:
                            return -0.0885124654
                        if state == 22:
                            return 0.0725146085
    elif num_booster == 24:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.647312045) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.995249987)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.78549999)
                        else 8
                    )
                    if state == 7:
                        state = 11 if x["distnr_med"] < 0.469456315 else 12
                        if state == 11:
                            state = 19 if x["distnr_med"] < 0.320005119 else 20
                            if state == 19:
                                return -0.0634747446
                            if state == 20:
                                return 0.108959116
                        if state == 12:
                            return -0.113319039
                    if state == 8:
                        state = 13 if x["distnr_med"] < 0.2205984 else 14
                        if state == 13:
                            state = 21 if x["distnr_med"] < 0.1546579 else 22
                            if state == 21:
                                return -0.160379708
                            if state == 22:
                                return 0.111488715
                        if state == 14:
                            return -0.191652834
                if state == 4:
                    return 0.106613472
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.605250001)
                    else 6
                )
                if state == 5:
                    return -0.198669463
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.79974997)
                        else 10
                    )
                    if state == 9:
                        state = 15 if x["distnr_med"] < 0.87906146 else 16
                        if state == 15:
                            return -0.00955648534
                        if state == 16:
                            state = 25 if x["distnr_med"] < 0.96874094 else 26
                            if state == 25:
                                return 0.20080474
                            if state == 26:
                                state = (
                                    33
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0129282493)
                                    else 34
                                )
                                if state == 33:
                                    return -0.0657284111
                                if state == 34:
                                    state = (
                                        41
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 2.91537046)
                                        else 42
                                    )
                                    if state == 41:
                                        state = (
                                            51
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4548988)
                                            else 52
                                        )
                                        if state == 51:
                                            state = (
                                                67
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.286049843)
                                                else 68
                                            )
                                            if state == 67:
                                                return 0.212822542
                                            if state == 68:
                                                return -0.00609036302
                                        if state == 52:
                                            state = (
                                                69
                                                if x["col_det"] < 0.0431022644
                                                else 70
                                            )
                                            if state == 69:
                                                return -0.115161009
                                            if state == 70:
                                                state = (
                                                    79
                                                    if np.isnan(x["col_det"])
                                                    or (x["col_det"] < 0.0908622742)
                                                    else 80
                                                )
                                                if state == 79:
                                                    return 0.149325371
                                                if state == 80:
                                                    return -0.0429104418
                                    if state == 42:
                                        return -0.0183992833
                    if state == 10:
                        state = 17 if x["distnr_med"] < 2.61319733 else 18
                        if state == 17:
                            state = 27 if x["distnr_med"] < 1.86470771 else 28
                            if state == 27:
                                state = (
                                    35
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.9770081)
                                    else 36
                                )
                                if state == 35:
                                    state = (
                                        43
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 0.0359664485)
                                        else 44
                                    )
                                    if state == 43:
                                        state = (
                                            55
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.8074493)
                                            else 56
                                        )
                                        if state == 55:
                                            return 0.131674245
                                        if state == 56:
                                            return -0.181001306
                                    if state == 44:
                                        state = (
                                            57
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.421299)
                                            else 58
                                        )
                                        if state == 57:
                                            state = (
                                                71
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.340242386)
                                                else 72
                                            )
                                            if state == 71:
                                                return 0.0925886929
                                            if state == 72:
                                                return -0.101996131
                                        if state == 58:
                                            return 0.16879496
                                if state == 36:
                                    state = (
                                        45
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 2.98111105)
                                        else 46
                                    )
                                    if state == 45:
                                        return -0.229046434
                                    if state == 46:
                                        return 0.0345125422
                            if state == 28:
                                return 0.176289782
                        if state == 18:
                            state = 29 if x["distnr_med"] < 2.89385748 else 30
                            if state == 29:
                                return -0.27475813
                            if state == 30:
                                state = (
                                    39
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0510416999)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        47
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 0.0176561996)
                                        else 48
                                    )
                                    if state == 47:
                                        return -0.225485459
                                    if state == 48:
                                        state = (
                                            61
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.0453491)
                                            else 62
                                        )
                                        if state == 61:
                                            state = (
                                                75
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.0621881485)
                                                else 76
                                            )
                                            if state == 75:
                                                return -0.269324839
                                            if state == 76:
                                                return 0.0905909091
                                        if state == 62:
                                            return 0.0403767601
                                if state == 40:
                                    state = (
                                        49
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 2.94900465)
                                        else 50
                                    )
                                    if state == 49:
                                        state = (
                                            63
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.3738499)
                                            else 64
                                        )
                                        if state == 63:
                                            return -0.177718267
                                        if state == 64:
                                            return 0.144879892
                                    if state == 50:
                                        state = (
                                            65
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.1023006)
                                            else 66
                                        )
                                        if state == 65:
                                            return -0.181134313
                                        if state == 66:
                                            return 0.00261318847
    elif num_booster == 25:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.0562744) else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.420833349) else 4
                if state == 3:
                    state = 7 if x["neargaia_med"] < 11.8789139 else 8
                    if state == 7:
                        return 0.0162903294
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0286342502)
                            else 16
                        )
                        if state == 15:
                            return -0.0133588128
                        if state == 16:
                            state = (
                                29
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 20.0253677)
                                else 30
                            )
                            if state == 29:
                                return -0.233293355
                            if state == 30:
                                return 0.09623193
                if state == 4:
                    state = 9 if x["neargaia_med"] < 25.6445923 else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.116880804)
                            else 18
                        )
                        if state == 17:
                            state = (
                                31
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 16.759964)
                                else 32
                            )
                            if state == 31:
                                return 0.00676461263
                            if state == 32:
                                state = (
                                    47
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.8733616)
                                    else 48
                                )
                                if state == 47:
                                    return -0.195365623
                                if state == 48:
                                    state = (
                                        59 if x["distpsnr1_med"] < 0.568983793 else 60
                                    )
                                    if state == 59:
                                        return -0.194379613
                                    if state == 60:
                                        state = (
                                            69
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0127083501)
                                            else 70
                                        )
                                        if state == 69:
                                            return 0.142826378
                                        if state == 70:
                                            state = (
                                                77
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.5980492)
                                                else 78
                                            )
                                            if state == 77:
                                                return 0.0771624297
                                            if state == 78:
                                                return -0.200582474
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.7157612)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    49
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 17.5890694)
                                    else 50
                                )
                                if state == 49:
                                    return -0.111590832
                                if state == 50:
                                    state = (
                                        61 if x["distpsnr1_med"] < 0.144867599 else 62
                                    )
                                    if state == 61:
                                        return -0.0568131097
                                    if state == 62:
                                        state = (
                                            71 if x["sgscore1_med"] < 0.87708652 else 72
                                        )
                                        if state == 71:
                                            state = (
                                                79
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.4566498)
                                                else 80
                                            )
                                            if state == 79:
                                                state = (
                                                    85
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.357542)
                                                    else 86
                                                )
                                                if state == 85:
                                                    return 0.183149695
                                                if state == 86:
                                                    return -0.089590542
                                            if state == 80:
                                                return 0.244403154
                                        if state == 72:
                                            return -0.113287076
                            if state == 34:
                                return -0.103448197
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0288947001)
                            else 20
                        )
                        if state == 19:
                            state = (
                                35
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.6774731)
                                else 36
                            )
                            if state == 35:
                                return -0.268111706
                            if state == 36:
                                return 0.0884815976
                        if state == 20:
                            state = (
                                37
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.4198036)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    51
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 17.866787)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        63 if x["distpsnr1_med"] < 4.61794519 else 64
                                    )
                                    if state == 63:
                                        return 0.084350124
                                    if state == 64:
                                        return -0.128782541
                                if state == 52:
                                    return -0.144507319
                            if state == 38:
                                state = (
                                    53
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.8453484)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        65 if x["distpsnr1_med"] < 1.37765539 else 66
                                    )
                                    if state == 65:
                                        state = (
                                            73
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.00904166512)
                                            else 74
                                        )
                                        if state == 73:
                                            return 0.157336399
                                        if state == 74:
                                            state = (
                                                83
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.2085991)
                                                else 84
                                            )
                                            if state == 83:
                                                return -0.100866415
                                            if state == 84:
                                                state = (
                                                    87
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.3630714)
                                                    else 88
                                                )
                                                if state == 87:
                                                    return 0.145039812
                                                if state == 88:
                                                    return -0.0935268849
                                    if state == 66:
                                        return 0.227366015
                                if state == 54:
                                    return 0.0210587084
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.526904941) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 19.1572304)
                        else 12
                    )
                    if state == 11:
                        return -0.125793442
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0352951512)
                            else 24
                        )
                        if state == 23:
                            state = (
                                41
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 20.6621895)
                                else 42
                            )
                            if state == 41:
                                return -0.117339276
                            if state == 42:
                                return 0.087328732
                        if state == 24:
                            return 0.0730363876
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 31.7810059)
                        else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0265161991)
                            else 26
                        )
                        if state == 25:
                            return 0.0085420562
                        if state == 26:
                            return -0.243056476
                    if state == 14:
                        return -0.0438046642
    elif num_booster == 26:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.593250036)
                else 2
            )
            if state == 1:
                return -0.221703321
            if state == 2:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.9823125)
                    else 4
                )
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.99323511)
                        else 6
                    )
                    if state == 5:
                        state = (
                            7
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.93457747)
                            else 8
                        )
                        if state == 7:
                            state = (
                                11
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0405555516)
                                else 12
                            )
                            if state == 11:
                                state = (
                                    17
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0235358998)
                                    else 18
                                )
                                if state == 17:
                                    state = (
                                        27
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.3492012)
                                        else 28
                                    )
                                    if state == 27:
                                        return -0.179343075
                                    if state == 28:
                                        return 0.122856997
                                if state == 18:
                                    state = (
                                        29
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.263649)
                                        else 30
                                    )
                                    if state == 29:
                                        return 0.080389142
                                    if state == 30:
                                        return -0.285630137
                            if state == 12:
                                state = (
                                    19
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.93854761)
                                    else 20
                                )
                                if state == 19:
                                    state = (
                                        31
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.4323997)
                                        else 32
                                    )
                                    if state == 31:
                                        return 0.00793258566
                                    if state == 32:
                                        state = (
                                            39
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 31.307682)
                                            else 40
                                        )
                                        if state == 39:
                                            state = (
                                                49
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.7303333)
                                                else 50
                                            )
                                            if state == 49:
                                                return 0.220174447
                                            if state == 50:
                                                state = (
                                                    63
                                                    if x["magnr_med"] < 21.6267509
                                                    else 64
                                                )
                                                if state == 63:
                                                    state = (
                                                        77
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.277019501)
                                                        else 78
                                                    )
                                                    if state == 77:
                                                        return -0.125296533
                                                    if state == 78:
                                                        return 0.0747144297
                                                if state == 64:
                                                    return 0.136547372
                                        if state == 40:
                                            state = (
                                                51
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.1365509)
                                                else 52
                                            )
                                            if state == 51:
                                                return -0.113354713
                                            if state == 52:
                                                return 0.108601548
                                if state == 20:
                                    state = (
                                        33
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.9824009)
                                        else 34
                                    )
                                    if state == 33:
                                        state = (
                                            41
                                            if x["neargaia_med"] < 0.239404768
                                            else 42
                                        )
                                        if state == 41:
                                            return 0.0896113589
                                        if state == 42:
                                            state = (
                                                53
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.8917923)
                                                else 54
                                            )
                                            if state == 53:
                                                return 0.00219868612
                                            if state == 54:
                                                return -0.208018035
                                    if state == 34:
                                        state = (
                                            43 if x["neargaia_med"] < 11.4189167 else 44
                                        )
                                        if state == 43:
                                            return -0.0811712667
                                        if state == 44:
                                            state = (
                                                55
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.633543)
                                                else 56
                                            )
                                            if state == 55:
                                                return 0.153962135
                                            if state == 56:
                                                return -0.0883279294
                        if state == 8:
                            state = (
                                13
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.96979189)
                                else 14
                            )
                            if state == 13:
                                state = (
                                    21
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0122510996)
                                    else 22
                                )
                                if state == 21:
                                    return 0.00308907987
                                if state == 22:
                                    state = (
                                        35
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.4554996)
                                        else 36
                                    )
                                    if state == 35:
                                        state = (
                                            45 if x["neargaia_med"] < 4.44630623 else 46
                                        )
                                        if state == 45:
                                            return -0.0171083044
                                        if state == 46:
                                            return 0.207056254
                                    if state == 36:
                                        state = (
                                            47 if x["neargaia_med"] < 24.4081154 else 48
                                        )
                                        if state == 47:
                                            return 0.118300557
                                        if state == 48:
                                            return -0.116502292
                            if state == 14:
                                state = (
                                    23
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.0070138)
                                    else 24
                                )
                                if state == 23:
                                    return -0.124316745
                                if state == 24:
                                    return 0.148200542
                    if state == 6:
                        state = (
                            9
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 3.0244503)
                            else 10
                        )
                        if state == 9:
                            return -0.171906695
                        if state == 10:
                            return 0.0918504298
                if state == 4:
                    return -0.124156244
    elif num_booster == 27:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6987839) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5758858) else 4
                )
                if state == 3:
                    state = 7 if x["magnr_med"] < 22.2947502 else 8
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 0.415435493)
                            else 12
                        )
                        if state == 11:
                            state = (
                                17
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.650595307)
                                else 18
                            )
                            if state == 17:
                                return 0.0073968037
                            if state == 18:
                                return 0.178551346
                        if state == 12:
                            state = (
                                19
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.804166675)
                                else 20
                            )
                            if state == 19:
                                state = (
                                    27
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.589224458)
                                    else 28
                                )
                                if state == 27:
                                    state = 37 if x["magnr_med"] < 17.3974991 else 38
                                    if state == 37:
                                        return -0.125683531
                                    if state == 38:
                                        state = (
                                            53
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 3.01626158)
                                            else 54
                                        )
                                        if state == 53:
                                            return 0.223850325
                                        if state == 54:
                                            return -0.0213732012
                                if state == 28:
                                    return -0.0938726068
                            if state == 20:
                                return -0.166038066
                    if state == 8:
                        state = 13 if x["neargaia_med"] < 13.8477135 else 14
                        if state == 13:
                            return 0.0438253172
                        if state == 14:
                            return -0.206112072
                if state == 4:
                    return 0.162498951
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7262497) else 6
                )
                if state == 5:
                    return -0.140468612
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.9864998)
                        else 10
                    )
                    if state == 9:
                        return -0.167325243
                    if state == 10:
                        state = 15 if x["neargaia_med"] < 22.8072262 else 16
                        if state == 15:
                            state = (
                                21
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.354166597)
                                else 22
                            )
                            if state == 21:
                                return -0.00917191245
                            if state == 22:
                                state = (
                                    31
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.114959501)
                                    else 32
                                )
                                if state == 31:
                                    state = 41 if x["magnr_med"] < 18.2884998 else 42
                                    if state == 41:
                                        return 0.0134025933
                                    if state == 42:
                                        return -0.199225307
                                if state == 32:
                                    return -0.0388590582
                        if state == 16:
                            state = (
                                23
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.812499881)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    33
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.0140624996)
                                    else 34
                                )
                                if state == 33:
                                    state = 45 if x["magnr_med"] < 18.4212494 else 46
                                    if state == 45:
                                        return 0.0679186657
                                    if state == 46:
                                        state = (
                                            57
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 3.00334501)
                                            else 58
                                        )
                                        if state == 57:
                                            state = (
                                                67
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 31.9877739)
                                                else 68
                                            )
                                            if state == 67:
                                                return -0.166080594
                                            if state == 68:
                                                return 0.0016587493
                                        if state == 58:
                                            return 0.0826964453
                                if state == 34:
                                    return 0.0767406076
                            if state == 24:
                                return 0.0841980502
    elif num_booster == 28:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 1.86631393 else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.98112845) else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.0362351499)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.932857037)
                            else 16
                        )
                        if state == 15:
                            state = 29 if x["distpsnr1_med"] < 0.899805307 else 30
                            if state == 29:
                                state = (
                                    39
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.00931248534)
                                    else 40
                                )
                                if state == 39:
                                    return 0.143827468
                                if state == 40:
                                    return -0.0356453396
                            if state == 30:
                                return -0.181963846
                        if state == 16:
                            return 0.110485435
                    if state == 8:
                        return -0.200742036
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.201168001)
                        else 10
                    )
                    if state == 9:
                        return 0.112384707
                    if state == 10:
                        return -0.0550414696
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0129282493) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.00135416491)
                        else 12
                    )
                    if state == 11:
                        return 0.0590678938
                    if state == 12:
                        return -0.16704753
                if state == 6:
                    state = 13 if x["sgscore1_med"] < 0.956738472 else 14
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.367857277)
                            else 26
                        )
                        if state == 25:
                            state = 35 if x["distpsnr1_med"] < 17.9426575 else 36
                            if state == 35:
                                return -0.0913035572
                            if state == 36:
                                return 0.105752468
                        if state == 26:
                            return 0.107389256
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.630833387)
                            else 28
                        )
                        if state == 27:
                            state = 37 if x["distpsnr1_med"] < 57.372757 else 38
                            if state == 37:
                                return -0.0877756327
                            if state == 38:
                                return 0.0682082102
                        if state == 28:
                            return -0.116055474
    elif num_booster == 29:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9915504) else 2
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 0.223388016 else 4
                if state == 3:
                    return -0.19714357
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.4293747)
                        else 8
                    )
                    if state == 7:
                        state = 13 if x["maggaia_med"] < 16.1306839 else 14
                        if state == 13:
                            return -0.12520507
                        if state == 14:
                            state = (
                                19
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9398003)
                                else 20
                            )
                            if state == 19:
                                state = (
                                    25
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.7999496)
                                    else 26
                                )
                                if state == 25:
                                    state = (
                                        33
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 17.8626213)
                                        else 34
                                    )
                                    if state == 33:
                                        state = (
                                            43 if x["distnr_med"] < 0.511026263 else 44
                                        )
                                        if state == 43:
                                            return 0.103452675
                                        if state == 44:
                                            state = (
                                                49
                                                if x["magnr_med"] < 20.1207504
                                                else 50
                                            )
                                            if state == 49:
                                                state = (
                                                    57
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 16.6371918)
                                                    else 58
                                                )
                                                if state == 57:
                                                    return 0.0910582393
                                                if state == 58:
                                                    return -0.0881268382
                                            if state == 50:
                                                return -0.132124081
                                    if state == 34:
                                        state = (
                                            45 if x["distnr_med"] < 0.672421575 else 46
                                        )
                                        if state == 45:
                                            return -0.0283782799
                                        if state == 46:
                                            state = (
                                                51
                                                if x["magnr_med"] < 21.6662483
                                                else 52
                                            )
                                            if state == 51:
                                                return 0.160413444
                                            if state == 52:
                                                return -0.0173915997
                                if state == 26:
                                    return 0.147104889
                            if state == 20:
                                return -0.115585037
                    if state == 8:
                        return -0.160118982
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.611245155 else 6
                if state == 5:
                    return -0.039755743
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.3565578)
                        else 12
                    )
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 18.4482422)
                            else 18
                        )
                        if state == 17:
                            state = (
                                21
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.52495)
                                else 22
                            )
                            if state == 21:
                                state = (
                                    29
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.3922005)
                                    else 30
                                )
                                if state == 29:
                                    state = (
                                        37
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 15.6601439)
                                        else 38
                                    )
                                    if state == 37:
                                        return 0.0444715098
                                    if state == 38:
                                        return -0.117731027
                                if state == 30:
                                    return 0.115308315
                            if state == 22:
                                return -0.139365852
                        if state == 18:
                            state = (
                                23
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.361351)
                                else 24
                            )
                            if state == 23:
                                return 0.168774992
                            if state == 24:
                                return 0.0206486899
                    if state == 12:
                        return -0.0751999095
    elif num_booster == 30:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1954498) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.503708482)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 48.9493942)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.753095269)
                            else 14
                        )
                        if state == 13:
                            state = (
                                21
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 21.4964237)
                                else 22
                            )
                            if state == 21:
                                state = (
                                    29
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 18.9741001)
                                    else 30
                                )
                                if state == 29:
                                    state = (
                                        39
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.145419508)
                                        else 40
                                    )
                                    if state == 39:
                                        return -0.136627421
                                    if state == 40:
                                        return 0.0579558946
                                if state == 30:
                                    state = (
                                        41 if x["sgscore1_med"] < 0.205568492 else 42
                                    )
                                    if state == 41:
                                        state = (
                                            55
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.9322014)
                                            else 56
                                        )
                                        if state == 55:
                                            return -0.0420941897
                                        if state == 56:
                                            return 0.102509737
                                    if state == 42:
                                        state = (
                                            57
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.09025)
                                            else 58
                                        )
                                        if state == 57:
                                            return 0.148564577
                                        if state == 58:
                                            return -0.0526434705
                            if state == 22:
                                return 0.154361457
                        if state == 14:
                            state = 23 if x["neargaia_med"] < 32.4735413 else 24
                            if state == 23:
                                return -0.0737082586
                            if state == 24:
                                state = (
                                    33
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.1392994)
                                    else 34
                                )
                                if state == 33:
                                    return -0.0720516294
                                if state == 34:
                                    return 0.113977186
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.822857141)
                            else 16
                        )
                        if state == 15:
                            return -0.138601527
                        if state == 16:
                            return 0.0430035852
                if state == 4:
                    return -0.129766271
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.634961009)
                    else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 24.3428116)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.507976174)
                            else 18
                        )
                        if state == 17:
                            state = (
                                25
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 7.75372791)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    35
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.40695)
                                    else 36
                                )
                                if state == 35:
                                    return 0.0788250417
                                if state == 36:
                                    return -0.137962908
                            if state == 26:
                                return -0.109804802
                        if state == 18:
                            state = (
                                27
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 11.2607098)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    37
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.4590988)
                                    else 38
                                )
                                if state == 37:
                                    return -0.126848906
                                if state == 38:
                                    return 0.0373401865
                            if state == 28:
                                return 0.107682243
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.851071477)
                            else 20
                        )
                        if state == 19:
                            return -0.210142493
                        if state == 20:
                            return 0.0419110321
                if state == 6:
                    return 0.0293512084
    elif num_booster == 31:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.9202499) else 2
            if state == 1:
                return -0.105118893
            if state == 2:
                state = 3 if x["neargaia_med"] < 27.2281685 else 4
                if state == 3:
                    state = 5 if x["neargaia_med"] < 14.7388268 else 6
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.276171684)
                            else 10
                        )
                        if state == 9:
                            state = (
                                17
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < 0.0921220779)
                                else 18
                            )
                            if state == 17:
                                state = 31 if x["distpsnr1_med"] < 0.223388016 else 32
                                if state == 31:
                                    return -0.13385281
                                if state == 32:
                                    state = (
                                        43
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.569999933)
                                        else 44
                                    )
                                    if state == 43:
                                        return -0.0372466892
                                    if state == 44:
                                        state = (
                                            57
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.86372089)
                                            else 58
                                        )
                                        if state == 57:
                                            state = (
                                                73
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.0873985)
                                                else 74
                                            )
                                            if state == 73:
                                                return 0.109134085
                                            if state == 74:
                                                return -0.0958252698
                                        if state == 58:
                                            state = (
                                                75
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.778801)
                                                else 76
                                            )
                                            if state == 75:
                                                return 0.199926093
                                            if state == 76:
                                                state = (
                                                    81
                                                    if x["neargaia_med"] < 2.10691881
                                                    else 82
                                                )
                                                if state == 81:
                                                    return 0.112470277
                                                if state == 82:
                                                    return -0.133008778
                            if state == 18:
                                return -0.0690732673
                        if state == 10:
                            return 0.0960987583
                    if state == 6:
                        state = 11 if x["col_det"] < 0.0493364334 else 12
                        if state == 11:
                            return -0.173384219
                        if state == 12:
                            state = 21 if x["col_det"] < 0.285839081 else 22
                            if state == 21:
                                return 0.0332823656
                            if state == 22:
                                state = 35 if x["distpsnr1_med"] < 1.61699224 else 36
                                if state == 35:
                                    state = (
                                        45
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.67464298)
                                        else 46
                                    )
                                    if state == 45:
                                        return -0.0786036849
                                    if state == 46:
                                        return 0.0821016058
                                if state == 36:
                                    return -0.158288136
                if state == 4:
                    state = 7 if x["neargaia_med"] < 55.2961464 else 8
                    if state == 7:
                        state = 13 if x["col_det"] < -0.0593671799 else 14
                        if state == 13:
                            return -0.0785892159
                        if state == 14:
                            state = 25 if x["col_det"] < 0.203544617 else 26
                            if state == 25:
                                return 0.184283555
                            if state == 26:
                                state = 37 if x["distpsnr1_med"] < 6.72001505 else 38
                                if state == 37:
                                    return 0.114955395
                                if state == 38:
                                    state = (
                                        49
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.422261983)
                                        else 50
                                    )
                                    if state == 49:
                                        return 0.0893769339
                                    if state == 50:
                                        return -0.125364065
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.0814504623)
                            else 16
                        )
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < -0.0558567047)
                                else 28
                            )
                            if state == 27:
                                return 0.0202360172
                            if state == 28:
                                return -0.148584232
                        if state == 16:
                            state = 29 if x["col_det"] < 0.237739563 else 30
                            if state == 29:
                                return 0.145246074
                            if state == 30:
                                return -0.019897772
    elif num_booster == 32:
        state = 0
        if state == 0:
            state = 1 if x["distnr_med"] < 0.218413025 else 2
            if state == 1:
                state = 3 if x["maggaia_med"] < 18.9309082 else 4
                if state == 3:
                    return 0.143456101
                if state == 4:
                    return -0.0381341837
            if state == 2:
                state = (
                    5
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 18.6130486)
                    else 6
                )
                if state == 5:
                    state = 7 if x["maggaia_med"] < 13.786644 else 8
                    if state == 7:
                        return -0.114133239
                    if state == 8:
                        state = (
                            11
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 0.512381792)
                            else 12
                        )
                        if state == 11:
                            state = 17 if x["distnr_med"] < 3.53622746 else 18
                            if state == 17:
                                state = (
                                    27
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.2020988)
                                    else 28
                                )
                                if state == 27:
                                    state = 41 if x["distnr_med"] < 0.509679437 else 42
                                    if state == 41:
                                        return 0.0564929694
                                    if state == 42:
                                        return -0.107534669
                                if state == 28:
                                    state = 43 if x["distnr_med"] < 0.356557518 else 44
                                    if state == 43:
                                        return -0.117935732
                                    if state == 44:
                                        return 0.0751838908
                            if state == 18:
                                return -0.121959552
                        if state == 12:
                            state = 19 if x["distnr_med"] < 0.60299921 else 20
                            if state == 19:
                                return -0.103901826
                            if state == 20:
                                state = (
                                    31
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.0113983)
                                    else 32
                                )
                                if state == 31:
                                    state = 45 if x["distnr_med"] < 4.11653566 else 46
                                    if state == 45:
                                        state = (
                                            55
                                            if x["distpsnr1_med"] < 1.33121943
                                            else 56
                                        )
                                        if state == 55:
                                            state = (
                                                63
                                                if x["magnr_med"] < 17.0219994
                                                else 64
                                            )
                                            if state == 63:
                                                return -0.0954758748
                                            if state == 64:
                                                return 0.135826021
                                        if state == 56:
                                            return 0.185200363
                                    if state == 46:
                                        state = (
                                            57
                                            if x["distpsnr1_med"] < 8.34697151
                                            else 58
                                        )
                                        if state == 57:
                                            return -0.124780819
                                        if state == 58:
                                            return 0.075401023
                                if state == 32:
                                    state = 47 if x["distnr_med"] < 4.69015408 else 48
                                    if state == 47:
                                        state = (
                                            59 if x["distpsnr1_med"] < 3.2551477 else 60
                                        )
                                        if state == 59:
                                            return 0.0594991744
                                        if state == 60:
                                            return -0.140700743
                                    if state == 48:
                                        return 0.0396468416
                if state == 6:
                    state = 9 if x["maggaia_med"] < 19.9505882 else 10
                    if state == 9:
                        state = (
                            13
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 6.42328262)
                            else 14
                        )
                        if state == 13:
                            state = 21 if x["distnr_med"] < 3.48325419 else 22
                            if state == 21:
                                state = (
                                    33
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.000351)
                                    else 34
                                )
                                if state == 33:
                                    return -0.20990175
                                if state == 34:
                                    state = 51 if x["distnr_med"] < 1.20266461 else 52
                                    if state == 51:
                                        return -0.161613956
                                    if state == 52:
                                        return 0.0858094245
                            if state == 22:
                                return -0.0160276257
                        if state == 14:
                            state = 23 if x["distnr_med"] < 3.87892318 else 24
                            if state == 23:
                                return 0.121131793
                            if state == 24:
                                return -0.0535075217
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 0.67551291)
                            else 16
                        )
                        if state == 15:
                            return -0.0758501142
                        if state == 16:
                            return 0.0846809149
    elif num_booster == 33:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.0424843) else 2
            if state == 1:
                state = 3 if x["neargaia_med"] < 28.7846642 else 4
                if state == 3:
                    state = 7 if x["sgscore1_med"] < 0.382836521 else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.682500124)
                            else 16
                        )
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 17.9813595)
                                else 28
                            )
                            if state == 27:
                                return 0.0803432241
                            if state == 28:
                                state = 43 if x["distnr_med"] < 1.15329671 else 44
                                if state == 43:
                                    return -0.0991990045
                                if state == 44:
                                    state = 63 if x["neargaia_med"] < 14.6812401 else 64
                                    if state == 63:
                                        state = (
                                            77 if x["magnr_med"] < 19.0825005 else 78
                                        )
                                        if state == 77:
                                            return -0.0488295779
                                        if state == 78:
                                            return 0.139387041
                                    if state == 64:
                                        return -0.116539069
                        if state == 16:
                            state = (
                                29
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.5266266)
                                else 30
                            )
                            if state == 29:
                                state = 45 if x["distnr_med"] < 0.278383493 else 46
                                if state == 45:
                                    return -0.0360263176
                                if state == 46:
                                    return 0.148192734
                            if state == 30:
                                return 0.019804731
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.650000215)
                            else 18
                        )
                        if state == 17:
                            return -0.0332555547
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.6717129)
                                else 34
                            )
                            if state == 33:
                                return -0.162268341
                            if state == 34:
                                return 0.0366421901
                if state == 4:
                    state = 9 if x["sgscore1_med"] < 0.521456957 else 10
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.392499924)
                            else 20
                        )
                        if state == 19:
                            return -0.0416885242
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.3750267)
                                else 36
                            )
                            if state == 35:
                                state = 53 if x["distnr_med"] < 0.415127635 else 54
                                if state == 53:
                                    return 0.0107263615
                                if state == 54:
                                    state = 71 if x["neargaia_med"] < 33.6673317 else 72
                                    if state == 71:
                                        return -0.0332376771
                                    if state == 72:
                                        return 0.210070282
                            if state == 36:
                                state = 55 if x["distnr_med"] < 0.754168987 else 56
                                if state == 55:
                                    return -0.0692981556
                                if state == 56:
                                    state = (
                                        75
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 37.2960014)
                                        else 76
                                    )
                                    if state == 75:
                                        return 0.138169467
                                    if state == 76:
                                        return -0.0283865873
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.580000043)
                            else 22
                        )
                        if state == 21:
                            state = (
                                37
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.9827995)
                                else 38
                            )
                            if state == 37:
                                return -0.141446099
                            if state == 38:
                                return 0.136359885
                        if state == 22:
                            state = (
                                39
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.1671886)
                                else 40
                            )
                            if state == 39:
                                state = 57 if x["distnr_med"] < 1.77265751 else 58
                                if state == 57:
                                    return 0.10129071
                                if state == 58:
                                    return -0.107650012
                            if state == 40:
                                return 0.0691771656
            if state == 2:
                state = 5 if x["neargaia_med"] < 19.5059471 else 6
                if state == 5:
                    return -0.0146857472
                if state == 6:
                    state = 13 if x["sgscore1_med"] < 0.636723042 else 14
                    if state == 13:
                        return -0.167159855
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.67738086)
                            else 26
                        )
                        if state == 25:
                            return -0.0925192758
                        if state == 26:
                            return 0.0877983272
    elif num_booster == 34:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 36.1096725)
                else 2
            )
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 0.105146483 else 4
                if state == 3:
                    return -0.160621881
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.1238823)
                        else 8
                    )
                    if state == 7:
                        state = 11 if x["distpsnr1_med"] < 1.9808867 else 12
                        if state == 11:
                            state = (
                                15
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0363194495)
                                else 16
                            )
                            if state == 15:
                                return -0.0822568312
                            if state == 16:
                                state = (
                                    23
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.679166675)
                                    else 24
                                )
                                if state == 23:
                                    state = 29 if x["neargaia_med"] < 29.0862751 else 30
                                    if state == 29:
                                        return -0.113960013
                                    if state == 30:
                                        return 0.0568372458
                                if state == 24:
                                    return 0.122569382
                        if state == 12:
                            state = (
                                17
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.01929975)
                                else 18
                            )
                            if state == 17:
                                state = (
                                    25
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.414642662)
                                    else 26
                                )
                                if state == 25:
                                    return 0.0137421135
                                if state == 26:
                                    state = 35 if x["neargaia_med"] < 7.11181116 else 36
                                    if state == 35:
                                        state = (
                                            43
                                            if x["distpsnr1_med"] < 4.59342098
                                            else 44
                                        )
                                        if state == 43:
                                            return 0.13864395
                                        if state == 44:
                                            return -0.108092241
                                    if state == 36:
                                        return 0.144720197
                            if state == 18:
                                return -0.147292539
                    if state == 8:
                        state = 13 if x["distpsnr1_med"] < 1.30585909 else 14
                        if state == 13:
                            return -0.113050587
                        if state == 14:
                            state = (
                                19
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0751099512)
                                else 20
                            )
                            if state == 19:
                                state = (
                                    27
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.665237963)
                                    else 28
                                )
                                if state == 27:
                                    return -0.0524451323
                                if state == 28:
                                    return 0.177400216
                            if state == 20:
                                return -0.172420293
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.219411314 else 6
                if state == 5:
                    return 0.0548481643
                if state == 6:
                    return -0.117884427
    elif num_booster == 35:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0105786994) else 2
            if state == 1:
                return -0.122485608
            if state == 2:
                state = 5 if x["magnr_med"] < 16.0812492 else 6
                if state == 5:
                    return -0.131899148
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.503333211)
                        else 12
                    )
                    if state == 11:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.9979477)
                            else 14
                        )
                        if state == 13:
                            return -0.0966622308
                        if state == 14:
                            state = (
                                19
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 10.4593801)
                                else 20
                            )
                            if state == 19:
                                state = 27 if x["magnr_med"] < 21.96525 else 28
                                if state == 27:
                                    return -0.0377823934
                                if state == 28:
                                    return 0.123496003
                            if state == 20:
                                return -0.0684858188
                    if state == 12:
                        state = (
                            15
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8389549)
                            else 16
                        )
                        if state == 15:
                            state = (
                                21
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 6.98908234)
                                else 22
                            )
                            if state == 21:
                                state = 29 if x["magnr_med"] < 21.3552513 else 30
                                if state == 29:
                                    state = (
                                        39
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 17.4242744)
                                        else 40
                                    )
                                    if state == 39:
                                        return 0.112203382
                                    if state == 40:
                                        state = (
                                            55
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 2.96799183)
                                            else 56
                                        )
                                        if state == 55:
                                            state = (
                                                65
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.04251742)
                                                else 66
                                            )
                                            if state == 65:
                                                return 0.107114509
                                            if state == 66:
                                                state = (
                                                    71
                                                    if x["magnr_med"] < 18.4632492
                                                    else 72
                                                )
                                                if state == 71:
                                                    return 0.0752220079
                                                if state == 72:
                                                    return -0.0744416639
                                        if state == 56:
                                            return -0.148219064
                                if state == 30:
                                    return -0.134541899
                            if state == 22:
                                state = 31 if x["magnr_med"] < 21.29175 else 32
                                if state == 31:
                                    state = 41 if x["maggaia_med"] < 19.0915947 else 42
                                    if state == 41:
                                        return 0.207883254
                                    if state == 42:
                                        state = (
                                            59
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 0.122725651)
                                            else 60
                                        )
                                        if state == 59:
                                            return -0.0283192545
                                        if state == 60:
                                            state = (
                                                69
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.12938666)
                                                else 70
                                            )
                                            if state == 69:
                                                return -0.0633082613
                                            if state == 70:
                                                return 0.123087488
                                if state == 32:
                                    state = 43 if x["maggaia_med"] < 19.4443607 else 44
                                    if state == 43:
                                        return 0.0759002343
                                    if state == 44:
                                        return -0.0787991434
                        if state == 16:
                            state = (
                                23
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 21.6142979)
                                else 24
                            )
                            if state == 23:
                                state = 33 if x["magnr_med"] < 18.0820007 else 34
                                if state == 33:
                                    return 0.0114588719
                                if state == 34:
                                    return -0.174889952
                            if state == 24:
                                return 0.0175766684
    elif num_booster == 36:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.604749978)
                else 2
            )
            if state == 1:
                return -0.153802171
            if state == 2:
                state = 3 if x["distpsnr1_med"] < 0.512381792 else 4
                if state == 3:
                    state = 5 if x["distpsnr1_med"] < 0.131968945 else 6
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1009731)
                            else 10
                        )
                        if state == 9:
                            return -0.120127141
                        if state == 10:
                            return 0.0875105113
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.20644)
                            else 12
                        )
                        if state == 11:
                            return 0.0170215815
                        if state == 12:
                            return -0.217558712
                if state == 4:
                    state = 7 if x["distpsnr1_med"] < 0.778483152 else 8
                    if state == 7:
                        return 0.150649309
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5716743)
                            else 14
                        )
                        if state == 13:
                            state = (
                                17
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.2310505)
                                else 18
                            )
                            if state == 17:
                                state = 23 if x["distnr_med"] < 1.86665654 else 24
                                if state == 23:
                                    return -0.122831255
                                if state == 24:
                                    state = 29 if x["sgscore1_med"] < 0.4264175 else 30
                                    if state == 29:
                                        return 0.121647455
                                    if state == 30:
                                        state = (
                                            37
                                            if x["sgscore1_med"] < 0.712363005
                                            else 38
                                        )
                                        if state == 37:
                                            state = (
                                                43
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 0.0439352021)
                                                else 44
                                            )
                                            if state == 43:
                                                return -0.105226636
                                            if state == 44:
                                                return 0.0787867829
                                        if state == 38:
                                            return -0.10245432
                            if state == 18:
                                return 0.15765667
                        if state == 14:
                            state = (
                                19
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8314514)
                                else 20
                            )
                            if state == 19:
                                return 0.0987771302
                            if state == 20:
                                state = 25 if x["distnr_med"] < 2.04341197 else 26
                                if state == 25:
                                    state = (
                                        31
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.00552083505)
                                        else 32
                                    )
                                    if state == 31:
                                        return -0.015921073
                                    if state == 32:
                                        return 0.115712933
                                if state == 26:
                                    state = (
                                        33
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.496340513)
                                        else 34
                                    )
                                    if state == 33:
                                        state = (
                                            39
                                            if x["sgscore1_med"] < 0.0144375004
                                            else 40
                                        )
                                        if state == 39:
                                            return 0.0276627149
                                        if state == 40:
                                            return -0.140566826
                                    if state == 34:
                                        return 0.0576601475
    elif num_booster == 37:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < 0.655822754) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["col_det"]) or (x["col_det"] < 0.0104484558) else 4
                )
                if state == 3:
                    state = (
                        5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.536547542) else 6
                    )
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.350357324)
                            else 10
                        )
                        if state == 9:
                            return -0.0874387398
                        if state == 10:
                            state = (
                                15
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.4272404)
                                else 16
                            )
                            if state == 15:
                                return -0.0753791407
                            if state == 16:
                                state = 21 if x["col_det"] < -0.254532814 else 22
                                if state == 21:
                                    return -0.0520065539
                                if state == 22:
                                    state = (
                                        27
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 0.128396958)
                                        else 28
                                    )
                                    if state == 27:
                                        return -0.0398109443
                                    if state == 28:
                                        return 0.145482391
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.573333442)
                            else 12
                        )
                        if state == 11:
                            return -0.149708018
                        if state == 12:
                            state = (
                                17
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.7920418)
                                else 18
                            )
                            if state == 17:
                                state = (
                                    23
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.300398827)
                                    else 24
                                )
                                if state == 23:
                                    state = (
                                        29
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 0.0234490503)
                                        else 30
                                    )
                                    if state == 29:
                                        return -0.0745101646
                                    if state == 30:
                                        state = (
                                            35 if x["distnr_med"] < 2.85448027 else 36
                                        )
                                        if state == 35:
                                            state = (
                                                39
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 3.01968169)
                                                else 40
                                            )
                                            if state == 39:
                                                state = (
                                                    43
                                                    if x["distnr_med"] < 0.58251375
                                                    else 44
                                                )
                                                if state == 43:
                                                    return -0.0351914577
                                                if state == 44:
                                                    return 0.212524936
                                            if state == 40:
                                                return 0.0118733775
                                        if state == 36:
                                            return -0.0557384528
                                if state == 24:
                                    state = (
                                        31
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 2.94567132)
                                        else 32
                                    )
                                    if state == 31:
                                        return -0.141759187
                                    if state == 32:
                                        return 0.0394386537
                            if state == 18:
                                state = 25 if x["col_det"] < -0.0200681686 else 26
                                if state == 25:
                                    return 0.00418294594
                                if state == 26:
                                    return -0.229971647
                if state == 4:
                    return 0.0850253552
            if state == 2:
                return -0.123250417
    elif num_booster == 38:
        state = 0
        if state == 0:
            state = 1 if x["col_det"] < 0.132285118 else 2
            if state == 1:
                return 0.0386008881
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.863214135) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["col_det"]) or (x["col_det"] < 0.643074989)
                        else 12
                    )
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0616376996)
                            else 20
                        )
                        if state == 19:
                            return -0.110825256
                        if state == 20:
                            state = (
                                27
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 18.593853)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    37
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.712499976)
                                    else 38
                                )
                                if state == 37:
                                    return -0.144871533
                                if state == 38:
                                    state = (
                                        47
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.731190503)
                                        else 48
                                    )
                                    if state == 47:
                                        state = (
                                            51
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.989000022)
                                            else 52
                                        )
                                        if state == 51:
                                            state = (
                                                55
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.04005206)
                                                else 56
                                            )
                                            if state == 55:
                                                return 0.129937619
                                            if state == 56:
                                                state = (
                                                    57
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.96875)
                                                    else 58
                                                )
                                                if state == 57:
                                                    state = (
                                                        59
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.97912025
                                                        )
                                                        else 60
                                                    )
                                                    if state == 59:
                                                        return -0.091192089
                                                    if state == 60:
                                                        return 0.0707151368
                                                if state == 58:
                                                    return 0.0901574492
                                        if state == 52:
                                            return -0.0630751997
                                    if state == 48:
                                        return -0.115768164
                            if state == 28:
                                return 0.0249180682
                    if state == 12:
                        return -0.120213486
                if state == 6:
                    return 0.0872827023
    elif num_booster == 39:
        state = 0
        if state == 0:
            state = 1 if x["distnr_med"] < 4.83447599 else 2
            if state == 1:
                state = 3 if x["magnr_med"] < 17.5377502 else 4
                if state == 3:
                    return -0.120117545
                if state == 4:
                    state = 9 if x["distnr_med"] < 0.16133821 else 10
                    if state == 9:
                        return -0.0743167624
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8228493)
                            else 16
                        )
                        if state == 15:
                            state = 19 if x["col_det"] < 0.804894447 else 20
                            if state == 19:
                                return 0.18482618
                            if state == 20:
                                return 0.015299568
                        if state == 16:
                            state = (
                                21
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < -0.0415124893)
                                else 22
                            )
                            if state == 21:
                                state = (
                                    29
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.9769497)
                                    else 30
                                )
                                if state == 29:
                                    return -0.119634964
                                if state == 30:
                                    state = (
                                        39
                                        if np.isnan(x["classtar_med"])
                                        or (x["classtar_med"] < 0.915000021)
                                        else 40
                                    )
                                    if state == 39:
                                        state = (
                                            47
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4176502)
                                            else 48
                                        )
                                        if state == 47:
                                            return 0.0915645882
                                        if state == 48:
                                            return -0.0816008821
                                    if state == 40:
                                        return -0.0829589292
                            if state == 22:
                                return 0.0504931547
            if state == 2:
                state = 5 if x["magnr_med"] < 18.8052502 else 6
                if state == 5:
                    return 0.0422704443
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 11.5260715)
                        else 12
                    )
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.1327171)
                            else 18
                        )
                        if state == 17:
                            return -0.199523002
                        if state == 18:
                            state = 23 if x["col_det"] < 0.277825356 else 24
                            if state == 23:
                                return 0.0412341319
                            if state == 24:
                                return -0.142881349
                    if state == 12:
                        return 0.0124379834
    elif num_booster == 40:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5253105) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.973894596)
                    else 4
                )
                if state == 3:
                    return 0.0946020633
                if state == 4:
                    state = 9 if x["neargaia_med"] < 11.5132608 else 10
                    if state == 9:
                        return 0.0352262482
                    if state == 10:
                        state = 19 if x["distnr_med"] < 2.79366302 else 20
                        if state == 19:
                            state = 31 if x["distnr_med"] < 1.65355206 else 32
                            if state == 31:
                                return -0.097944133
                            if state == 32:
                                return 0.112206534
                        if state == 20:
                            return -0.120950542
            if state == 2:
                state = (
                    5
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.8249073)
                    else 6
                )
                if state == 5:
                    state = 11 if x["neargaia_med"] < 175.897018 else 12
                    if state == 11:
                        return -0.164544702
                    if state == 12:
                        return 0.0184494033
                if state == 6:
                    state = 13 if x["neargaia_med"] < 17.0009556 else 14
                    if state == 13:
                        state = 23 if x["distnr_med"] < 0.581920445 else 24
                        if state == 23:
                            return -0.0440715402
                        if state == 24:
                            state = 37 if x["distnr_med"] < 1.36199725 else 38
                            if state == 37:
                                return 0.0986892283
                            if state == 38:
                                state = 49 if x["neargaia_med"] < 7.3961525 else 50
                                if state == 49:
                                    return -0.0617999546
                                if state == 50:
                                    return 0.0826500654
                    if state == 14:
                        state = 25 if x["distnr_med"] < 0.756918728 else 26
                        if state == 25:
                            return -0.0900800079
                        if state == 26:
                            state = 41 if x["distnr_med"] < 2.22883248 else 42
                            if state == 41:
                                return 0.0457385331
                            if state == 42:
                                state = (
                                    53
                                    if np.isnan(x["neargaia_med"])
                                    or (x["neargaia_med"] < 29.7097034)
                                    else 54
                                )
                                if state == 53:
                                    return -0.140473723
                                if state == 54:
                                    return 0.0603330694
    elif num_booster == 41:
        state = 0
        if state == 0:
            state = 1 if x["magnr_med"] < 20.6757507 else 2
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 6.27689552 else 4
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.9691782) else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.9979167)
                            else 16
                        )
                        if state == 15:
                            state = 29 if x["magnr_med"] < 19.257 else 30
                            if state == 29:
                                state = (
                                    43
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.005909)
                                    else 44
                                )
                                if state == 43:
                                    return -0.0916258395
                                if state == 44:
                                    state = 55 if x["maggaia_med"] < 19.8072891 else 56
                                    if state == 55:
                                        return 0.0725912824
                                    if state == 56:
                                        return -0.101705417
                            if state == 30:
                                state = (
                                    45
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.1418343)
                                    else 46
                                )
                                if state == 45:
                                    return -0.0283128079
                                if state == 46:
                                    return 0.163536638
                        if state == 16:
                            return -0.0693089366
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 3.02593184)
                            else 18
                        )
                        if state == 17:
                            return -0.125375554
                        if state == 18:
                            return 0.0767574534
                if state == 4:
                    return 0.0947744399
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 10.7328424)
                    else 6
                )
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0559896529) else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.90942144)
                            else 24
                        )
                        if state == 23:
                            return 0.0249102525
                        if state == 24:
                            state = 39 if x["magnr_med"] < 21.4127502 else 40
                            if state == 39:
                                return 0.0483623222
                            if state == 40:
                                return -0.127136394
                    if state == 12:
                        return -0.140032381
                if state == 6:
                    state = (
                        13 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0227256995) else 14
                    )
                    if state == 13:
                        return -0.0268787295
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.91774893)
                            else 28
                        )
                        if state == 27:
                            return 0.118759416
                        if state == 28:
                            return -0.0552839562
    elif num_booster == 42:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 17.7361946) else 2
            if state == 1:
                return -0.115902841
            if state == 2:
                state = 3 if x["distnr_med"] < 5.26400042 else 4
                if state == 3:
                    state = 5 if x["distnr_med"] < 1.47439265 else 6
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["col_det"]) or (x["col_det"] < -0.361822128)
                            else 10
                        )
                        if state == 9:
                            state = (
                                15
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.2712402)
                                else 16
                            )
                            if state == 15:
                                return 0.0828181952
                            if state == 16:
                                state = (
                                    27
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.0347023)
                                    else 28
                                )
                                if state == 27:
                                    return -0.100019835
                                if state == 28:
                                    state = (
                                        41
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.0201250017)
                                        else 42
                                    )
                                    if state == 41:
                                        state = (
                                            53
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 25.1215019)
                                            else 54
                                        )
                                        if state == 53:
                                            return 0.133690283
                                        if state == 54:
                                            return -0.0421656258
                                    if state == 42:
                                        return -0.0815979242
                        if state == 10:
                            state = (
                                17
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.4400139)
                                else 18
                            )
                            if state == 17:
                                return 0.00314852176
                            if state == 18:
                                state = (
                                    31
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 20.4189339)
                                    else 32
                                )
                                if state == 31:
                                    state = (
                                        45 if x["sgscore1_med"] < 0.0238124989 else 46
                                    )
                                    if state == 45:
                                        return 0.0422668047
                                    if state == 46:
                                        return -0.139597535
                                if state == 32:
                                    return 0.00131460628
                    if state == 6:
                        state = 11 if x["col_det"] < 0.0414419174 else 12
                        if state == 11:
                            return -0.0701307058
                        if state == 12:
                            state = (
                                21
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 20.0424004)
                                else 22
                            )
                            if state == 21:
                                state = (
                                    35
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.5312958)
                                    else 36
                                )
                                if state == 35:
                                    return 0.00702018151
                                if state == 36:
                                    state = (
                                        49
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.503708482)
                                        else 50
                                    )
                                    if state == 49:
                                        state = (
                                            59 if x["neargaia_med"] < 2.77428055 else 60
                                        )
                                        if state == 59:
                                            return -0.054083854
                                        if state == 60:
                                            return 0.188781366
                                    if state == 50:
                                        return 0.0103422906
                            if state == 22:
                                return 0.00571461394
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 6.27143288)
                        else 8
                    )
                    if state == 7:
                        return -0.106019564
                    if state == 8:
                        state = 13 if x["col_det"] < 0.0596456528 else 14
                        if state == 13:
                            return 0.0679752603
                        if state == 14:
                            return -0.074011974
    elif num_booster == 43:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.6380005) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 2.67024803)
                    else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.88178575) else 8
                    )
                    if state == 7:
                        return -0.138775408
                    if state == 8:
                        return 0.0536069945
                if state == 4:
                    return 0.00841690972
            if state == 2:
                state = (
                    5
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 28.7859173)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.733452559)
                        else 12
                    )
                    if state == 11:
                        state = 17 if x["maggaia_med"] < 17.8218079 else 18
                        if state == 17:
                            return -0.0971149653
                        if state == 18:
                            state = (
                                23
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.00404514978)
                                else 24
                            )
                            if state == 23:
                                return -0.078793183
                            if state == 24:
                                state = (
                                    31
                                    if np.isnan(x["neargaia_med"])
                                    or (x["neargaia_med"] < 1.85272598)
                                    else 32
                                )
                                if state == 31:
                                    state = 33 if x["magnr_med"] < 21.9362507 else 34
                                    if state == 33:
                                        return -0.0328138322
                                    if state == 34:
                                        return 0.100860476
                                if state == 32:
                                    state = 35 if x["magnr_med"] < 22.3322506 else 36
                                    if state == 35:
                                        return 0.138274267
                                    if state == 36:
                                        return -0.0453140624
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 16.8267136)
                            else 20
                        )
                        if state == 19:
                            return 0.0471555665
                        if state == 20:
                            state = (
                                27
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0373958498)
                                else 28
                            )
                            if state == 27:
                                return 0.0560154989
                            if state == 28:
                                return -0.167205527
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.49666661)
                        else 14
                    )
                    if state == 13:
                        return 0.00672265561
                    if state == 14:
                        state = 21 if x["maggaia_med"] < 19.7799625 else 22
                        if state == 21:
                            state = (
                                29
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0294502489)
                                else 30
                            )
                            if state == 29:
                                return -0.0258067492
                            if state == 30:
                                return 0.178858399
                        if state == 22:
                            return -0.0200489126
    elif num_booster == 44:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0407233499) else 2
            if state == 1:
                return -0.0742460862
            if state == 2:
                state = 5 if x["neargaia_med"] < 10.4105072 else 6
                if state == 5:
                    return 0.0628610998
                if state == 6:
                    state = (
                        13 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.93840861) else 14
                    )
                    if state == 13:
                        state = (
                            21
                            if np.isnan(x["col_det"]) or (x["col_det"] < -0.446475983)
                            else 22
                        )
                        if state == 21:
                            return 0.130560935
                        if state == 22:
                            state = (
                                31
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.383571327)
                                else 32
                            )
                            if state == 31:
                                return 0.0690542161
                            if state == 32:
                                state = 37 if x["col_det"] < -0.111516953 else 38
                                if state == 37:
                                    return -0.186390951
                                if state == 38:
                                    state = 43 if x["neargaia_med"] < 28.9235077 else 44
                                    if state == 43:
                                        return -0.0862248465
                                    if state == 44:
                                        return 0.0947969928
                    if state == 14:
                        return -0.0494943969
    elif num_booster == 45:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 0.0862373039)
                else 2
            )
            if state == 1:
                return -0.0457016528
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0623322502) else 6
                if state == 5:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.3487968)
                        else 8
                    )
                    if state == 7:
                        state = 11 if x["magnr_med"] < 19.7137489 else 12
                        if state == 11:
                            return 0.0712158158
                        if state == 12:
                            state = (
                                17
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.526904941)
                                else 18
                            )
                            if state == 17:
                                state = (
                                    27
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.796000004)
                                    else 28
                                )
                                if state == 27:
                                    return -0.071764864
                                if state == 28:
                                    return 0.0892926604
                            if state == 18:
                                return -0.119230844
                    if state == 8:
                        return -0.117249325
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.2328415)
                        else 10
                    )
                    if state == 9:
                        state = 13 if x["magnr_med"] < 18.3637505 else 14
                        if state == 13:
                            state = (
                                19
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.580833316)
                                else 20
                            )
                            if state == 19:
                                return -0.113132216
                            if state == 20:
                                state = (
                                    29
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.976750016)
                                    else 30
                                )
                                if state == 29:
                                    state = 37 if x["distnr_med"] < 0.961011529 else 38
                                    if state == 37:
                                        return -0.104012035
                                    if state == 38:
                                        return 0.0442859828
                                if state == 30:
                                    return 0.115480721
                        if state == 14:
                            state = (
                                21
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.835357308)
                                else 22
                            )
                            if state == 21:
                                return 0.126259401
                            if state == 22:
                                return -0.0579369217
                    if state == 10:
                        return -0.0567421094
    elif num_booster == 46:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 19.9310112 else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.883214176) else 4
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.733333409) else 8
                    )
                    if state == 7:
                        state = 13 if x["distnr_med"] < 5.86913109 else 14
                        if state == 13:
                            state = 25 if x["distnr_med"] < 0.699022412 else 26
                            if state == 25:
                                state = 29 if x["sgscore1_med"] < 0.0110208355 else 30
                                if state == 29:
                                    return 0.0577592179
                                if state == 30:
                                    return -0.131299913
                            if state == 26:
                                state = (
                                    31
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.418479502)
                                    else 32
                                )
                                if state == 31:
                                    state = 33 if x["maggaia_med"] < 19.4244957 else 34
                                    if state == 33:
                                        state = (
                                            37 if x["distnr_med"] < 1.78412545 else 38
                                        )
                                        if state == 37:
                                            state = (
                                                39
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0518362969)
                                                else 40
                                            )
                                            if state == 39:
                                                return 0.113406703
                                            if state == 40:
                                                return -0.050853435
                                        if state == 38:
                                            return 0.142285436
                                    if state == 34:
                                        return -0.105332032
                                if state == 32:
                                    return -0.0469031483
                        if state == 14:
                            return -0.147305503
                    if state == 8:
                        state = 15 if x["distnr_med"] < 0.208828807 else 16
                        if state == 15:
                            return 0.0401141867
                        if state == 16:
                            return -0.162319079
                if state == 4:
                    return 0.116460182
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.580000043) else 6
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.382737815)
                        else 10
                    )
                    if state == 9:
                        return 0.0692531317
                    if state == 10:
                        state = 19 if x["distnr_med"] < 6.14177227 else 20
                        if state == 19:
                            return -0.125217021
                        if state == 20:
                            return 0.084343262
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.753095269)
                        else 12
                    )
                    if state == 11:
                        state = 21 if x["distnr_med"] < 2.59481144 else 22
                        if state == 21:
                            return 0.134252846
                        if state == 22:
                            return -0.0740007386
                    if state == 12:
                        return -0.0129750893
    elif num_booster == 47:
        state = 0
        if state == 0:
            state = 1 if x["magnr_med"] < 21.7132492 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.97357059)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.93457747)
                        else 8
                    )
                    if state == 7:
                        state = 13 if x["col_det"] < 0.128781319 else 14
                        if state == 13:
                            return -0.0654625297
                        if state == 14:
                            state = 25 if x["magnr_med"] < 19.7147503 else 26
                            if state == 25:
                                state = 39 if x["distnr_med"] < 1.77578926 else 40
                                if state == 39:
                                    return 0.0131625915
                                if state == 40:
                                    return 0.169812396
                            if state == 26:
                                state = 41 if x["distnr_med"] < 0.731696486 else 42
                                if state == 41:
                                    return 0.0836014301
                                if state == 42:
                                    return -0.131437257
                    if state == 8:
                        return 0.115993053
                if state == 4:
                    return -0.0401026011
            if state == 2:
                return -0.0883183032
    elif num_booster == 48:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7072124) else 2
            if state == 1:
                state = 3 if x["sgscore1_med"] < 0.00204166491 else 4
                if state == 3:
                    return -0.0695437267
                if state == 4:
                    state = 7 if x["neargaia_med"] < 6.98908234 else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.213014513)
                            else 14
                        )
                        if state == 13:
                            state = 19 if x["sgscore1_med"] < 0.137127489 else 20
                            if state == 19:
                                return -0.0455117449
                            if state == 20:
                                return 0.119928963
                        if state == 14:
                            return -0.114146121
                    if state == 8:
                        state = 15 if x["sgscore1_med"] < 0.0586815476 else 16
                        if state == 15:
                            return 0.134687021
                        if state == 16:
                            state = 21 if x["sgscore1_med"] < 0.149636999 else 22
                            if state == 21:
                                return -0.0512833074
                            if state == 22:
                                state = (
                                    27
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.3405457)
                                    else 28
                                )
                                if state == 27:
                                    return -0.0214568898
                                if state == 28:
                                    state = (
                                        33
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.502499998)
                                        else 34
                                    )
                                    if state == 33:
                                        return -0.0296124723
                                    if state == 34:
                                        state = (
                                            39
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 0.0355671495)
                                            else 40
                                        )
                                        if state == 39:
                                            return -0.0418964699
                                        if state == 40:
                                            return 0.159826279
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.0030878)
                    else 6
                )
                if state == 5:
                    return 0.0401873887
                if state == 6:
                    return -0.0878552943
    elif num_booster == 49:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 6.53480959)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.584944963)
                    else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0200579017) else 8
                    )
                    if state == 7:
                        return -0.0816905349
                    if state == 8:
                        state = 11 if x["distpsnr1_med"] < 0.0847772956 else 12
                        if state == 11:
                            return -0.102715075
                        if state == 12:
                            state = (
                                15
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.04649305)
                                else 16
                            )
                            if state == 15:
                                return -0.0542964749
                            if state == 16:
                                state = (
                                    21
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.91218758)
                                    else 22
                                )
                                if state == 21:
                                    state = (
                                        27
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.406496)
                                        else 28
                                    )
                                    if state == 27:
                                        return -0.0628758147
                                    if state == 28:
                                        state = (
                                            35
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.5580044)
                                            else 36
                                        )
                                        if state == 35:
                                            return 0.145735726
                                        if state == 36:
                                            state = (
                                                43
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.97057295)
                                                else 44
                                            )
                                            if state == 43:
                                                return 0.0861398578
                                            if state == 44:
                                                return -0.118364364
                                if state == 22:
                                    state = (
                                        29
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.7686653)
                                        else 30
                                    )
                                    if state == 29:
                                        return 0.0508902706
                                    if state == 30:
                                        return -0.147576347
                if state == 4:
                    return -0.10890118
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.0114374999)
                    else 6
                )
                if state == 5:
                    return -0.0393709466
                if state == 6:
                    state = (
                        9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0206017997) else 10
                    )
                    if state == 9:
                        return -0.0549040921
                    if state == 10:
                        return 0.108398035
    elif num_booster == 50:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.119902998)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 4.5816927)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4999504)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.981750011)
                            else 16
                        )
                        if state == 15:
                            return -0.0269332658
                        if state == 16:
                            state = 25 if x["magnr_med"] < 21.161499 else 26
                            if state == 25:
                                return 0.149898723
                            if state == 26:
                                return -0.0522688217
                    if state == 8:
                        return -0.120548181
                if state == 4:
                    return 0.00813348498
            if state == 2:
                state = 5 if x["distnr_med"] < 0.64575696 else 6
                if state == 5:
                    return -0.0596508905
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.6693573)
                        else 14
                    )
                    if state == 13:
                        state = (
                            21
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.635249972)
                            else 22
                        )
                        if state == 21:
                            return -0.104022354
                        if state == 22:
                            state = 31 if x["magnr_med"] < 20.0709991 else 32
                            if state == 31:
                                return 0.139890179
                            if state == 32:
                                state = (
                                    39
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.4115982)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        45
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 17.9982452)
                                        else 46
                                    )
                                    if state == 45:
                                        return -0.0412640683
                                    if state == 46:
                                        return 0.0993828103
                                if state == 40:
                                    return -0.102994852
                    if state == 14:
                        return 0.0927764475
    elif num_booster == 51:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.00281250011 else 2
            if state == 1:
                return -0.0606961884
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.492864847 else 6
                if state == 5:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.04328705)
                        else 8
                    )
                    if state == 7:
                        return 0.101189278
                    if state == 8:
                        return -0.120841235
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.82625008)
                        else 10
                    )
                    if state == 9:
                        state = (
                            11
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0386285)
                            else 12
                        )
                        if state == 11:
                            return 0.0604716279
                        if state == 12:
                            return -0.077085726
                    if state == 10:
                        return 0.0627267361
    elif num_booster == 52:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < 0.207983017) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9853001) else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.879999876) else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.958000004)
                            else 16
                        )
                        if state == 15:
                            return -0.100015715
                        if state == 16:
                            return 0.00139331492
                    if state == 8:
                        return 0.067746833
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.395000011)
                        else 10
                    )
                    if state == 9:
                        return -0.0542117134
                    if state == 10:
                        return 0.084872365
            if state == 2:
                return -0.0768339261
    elif num_booster == 53:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 19.0999393 else 2
            if state == 1:
                state = 3 if x["maggaia_med"] < 18.6130486 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.88228011)
                        else 8
                    )
                    if state == 7:
                        return 0.077396147
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.822857141)
                            else 16
                        )
                        if state == 15:
                            state = (
                                21
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.451666594)
                                else 22
                            )
                            if state == 21:
                                return 0.0395127088
                            if state == 22:
                                state = 27 if x["maggaia_med"] < 17.8532715 else 28
                                if state == 27:
                                    return -0.146986589
                                if state == 28:
                                    return 0.0299496651
                        if state == 16:
                            return 0.0533426739
                if state == 4:
                    return -0.110233031
            if state == 2:
                state = 5 if x["maggaia_med"] < 19.4107971 else 6
                if state == 5:
                    return 0.10651572
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.95881367)
                        else 12
                    )
                    if state == 11:
                        return -0.0728850365
                    if state == 12:
                        return 0.102723569
    elif num_booster == 54:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.0406249985 else 2
            if state == 1:
                state = 3 if x["sgscore1_med"] < 0.00774999987 else 4
                if state == 3:
                    state = 7 if x["distnr_med"] < 1.3882103 else 8
                    if state == 7:
                        return 0.0905046239
                    if state == 8:
                        return -0.0885332599
                if state == 4:
                    return 0.0714006275
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.119902998 else 6
                if state == 5:
                    return -0.10208796
                if state == 6:
                    state = 11 if x["distnr_med"] < 1.06072903 else 12
                    if state == 11:
                        return 0.0530361496
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.92714691)
                            else 20
                        )
                        if state == 19:
                            return -0.0747711137
                        if state == 20:
                            return 0.0299012382
    elif num_booster == 55:
        state = 0
        if state == 0:
            state = 1 if x["magnr_med"] < 20.3287506 else 2
            if state == 1:
                state = 3 if x["sgscore1_med"] < 0.00562500022 else 4
                if state == 3:
                    return -0.0678295195
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7049294)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.319568276)
                            else 16
                        )
                        if state == 15:
                            state = 21 if x["magnr_med"] < 16.5545006 else 22
                            if state == 21:
                                return -0.0663626641
                            if state == 22:
                                return 0.131193399
                        if state == 16:
                            return -0.0376915671
                    if state == 10:
                        state = 17 if x["sgscore1_med"] < 0.0847499967 else 18
                        if state == 17:
                            state = 25 if x["magnr_med"] < 19.5857506 else 26
                            if state == 25:
                                return -0.1458866
                            if state == 26:
                                return 0.0837652981
                        if state == 18:
                            return 0.0258391891
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.0162083507 else 6
                if state == 5:
                    return 0.0223107897
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8176193)
                        else 14
                    )
                    if state == 13:
                        return -0.0842192098
                    if state == 14:
                        state = 19 if x["sgscore1_med"] < 0.410145998 else 20
                        if state == 19:
                            return -0.0669817775
                        if state == 20:
                            state = (
                                29
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 22.3222504)
                                else 30
                            )
                            if state == 29:
                                return -0.0601223372
                            if state == 30:
                                return 0.107313752
    elif num_booster == 56:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.9823125 else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.650000215) else 4
                if state == 3:
                    state = 7 if x["distnr_med"] < 0.808425784 else 8
                    if state == 7:
                        return -0.0799484402
                    if state == 8:
                        state = 17 if x["distpsnr1_med"] < 1.12061048 else 18
                        if state == 17:
                            return -0.0236024894
                        if state == 18:
                            state = 23 if x["distnr_med"] < 9.35765076 else 24
                            if state == 23:
                                state = (
                                    27
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.733999968)
                                    else 28
                                )
                                if state == 27:
                                    return -0.0223080311
                                if state == 28:
                                    return 0.137554303
                            if state == 24:
                                return -0.0112476116
                if state == 4:
                    state = 9 if x["distnr_med"] < 0.468597054 else 10
                    if state == 9:
                        return -0.0788545087
                    if state == 10:
                        state = 21 if x["distpsnr1_med"] < 7.0544672 else 22
                        if state == 21:
                            state = 25 if x["distnr_med"] < 2.59656858 else 26
                            if state == 25:
                                state = (
                                    29
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.893749952)
                                    else 30
                                )
                                if state == 29:
                                    return 0.0850601494
                                if state == 30:
                                    state = 35 if x["magnr_med"] < 18.5927505 else 36
                                    if state == 35:
                                        return -0.121502183
                                    if state == 36:
                                        return 0.0772258192
                            if state == 26:
                                return -0.123510733
                        if state == 22:
                            return 0.0732715651
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.533333421) else 6
                if state == 5:
                    state = 11 if x["distnr_med"] < 0.701883912 else 12
                    if state == 11:
                        return 0.0867624134
                    if state == 12:
                        return -0.0645353645
                if state == 6:
                    return -0.0708936751
    elif num_booster == 57:
        state = 0
        if state == 0:
            state = 1 if x["magnr_med"] < 18.3654995 else 2
            if state == 1:
                return -0.0917271152
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.500625014 else 6
                if state == 5:
                    return 0.0596567355
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.956839502)
                        else 12
                    )
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 16.7245636)
                            else 20
                        )
                        if state == 19:
                            state = 29 if x["distnr_med"] < 4.82937908 else 30
                            if state == 29:
                                state = (
                                    35
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 20.4657192)
                                    else 36
                                )
                                if state == 35:
                                    return 0.0814813673
                                if state == 36:
                                    return -0.0605932139
                            if state == 30:
                                return -0.0321487412
                        if state == 20:
                            return -0.0890430883
                    if state == 12:
                        return -0.0889320523
    elif num_booster == 58:
        return -0.00766548188
    elif num_booster == 59:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1859512) else 2
            if state == 1:
                state = 3 if x["neargaia_med"] < 28.7846642 else 4
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.678809643) else 8
                    )
                    if state == 7:
                        return -0.0453691892
                    if state == 8:
                        state = 17 if x["magnr_med"] < 17.3715 else 18
                        if state == 17:
                            return 0.126925558
                        if state == 18:
                            return -0.0233807378
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.867857337)
                        else 10
                    )
                    if state == 9:
                        return 0.084864758
                    if state == 10:
                        return -0.0590884313
            if state == 2:
                state = (
                    5
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 21.1738548)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.414642662)
                        else 12
                    )
                    if state == 11:
                        state = 21 if x["magnr_med"] < 21.9550018 else 22
                        if state == 21:
                            return -0.142759234
                        if state == 22:
                            return 0.0515590012
                    if state == 12:
                        state = 23 if x["magnr_med"] < 19.5682487 else 24
                        if state == 23:
                            return -0.054550536
                        if state == 24:
                            return 0.0997822657
                if state == 6:
                    return -0.12745969
    elif num_booster == 60:
        state = 0
        if state == 0:
            state = 1 if x["magnr_med"] < 22.0602493 else 2
            if state == 1:
                state = 3 if x["sgscore1_med"] < 0.317470014 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.747999966)
                        else 8
                    )
                    if state == 7:
                        return -0.0878475904
                    if state == 8:
                        return 0.0979402363
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.870249987)
                        else 10
                    )
                    if state == 9:
                        return -0.107360721
                    if state == 10:
                        return 0.00922169909
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.367482007)
                    else 6
                )
                if state == 5:
                    return -0.146315023
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.919499993)
                        else 12
                    )
                    if state == 11:
                        return 0.0906031802
                    if state == 12:
                        return -0.0823387727
    elif num_booster == 61:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0195717495) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.5938492) else 4
                )
                if state == 3:
                    return 0.0311457347
                if state == 4:
                    return -0.144724995
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4860001) else 6
                )
                if state == 5:
                    state = 7 if x["magnr_med"] < 19.8024998 else 8
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.617500007)
                            else 12
                        )
                        if state == 11:
                            return -0.0719697103
                        if state == 12:
                            state = 17 if x["neargaia_med"] < 6.99839211 else 18
                            if state == 17:
                                state = 25 if x["neargaia_med"] < 0.413720965 else 26
                                if state == 25:
                                    return 0.0926594213
                                if state == 26:
                                    return -0.0524383821
                            if state == 18:
                                return 0.0949563459
                    if state == 8:
                        return -0.0208603218
                if state == 6:
                    return -0.0446178429
    elif num_booster == 62:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.511190414) else 2
            if state == 1:
                return -0.0270207673
            if state == 2:
                state = 5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.0007) else 6
                if state == 5:
                    return -0.0802389532
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7842503)
                        else 10
                    )
                    if state == 9:
                        state = (
                            13
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.99838543)
                            else 14
                        )
                        if state == 13:
                            state = (
                                19
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0317130014)
                                else 20
                            )
                            if state == 19:
                                state = (
                                    27
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.92177081)
                                    else 28
                                )
                                if state == 27:
                                    return -0.0886406973
                                if state == 28:
                                    return 0.0721398294
                            if state == 20:
                                return 0.0998461843
                        if state == 14:
                            return -0.0249999631
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.112783551)
                            else 16
                        )
                        if state == 15:
                            state = (
                                21
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0196701512)
                                else 22
                            )
                            if state == 21:
                                return -0.100950189
                            if state == 22:
                                state = (
                                    29
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.89795732)
                                    else 30
                                )
                                if state == 29:
                                    return 0.0142580969
                                if state == 30:
                                    state = 35 if x["col_det"] < 0.212035179 else 36
                                    if state == 35:
                                        return 0.053412687
                                    if state == 36:
                                        return -0.113542743
                        if state == 16:
                            return 0.0417340472
    elif num_booster == 63:
        state = 0
        if state == 0:
            state = 1 if x["magnr_med"] < 22.0602493 else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.4461823) else 4
                )
                if state == 3:
                    return 0.0672043115
                if state == 4:
                    state = 9 if x["magnr_med"] < 18.0037498 else 10
                    if state == 9:
                        return -0.0688755661
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.0569115)
                            else 18
                        )
                        if state == 17:
                            state = (
                                25
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 18.965313)
                                else 26
                            )
                            if state == 25:
                                return 0.0785110965
                            if state == 26:
                                state = (
                                    35
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.9660339)
                                    else 36
                                )
                                if state == 35:
                                    return -0.100175999
                                if state == 36:
                                    return 0.0736256018
                        if state == 18:
                            state = (
                                27
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 18.801321)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    37
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 20.2104797)
                                    else 38
                                )
                                if state == 37:
                                    return -0.0666340515
                                if state == 38:
                                    state = (
                                        47 if x["sgscore1_med"] < 0.0192291513 else 48
                                    )
                                    if state == 47:
                                        return -0.100892499
                                    if state == 48:
                                        return 0.102973886
                            if state == 28:
                                return -0.0770201981
            if state == 2:
                return -0.0719390363
    elif num_booster == 64:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.4327507) else 2
            if state == 1:
                return -0.0252696164
            if state == 2:
                state = (
                    5
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.95854759)
                    else 6
                )
                if state == 5:
                    return 0.00868856069
                if state == 6:
                    state = (
                        13 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0104339998) else 14
                    )
                    if state == 13:
                        return -0.0102124028
                    if state == 14:
                        state = (
                            23
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.864500046)
                            else 24
                        )
                        if state == 23:
                            state = (
                                33
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.800000012)
                                else 34
                            )
                            if state == 33:
                                return 0.0891654417
                            if state == 34:
                                return -0.0971884131
                        if state == 24:
                            return 0.118607692
    elif num_booster == 65:
        state = 0
        if state == 0:
            state = 1 if x["magnr_med"] < 17.5467491 else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.721190631) else 4
                if state == 3:
                    return -0.149837345
                if state == 4:
                    return 0.0483120382
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.536547542) else 6
                if state == 5:
                    return 0.0471913368
                if state == 6:
                    state = 11 if x["distnr_med"] < 3.36395979 else 12
                    if state == 11:
                        state = 15 if x["magnr_med"] < 21.161499 else 16
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.8040657)
                                else 24
                            )
                            if state == 23:
                                return 0.097403951
                            if state == 24:
                                state = (
                                    27
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.9220905)
                                    else 28
                                )
                                if state == 27:
                                    return -0.0899719819
                                if state == 28:
                                    state = (
                                        31
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.4670792)
                                        else 32
                                    )
                                    if state == 31:
                                        state = (
                                            33
                                            if x["sgscore1_med"] < 0.0203333013
                                            else 34
                                        )
                                        if state == 33:
                                            return -0.0666222796
                                        if state == 34:
                                            return 0.103534706
                                    if state == 32:
                                        return -0.0852313414
                        if state == 16:
                            return -0.0801583678
                    if state == 12:
                        return -0.0800962225
    elif num_booster == 66:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.617750049)
                else 2
            )
            if state == 1:
                return -0.100329936
            if state == 2:
                state = (
                    3 if np.isnan(x["col_det"]) or (x["col_det"] < 0.0726747513) else 4
                )
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 4.19241428)
                        else 6
                    )
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.9917507)
                            else 10
                        )
                        if state == 9:
                            return -0.0647079051
                        if state == 10:
                            state = 17 if x["magnr_med"] < 18.5939999 else 18
                            if state == 17:
                                return 0.0944153294
                            if state == 18:
                                state = (
                                    27
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.0382118523)
                                    else 28
                                )
                                if state == 27:
                                    return 0.0136178182
                                if state == 28:
                                    state = 33 if x["magnr_med"] < 19.8487511 else 34
                                    if state == 33:
                                        return -0.0879304335
                                    if state == 34:
                                        state = (
                                            39
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.964249969)
                                            else 40
                                        )
                                        if state == 39:
                                            return 0.0794270635
                                        if state == 40:
                                            return -0.113810755
                    if state == 6:
                        return 0.0360550396
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 0.0856859684)
                        else 8
                    )
                    if state == 7:
                        return -0.0567062125
                    if state == 8:
                        return 0.116326414
    elif num_booster == 67:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.00774999987 else 2
            if state == 1:
                return -0.0878765807
            if state == 2:
                state = 5 if x["col_det"] < -0.350215912 else 6
                if state == 5:
                    return -0.111599058
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.394001)
                        else 10
                    )
                    if state == 9:
                        state = (
                            13
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.954750001)
                            else 14
                        )
                        if state == 13:
                            state = (
                                17
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 27.2281685)
                                else 18
                            )
                            if state == 17:
                                state = 23 if x["neargaia_med"] < 3.23744392 else 24
                                if state == 23:
                                    return 0.0262294281
                                if state == 24:
                                    return -0.104758985
                            if state == 18:
                                return 0.0629292578
                        if state == 14:
                            return 0.0298997387
                    if state == 10:
                        return 0.0632319227
    elif num_booster == 68:
        state = 0
        if state == 0:
            state = 1 if x["distnr_med"] < 4.15871811 else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.733452559) else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.956249952)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0289745)
                            else 14
                        )
                        if state == 13:
                            return -0.132757828
                        if state == 14:
                            state = 21 if x["maggaia_med"] < 19.4357758 else 22
                            if state == 21:
                                return 0.0909414291
                            if state == 22:
                                return -0.0718801171
                    if state == 8:
                        return 0.132805094
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.782500029)
                        else 10
                    )
                    if state == 9:
                        return 0.0769789144
                    if state == 10:
                        return -0.0881410986
            if state == 2:
                return -0.0494015776
    elif num_booster == 69:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 17.4135361 else 2
            if state == 1:
                return 0.026190633
            if state == 2:
                state = (
                    5
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.1371384)
                    else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 12.2973423)
                        else 10
                    )
                    if state == 9:
                        state = 15 if x["col_det"] < 0.415416718 else 16
                        if state == 15:
                            return 0.026110813
                        if state == 16:
                            state = (
                                21
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.00406837)
                                else 22
                            )
                            if state == 21:
                                state = (
                                    29
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.722499847)
                                    else 30
                                )
                                if state == 29:
                                    return -0.00292111957
                                if state == 30:
                                    return -0.172208548
                            if state == 22:
                                return 0.047390487
                    if state == 10:
                        return -0.076689221
                if state == 6:
                    return 0.0131140901
    elif num_booster == 70:
        return -0.00577309541
    elif num_booster == 71:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0291724503) else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.00137155014) else 4
                if state == 3:
                    return -0.0671450347
                if state == 4:
                    return 0.0855460986
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.113969952) else 6
                if state == 5:
                    state = 9 if x["magnr_med"] < 22.7992496 else 10
                    if state == 9:
                        state = 13 if x["maggaia_med"] < 19.4115982 else 14
                        if state == 13:
                            state = (
                                19
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0336042009)
                                else 20
                            )
                            if state == 19:
                                return 0.0634400174
                            if state == 20:
                                return -0.0922276303
                        if state == 14:
                            return -0.110195279
                    if state == 10:
                        return 0.0593296327
                if state == 6:
                    state = 11 if x["magnr_med"] < 17.3435001 else 12
                    if state == 11:
                        return 0.0296825171
                    if state == 12:
                        state = 17 if x["maggaia_med"] < 19.0922775 else 18
                        if state == 17:
                            return 0.0242977142
                        if state == 18:
                            return -0.0874383226
    elif num_booster == 72:
        return 0.0189674441
    elif num_booster == 73:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 16.3983517 else 2
            if state == 1:
                return -0.0637473762
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.957051039)
                    else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.536547542)
                        else 10
                    )
                    if state == 9:
                        return 0.0498849526
                    if state == 10:
                        state = 13 if x["maggaia_med"] < 18.008667 else 14
                        if state == 13:
                            return 0.0515075922
                        if state == 14:
                            state = (
                                17
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 6.53033781)
                                else 18
                            )
                            if state == 17:
                                return -0.0457098447
                            if state == 18:
                                return 0.0781349093
                if state == 6:
                    return -0.0651269332
    elif num_booster == 74:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.706501) else 2
            if state == 1:
                return -0.0906154588
            if state == 2:
                state = 3 if x["maggaia_med"] < 19.1041794 else 4
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.642383993)
                        else 6
                    )
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.6837006)
                            else 10
                        )
                        if state == 9:
                            return 0.0349690206
                        if state == 10:
                            state = 17 if x["magnr_med"] < 18.5605011 else 18
                            if state == 17:
                                return -0.1106923
                            if state == 18:
                                return 0.0192105174
                    if state == 6:
                        return -0.0789164975
                if state == 4:
                    return 0.0573318265
    elif num_booster == 75:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 12.038763)
                else 2
            )
            if state == 1:
                state = 3 if x["magnr_med"] < 22.2439995 else 4
                if state == 3:
                    state = 7 if x["magnr_med"] < 20.3287506 else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.93674183)
                            else 14
                        )
                        if state == 13:
                            return 0.0717160329
                        if state == 14:
                            return -0.0409476124
                    if state == 8:
                        return -0.0657376349
                if state == 4:
                    return 0.0628934503
            if state == 2:
                return -0.0487761013
    elif num_booster == 76:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 0.522184193 else 2
            if state == 1:
                return -0.0512675308
            if state == 2:
                state = 5 if x["distnr_med"] < 2.5624249 else 6
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 41.6490822)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.768749952)
                            else 16
                        )
                        if state == 15:
                            return -0.0347160101
                        if state == 16:
                            state = (
                                23
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.512499928)
                                else 24
                            )
                            if state == 23:
                                return -0.0389181674
                            if state == 24:
                                return 0.104654595
                    if state == 10:
                        return -0.0757762864
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 16.5640144)
                        else 12
                    )
                    if state == 11:
                        return 0.0596412979
                    if state == 12:
                        return -0.0936794952
    elif num_booster == 77:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.593000054)
                else 2
            )
            if state == 1:
                return -0.0982018039
            if state == 2:
                state = 3 if x["maggaia_med"] < 17.3738327 else 4
                if state == 3:
                    return -0.056821391
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 0.984343529)
                        else 8
                    )
                    if state == 7:
                        return 0.0564725436
                    if state == 8:
                        state = (
                            11
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5127754)
                            else 12
                        )
                        if state == 11:
                            return 0.0466810651
                        if state == 12:
                            state = (
                                17
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.49271989)
                                else 18
                            )
                            if state == 17:
                                return 0.00690863933
                            if state == 18:
                                return -0.157933086
    elif num_booster == 78:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.0562744) else 2
            if state == 1:
                return 0.0336731784
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.4238319) else 6
                )
                if state == 5:
                    return -0.0844558179
                if state == 6:
                    return 0.046704568
    elif num_booster == 79:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.9917507) else 2
            )
            if state == 1:
                return -0.0404569134
            if state == 2:
                state = 5 if x["neargaia_med"] < 34.8755455 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.98574996)
                        else 12
                    )
                    if state == 11:
                        state = 17 if x["maggaia_med"] < 20.2380981 else 18
                        if state == 17:
                            return 0.0851085559
                        if state == 18:
                            return -0.0637193024
                    if state == 12:
                        return -0.0489872955
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.771999955)
                        else 14
                    )
                    if state == 13:
                        return -0.0760236382
                    if state == 14:
                        state = 21 if x["maggaia_med"] < 17.7177315 else 22
                        if state == 21:
                            return 0.0376456082
                        if state == 22:
                            state = 25 if x["distpsnr1_med"] < 17.5803566 else 26
                            if state == 25:
                                return -0.101309069
                            if state == 26:
                                return 0.0613505766
    elif num_booster == 80:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.925000012)
                else 2
            )
            if state == 1:
                return 0.0356339701
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.380378008)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.735833287)
                        else 12
                    )
                    if state == 11:
                        return 0.0791726857
                    if state == 12:
                        return -0.0669468418
                if state == 6:
                    return -0.0715935007
    elif num_booster == 81:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.6329994) else 2
            )
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.69083333) else 4
                if state == 3:
                    return -0.0956548378
                if state == 4:
                    state = 7 if x["sgscore1_med"] < 0.130116001 else 8
                    if state == 7:
                        return -0.0948466286
                    if state == 8:
                        return 0.113215283
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.533333421) else 6
                if state == 5:
                    return 0.0578587428
                if state == 6:
                    return -0.0374870561
    elif num_booster == 82:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.0826815516 else 2
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 0.15092507 else 4
                if state == 3:
                    return 0.0636750236
                if state == 4:
                    return -0.0810220838
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.216608286 else 6
                if state == 5:
                    return -0.0983166993
                if state == 6:
                    return 0.0371749476
    elif num_booster == 83:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 19.4314137)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["col_det"]) or (x["col_det"] < 0.235736847) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 18.3622265)
                        else 8
                    )
                    if state == 7:
                        return -0.0766444057
                    if state == 8:
                        state = 13 if x["neargaia_med"] < 2.66573143 else 14
                        if state == 13:
                            return 0.0745385364
                        if state == 14:
                            return -0.0794518366
                if state == 4:
                    return 0.0352594145
            if state == 2:
                return 0.0147256441
    elif num_booster == 84:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.56157124) else 2
            )
            if state == 1:
                return -0.0200344212
            if state == 2:
                state = (
                    5
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.99895811)
                    else 6
                )
                if state == 5:
                    return 0.0555846319
                if state == 6:
                    return -0.0393636338
    elif num_booster == 85:
        return -0.0091948323
    elif num_booster == 86:
        return 0.000853671751
    elif num_booster == 87:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 10.4068975 else 2
            if state == 1:
                return 0.0426127389
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.644285917) else 6
                if state == 5:
                    return -0.0525996089
                if state == 6:
                    return 0.0404563993
    elif num_booster == 88:
        return 0.00472516753
    elif num_booster == 89:
        state = 0
        if state == 0:
            state = 1 if x["magnr_med"] < 22.0602493 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.3797264)
                    else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.413571268) else 8
                    )
                    if state == 7:
                        return -0.0885086954
                    if state == 8:
                        return 0.041633483
                if state == 4:
                    return -0.0580154993
            if state == 2:
                return -0.0522805974
    elif num_booster == 90:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.1674366) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 26.2886658)
                    else 4
                )
                if state == 3:
                    state = 7 if x["col_det"] < 0.0726747513 else 8
                    if state == 7:
                        return -0.0654467195
                    if state == 8:
                        state = 17 if x["sgscore1_med"] < 0.0475624986 else 18
                        if state == 17:
                            return 0.0603041276
                        if state == 18:
                            state = 27 if x["magnr_med"] < 21.2635002 else 28
                            if state == 27:
                                return -0.0542250909
                            if state == 28:
                                return 0.0673738942
                if state == 4:
                    state = 9 if x["col_det"] < -0.0407867432 else 10
                    if state == 9:
                        return -0.0416517407
                    if state == 10:
                        state = 19 if x["sgscore1_med"] < 0.0036249999 else 20
                        if state == 19:
                            return -0.0738520175
                        if state == 20:
                            return 0.103103325
            if state == 2:
                return -0.0807990804
    elif num_booster == 91:
        state = 0
        if state == 0:
            state = 1 if x["magnr_med"] < 22.0602493 else 2
            if state == 1:
                state = 3 if x["neargaia_med"] < 6.98908234 else 4
                if state == 3:
                    return -0.0518089384
                if state == 4:
                    state = 9 if x["magnr_med"] < 18.6227493 else 10
                    if state == 9:
                        return -0.025594173
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.767499983)
                            else 16
                        )
                        if state == 15:
                            return 0.0836137682
                        if state == 16:
                            return -0.0380724967
            if state == 2:
                return -0.0577936471
    elif num_booster == 92:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.83549333) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.1771851)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.00217605)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0129375001)
                            else 14
                        )
                        if state == 13:
                            return -0.0181386098
                        if state == 14:
                            state = 23 if x["magnr_med"] < 17.0532494 else 24
                            if state == 23:
                                return 0.000293811958
                            if state == 24:
                                state = (
                                    27
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.8791695)
                                    else 28
                                )
                                if state == 27:
                                    return 0.0430392027
                                if state == 28:
                                    return -0.147282347
                    if state == 8:
                        return 0.0122030256
                if state == 4:
                    return 0.0507497489
            if state == 2:
                state = 5 if x["maggaia_med"] < 20.2328415 else 6
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.96107054)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["sgscore1_med"] < 0.373211503 else 18
                        if state == 17:
                            return 0.0886910036
                        if state == 18:
                            return -0.0803347081
                    if state == 10:
                        return 0.0761027709
                if state == 6:
                    return -0.0321929976
    elif num_booster == 93:
        return 0.00788587704
    elif num_booster == 94:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.97724998)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7920418) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8374996)
                        else 8
                    )
                    if state == 7:
                        return -0.0913957357
                    if state == 8:
                        return 0.105837747
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8314514)
                        else 10
                    )
                    if state == 9:
                        return 0.0541905798
                    if state == 10:
                        return -0.0998337269
            if state == 2:
                return 0.0205878336
    elif num_booster == 95:
        return 0.0021443197
    elif num_booster == 96:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.00964117) else 2
            if state == 1:
                state = 3 if x["sgscore1_med"] < 0.336827517 else 4
                if state == 3:
                    return 0.055505313
                if state == 4:
                    state = 9 if x["maggaia_med"] < 19.9504242 else 10
                    if state == 9:
                        return -0.0658948421
                    if state == 10:
                        return 0.0416982025
            if state == 2:
                return -0.0782744363
    elif num_booster == 97:
        return 0.0201248415
    elif num_booster == 98:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.1238823) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.87671876)
                    else 4
                )
                if state == 3:
                    return 0.043691881
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.96515036)
                        else 10
                    )
                    if state == 9:
                        return -0.0685957298
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.343710899)
                            else 18
                        )
                        if state == 17:
                            state = (
                                25
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.5758858)
                                else 26
                            )
                            if state == 25:
                                return -0.0367292054
                            if state == 26:
                                return 0.103944883
                        if state == 18:
                            return -0.0525639504
            if state == 2:
                return -0.0402471721
    elif num_booster == 99:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5758858) else 2
            if state == 1:
                return -0.0249658078
            if state == 2:
                state = 5 if x["neargaia_med"] < 36.0913239 else 6
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.01377892) else 12
                    )
                    if state == 11:
                        return 0.0701781511
                    if state == 12:
                        return -0.0641591921
                if state == 6:
                    return -0.0131347477


def xgb_tree_3(x, num_booster):
    if num_booster == 0:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.944000006)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 30.4451332)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.877499998)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 1.16323137)
                            else 16
                        )
                        if state == 15:
                            return -0.313600004
                        if state == 16:
                            state = 27 if x["sgscore1_med"] < 0.332547486 else 28
                            if state == 27:
                                state = 41 if x["sgscore1_med"] < 0.0299166515 else 42
                                if state == 41:
                                    return -0.224000007
                                if state == 42:
                                    return 0.121794075
                            if state == 28:
                                return -0.280000001
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.909000039)
                            else 18
                        )
                        if state == 17:
                            state = (
                                29
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.1970005)
                                else 30
                            )
                            if state == 29:
                                return -0.112000003
                            if state == 30:
                                return 0.161434487
                        if state == 18:
                            state = (
                                31
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.97333336)
                                else 32
                            )
                            if state == 31:
                                return 0.0322559997
                            if state == 32:
                                return -0.232615381
                if state == 4:
                    state = 9 if x["neargaia_med"] < 56.6469116 else 10
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5810509)
                            else 20
                        )
                        if state == 19:
                            state = 33 if x["sgscore1_med"] < 0.00177083502 else 34
                            if state == 33:
                                return -0.0159629192
                            if state == 34:
                                return 0.249066979
                        if state == 20:
                            return -0.143999994
                    if state == 10:
                        return -0.2016
            if state == 2:
                state = 5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.276001) else 6
                if state == 5:
                    state = 11 if x["neargaia_med"] < 24.9923973 else 12
                    if state == 11:
                        state = 21 if x["distpsnr1_med"] < 7.83899212 else 22
                        if state == 21:
                            return -0.287999988
                        if state == 22:
                            return 0.0322559997
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.3089504)
                            else 24
                        )
                        if state == 23:
                            return -0.112000003
                        if state == 24:
                            return 0.208590612
                if state == 6:
                    state = 13 if x["distpsnr1_med"] < 0.153212503 else 14
                    if state == 13:
                        return -0.2016
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.712202013)
                            else 26
                        )
                        if state == 25:
                            state = (
                                37
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0340162516)
                                else 38
                            )
                            if state == 37:
                                return -0.0671999976
                            if state == 38:
                                state = (
                                    49
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.187175542)
                                    else 50
                                )
                                if state == 49:
                                    return -0.0671999976
                                if state == 50:
                                    return 0.307409644
                        if state == 26:
                            state = (
                                39
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.973999977)
                                else 40
                            )
                            if state == 39:
                                return -0.167999998
                            if state == 40:
                                return 0.0923550799
    elif num_booster == 1:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7672234) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6357498) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 3.64184141)
                        else 8
                    )
                    if state == 7:
                        return -0.238010198
                    if state == 8:
                        state = 17 if x["sgscore1_med"] < 0.618071496 else 18
                        if state == 17:
                            return 0.220449671
                        if state == 18:
                            return -0.160770699
                if state == 4:
                    state = 9 if x["distpsnr1_med"] < 0.868167281 else 10
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.050270848)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.9397507)
                                else 32
                            )
                            if state == 31:
                                return -0.0605713464
                            if state == 32:
                                return 0.233003139
                        if state == 20:
                            state = (
                                33
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.711666644)
                                else 34
                            )
                            if state == 33:
                                return -0.220658198
                            if state == 34:
                                state = (
                                    41
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.96045709)
                                    else 42
                                )
                                if state == 41:
                                    return 0.158980012
                                if state == 42:
                                    return -0.130089179
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 20.6646309)
                            else 22
                        )
                        if state == 21:
                            state = (
                                35
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.959818482)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    43
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.460500002)
                                    else 44
                                )
                                if state == 43:
                                    return -0.0570244193
                                if state == 44:
                                    return 0.276426226
                            if state == 36:
                                return -0.0999571607
                        if state == 22:
                            return -0.110059023
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.9962673) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 2.04569888)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8070488)
                            else 24
                        )
                        if state == 23:
                            return 0.0212526023
                        if state == 24:
                            return -0.250615776
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.97837973)
                            else 26
                        )
                        if state == 25:
                            state = 39 if x["maggaia_med"] < 16.3179131 else 40
                            if state == 39:
                                return -0.0624344535
                            if state == 40:
                                return 0.230058312
                        if state == 26:
                            return -0.123899341
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.890714288)
                        else 14
                    )
                    if state == 13:
                        return -0.281296462
                    if state == 14:
                        return 0.0300846696
    elif num_booster == 2:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.92050004)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 28.3113251)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 21.2101994)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.881428659)
                            else 16
                        )
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.03033543)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    41
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.55974817)
                                    else 42
                                )
                                if state == 41:
                                    return -0.259711623
                                if state == 42:
                                    state = (
                                        51
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.6054993)
                                        else 52
                                    )
                                    if state == 51:
                                        state = (
                                            57
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.93366337)
                                            else 58
                                        )
                                        if state == 57:
                                            return 0.128685147
                                        if state == 58:
                                            state = (
                                                67
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.4659996)
                                                else 68
                                            )
                                            if state == 67:
                                                return -0.19315733
                                            if state == 68:
                                                return 0.0776001662
                                    if state == 52:
                                        return -0.223537818
                            if state == 28:
                                return -0.0214146301
                        if state == 16:
                            return 0.0459842794
                    if state == 8:
                        return 0.123927981
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.0573997)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.4589996)
                            else 18
                        )
                        if state == 17:
                            return -0.123381414
                        if state == 18:
                            return 0.196734712
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.642499983)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.49644423)
                                else 32
                            )
                            if state == 31:
                                return 0.174962282
                            if state == 32:
                                return -0.162193432
                        if state == 20:
                            return -0.229435161
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.1480007) else 6
                )
                if state == 5:
                    state = 11 if x["neargaia_med"] < 23.9629917 else 12
                    if state == 11:
                        return -0.229532391
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.735776305)
                            else 22
                        )
                        if state == 21:
                            return -0.127762422
                        if state == 22:
                            return 0.134939209
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.5965004)
                        else 14
                    )
                    if state == 13:
                        state = (
                            23
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.422380805)
                            else 24
                        )
                        if state == 23:
                            return -0.14776665
                        if state == 24:
                            state = (
                                35
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.016180601)
                                else 36
                            )
                            if state == 35:
                                return -0.0680796653
                            if state == 36:
                                state = (
                                    45
                                    if np.isnan(x["neargaia_med"])
                                    or (x["neargaia_med"] < 61.521347)
                                    else 46
                                )
                                if state == 45:
                                    return 0.247885495
                                if state == 46:
                                    return -0.0536839701
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.489698797)
                            else 26
                        )
                        if state == 25:
                            state = (
                                37
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 34.5825272)
                                else 38
                            )
                            if state == 37:
                                return -0.216012657
                            if state == 38:
                                return 0.0715537667
                        if state == 26:
                            state = (
                                39
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.973500013)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    47
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 21.5180016)
                                    else 48
                                )
                                if state == 47:
                                    return 0.141123414
                                if state == 48:
                                    return -0.206484616
                            if state == 40:
                                state = 49 if x["neargaia_med"] < 8.69891071 else 50
                                if state == 49:
                                    return -0.106205955
                                if state == 50:
                                    state = (
                                        55
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.0401201248)
                                        else 56
                                    )
                                    if state == 55:
                                        return 0.229434714
                                    if state == 56:
                                        return -0.0638426393
    elif num_booster == 3:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.0442085) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.5514984)
                    else 4
                )
                if state == 3:
                    return -0.203019872
                if state == 4:
                    state = 9 if x["distpsnr1_med"] < 0.656560123 else 10
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.3530006)
                            else 16
                        )
                        if state == 15:
                            state = (
                                19
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.656666517)
                                else 20
                            )
                            if state == 19:
                                return -0.0814990401
                            if state == 20:
                                return 0.192291141
                        if state == 16:
                            state = (
                                21
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.00406249985)
                                else 22
                            )
                            if state == 21:
                                return 0.143344223
                            if state == 22:
                                state = (
                                    29
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.00034714)
                                    else 30
                                )
                                if state == 29:
                                    return -0.22902666
                                if state == 30:
                                    return 0.049245514
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.963776946)
                            else 18
                        )
                        if state == 17:
                            state = 23 if x["col_det"] < -0.508301258 else 24
                            if state == 23:
                                return -0.108681098
                            if state == 24:
                                state = (
                                    31
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.9982233)
                                    else 32
                                )
                                if state == 31:
                                    return 0.242264032
                                if state == 32:
                                    state = (
                                        41
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.6107216)
                                        else 42
                                    )
                                    if state == 41:
                                        state = (
                                            45
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.4819984)
                                            else 46
                                        )
                                        if state == 45:
                                            state = (
                                                47
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 17.5370007)
                                                else 48
                                            )
                                            if state == 47:
                                                return -0.0304900594
                                            if state == 48:
                                                return 0.199098051
                                        if state == 46:
                                            return -0.0192823391
                                    if state == 42:
                                        return -0.17397961
                        if state == 18:
                            return -0.0718256161
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 21.2101994) else 6
                )
                if state == 5:
                    return -0.247759789
                if state == 6:
                    return 0.0651815161
    elif num_booster == 4:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.924000025)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 5.53697681)
                    else 4
                )
                if state == 3:
                    state = 7 if x["sgscore1_med"] < 0.00883333478 else 8
                    if state == 7:
                        state = 15 if x["sgscore1_med"] < 0.00797916483 else 16
                        if state == 15:
                            state = 29 if x["neargaia_med"] < 59.713562 else 30
                            if state == 29:
                                return -0.184344605
                            if state == 30:
                                return 0.104241572
                        if state == 16:
                            return 0.17687057
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.02598381)
                            else 18
                        )
                        if state == 17:
                            state = (
                                31
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.881428659)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    41
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 21.9630013)
                                    else 42
                                )
                                if state == 41:
                                    return -0.229294419
                                if state == 42:
                                    state = (
                                        47
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 22.0880013)
                                        else 48
                                    )
                                    if state == 47:
                                        return 0.132965028
                                    if state == 48:
                                        return -0.147183061
                            if state == 32:
                                return -0.00601336779
                        if state == 18:
                            return 0.0439582951
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 6.72052193)
                        else 10
                    )
                    if state == 9:
                        return 0.180538118
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 23.2770004)
                            else 20
                        )
                        if state == 19:
                            return -0.18037346
                        if state == 20:
                            return 0.103351273
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.587669492)
                    else 6
                )
                if state == 5:
                    state = 11 if x["distpsnr1_med"] < 0.375561744 else 12
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.4475002)
                            else 22
                        )
                        if state == 21:
                            state = (
                                35
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0947411507)
                                else 36
                            )
                            if state == 35:
                                return 0.161501661
                            if state == 36:
                                return -0.114846446
                        if state == 22:
                            return -0.208841711
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.993499994)
                            else 24
                        )
                        if state == 23:
                            state = (
                                37
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 14.9554996)
                                else 38
                            )
                            if state == 37:
                                return -0.103396066
                            if state == 38:
                                state = (
                                    45
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 21.4274998)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        49
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.388095081)
                                        else 50
                                    )
                                    if state == 49:
                                        return -0.0911015719
                                    if state == 50:
                                        state = (
                                            53
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.942999959)
                                            else 54
                                        )
                                        if state == 53:
                                            state = (
                                                57
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.2609997)
                                                else 58
                                            )
                                            if state == 57:
                                                return -0.111766733
                                            if state == 58:
                                                return 0.142761946
                                        if state == 54:
                                            return 0.227580339
                                if state == 46:
                                    state = (
                                        51
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 9.12114239)
                                        else 52
                                    )
                                    if state == 51:
                                        return 0.150932491
                                    if state == 52:
                                        return -0.0677119195
                        if state == 24:
                            return -0.165766045
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.844523668)
                        else 14
                    )
                    if state == 13:
                        return -0.201483935
                    if state == 14:
                        return 0.0609389022
    elif num_booster == 5:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.970000029)
                else 2
            )
            if state == 1:
                state = 3 if x["col_det"] < 0.365387917 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 16.4900208)
                        else 8
                    )
                    if state == 7:
                        return -0.15909934
                    if state == 8:
                        state = 17 if x["sgscore1_med"] < 0.0322291479 else 18
                        if state == 17:
                            state = (
                                33
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.93599999)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    47
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.9828987)
                                    else 48
                                )
                                if state == 47:
                                    return 0.0571391098
                                if state == 48:
                                    return -0.183440983
                            if state == 34:
                                return 0.128888756
                        if state == 18:
                            state = (
                                35
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.93599999)
                                else 36
                            )
                            if state == 35:
                                return 0.180348441
                            if state == 36:
                                return -0.0485087447
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 21.0964508)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 5.03026772)
                            else 20
                        )
                        if state == 19:
                            state = (
                                37
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.05842018)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    53
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.947142839)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        61 if x["sgscore1_med"] < 0.000916666526 else 62
                                    )
                                    if state == 61:
                                        return 0.0139286481
                                    if state == 62:
                                        state = (
                                            69 if x["maggaia_med"] < 41.3903427 else 70
                                        )
                                        if state == 69:
                                            return -0.222020879
                                        if state == 70:
                                            state = (
                                                73
                                                if x["sgscore1_med"] < 0.0347023644
                                                else 74
                                            )
                                            if state == 73:
                                                return 0.0921638831
                                            if state == 74:
                                                return -0.165198237
                                if state == 54:
                                    return 0.0474725626
                            if state == 38:
                                return 0.0508653112
                        if state == 20:
                            state = (
                                39
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 6.12963486)
                                else 40
                            )
                            if state == 39:
                                return 0.113476217
                            if state == 40:
                                return -0.103115283
                    if state == 10:
                        return 0.115401328
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.2519989) else 6
                )
                if state == 5:
                    return -0.160982266
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.536499)
                        else 14
                    )
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.587669492)
                            else 28
                        )
                        if state == 27:
                            return 0.213622794
                        if state == 28:
                            return -0.0492184237
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0319375023)
                            else 30
                        )
                        if state == 29:
                            return 0.168364227
                        if state == 30:
                            return -0.147456422
    elif num_booster == 6:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.9403725) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.2779999)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.0597648509)
                        else 8
                    )
                    if state == 7:
                        return 0.0416698232
                    if state == 8:
                        return -0.190915897
                if state == 4:
                    state = 9 if x["distpsnr1_med"] < 0.195022345 else 10
                    if state == 9:
                        return -0.186591908
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.630880475)
                            else 20
                        )
                        if state == 19:
                            state = (
                                27
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.412380785)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    33
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.3877163)
                                    else 34
                                )
                                if state == 33:
                                    return 0.0961903185
                                if state == 34:
                                    return -0.136476502
                            if state == 28:
                                state = (
                                    35
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 22.1280003)
                                    else 36
                                )
                                if state == 35:
                                    return 0.189623117
                                if state == 36:
                                    state = (
                                        43 if x["distpsnr1_med"] < 3.73938107 else 44
                                    )
                                    if state == 43:
                                        return -0.124635227
                                    if state == 44:
                                        return 0.12818408
                        if state == 20:
                            state = 29 if x["distpsnr1_med"] < 9.51527691 else 30
                            if state == 29:
                                return -0.17983447
                            if state == 30:
                                return 0.0570784025
            if state == 2:
                state = (
                    5
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.6205959)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.0114757)
                        else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.00776620023)
                            else 22
                        )
                        if state == 21:
                            return -0.139880717
                        if state == 22:
                            return 0.15305911
                    if state == 12:
                        return -0.208640933
                if state == 6:
                    return 0.0736802369
    elif num_booster == 7:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.855648) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.2384987)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.91971004)
                        else 8
                    )
                    if state == 7:
                        return -0.175413489
                    if state == 8:
                        return 0.122048847
                if state == 4:
                    state = 9 if x["distpsnr1_med"] < 0.192713603 else 10
                    if state == 9:
                        return -0.150510922
                    if state == 10:
                        state = 17 if x["neargaia_med"] < 2.05946541 else 18
                        if state == 17:
                            return -0.0275282729
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < 0.591900826)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    37
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 18.5033493)
                                    else 38
                                )
                                if state == 37:
                                    state = (
                                        43
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.0557098)
                                        else 44
                                    )
                                    if state == 43:
                                        return 0.109296754
                                    if state == 44:
                                        return -0.111138545
                                if state == 38:
                                    state = (
                                        45
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 17.4295006)
                                        else 46
                                    )
                                    if state == 45:
                                        return -0.0329517275
                                    if state == 46:
                                        state = (
                                            51
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.7793388)
                                            else 52
                                        )
                                        if state == 51:
                                            return 0.204197913
                                        if state == 52:
                                            state = (
                                                55
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 3.04636574)
                                                else 56
                                            )
                                            if state == 55:
                                                return 0.149739742
                                            if state == 56:
                                                return -0.0920136198
                            if state == 30:
                                return -0.0977149606
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 21.1078491) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.3110008)
                        else 12
                    )
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.95983219)
                            else 20
                        )
                        if state == 19:
                            return 0.154838324
                        if state == 20:
                            return -0.120696545
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5236492)
                            else 22
                        )
                        if state == 21:
                            return -0.213503212
                        if state == 22:
                            state = (
                                31
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5356503)
                                else 32
                            )
                            if state == 31:
                                return 0.105072699
                            if state == 32:
                                state = 39 if x["col_det"] < -0.0885648727 else 40
                                if state == 39:
                                    return 0.045934163
                                if state == 40:
                                    return -0.180924088
                if state == 6:
                    return 0.13609013
    elif num_booster == 8:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.586961031)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distpsnr1_med"])
                    or (x["distpsnr1_med"] < 0.680792332)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 36.2071877)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.97862267)
                            else 14
                        )
                        if state == 13:
                            state = (
                                23
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.9708333)
                                else 24
                            )
                            if state == 23:
                                return -0.110281803
                            if state == 24:
                                return 0.136422858
                        if state == 14:
                            state = (
                                25
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.0169983)
                                else 26
                            )
                            if state == 25:
                                return 0.0126054836
                            if state == 26:
                                return -0.185057551
                    if state == 8:
                        return 0.100493066
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.422857285)
                        else 10
                    )
                    if state == 9:
                        return -0.169711724
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0295834001)
                            else 20
                        )
                        if state == 19:
                            return -0.137254655
                        if state == 20:
                            state = (
                                31
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 15.6219997)
                                else 32
                            )
                            if state == 31:
                                return -0.104297608
                            if state == 32:
                                state = (
                                    39
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.00116071501)
                                    else 40
                                )
                                if state == 39:
                                    return -0.0228098109
                                if state == 40:
                                    state = 47 if x["maggaia_med"] < 14.0630693 else 48
                                    if state == 47:
                                        return -0.0802784339
                                    if state == 48:
                                        state = (
                                            53
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.0125141)
                                            else 54
                                        )
                                        if state == 53:
                                            return 0.160511583
                                        if state == 54:
                                            return 0.0588513389
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.724523664) else 6
                if state == 5:
                    return -0.196674421
                if state == 6:
                    return 0.00678870315
    elif num_booster == 9:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.967499971)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 1.9596498)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.9407864)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["sgscore1_med"] < 0.0159374997 else 16
                        if state == 15:
                            return 0.127597317
                        if state == 16:
                            state = (
                                29
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.78000021)
                                else 30
                            )
                            if state == 29:
                                return -0.174313858
                            if state == 30:
                                state = 39 if x["distpsnr1_med"] < 0.48820895 else 40
                                if state == 39:
                                    return -0.106280342
                                if state == 40:
                                    return 0.13740471
                    if state == 8:
                        return -0.194085717
                if state == 4:
                    state = 9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 4.46839714) else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.421428561)
                            else 18
                        )
                        if state == 17:
                            return -0.149904013
                        if state == 18:
                            state = (
                                31
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0211979002)
                                else 32
                            )
                            if state == 31:
                                return -0.105205901
                            if state == 32:
                                state = (
                                    41
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.3106003)
                                    else 42
                                )
                                if state == 41:
                                    state = (
                                        47
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.8781643)
                                        else 48
                                    )
                                    if state == 47:
                                        return 0.109312847
                                    if state == 48:
                                        return -0.105611131
                                if state == 42:
                                    state = 49 if x["col_det"] < -0.0662412643 else 50
                                    if state == 49:
                                        return -0.0540753566
                                    if state == 50:
                                        return 0.227017432
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1439667)
                            else 20
                        )
                        if state == 19:
                            return 0.0870903134
                        if state == 20:
                            return -0.192035109
            if state == 2:
                state = 5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.276001) else 6
                if state == 5:
                    return -0.122098848
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4569931)
                        else 14
                    )
                    if state == 13:
                        state = (
                            23
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 0.134956226)
                            else 24
                        )
                        if state == 23:
                            return -0.0225987863
                        if state == 24:
                            return 0.198161215
                    if state == 14:
                        return -0.0956786051
    elif num_booster == 10:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4899502) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.7066498) else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.941428423) else 8
                    )
                    if state == 7:
                        return -0.172801211
                    if state == 8:
                        return 0.062980406
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.499102831)
                        else 10
                    )
                    if state == 9:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.004425)
                            else 14
                        )
                        if state == 13:
                            return 0.0766752586
                        if state == 14:
                            return -0.149922624
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 16.1481457)
                            else 16
                        )
                        if state == 15:
                            return -0.0642107576
                        if state == 16:
                            state = 25 if x["distpsnr1_med"] < 0.288145602 else 26
                            if state == 25:
                                return -0.0638725907
                            if state == 26:
                                state = (
                                    37
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.3426247)
                                    else 38
                                )
                                if state == 37:
                                    return 0.193766907
                                if state == 38:
                                    state = (
                                        51
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 3.55114007)
                                        else 52
                                    )
                                    if state == 51:
                                        return 0.145674556
                                    if state == 52:
                                        return -0.108122021
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 4.00269127) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.9415054)
                        else 12
                    )
                    if state == 11:
                        return 0.0232110955
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 2.76356673)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 21.2101994)
                                else 32
                            )
                            if state == 31:
                                return -0.17778872
                            if state == 32:
                                return 0.0728831142
                        if state == 20:
                            return 0.0171594694
                if state == 6:
                    return -0.207574204
    elif num_booster == 11:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.847499967)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 17.581295)
                    else 4
                )
                if state == 3:
                    return -0.179290056
                if state == 4:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.02914929) else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.1130257)
                            else 14
                        )
                        if state == 13:
                            state = 23 if x["sgscore1_med"] < 0.966297984 else 24
                            if state == 23:
                                return 0.195169017
                            if state == 24:
                                return -0.0597325042
                        if state == 14:
                            return -0.122931406
                    if state == 8:
                        return -0.168806449
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.682606995)
                    else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7879333)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.2327499)
                            else 16
                        )
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.5494995)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    35
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.0628128)
                                    else 36
                                )
                                if state == 35:
                                    return -0.193474367
                                if state == 36:
                                    return 0.0431389697
                            if state == 26:
                                state = (
                                    37
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 21.0914993)
                                    else 38
                                )
                                if state == 37:
                                    return 0.125274837
                                if state == 38:
                                    return -0.0504356883
                        if state == 16:
                            return 0.141293094
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.50373268)
                            else 18
                        )
                        if state == 17:
                            state = (
                                29
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3376007)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    41
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.875452)
                                    else 42
                                )
                                if state == 41:
                                    return 0.0869329646
                                if state == 42:
                                    return -0.131488889
                            if state == 30:
                                return 0.115826853
                        if state == 18:
                            return -0.167583838
                if state == 6:
                    return -0.137908548
    elif num_booster == 12:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.0442791) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.4258499) else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.671666682) else 8
                    )
                    if state == 7:
                        return -0.154249936
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.804523647)
                            else 16
                        )
                        if state == 15:
                            return 0.117271177
                        if state == 16:
                            return -0.0664894953
                if state == 4:
                    state = 9 if x["distpsnr1_med"] < 0.48820895 else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.4957008)
                            else 18
                        )
                        if state == 17:
                            return 0.0830162168
                        if state == 18:
                            return -0.153767124
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.98327541)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.524500012)
                                else 32
                            )
                            if state == 31:
                                return -0.0386274941
                            if state == 32:
                                state = (
                                    43
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.94896412)
                                    else 44
                                )
                                if state == 43:
                                    return 0.200046301
                                if state == 44:
                                    state = (
                                        53
                                        if np.isnan(x["classtar_med"])
                                        or (x["classtar_med"] < 0.951499999)
                                        else 54
                                    )
                                    if state == 53:
                                        return -0.11429812
                                    if state == 54:
                                        return 0.146030009
                        if state == 20:
                            state = (
                                33
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.5646667)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    45
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.923500001)
                                    else 46
                                )
                                if state == 45:
                                    return -0.114582591
                                if state == 46:
                                    return 0.139281571
                            if state == 34:
                                return -0.142160177
            if state == 2:
                return -0.165452346
    elif num_booster == 13:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.9745) else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.7438507) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.86811924)
                        else 8
                    )
                    if state == 7:
                        return -0.151375055
                    if state == 8:
                        state = 17 if x["sgscore1_med"] < 0.327614754 else 18
                        if state == 17:
                            return 0.0718957558
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 2.46249413)
                                else 34
                            )
                            if state == 33:
                                return 0.0525182225
                            if state == 34:
                                return -0.173716888
                if state == 4:
                    return 0.0839135498
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.4130001) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.983500004)
                        else 12
                    )
                    if state == 11:
                        return -0.151782051
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 1.57882559)
                            else 22
                        )
                        if state == 21:
                            return -0.097576201
                        if state == 22:
                            return 0.157482728
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 0.132762462)
                        else 14
                    )
                    if state == 13:
                        return -0.080320321
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 3.05829859)
                            else 26
                        )
                        if state == 25:
                            return 0.19166927
                        if state == 26:
                            return -0.0380654074
    elif num_booster == 14:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6755142) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.5340004)
                    else 4
                )
                if state == 3:
                    return -0.128780976
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.386666477)
                        else 10
                    )
                    if state == 9:
                        return -0.185071394
                    if state == 10:
                        state = 17 if x["distpsnr1_med"] < 0.32053408 else 18
                        if state == 17:
                            state = (
                                27
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.297610879)
                                else 28
                            )
                            if state == 27:
                                return 0.0484472327
                            if state == 28:
                                return -0.156946853
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.969496965)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    41
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.223726004)
                                    else 42
                                )
                                if state == 41:
                                    return -0.0773142651
                                if state == 42:
                                    state = (
                                        47
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 17.2524986)
                                        else 48
                                    )
                                    if state == 47:
                                        state = (
                                            49
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.965999961)
                                            else 50
                                        )
                                        if state == 49:
                                            return -0.125936419
                                        if state == 50:
                                            return 0.109225698
                                    if state == 48:
                                        return 0.165128097
                            if state == 30:
                                return -0.0706321374
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.00870833546 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.83949995)
                        else 12
                    )
                    if state == 11:
                        return -0.108957924
                    if state == 12:
                        return 0.144550234
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.6408997)
                        else 14
                    )
                    if state == 13:
                        return -0.169288501
                    if state == 14:
                        state = 23 if x["distpsnr1_med"] < 2.72369432 else 24
                        if state == 23:
                            return -0.100899324
                        if state == 24:
                            return 0.137130961
    elif num_booster == 15:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 1.98872685) else 2
            if state == 1:
                return -0.135317832
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.2975006)
                    else 6
                )
                if state == 5:
                    return -0.139978766
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.4443607)
                        else 12
                    )
                    if state == 11:
                        state = (
                            13
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.842999995)
                            else 14
                        )
                        if state == 13:
                            state = 17 if x["distpsnr1_med"] < 0.381066263 else 18
                            if state == 17:
                                return 0.0668758228
                            if state == 18:
                                return -0.124440111
                        if state == 14:
                            state = (
                                19
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.435952365)
                                else 20
                            )
                            if state == 19:
                                return -0.0206533801
                            if state == 20:
                                state = (
                                    29
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.995000005)
                                    else 30
                                )
                                if state == 29:
                                    return 0.158077165
                                if state == 30:
                                    state = (
                                        43
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 2.99526048)
                                        else 44
                                    )
                                    if state == 43:
                                        return 0.0963215455
                                    if state == 44:
                                        return -0.16081512
                    if state == 12:
                        state = 15 if x["distpsnr1_med"] < 7.01866817 else 16
                        if state == 15:
                            state = (
                                21
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.3610001)
                                else 22
                            )
                            if state == 21:
                                return 0.0261238366
                            if state == 22:
                                return -0.138528153
                        if state == 16:
                            return 0.14067398
    elif num_booster == 16:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.105175) else 2
            if state == 1:
                state = 3 if x["neargaia_med"] < 7.03467417 else 4
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.00858333521)
                        else 6
                    )
                    if state == 5:
                        return 0.0871626958
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.829149306)
                            else 12
                        )
                        if state == 11:
                            return -0.165293947
                        if state == 12:
                            state = 19 if x["neargaia_med"] < 0.960421324 else 20
                            if state == 19:
                                return 0.11047861
                            if state == 20:
                                return -0.0902216956
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.5548573)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.967499971)
                            else 14
                        )
                        if state == 13:
                            return -0.163161337
                        if state == 14:
                            state = (
                                21
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.5033302)
                                else 22
                            )
                            if state == 21:
                                state = (
                                    31
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.735000014)
                                    else 32
                                )
                                if state == 31:
                                    return 0.0535421893
                                if state == 32:
                                    return -0.126842812
                            if state == 22:
                                state = (
                                    33
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.5539074)
                                    else 34
                                )
                                if state == 33:
                                    return 0.158239603
                                if state == 34:
                                    return -0.121640213
                    if state == 8:
                        state = 15 if x["maggaia_med"] < 17.1613007 else 16
                        if state == 15:
                            return -0.0346760377
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 20.6344776)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    35
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 3.33313441)
                                    else 36
                                )
                                if state == 35:
                                    return 0.199106663
                                if state == 36:
                                    return 0.0194968283
                            if state == 26:
                                return -0.0624348111
            if state == 2:
                return -0.152724802
    elif num_booster == 17:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 8.93502045 else 2
            if state == 1:
                state = 3 if x["sgscore1_med"] < 0.586961031 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.904000044)
                        else 8
                    )
                    if state == 7:
                        return -0.117617413
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.815000176)
                            else 16
                        )
                        if state == 15:
                            return 0.108664118
                        if state == 16:
                            return -0.0897387341
                if state == 4:
                    return -0.14631997
            if state == 2:
                state = (
                    5 if np.isnan(x["col_det"]) or (x["col_det"] < -0.295884609) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.7870007)
                        else 12
                    )
                    if state == 11:
                        return -0.159808666
                    if state == 12:
                        state = 17 if x["neargaia_med"] < 19.4717751 else 18
                        if state == 17:
                            return -0.0752355158
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 20.8730011)
                                else 30
                            )
                            if state == 29:
                                return 0.121752381
                            if state == 30:
                                state = (
                                    41
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.976500034)
                                    else 42
                                )
                                if state == 41:
                                    return -0.120297126
                                if state == 42:
                                    return 0.0703043491
                if state == 6:
                    return 0.108386882
    elif num_booster == 18:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.698779464 else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.435952365) else 4
                if state == 3:
                    return -0.145999476
                if state == 4:
                    state = 9 if x["neargaia_med"] < 13.667038 else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.982499957)
                            else 18
                        )
                        if state == 17:
                            state = (
                                27
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.0402025506)
                                else 28
                            )
                            if state == 27:
                                return -0.0966001973
                            if state == 28:
                                state = (
                                    41
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.96335077)
                                    else 42
                                )
                                if state == 41:
                                    return 0.124239191
                                if state == 42:
                                    return -0.0375261977
                        if state == 18:
                            return -0.157428712
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.845000029)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < -0.225169182)
                                else 32
                            )
                            if state == 31:
                                return -0.115347862
                            if state == 32:
                                return 0.0883732066
                        if state == 20:
                            return 0.130223602
            if state == 2:
                return -0.104204416
    elif num_booster == 19:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8857651) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.1658249) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.95818281)
                        else 8
                    )
                    if state == 7:
                        return -0.119008124
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.7205009)
                            else 18
                        )
                        if state == 17:
                            return -0.102952652
                        if state == 18:
                            state = (
                                27
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.9524994)
                                else 28
                            )
                            if state == 27:
                                return 0.150558278
                            if state == 28:
                                return -0.0793404728
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4534302)
                        else 10
                    )
                    if state == 9:
                        return 0.142669067
                    if state == 10:
                        return 0.0159989949
            if state == 2:
                state = (
                    5
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.6205959)
                    else 6
                )
                if state == 5:
                    return -0.164369181
                if state == 6:
                    return 0.0657925829
    elif num_booster == 20:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.768379688) else 2
            )
            if state == 1:
                return -0.0867643878
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.103117) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.2294006)
                        else 12
                    )
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.2455006)
                            else 20
                        )
                        if state == 19:
                            state = (
                                25
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.980499983)
                                else 26
                            )
                            if state == 25:
                                return -0.119347379
                            if state == 26:
                                return 0.122367494
                        if state == 20:
                            return -0.16675435
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5646667)
                            else 22
                        )
                        if state == 21:
                            return 0.151011646
                        if state == 22:
                            state = (
                                29
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.46092677)
                                else 30
                            )
                            if state == 29:
                                return 0.15194577
                            if state == 30:
                                return -0.066630505
                if state == 6:
                    return -0.103706524
    elif num_booster == 21:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.07608795) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.3888512) else 4
                )
                if state == 3:
                    return -0.0570736118
                if state == 4:
                    state = 9 if x["col_det"] < -0.153840065 else 10
                    if state == 9:
                        return -0.0987656415
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.9407864)
                            else 22
                        )
                        if state == 21:
                            return 0.163003996
                        if state == 22:
                            state = (
                                33
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5172997)
                                else 34
                            )
                            if state == 33:
                                return -0.136793137
                            if state == 34:
                                state = (
                                    45
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 20.3637466)
                                    else 46
                                )
                                if state == 45:
                                    return 0.179187194
                                if state == 46:
                                    return -0.0661102086
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1519699) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.59375)
                        else 12
                    )
                    if state == 11:
                        return -0.1142461
                    if state == 12:
                        return 0.141459301
                if state == 6:
                    return -0.170599744
    elif num_booster == 22:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 1.9596498 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"])
                    or (x["sgscore1_med"] < 0.00858333521)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8599434)
                        else 8
                    )
                    if state == 7:
                        return 0.0960616469
                    if state == 8:
                        return -0.119809352
                if state == 4:
                    return -0.132285491
            if state == 2:
                state = (
                    5
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 21.2390022)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 11.7429276)
                        else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.9859676)
                            else 22
                        )
                        if state == 21:
                            return 0.0641954094
                        if state == 22:
                            return -0.105406903
                    if state == 12:
                        return -0.117013142
                if state == 6:
                    return 0.10925512
    elif num_booster == 23:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 19.4897728 else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.973999) else 4
                )
                if state == 3:
                    return -0.0996513963
                if state == 4:
                    return 0.0549369752
            if state == 2:
                state = 5 if x["neargaia_med"] < 19.3889256 else 6
                if state == 5:
                    return -0.147846639
                if state == 6:
                    return -0.0104582934
    elif num_booster == 24:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0022335) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.69127351)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.99849999)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.558333516)
                            else 16
                        )
                        if state == 15:
                            return -0.00409352034
                        if state == 16:
                            return 0.164065316
                    if state == 8:
                        return -0.107874826
                if state == 4:
                    return -0.0799016133
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.646666527) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.0500431)
                        else 12
                    )
                    if state == 11:
                        return 0.0457740575
                    if state == 12:
                        return -0.1166199
                if state == 6:
                    return -0.156236544
    elif num_booster == 25:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.90901613) else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.857380986) else 4
                if state == 3:
                    return -0.171921924
                if state == 4:
                    return 0.0732517689
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 6.31456184 else 6
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.473999)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.89190388)
                            else 16
                        )
                        if state == 15:
                            return 0.0399728119
                        if state == 16:
                            return -0.101122521
                    if state == 10:
                        return -0.192919254
                if state == 6:
                    return 0.104316063
    elif num_booster == 26:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7896996) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.815782487)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.985499978)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0340162516)
                            else 14
                        )
                        if state == 13:
                            return -0.115732811
                        if state == 14:
                            state = (
                                19
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.528999984)
                                else 20
                            )
                            if state == 19:
                                return -0.0843096301
                            if state == 20:
                                state = 27 if x["distpsnr1_med"] < 0.126201794 else 28
                                if state == 27:
                                    return -0.0731473267
                                if state == 28:
                                    state = (
                                        33
                                        if np.isnan(x["classtar_med"])
                                        or (x["classtar_med"] < 0.967000008)
                                        else 34
                                    )
                                    if state == 33:
                                        state = (
                                            35
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.1177006)
                                            else 36
                                        )
                                        if state == 35:
                                            return -0.116406657
                                        if state == 36:
                                            state = (
                                                37
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.99960065)
                                                else 38
                                            )
                                            if state == 37:
                                                return 0.161571696
                                            if state == 38:
                                                return -0.0820194185
                                    if state == 34:
                                        return 0.166847423
                    if state == 8:
                        return -0.110114157
                if state == 4:
                    return -0.109999321
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.0213716) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.103117)
                        else 12
                    )
                    if state == 11:
                        return 0.0689285323
                    if state == 12:
                        return -0.110486656
                if state == 6:
                    return -0.159196332
    elif num_booster == 27:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4070511) else 2
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 8.26251125 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.90730333)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.05429983)
                            else 16
                        )
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.4290009)
                                else 28
                            )
                            if state == 27:
                                return -0.11716155
                            if state == 28:
                                return 0.0658148602
                        if state == 16:
                            return -0.204357222
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.0259991)
                            else 18
                        )
                        if state == 17:
                            return 0.0245854817
                        if state == 18:
                            return -0.124602981
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.967000008)
                        else 10
                    )
                    if state == 9:
                        return -0.0646958724
                    if state == 10:
                        return 0.138262957
            if state == 2:
                return 0.0850518346
    elif num_booster == 28:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 0.243317068 else 2
            if state == 1:
                return -0.125109926
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.43761903) else 6
                if state == 5:
                    return -0.135079607
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.9424667)
                        else 12
                    )
                    if state == 11:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.4801998)
                            else 16
                        )
                        if state == 15:
                            return -0.0620646551
                        if state == 16:
                            state = (
                                21
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 4.00547457)
                                else 22
                            )
                            if state == 21:
                                return 0.130640626
                            if state == 22:
                                state = (
                                    29
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.3426247)
                                    else 30
                                )
                                if state == 29:
                                    return 0.106612988
                                if state == 30:
                                    return -0.15616405
                    if state == 12:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 21.0657501)
                            else 18
                        )
                        if state == 17:
                            return -0.118222579
                        if state == 18:
                            return 0.115830518
    elif num_booster == 29:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 15.9054508 else 2
            if state == 1:
                return -0.140807867
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distpsnr1_med"])
                    or (x["distpsnr1_med"] < 0.195042223)
                    else 6
                )
                if state == 5:
                    return -0.0925275907
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.4597301)
                        else 10
                    )
                    if state == 9:
                        state = 15 if x["neargaia_med"] < 9.04711246 else 16
                        if state == 15:
                            return -0.0273450445
                        if state == 16:
                            state = (
                                21
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 20.1057739)
                                else 22
                            )
                            if state == 21:
                                return 0.156268924
                            if state == 22:
                                return -0.0351374038
                    if state == 10:
                        state = 17 if x["maggaia_med"] < 20.4755287 else 18
                        if state == 17:
                            return -0.106112786
                        if state == 18:
                            return 0.0778201893
    elif num_booster == 30:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.2751522)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.0900002)
                    else 4
                )
                if state == 3:
                    state = 7 if x["maggaia_med"] < 17.3341408 else 8
                    if state == 7:
                        return -0.0943958089
                    if state == 8:
                        return 0.0469355732
                if state == 4:
                    return -0.168344483
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 1.02120018 else 6
                if state == 5:
                    return -0.0668995604
                if state == 6:
                    return 0.117867649
    elif num_booster == 31:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < 0.33775425) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.71449995)
                    else 4
                )
                if state == 3:
                    return -0.074084647
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.4106503)
                        else 10
                    )
                    if state == 9:
                        return -0.0712641105
                    if state == 10:
                        state = (
                            13
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 1.90869212)
                            else 14
                        )
                        if state == 13:
                            return -0.0890880376
                        if state == 14:
                            return 0.0834973752
            if state == 2:
                return -0.156423032
    elif num_booster == 32:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.04211235) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.38902009)
                    else 4
                )
                if state == 3:
                    return 0.106831409
                if state == 4:
                    state = 9 if x["col_det"] < 0.201600075 else 10
                    if state == 9:
                        return -0.0926291049
                    if state == 10:
                        return 0.0752354562
            if state == 2:
                state = 5 if x["col_det"] < 0.316198349 else 6
                if state == 5:
                    return 0.0583914332
                if state == 6:
                    return -0.108361006
    elif num_booster == 33:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.965499997)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3458996) else 4
                )
                if state == 3:
                    state = 7 if x["col_det"] < 0.0670595169 else 8
                    if state == 7:
                        return 0.023109505
                    if state == 8:
                        return -0.156838581
                if state == 4:
                    return 0.0190595053
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.5149994)
                    else 6
                )
                if state == 5:
                    return 0.0919425786
                if state == 6:
                    return -0.0821255073
    elif num_booster == 34:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7930489) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7919502) else 4
                )
                if state == 3:
                    return -0.0310074594
                if state == 4:
                    state = 9 if x["col_det"] < -0.466777325 else 10
                    if state == 9:
                        return -0.0929257721
                    if state == 10:
                        state = 19 if x["maggaia_med"] < 15.0223427 else 20
                        if state == 19:
                            return -0.0916430727
                        if state == 20:
                            return 0.129504517
            if state == 2:
                return -0.107602306
    elif num_booster == 35:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.369999826) else 2
            if state == 1:
                return -0.147960767
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.105175) else 6
                )
                if state == 5:
                    state = (
                        7
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 0.700556099)
                        else 8
                    )
                    if state == 7:
                        state = (
                            9
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 25.2205677)
                            else 10
                        )
                        if state == 9:
                            return -0.0891550779
                        if state == 10:
                            return 0.0807947293
                    if state == 8:
                        state = (
                            11
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.8824997)
                            else 12
                        )
                        if state == 11:
                            return -0.0776164234
                        if state == 12:
                            state = (
                                19
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.743333459)
                                else 20
                            )
                            if state == 19:
                                state = (
                                    27
                                    if np.isnan(x["neargaia_med"])
                                    or (x["neargaia_med"] < 17.4481621)
                                    else 28
                                )
                                if state == 27:
                                    return 0.155366361
                                if state == 28:
                                    state = 39 if x["neargaia_med"] < 20.998188 else 40
                                    if state == 39:
                                        return -0.148415804
                                    if state == 40:
                                        return 0.096989125
                            if state == 20:
                                return -0.014767345
                if state == 6:
                    return -0.111789554
    elif num_booster == 36:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 4.89188957) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.83038998)
                    else 4
                )
                if state == 3:
                    state = 7 if x["neargaia_med"] < 29.0151443 else 8
                    if state == 7:
                        return -0.0963235199
                    if state == 8:
                        return 0.0428599641
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7311249)
                        else 10
                    )
                    if state == 9:
                        return 0.141229287
                    if state == 10:
                        return -0.0514542162
            if state == 2:
                return -0.162122399
    elif num_booster == 37:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 0.333165824)
                else 2
            )
            if state == 1:
                return -0.0769351497
            if state == 2:
                state = 5 if x["maggaia_med"] < 15.9613419 else 6
                if state == 5:
                    return -0.0848953947
                if state == 6:
                    state = 13 if x["col_det"] < -0.295884609 else 14
                    if state == 13:
                        return -0.0806528479
                    if state == 14:
                        state = (
                            21 if np.isnan(x["t_lc"]) or (x["t_lc"] < 4.0503006) else 22
                        )
                        if state == 21:
                            state = (
                                27
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.600499988)
                                else 28
                            )
                            if state == 27:
                                return -0.0702135637
                            if state == 28:
                                state = 35 if x["neargaia_med"] < 1.94470668 else 36
                                if state == 35:
                                    return -0.0655686557
                                if state == 36:
                                    return 0.144464895
                        if state == 22:
                            state = (
                                29
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.2872658)
                                else 30
                            )
                            if state == 29:
                                return 0.109444015
                            if state == 30:
                                return -0.14935796
    elif num_booster == 38:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.99730921)
                else 2
            )
            if state == 1:
                state = 3 if x["maggaia_med"] < 16.4554996 else 4
                if state == 3:
                    return -0.0802148953
                if state == 4:
                    state = 9 if x["col_det"] < -0.278990269 else 10
                    if state == 9:
                        return -0.0919627845
                    if state == 10:
                        return 0.0870161057
            if state == 2:
                return -0.0988503397
    elif num_booster == 39:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.608921409) else 2
            )
            if state == 1:
                return -0.0876054689
            if state == 2:
                return 0.0410716198
    elif num_booster == 40:
        return 0.0286544785
    elif num_booster == 41:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 8.99505424 else 2
            if state == 1:
                return -0.131363586
            if state == 2:
                state = (
                    5
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.153171301)
                    else 6
                )
                if state == 5:
                    return -0.0906200856
                if state == 6:
                    return 0.0627302304
    elif num_booster == 42:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 17.3341408)
                else 2
            )
            if state == 1:
                return -0.0662285313
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.31446815)
                    else 6
                )
                if state == 5:
                    state = 11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.978374) else 12
                    if state == 11:
                        return -0.0631377846
                    if state == 12:
                        return 0.135000944
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.83965731)
                        else 14
                    )
                    if state == 13:
                        return -0.145303443
                    if state == 14:
                        state = 25 if x["maggaia_med"] < 19.4632378 else 26
                        if state == 25:
                            return 0.0887715369
                        if state == 26:
                            return -0.066749312
    elif num_booster == 43:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.68335402)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.103117) else 4
                )
                if state == 3:
                    state = (
                        5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.79333353) else 6
                    )
                    if state == 5:
                        state = (
                            7
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.5755081)
                            else 8
                        )
                        if state == 7:
                            state = 11 if x["distpsnr1_med"] < 6.21901321 else 12
                            if state == 11:
                                return 0.0534853861
                            if state == 12:
                                return -0.189156532
                        if state == 8:
                            return 0.104495123
                    if state == 6:
                        return -0.05373317
                if state == 4:
                    return -0.0981033519
            if state == 2:
                return -0.114775695
    elif num_booster == 44:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.5226002) else 2
            if state == 1:
                return -0.108951695
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.963999987)
                    else 6
                )
                if state == 5:
                    state = 9 if x["col_det"] < 0.352702141 else 10
                    if state == 9:
                        return 0.06371665
                    if state == 10:
                        return -0.0932844803
                if state == 6:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 1.99926496) else 12
                    )
                    if state == 11:
                        return -0.0755888894
                    if state == 12:
                        return 0.121373281
    elif num_booster == 45:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.8486004) else 2
            if state == 1:
                return -0.100566104
            if state == 2:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1633492) else 4
                )
                if state == 3:
                    return 0.0917329639
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3435001)
                        else 8
                    )
                    if state == 7:
                        return -0.0865757316
                    if state == 8:
                        return 0.0777517855
    elif num_booster == 46:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 18.1355629 else 2
            if state == 1:
                return -0.0588986687
            if state == 2:
                return 0.0607936569
    elif num_booster == 47:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < 0.368588448) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 18.8845673)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4350471)
                        else 8
                    )
                    if state == 7:
                        return 0.108603708
                    if state == 8:
                        return -0.0271323733
                if state == 4:
                    return -0.050325647
            if state == 2:
                return -0.161474198
    elif num_booster == 48:
        return 0.00872695073
    elif num_booster == 49:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 17.8387623)
                else 2
            )
            if state == 1:
                return -0.0726563185
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.722143054) else 6
                if state == 5:
                    return 0.0757862628
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.874285817)
                        else 14
                    )
                    if state == 13:
                        return -0.130781114
                    if state == 14:
                        return 0.0849539116
    elif num_booster == 50:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < 0.18844986) else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.796904922) else 4
                if state == 3:
                    return 0.0538446195
                if state == 4:
                    return -0.0707502514
            if state == 2:
                return -0.11183615
    elif num_booster == 51:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 0.693132401)
                else 2
            )
            if state == 1:
                return -0.0934397429
            if state == 2:
                return 0.0281168837
    elif num_booster == 52:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.7438507) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.8105011)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.1310787)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.4594994)
                            else 14
                        )
                        if state == 13:
                            return 0.0381855927
                        if state == 14:
                            return -0.11905767
                    if state == 8:
                        return 0.0383154899
                if state == 4:
                    return 0.077286832
            if state == 2:
                return 0.0873880461
    elif num_booster == 53:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7879486) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.1845016)
                    else 4
                )
                if state == 3:
                    return -0.0691094324
                if state == 4:
                    state = (
                        9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0460126996) else 10
                    )
                    if state == 9:
                        return -0.0837469697
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.1719513)
                            else 18
                        )
                        if state == 17:
                            state = (
                                23
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 20.2335014)
                                else 24
                            )
                            if state == 23:
                                return 0.107788451
                            if state == 24:
                                return -0.0794242769
                        if state == 18:
                            return 0.13495551
            if state == 2:
                return -0.0501456372
    elif num_booster == 54:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8599434) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0238991) else 4
                )
                if state == 3:
                    return -0.0707474574
                if state == 4:
                    return 0.0987016484
            if state == 2:
                return -0.0925305262
    elif num_booster == 55:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 7.17403793)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.8882828) else 4
                )
                if state == 3:
                    return 0.0719487742
                if state == 4:
                    return -0.115491018
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.0311160497)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.00870833546)
                        else 12
                    )
                    if state == 11:
                        state = 21 if x["maggaia_med"] < 19.9814205 else 22
                        if state == 21:
                            return 0.10961853
                        if state == 22:
                            return -0.0890565068
                    if state == 12:
                        return -0.091291599
                if state == 6:
                    return 0.107282095
    elif num_booster == 56:
        return -0.00602590153
    elif num_booster == 57:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.967999995)
                else 2
            )
            if state == 1:
                return -0.0389312394
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.0955009)
                    else 6
                )
                if state == 5:
                    return 0.120595738
                if state == 6:
                    return -0.0705319792
    elif num_booster == 58:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 19.4717751)
                else 2
            )
            if state == 1:
                return -0.0858616233
            if state == 2:
                state = (
                    5
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.0509606525)
                    else 6
                )
                if state == 5:
                    return -0.115422145
                if state == 6:
                    return 0.0857581049
    elif num_booster == 59:
        return 0.0211715233
    elif num_booster == 60:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.2880001) else 2
            )
            if state == 1:
                return 0.0743256956
            if state == 2:
                state = 5 if x["col_det"] < 1.33747005 else 6
                if state == 5:
                    state = 11 if x["maggaia_med"] < 17.1895065 else 12
                    if state == 11:
                        return 0.0459694564
                    if state == 12:
                        return -0.208425909
                if state == 6:
                    return 0.0339834318
    elif num_booster == 61:
        return 0.0285121556
    elif num_booster == 62:
        return -0.00867379177
    elif num_booster == 63:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.9446125) else 2
            if state == 1:
                return 0.0484436192
            if state == 2:
                return -0.0641063973
    elif num_booster == 64:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 18.2574062)
                else 2
            )
            if state == 1:
                return -0.0604616702
            if state == 2:
                return 0.0638728142
    elif num_booster == 65:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.99916077) else 2
            if state == 1:
                return 0.0398670435
            if state == 2:
                return -0.0774047002
    elif num_booster == 66:
        return -0.0341530517
    elif num_booster == 67:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.191660494)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.0412291996)
                    else 4
                )
                if state == 3:
                    return -0.0109182084
                if state == 4:
                    return -0.172221377
            if state == 2:
                return 0.0478592999
    elif num_booster == 68:
        return -0.005979056
    elif num_booster == 69:
        return 0.0446165167
    elif num_booster == 70:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.0506711) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0238991) else 4
                )
                if state == 3:
                    return -0.0920381621
                if state == 4:
                    return 0.0633914918
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.0415001)
                    else 6
                )
                if state == 5:
                    return -0.166958645
                if state == 6:
                    return 0.00460184645
    elif num_booster == 71:
        return 0.0132566271
    elif num_booster == 72:
        return -0.0512443967
    elif num_booster == 73:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 1.22003818)
                else 2
            )
            if state == 1:
                return 0.0617942847
            if state == 2:
                state = (
                    5
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 17.8058472)
                    else 6
                )
                if state == 5:
                    return -0.115068041
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.85198498)
                        else 12
                    )
                    if state == 11:
                        return -0.080567576
                    if state == 12:
                        return 0.0981564745
    elif num_booster == 74:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.723500013)
                else 2
            )
            if state == 1:
                return 0.0872657895
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1582012) else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 5.55685043)
                        else 10
                    )
                    if state == 9:
                        return 0.0831787437
                    if state == 10:
                        return -0.0971427038
                if state == 6:
                    return -0.0613005236
    elif num_booster == 75:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.502604008)
                else 2
            )
            if state == 1:
                return 0.0312818848
            if state == 2:
                return -0.116516739
    elif num_booster == 76:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.01630211) else 2
            if state == 1:
                return -0.0423961654
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1654778) else 6
                )
                if state == 5:
                    return 0.10131339
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.3085327)
                        else 14
                    )
                    if state == 13:
                        return -0.103176907
                    if state == 14:
                        return 0.0943199173
    elif num_booster == 77:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.1758614)
                else 2
            )
            if state == 1:
                return 0.0500904024
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.6126995) else 6
                )
                if state == 5:
                    return -0.103290401
                if state == 6:
                    return 0.0892500058
    elif num_booster == 78:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 19.6408997 else 2
            if state == 1:
                return -0.0479737855
            if state == 2:
                return 0.057702966
    elif num_booster == 79:
        return 0.0179466922
    elif num_booster == 80:
        return -0.0157403778
    elif num_booster == 81:
        state = 0
        if state == 0:
            state = 1 if x["col_det"] < 0.494688988 else 2
            if state == 1:
                return 0.0612632893
            if state == 2:
                return -0.0600244626
    elif num_booster == 82:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.855000019) else 2
            if state == 1:
                return -0.0740442127
            if state == 2:
                return 0.0803846121
    elif num_booster == 83:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.914499998)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.7330017)
                    else 4
                )
                if state == 3:
                    return -0.116652012
                if state == 4:
                    return 0.0695277601
            if state == 2:
                return 0.0470522195
    elif num_booster == 84:
        return -0.0237847082
    elif num_booster == 85:
        return -0.0107851094
    elif num_booster == 86:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.3016701) else 2
            if state == 1:
                return 0.0757053718
            if state == 2:
                state = 5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.15905) else 6
                if state == 5:
                    return -0.130925715
                if state == 6:
                    return 0.0211310349
    elif num_booster == 87:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.81153941)
                else 2
            )
            if state == 1:
                return 0.0824790448
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 4.99379539)
                    else 6
                )
                if state == 5:
                    return 0.00899840798
                if state == 6:
                    return -0.155694947
    elif num_booster == 88:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.4264412) else 2
            if state == 1:
                return -0.0549718626
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.99599552) else 6
                if state == 5:
                    return 0.10005074
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.941124)
                        else 14
                    )
                    if state == 13:
                        return 0.104633555
                    if state == 14:
                        return -0.0563359074
    elif num_booster == 89:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.3055763) else 2
            if state == 1:
                return -0.071779266
            if state == 2:
                return 0.0561837442
    elif num_booster == 90:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.97645831) else 2
            if state == 1:
                return 0.0736144483
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1654778) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.5402489)
                        else 12
                    )
                    if state == 11:
                        return -0.0700007379
                    if state == 12:
                        return 0.114192404
                if state == 6:
                    return -0.107267193
    elif num_booster == 91:
        return 0.0192480311
    elif num_booster == 92:
        return 0.0123694856
    elif num_booster == 93:
        return 0.0132344719
    elif num_booster == 94:
        return 0.0373514965
    elif num_booster == 95:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.102493852 else 2
            if state == 1:
                return 0.0475344658
            if state == 2:
                return -0.0751495212
    elif num_booster == 96:
        return -0.0451379642
    elif num_booster == 97:
        return -0.0259046517
    elif num_booster == 98:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < -0.0485024452) else 2
            if state == 1:
                return 0.0406284854
            if state == 2:
                return -0.0841086432
    elif num_booster == 99:
        return 0.00245346664


def xgb_tree_4(x, num_booster):
    if num_booster == 0:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.935249984)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 55.0134239)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.790250003)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7944489)
                            else 14
                        )
                        if state == 13:
                            state = (
                                23
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7535496)
                                else 24
                            )
                            if state == 23:
                                return -0.0533333346
                            if state == 24:
                                return 0.0269944146
                        if state == 14:
                            return -0.132173911
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.873750031)
                            else 16
                        )
                        if state == 15:
                            state = 25 if x["sgscore1_med"] < 0.0617156662 else 26
                            if state == 25:
                                return -0.0533333346
                            if state == 26:
                                return 0.0540296733
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 4.76760387)
                                else 28
                            )
                            if state == 27:
                                return -0.0902457982
                            if state == 28:
                                return 0.0269944146
                if state == 4:
                    return 0.0605513752
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.1286011) else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 19.0564346)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 16.2791004)
                            else 18
                        )
                        if state == 17:
                            state = (
                                29
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 16.0924187)
                                else 30
                            )
                            if state == 29:
                                return -0.0320000015
                            if state == 30:
                                return 0.0269944146
                        if state == 18:
                            return -0.0960000008
                    if state == 10:
                        return 0.0461950302
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.37139833)
                        else 12
                    )
                    if state == 11:
                        state = 19 if x["neargaia_med"] < 0.158616394 else 20
                        if state == 19:
                            return 0.0605513752
                        if state == 20:
                            state = (
                                31
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 25.8837776)
                                else 32
                            )
                            if state == 31:
                                return -0.088888891
                            if state == 32:
                                return 0.0269944146
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.991145968)
                            else 22
                        )
                        if state == 21:
                            state = (
                                33
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.953499973)
                                else 34
                            )
                            if state == 33:
                                return 0.0252173916
                            if state == 34:
                                return 0.131279677
                        if state == 22:
                            return -0.0320000015
    elif num_booster == 1:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8599606) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6241493) else 4
                )
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.984250069)
                        else 6
                    )
                    if state == 5:
                        return -0.120376565
                    if state == 6:
                        state = (
                            9
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 16.0924187)
                            else 10
                        )
                        if state == 9:
                            return -0.0524845496
                        if state == 10:
                            return 0.0576969087
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.773720503)
                        else 8
                    )
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.2062492)
                            else 12
                        )
                        if state == 11:
                            state = (
                                15
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.0251999)
                                else 16
                            )
                            if state == 15:
                                return 0.0261814352
                            if state == 16:
                                return -0.0790896043
                        if state == 12:
                            state = (
                                17
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8456001)
                                else 18
                            )
                            if state == 17:
                                return 0.0986726135
                            if state == 18:
                                return -0.0360363461
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5476322)
                            else 14
                        )
                        if state == 13:
                            state = (
                                19
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.989750028)
                                else 20
                            )
                            if state == 19:
                                return 0.139489949
                            if state == 20:
                                return -0.00846112892
                        if state == 14:
                            state = (
                                21
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.55810189)
                                else 22
                            )
                            if state == 21:
                                return 0.0574278533
                            if state == 22:
                                return -0.029328635
            if state == 2:
                return -0.133606255
    elif num_booster == 2:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.8427505) else 2
            )
            if state == 1:
                state = 3 if x["maggaia_med"] < 15.5517893 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.1172504)
                        else 8
                    )
                    if state == 7:
                        return -0.0831610486
                    if state == 8:
                        return -0.00524472306
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 0.523373544)
                        else 10
                    )
                    if state == 9:
                        state = 15 if x["col_det"] < 0.683629096 else 16
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 0.230069846)
                                else 26
                            )
                            if state == 25:
                                return 0.0873615071
                            if state == 26:
                                return -0.0251469612
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.3587494)
                                else 28
                            )
                            if state == 27:
                                return 0.026751928
                            if state == 28:
                                return -0.0805444494
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.579547882)
                            else 18
                        )
                        if state == 17:
                            state = 29 if x["distpsnr1_med"] < 7.07243967 else 30
                            if state == 29:
                                return 0.109218083
                            if state == 30:
                                return 0.0096986508
                        if state == 18:
                            return -0.00582497148
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 6.92862606)
                    else 6
                )
                if state == 5:
                    state = 11 if x["col_det"] < -0.192979813 else 12
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.02862263)
                            else 20
                        )
                        if state == 19:
                            return 0.0559721887
                        if state == 20:
                            return -0.0286178887
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.0649986)
                            else 22
                        )
                        if state == 21:
                            state = (
                                31
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 4.4594965)
                                else 32
                            )
                            if state == 31:
                                return 0.0410738885
                            if state == 32:
                                return -0.0278696623
                        if state == 22:
                            state = (
                                33
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.09059048)
                                else 34
                            )
                            if state == 33:
                                return -0.0980206728
                            if state == 34:
                                return 0.0268473886
                if state == 6:
                    state = 13 if x["col_det"] < 0.0665830001 else 14
                    if state == 13:
                        state = 23 if x["maggaia_med"] < 39.3187485 else 24
                        if state == 23:
                            return -0.0471649915
                        if state == 24:
                            return 0.0410738885
                    if state == 14:
                        return 0.0839940161
    elif num_booster == 3:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 1.32730019)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9292488) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.8325996)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["neargaia_med"] < 24.6568375 else 16
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6674004)
                                else 28
                            )
                            if state == 27:
                                return -0.0936668292
                            if state == 28:
                                return -0.00452763075
                        if state == 16:
                            state = 29 if x["distpsnr1_med"] < 0.280983627 else 30
                            if state == 29:
                                return -0.0517468527
                            if state == 30:
                                return 0.0672434121
                    if state == 8:
                        state = (
                            17 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.0119791) else 18
                        )
                        if state == 17:
                            return -0.0249780435
                        if state == 18:
                            return 0.0930879489
                if state == 4:
                    state = 9 if x["neargaia_med"] < 0.173155561 else 10
                    if state == 9:
                        return 0.0277541243
                    if state == 10:
                        return -0.118599996
            if state == 2:
                state = (
                    5
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 35.7347679)
                    else 6
                )
                if state == 5:
                    state = 11 if x["neargaia_med"] < 6.99131298 else 12
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.4916496)
                            else 20
                        )
                        if state == 19:
                            return -0.0338394381
                        if state == 20:
                            return 0.0418392234
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.99248266)
                            else 22
                        )
                        if state == 21:
                            state = 35 if x["distpsnr1_med"] < 2.16816545 else 36
                            if state == 35:
                                return 0.0237673596
                            if state == 36:
                                return 0.112460643
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.99584484)
                                else 38
                            )
                            if state == 37:
                                return -0.045313701
                            if state == 38:
                                return 0.0549792722
                if state == 6:
                    state = 13 if x["neargaia_med"] < 41.8831558 else 14
                    if state == 13:
                        return -0.056000419
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 1.97372699)
                            else 26
                        )
                        if state == 25:
                            return -0.00319623202
                        if state == 26:
                            return 0.0702970549
    elif num_booster == 4:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5919151) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.1327171) else 4
                )
                if state == 3:
                    state = 7 if x["distpsnr1_med"] < 1.34613085 else 8
                    if state == 7:
                        return -0.108372808
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.5970001)
                            else 14
                        )
                        if state == 13:
                            state = (
                                17
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.2363358)
                                else 18
                            )
                            if state == 17:
                                return 0.100932337
                            if state == 18:
                                return -0.0341560096
                        if state == 14:
                            return -0.0622697994
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.7425003)
                        else 10
                    )
                    if state == 9:
                        return 0.118342102
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.073349)
                            else 16
                        )
                        if state == 15:
                            state = (
                                21
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 22.6224995)
                                else 22
                            )
                            if state == 21:
                                return -0.0604983047
                            if state == 22:
                                return 0.0379300937
                        if state == 16:
                            return 0.0716860592
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.3132515)
                    else 6
                )
                if state == 5:
                    return -0.123278007
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.6019001)
                        else 12
                    )
                    if state == 11:
                        return 0.0390459262
                    if state == 12:
                        return -0.0275111627
    elif num_booster == 5:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8252144) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.588625014)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5919151)
                        else 8
                    )
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 16.4072189)
                            else 12
                        )
                        if state == 11:
                            return -0.044076588
                        if state == 12:
                            state = (
                                19
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.73150003)
                                else 20
                            )
                            if state == 19:
                                return -0.026153693
                            if state == 20:
                                return 0.103228144
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.55810189)
                            else 14
                        )
                        if state == 13:
                            return 0.0512824766
                        if state == 14:
                            state = (
                                21
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.7978439)
                                else 22
                            )
                            if state == 21:
                                return -0.075243257
                            if state == 22:
                                return 0.0295909233
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.7116299)
                        else 10
                    )
                    if state == 9:
                        state = 15 if x["sgscore1_med"] < 0.707957983 else 16
                        if state == 15:
                            return -0.00249410211
                        if state == 16:
                            state = (
                                23
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.99273729)
                                else 24
                            )
                            if state == 23:
                                return -0.10525728
                            if state == 24:
                                return -0.000667079235
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.731000006)
                            else 18
                        )
                        if state == 17:
                            return -0.0250382982
                        if state == 18:
                            return 0.0366731472
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.93741322) else 6
                if state == 5:
                    return 0.00560901733
                if state == 6:
                    return -0.115477428
    elif num_booster == 6:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8252144) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.6564751) else 4
                )
                if state == 3:
                    return -0.0949623212
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.511013)
                        else 8
                    )
                    if state == 7:
                        state = 9 if x["maggaia_med"] < 15.8999462 else 10
                        if state == 9:
                            return -0.0272644721
                        if state == 10:
                            state = (
                                13
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 20.5655003)
                                else 14
                            )
                            if state == 13:
                                return 0.11568401
                            if state == 14:
                                return 0.0406048112
                    if state == 8:
                        state = (
                            11
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 16.3356342)
                            else 12
                        )
                        if state == 11:
                            return 0.0684992075
                        if state == 12:
                            state = (
                                15
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9814987)
                                else 16
                            )
                            if state == 15:
                                return -0.0953085423
                            if state == 16:
                                return 0.0162665453
            if state == 2:
                state = 5 if x["col_det"] < -0.167057514 else 6
                if state == 5:
                    return 0.00122714671
                if state == 6:
                    return -0.110000178
    elif num_booster == 7:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8673592) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.1327171) else 4
                )
                if state == 3:
                    state = 5 if x["neargaia_med"] < 17.6644573 else 6
                    if state == 5:
                        state = 9 if x["neargaia_med"] < 0.610419869 else 10
                        if state == 9:
                            return -0.00248043821
                        if state == 10:
                            return -0.0793422908
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0157013)
                            else 12
                        )
                        if state == 11:
                            return 0.0873629525
                        if state == 12:
                            return -0.0393083766
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5265446)
                        else 8
                    )
                    if state == 7:
                        return 0.111825943
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.97225)
                            else 14
                        )
                        if state == 13:
                            return -0.0700848028
                        if state == 14:
                            state = 15 if x["neargaia_med"] < 83.288887 else 16
                            if state == 15:
                                return 0.0757448897
                            if state == 16:
                                return -0.00442239735
            if state == 2:
                return -0.106792592
    elif num_booster == 8:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7388859) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.2439003) else 4
                )
                if state == 3:
                    state = 7 if x["col_det"] < -0.276728153 else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 18.1063881)
                            else 14
                        )
                        if state == 13:
                            return 0.0406594202
                        if state == 14:
                            return -0.0421048477
                    if state == 8:
                        return -0.0999264196
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.623383999)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.511013)
                            else 16
                        )
                        if state == 15:
                            state = 19 if x["maggaia_med"] < 17.3315735 else 20
                            if state == 19:
                                return 0.0413739495
                            if state == 20:
                                return 0.109722584
                        if state == 16:
                            state = 21 if x["col_det"] < 0.233263969 else 22
                            if state == 21:
                                return -0.0678408295
                            if state == 22:
                                return 0.0509123988
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8985996)
                            else 18
                        )
                        if state == 17:
                            state = (
                                23
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.1566219)
                                else 24
                            )
                            if state == 23:
                                return 0.000303218054
                            if state == 24:
                                return -0.0881472304
                        if state == 18:
                            return 0.0433898047
            if state == 2:
                state = 5 if x["col_det"] < -0.259850502 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7102013)
                        else 12
                    )
                    if state == 11:
                        return -0.0262517855
                    if state == 12:
                        return 0.0288971607
                if state == 6:
                    return -0.10205546
    elif num_booster == 9:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.7352505) else 2
            )
            if state == 1:
                return -0.0818214417
            if state == 2:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.9937496)
                    else 4
                )
                if state == 3:
                    state = 5 if x["neargaia_med"] < 53.1112862 else 6
                    if state == 5:
                        state = (
                            9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.49625587) else 10
                        )
                        if state == 9:
                            return -0.040923886
                        if state == 10:
                            state = 15 if x["neargaia_med"] < 41.6930161 else 16
                            if state == 15:
                                return 0.048266802
                            if state == 16:
                                return -0.0212191455
                    if state == 6:
                        return 0.0825420171
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.9237499)
                        else 8
                    )
                    if state == 7:
                        state = 11 if x["col_det"] < 0.00243282318 else 12
                        if state == 11:
                            state = (
                                17
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 4.53545713)
                                else 18
                            )
                            if state == 17:
                                return -0.0894488469
                            if state == 18:
                                return 0.00926622748
                        if state == 12:
                            state = (
                                19
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.3727493)
                                else 20
                            )
                            if state == 19:
                                return -0.0448784567
                            if state == 20:
                                return 0.0271325558
                    if state == 8:
                        return 0.0461234003
    elif num_booster == 10:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.584166467) else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.01997113) else 4
                if state == 3:
                    state = (
                        7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.0694386512) else 8
                    )
                    if state == 7:
                        return -0.0218207575
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.298333406)
                            else 16
                        )
                        if state == 15:
                            return -0.0198317207
                        if state == 16:
                            return 0.0679439753
                if state == 4:
                    state = 9 if x["col_det"] < -0.196491241 else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.02295113)
                            else 18
                        )
                        if state == 17:
                            return 0.0445297807
                        if state == 18:
                            return -0.026664637
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0314930491)
                            else 20
                        )
                        if state == 19:
                            state = (
                                29
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.00934604928)
                                else 30
                            )
                            if state == 29:
                                return -0.0192411356
                            if state == 30:
                                return 0.0292648766
                        if state == 20:
                            return -0.104619272
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.654992104)
                    else 6
                )
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.03766203) else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.98660874)
                            else 22
                        )
                        if state == 21:
                            state = (
                                31
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < 0.257889748)
                                else 32
                            )
                            if state == 31:
                                return 0.058946766
                            if state == 32:
                                return -0.00179084728
                        if state == 22:
                            return -0.0205838848
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.211897925)
                            else 24
                        )
                        if state == 23:
                            state = (
                                33
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 4.48007536)
                                else 34
                            )
                            if state == 33:
                                return -0.02035073
                            if state == 34:
                                return 0.0314819366
                        if state == 24:
                            return -0.0668307468
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 6.99187899)
                        else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.692023754)
                            else 26
                        )
                        if state == 25:
                            state = (
                                35
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.667500257)
                                else 36
                            )
                            if state == 35:
                                return 0.0404193215
                            if state == 36:
                                return -0.0484972075
                        if state == 26:
                            state = (
                                37
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.00549769)
                                else 38
                            )
                            if state == 37:
                                return -0.00359338243
                            if state == 38:
                                return 0.0782679617
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 8.62724876)
                            else 28
                        )
                        if state == 27:
                            return -0.0644488335
                        if state == 28:
                            state = (
                                39
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.03653359)
                                else 40
                            )
                            if state == 39:
                                return -0.0271252785
                            if state == 40:
                                return 0.028227346
    elif num_booster == 11:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.912499964)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 17.1026344)
                    else 4
                )
                if state == 3:
                    return -0.0956073329
                if state == 4:
                    state = 7 if x["maggaia_med"] < 18.9810524 else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.3662491)
                            else 14
                        )
                        if state == 13:
                            state = (
                                23
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.386496186)
                                else 24
                            )
                            if state == 23:
                                return -0.0200592652
                            if state == 24:
                                return 0.0726247877
                        if state == 14:
                            state = (
                                25
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.7280006)
                                else 26
                            )
                            if state == 25:
                                return -0.0504273511
                            if state == 26:
                                return 0.00177625509
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.65625)
                            else 16
                        )
                        if state == 15:
                            return -0.0835031793
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3066502)
                                else 28
                            )
                            if state == 27:
                                return -0.0203335546
                            if state == 28:
                                return 0.0343297645
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.6882515)
                    else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.1236496)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 19.8348808)
                            else 18
                        )
                        if state == 17:
                            return -0.0781025887
                        if state == 18:
                            return 0.0365880802
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8827515)
                            else 20
                        )
                        if state == 19:
                            state = (
                                29
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 19.1805)
                                else 30
                            )
                            if state == 29:
                                return 0.099368073
                            if state == 30:
                                return 0.0256342292
                        if state == 20:
                            state = (
                                31
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.958000004)
                                else 32
                            )
                            if state == 31:
                                return -0.0533349253
                            if state == 32:
                                return 0.0388866663
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.7422485)
                        else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.95174998)
                            else 22
                        )
                        if state == 21:
                            return -0.0041488586
                        if state == 22:
                            return -0.105643779
                    if state == 12:
                        return 0.0435559116
    elif num_booster == 12:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.3949852) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.3214989)
                    else 4
                )
                if state == 3:
                    return -0.0826107785
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.0577507)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.3440018)
                            else 14
                        )
                        if state == 13:
                            state = 21 if x["maggaia_med"] < 16.0115185 else 22
                            if state == 21:
                                return -0.00999055989
                            if state == 22:
                                return 0.102814898
                        if state == 14:
                            state = (
                                23
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.00310183)
                                else 24
                            )
                            if state == 23:
                                return 0.0405680984
                            if state == 24:
                                return -0.0290799197
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 3.01569462)
                            else 16
                        )
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.6337509)
                                else 26
                            )
                            if state == 25:
                                return 0.00611978816
                            if state == 26:
                                return -0.0818332881
                        if state == 16:
                            return 0.0419880636
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.969249964)
                    else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.6430473)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 19.999279)
                            else 18
                        )
                        if state == 17:
                            return -0.100287512
                        if state == 18:
                            state = (
                                27
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 20.0647736)
                                else 28
                            )
                            if state == 27:
                                return 0.0291353054
                            if state == 28:
                                return -0.0511682592
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.641749978)
                            else 20
                        )
                        if state == 19:
                            return -0.041059494
                        if state == 20:
                            return 0.0155654829
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.96270275)
                        else 12
                    )
                    if state == 11:
                        return 0.0623858534
                    if state == 12:
                        return -0.0660959035
    elif num_booster == 13:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.9440269) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.01982069)
                    else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.847619057) else 8
                    )
                    if state == 7:
                        return -0.0935880542
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 16.9869766)
                            else 14
                        )
                        if state == 13:
                            return -0.0229454301
                        if state == 14:
                            return 0.037772309
                if state == 4:
                    return 0.0355545878
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8675995) else 6
                )
                if state == 5:
                    state = 9 if x["neargaia_med"] < 17.9731522 else 10
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 2.18013358)
                            else 16
                        )
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8115997)
                                else 24
                            )
                            if state == 23:
                                return 0.0640616417
                            if state == 24:
                                return -0.00830770843
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.6765499)
                                else 26
                            )
                            if state == 25:
                                return -0.0570559166
                            if state == 26:
                                return 0.0276015773
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0569213033)
                            else 18
                        )
                        if state == 17:
                            return -0.0178432111
                        if state == 18:
                            return 0.0896688551
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.714404821)
                        else 12
                    )
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 1.54169607)
                            else 20
                        )
                        if state == 19:
                            return -0.0833758712
                        if state == 20:
                            state = (
                                27
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.77873707)
                                else 28
                            )
                            if state == 27:
                                return 0.0646229908
                            if state == 28:
                                return -0.0485658236
                    if state == 12:
                        state = 21 if x["neargaia_med"] < 45.5790253 else 22
                        if state == 21:
                            state = 29 if x["neargaia_med"] < 4.2717557 else 30
                            if state == 29:
                                return -0.0291743297
                            if state == 30:
                                return 0.0633650348
                        if state == 22:
                            return -0.0530527644
    elif num_booster == 14:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6331635) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.7002487)
                    else 4
                )
                if state == 3:
                    return -0.0801455006
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.5842514)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 6.7396183)
                            else 16
                        )
                        if state == 15:
                            state = (
                                19
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.0457002521)
                                else 20
                            )
                            if state == 19:
                                return -0.000072
                            if state == 20:
                                return 0.0921110138
                        if state == 16:
                            return -0.0360762626
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 3.66674662)
                            else 18
                        )
                        if state == 17:
                            state = 21 if x["col_det"] < -0.0750719681 else 22
                            if state == 21:
                                return -0.0700434893
                            if state == 22:
                                return -0.000489263621
                        if state == 18:
                            return 0.0469377078
            if state == 2:
                state = 5 if x["col_det"] < -0.259850502 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7646866)
                        else 12
                    )
                    if state == 11:
                        return -0.0291554444
                    if state == 12:
                        return 0.0278656166
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.785656)
                        else 14
                    )
                    if state == 13:
                        return -0.00674173702
                    if state == 14:
                        return -0.099955529
    elif num_booster == 15:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.77275002)
                else 2
            )
            if state == 1:
                return -0.0891266316
            if state == 2:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.0177498)
                    else 4
                )
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 15.68575)
                        else 6
                    )
                    if state == 5:
                        return -0.0593296364
                    if state == 6:
                        state = (
                            9
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9174004)
                            else 10
                        )
                        if state == 9:
                            return 0.0943527892
                        if state == 10:
                            state = 13 if x["col_det"] < 0.194000244 else 14
                            if state == 13:
                                return -0.037859939
                            if state == 14:
                                return 0.057127919
                if state == 4:
                    state = 7 if x["distpsnr1_med"] < 8.26984787 else 8
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.916749954)
                            else 12
                        )
                        if state == 11:
                            return -0.0118237333
                        if state == 12:
                            state = (
                                15
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.073349)
                                else 16
                            )
                            if state == 15:
                                return -0.104883775
                            if state == 16:
                                return -0.0110717081
                    if state == 8:
                        return 0.0740026012
    elif num_booster == 16:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.698948979)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 18.9883709)
                    else 4
                )
                if state == 3:
                    state = 5 if x["col_det"] < 0.154500008 else 6
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 10.7521629)
                            else 10
                        )
                        if state == 9:
                            state = (
                                17
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.31950599)
                                else 18
                            )
                            if state == 17:
                                return 0.0692156032
                            if state == 18:
                                return 0.00933047011
                        if state == 10:
                            state = (
                                19
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.96739006)
                                else 20
                            )
                            if state == 19:
                                return 0.0280020069
                            if state == 20:
                                return -0.0421840474
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.382063866)
                            else 12
                        )
                        if state == 11:
                            state = 21 if x["sgscore1_med"] < 0.00395833515 else 22
                            if state == 21:
                                return 0.0210075341
                            if state == 22:
                                return -0.0541612953
                        if state == 12:
                            state = (
                                23
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 17.1341476)
                                else 24
                            )
                            if state == 23:
                                return -0.0351876654
                            if state == 24:
                                return 0.0579659827
                if state == 4:
                    state = 7 if x["col_det"] < -0.110546112 else 8
                    if state == 7:
                        state = 13 if x["col_det"] < -0.231370926 else 14
                        if state == 13:
                            return 0.0210331585
                        if state == 14:
                            return -0.0415257551
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.062494196)
                            else 16
                        )
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.0417882502)
                                else 26
                            )
                            if state == 25:
                                return 0.0522127189
                            if state == 26:
                                return -0.0536391437
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < 0.316198349)
                                else 28
                            )
                            if state == 27:
                                return 0.0856634676
                            if state == 28:
                                return 0.00373713276
            if state == 2:
                return -0.0747085437
    elif num_booster == 17:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.790250003)
                else 2
            )
            if state == 1:
                return -0.0855978578
            if state == 2:
                state = 3 if x["neargaia_med"] < 29.0058823 else 4
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.9469676)
                        else 6
                    )
                    if state == 5:
                        state = 9 if x["maggaia_med"] < 15.5045052 else 10
                        if state == 9:
                            return -0.0446804985
                        if state == 10:
                            state = 15 if x["neargaia_med"] < 27.9597359 else 16
                            if state == 15:
                                return 0.0429881103
                            if state == 16:
                                return -0.0336438976
                    if state == 6:
                        state = 11 if x["neargaia_med"] < 1.42693305 else 12
                        if state == 11:
                            return 0.0323158987
                        if state == 12:
                            state = (
                                19
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.986750007)
                                else 20
                            )
                            if state == 19:
                                return -0.0647671521
                            if state == 20:
                                return 0.0226293933
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.91495943)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.963)
                            else 14
                        )
                        if state == 13:
                            state = (
                                21
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 35.6781235)
                                else 22
                            )
                            if state == 21:
                                return -0.0541480035
                            if state == 22:
                                return 0.0199218448
                        if state == 14:
                            state = (
                                23
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.90313101)
                                else 24
                            )
                            if state == 23:
                                return 0.0492951348
                            if state == 24:
                                return -0.00997664779
                    if state == 8:
                        return 0.0696815923
    elif num_booster == 18:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.595927)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.705000043)
                    else 4
                )
                if state == 3:
                    return -0.0834467933
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.4438782)
                        else 8
                    )
                    if state == 7:
                        state = 11 if x["maggaia_med"] < 17.6160126 else 12
                        if state == 11:
                            state = (
                                15
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.497500062)
                                else 16
                            )
                            if state == 15:
                                return 0.0422882661
                            if state == 16:
                                return -0.0379066803
                        if state == 12:
                            state = (
                                17
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.506666541)
                                else 18
                            )
                            if state == 17:
                                return -0.00501302397
                            if state == 18:
                                return 0.0730196163
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0850266516)
                            else 14
                        )
                        if state == 13:
                            state = (
                                19
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.799000025)
                                else 20
                            )
                            if state == 19:
                                return -0.0412503034
                            if state == 20:
                                return 0.0457000956
                        if state == 14:
                            state = 21 if x["maggaia_med"] < 20.1196842 else 22
                            if state == 21:
                                return -0.0937750861
                            if state == 22:
                                return -0.00188112061
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.831428468) else 6
                if state == 5:
                    return -0.0943186656
                if state == 6:
                    state = 9 if x["sgscore1_med"] < 0.849580526 else 10
                    if state == 9:
                        return -0.028042648
                    if state == 10:
                        return 0.0342421457
    elif num_booster == 19:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.342268) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.991484582)
                    else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.735000014) else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.34830147)
                            else 16
                        )
                        if state == 15:
                            state = (
                                21
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.69083339)
                                else 22
                            )
                            if state == 21:
                                return -0.0264853276
                            if state == 22:
                                return 0.0350396
                        if state == 16:
                            return -0.0732992589
                    if state == 8:
                        return 0.0518596768
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.5269699)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.59578705)
                            else 18
                        )
                        if state == 17:
                            state = (
                                23
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 15.3787851)
                                else 24
                            )
                            if state == 23:
                                return 0.0104196761
                            if state == 24:
                                return -0.0472560674
                        if state == 18:
                            state = (
                                25
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 6.63459587)
                                else 26
                            )
                            if state == 25:
                                return 0.0650075376
                            if state == 26:
                                return -0.0246029515
                    if state == 10:
                        return 0.0837767497
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.00994778) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.68452406)
                        else 12
                    )
                    if state == 11:
                        return 0.0477556661
                    if state == 12:
                        return -0.0556464978
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.913214326)
                        else 14
                    )
                    if state == 13:
                        return -0.0986033827
                    if state == 14:
                        return -0.000496848894
    elif num_booster == 20:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.896749973)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.77974999)
                    else 4
                )
                if state == 3:
                    return -0.0871895775
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.791999996)
                        else 8
                    )
                    if state == 7:
                        return 0.0370404273
                    if state == 8:
                        state = 11 if x["neargaia_med"] < 9.51260567 else 12
                        if state == 11:
                            state = 17 if x["sgscore1_med"] < 0.190556347 else 18
                            if state == 17:
                                return 0.024666518
                            if state == 18:
                                return -0.0187691022
                        if state == 12:
                            state = (
                                19
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 41.1075363)
                                else 20
                            )
                            if state == 19:
                                return -0.0653413981
                            if state == 20:
                                return 0.000177803056
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.595927)
                    else 6
                )
                if state == 5:
                    state = 9 if x["maggaia_med"] < 16.455162 else 10
                    if state == 9:
                        state = 13 if x["maggaia_med"] < 15.4198256 else 14
                        if state == 13:
                            return 0.0255443919
                        if state == 14:
                            return -0.0646032616
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 20.2958965)
                            else 16
                        )
                        if state == 15:
                            return 0.0886843726
                        if state == 16:
                            state = (
                                23
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.85146451)
                                else 24
                            )
                            if state == 23:
                                return 0.033054661
                            if state == 24:
                                return -0.0215357076
                if state == 6:
                    return -0.0821295604
    elif num_booster == 21:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.898499966)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 23.0779457)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 6.94351482)
                        else 8
                    )
                    if state == 7:
                        return -0.084708482
                    if state == 8:
                        return 0.00415166467
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.8852501)
                        else 10
                    )
                    if state == 9:
                        state = 13 if x["sgscore1_med"] < 0.0897561461 else 14
                        if state == 13:
                            return -0.00331176445
                        if state == 14:
                            return 0.0525165126
                    if state == 10:
                        return -0.0556731373
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.635178506)
                    else 6
                )
                if state == 5:
                    state = 11 if x["neargaia_med"] < 15.6657181 else 12
                    if state == 11:
                        state = 15 if x["neargaia_med"] < 9.79543877 else 16
                        if state == 15:
                            state = (
                                19
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 14.7897491)
                                else 20
                            )
                            if state == 19:
                                return -0.0340515338
                            if state == 20:
                                return 0.0524283499
                        if state == 16:
                            state = (
                                21
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.6862488)
                                else 22
                            )
                            if state == 21:
                                return -0.00510176271
                            if state == 22:
                                return -0.0718929693
                    if state == 12:
                        state = (
                            17
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 46.0309906)
                            else 18
                        )
                        if state == 17:
                            return 0.0801049992
                        if state == 18:
                            state = 23 if x["sgscore1_med"] < 0.32515201 else 24
                            if state == 23:
                                return 0.0243988745
                            if state == 24:
                                return -0.0426985063
                if state == 6:
                    return -0.0692782998
    elif num_booster == 22:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.675827) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.646502972)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0471992)
                        else 8
                    )
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0835841522)
                            else 12
                        )
                        if state == 11:
                            state = 15 if x["sgscore1_med"] < 0.017229151 else 16
                            if state == 15:
                                return -0.00871447567
                            if state == 16:
                                return 0.057303451
                        if state == 12:
                            state = (
                                17
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.97096062)
                                else 18
                            )
                            if state == 17:
                                return -0.045712769
                            if state == 18:
                                return 0.0269826669
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.3769989)
                            else 14
                        )
                        if state == 13:
                            state = (
                                19
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.2999535)
                                else 20
                            )
                            if state == 19:
                                return 0.0559122227
                            if state == 20:
                                return -0.0515151285
                        if state == 14:
                            return 0.0864411443
                if state == 4:
                    return -0.0723908097
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.00339583494 else 6
                if state == 5:
                    return -0.000151947097
                if state == 6:
                    return -0.0875877067
    elif num_booster == 23:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.969249964)
                else 2
            )
            if state == 1:
                state = 3 if x["col_det"] < 0.204384804 else 4
                if state == 3:
                    state = 7 if x["col_det"] < -0.18052578 else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.613666534)
                            else 16
                        )
                        if state == 15:
                            return 0.0383084826
                        if state == 16:
                            return -0.0262610912
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.07377315)
                            else 18
                        )
                        if state == 17:
                            return -0.0926239118
                        if state == 18:
                            state = (
                                25
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.59109378)
                                else 26
                            )
                            if state == 25:
                                return 0.0241784565
                            if state == 26:
                                return -0.0189955011
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.78275001)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.786666751)
                            else 20
                        )
                        if state == 19:
                            return -0.0596482679
                        if state == 20:
                            return 0.00893297512
                    if state == 10:
                        state = 21 if x["sgscore1_med"] < 0.966089487 else 22
                        if state == 21:
                            state = (
                                27
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.562500119)
                                else 28
                            )
                            if state == 27:
                                return -0.00120302557
                            if state == 28:
                                return 0.0630659983
                        if state == 22:
                            return -0.0346294306
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.525833368) else 6
                if state == 5:
                    state = 11 if x["col_det"] < 0.119606972 else 12
                    if state == 11:
                        return 0.0262697693
                    if state == 12:
                        return -0.0928092152
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.869202018)
                        else 14
                    )
                    if state == 13:
                        state = 23 if x["col_det"] < -0.467707634 else 24
                        if state == 23:
                            return -0.0138396937
                        if state == 24:
                            state = (
                                29
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.05178261)
                                else 30
                            )
                            if state == 29:
                                return 0.0805074945
                            if state == 30:
                                return -0.00904167537
                    if state == 14:
                        return -0.0366343409
    elif num_booster == 24:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.969249964)
                else 2
            )
            if state == 1:
                state = 3 if x["col_det"] < -0.186650276 else 4
                if state == 3:
                    return 0.0246021766
                if state == 4:
                    state = 9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.0126214) else 10
                    if state == 9:
                        state = (
                            15 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.0302546) else 16
                        )
                        if state == 15:
                            return -0.0465334356
                        if state == 16:
                            return 0.0451659709
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.8449993)
                            else 18
                        )
                        if state == 17:
                            state = (
                                25
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < 0.124790192)
                                else 26
                            )
                            if state == 25:
                                return -0.0759700313
                            if state == 26:
                                return -0.0235957038
                        if state == 18:
                            return 0.00693499483
            if state == 2:
                state = (
                    5 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.70825) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.1612892)
                        else 12
                    )
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 15.5844994)
                            else 20
                        )
                        if state == 19:
                            return -0.0277572833
                        if state == 20:
                            return 0.081339173
                    if state == 12:
                        state = 21 if x["col_det"] < 0.0767822266 else 22
                        if state == 21:
                            state = (
                                27
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 20.1054993)
                                else 28
                            )
                            if state == 27:
                                return -0.0661382601
                            if state == 28:
                                return 0.0218189713
                        if state == 22:
                            return 0.0517093614
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.5305004)
                        else 14
                    )
                    if state == 13:
                        return -0.0933133736
                    if state == 14:
                        return 0.0461052656
    elif num_booster == 25:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.774999976)
                else 2
            )
            if state == 1:
                return -0.0782162622
            if state == 2:
                state = 3 if x["distpsnr1_med"] < 0.0951836109 else 4
                if state == 3:
                    return -0.0712041631
                if state == 4:
                    state = (
                        5
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.971249998)
                        else 6
                    )
                    if state == 5:
                        state = (
                            7
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3501015)
                            else 8
                        )
                        if state == 7:
                            state = (
                                11
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8515511)
                                else 12
                            )
                            if state == 11:
                                return 0.0248554349
                            if state == 12:
                                return -0.0725169852
                        if state == 8:
                            state = (
                                13
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.43873978)
                                else 14
                            )
                            if state == 13:
                                return 0.0714289695
                            if state == 14:
                                return -0.00518508861
                    if state == 6:
                        state = (
                            9
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.137001)
                            else 10
                        )
                        if state == 9:
                            state = (
                                15
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.47713375)
                                else 16
                            )
                            if state == 15:
                                return 0.0190626886
                            if state == 16:
                                return -0.0513227209
                        if state == 10:
                            state = 17 if x["col_det"] < -1.31582832 else 18
                            if state == 17:
                                return -0.0222515929
                            if state == 18:
                                return 0.0825740546
    elif num_booster == 26:
        state = 0
        if state == 0:
            state = 1 if x["col_det"] < 0.182310104 else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.02237272) else 4
                if state == 3:
                    state = 7 if x["neargaia_med"] < 59.728096 else 8
                    if state == 7:
                        return -0.0778597146
                    if state == 8:
                        return 0.00311029702
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.669881105)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.491666585)
                            else 16
                        )
                        if state == 15:
                            return 0.0297684465
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 26.3756847)
                                else 26
                            )
                            if state == 25:
                                return -0.0594406985
                            if state == 26:
                                return 0.00409035059
                    if state == 10:
                        state = 17 if x["col_det"] < -0.000733375549 else 18
                        if state == 17:
                            state = (
                                27
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.02448463)
                                else 28
                            )
                            if state == 27:
                                return 0.0565849729
                            if state == 28:
                                return -0.00253203465
                        if state == 18:
                            state = 29 if x["col_det"] < 0.11384201 else 30
                            if state == 29:
                                return -0.0212385897
                            if state == 30:
                                return 0.0176087748
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.536428571) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["t_predetect"])
                        or (x["t_predetect"] < 0.0674479455)
                        else 12
                    )
                    if state == 11:
                        return 0.00103371381
                    if state == 12:
                        return -0.0660156012
                if state == 6:
                    state = 13 if x["neargaia_med"] < 10.1311321 else 14
                    if state == 13:
                        state = (
                            19
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.708333254)
                            else 20
                        )
                        if state == 19:
                            return -0.0462574698
                        if state == 20:
                            state = (
                                31
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.0386342481)
                                else 32
                            )
                            if state == 31:
                                return -0.0107650878
                            if state == 32:
                                return 0.0429269597
                    if state == 14:
                        state = (
                            21
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 60.8982315)
                            else 22
                        )
                        if state == 21:
                            state = (
                                33
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.55571425)
                                else 34
                            )
                            if state == 33:
                                return 0.000306166941
                            if state == 34:
                                return 0.0758457929
                        if state == 22:
                            return -0.00678923633
    elif num_booster == 27:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.0514984) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 16.470068)
                    else 4
                )
                if state == 3:
                    state = 7 if x["neargaia_med"] < 13.8682022 else 8
                    if state == 7:
                        return -0.0571655445
                    if state == 8:
                        state = 15 if x["distpsnr1_med"] < 0.551347733 else 16
                        if state == 15:
                            return -0.0254926719
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.8732491)
                                else 28
                            )
                            if state == 27:
                                return 0.0498516485
                            if state == 28:
                                return -0.0145566147
                if state == 4:
                    state = 9 if x["distpsnr1_med"] < 0.561049104 else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.96141768)
                            else 18
                        )
                        if state == 17:
                            return 0.0355082639
                        if state == 18:
                            return -0.032550063
                    if state == 10:
                        return 0.0811161771
            if state == 2:
                state = (
                    5
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 18.5806904)
                    else 6
                )
                if state == 5:
                    state = 11 if x["distpsnr1_med"] < 8.24716759 else 12
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 3.01104164)
                            else 20
                        )
                        if state == 19:
                            return -0.0824961662
                        if state == 20:
                            state = (
                                31
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.03695583)
                                else 32
                            )
                            if state == 31:
                                return 0.028730873
                            if state == 32:
                                return -0.0450516939
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.4157505)
                            else 22
                        )
                        if state == 21:
                            return 0.0238685906
                        if state == 22:
                            return -0.0191116147
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.92039919)
                        else 14
                    )
                    if state == 13:
                        state = 23 if x["maggaia_med"] < 18.8607559 else 24
                        if state == 23:
                            state = (
                                35
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.043750003)
                                else 36
                            )
                            if state == 35:
                                return 0.00453912327
                            if state == 36:
                                return -0.0536689609
                        if state == 24:
                            return 0.0162853058
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.7577496)
                            else 26
                        )
                        if state == 25:
                            return 0.069521673
                        if state == 26:
                            state = (
                                39
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 22.8867493)
                                else 40
                            )
                            if state == 39:
                                return -0.0444044992
                            if state == 40:
                                return 0.0217890684
    elif num_booster == 28:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.7397499) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.790250003)
                    else 4
                )
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.03145266) else 8
                    if state == 7:
                        return 0.0240536127
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.2102509)
                            else 16
                        )
                        if state == 15:
                            return -0.0680424199
                        if state == 16:
                            return 0.0136205601
                if state == 4:
                    state = 9 if x["maggaia_med"] < 17.3760796 else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.8859997)
                            else 18
                        )
                        if state == 17:
                            state = (
                                27
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 16.9295006)
                                else 28
                            )
                            if state == 27:
                                return -0.0241830554
                            if state == 28:
                                return 0.0510343909
                        if state == 18:
                            return -0.045024354
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.98175335)
                            else 20
                        )
                        if state == 19:
                            return 0.0698642284
                        if state == 20:
                            state = (
                                31
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.98648167)
                                else 32
                            )
                            if state == 31:
                                return -0.0451114513
                            if state == 32:
                                return 0.0300986674
            if state == 2:
                state = 5 if x["maggaia_med"] < 20.3039112 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.816071391)
                        else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.88322353)
                            else 22
                        )
                        if state == 21:
                            state = (
                                33
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 20.0714989)
                                else 34
                            )
                            if state == 33:
                                return -0.0184653345
                            if state == 34:
                                return -0.0859656185
                        if state == 22:
                            state = (
                                35
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.00076389)
                                else 36
                            )
                            if state == 35:
                                return 0.0163206272
                            if state == 36:
                                return -0.0394863226
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.93107152)
                            else 24
                        )
                        if state == 23:
                            return 0.0397826433
                        if state == 24:
                            return -0.0189764332
                if state == 6:
                    state = (
                        13 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.97904491) else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.984250009)
                            else 26
                        )
                        if state == 25:
                            state = (
                                37
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.974249959)
                                else 38
                            )
                            if state == 37:
                                return -0.00775098242
                            if state == 38:
                                return 0.0550674461
                        if state == 26:
                            return -0.0198864918
                    if state == 14:
                        return -0.0410503671
    elif num_booster == 29:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 1.25276625 else 2
            if state == 1:
                state = 3 if x["neargaia_med"] < 0.41447562 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.2851486)
                        else 8
                    )
                    if state == 7:
                        return 0.0380042531
                    if state == 8:
                        return -0.0190776754
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 55.0134239)
                        else 10
                    )
                    if state == 9:
                        state = (
                            13
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.289577484)
                            else 14
                        )
                        if state == 13:
                            return -0.0715463832
                        if state == 14:
                            return 0.012082953
                    if state == 10:
                        return 0.0290425532
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.6564751) else 6
                )
                if state == 5:
                    return -0.0441612862
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4316483)
                        else 12
                    )
                    if state == 11:
                        state = 15 if x["distpsnr1_med"] < 2.11146188 else 16
                        if state == 15:
                            state = 21 if x["col_det"] < -0.0551856346 else 22
                            if state == 21:
                                return -0.0394159891
                            if state == 22:
                                return 0.0232913941
                        if state == 16:
                            state = (
                                23
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < 0.169850349)
                                else 24
                            )
                            if state == 23:
                                return 0.0676871538
                            if state == 24:
                                return -0.000666223757
                    if state == 12:
                        state = (
                            17
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 18.9835567)
                            else 18
                        )
                        if state == 17:
                            return -0.0476654768
                        if state == 18:
                            state = (
                                25
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.58395)
                                else 26
                            )
                            if state == 25:
                                return -0.0228853989
                            if state == 26:
                                return 0.0324863717
    elif num_booster == 30:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5919151) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.4622498)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.9820824)
                        else 8
                    )
                    if state == 7:
                        return -0.0607945323
                    if state == 8:
                        return 0.0118601155
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.1172485)
                        else 10
                    )
                    if state == 9:
                        state = (
                            13
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.48501158)
                            else 14
                        )
                        if state == 13:
                            state = (
                                17
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 1.98324656)
                                else 18
                            )
                            if state == 17:
                                return 0.0314598791
                            if state == 18:
                                return -0.0387453698
                        if state == 14:
                            return 0.08546298
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.47063065)
                            else 16
                        )
                        if state == 15:
                            state = 19 if x["distpsnr1_med"] < 13.864563 else 20
                            if state == 19:
                                return -0.0746313781
                            if state == 20:
                                return 0.0241067503
                        if state == 16:
                            state = (
                                21
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 17.319931)
                                else 22
                            )
                            if state == 21:
                                return -0.00539514283
                            if state == 22:
                                return 0.0651106462
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.49837399) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.9796295)
                        else 12
                    )
                    if state == 11:
                        return 0.0291175973
                    if state == 12:
                        return -0.0346009172
                if state == 6:
                    return -0.0886074901
    elif num_booster == 31:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 7.35167456 else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.98759842) else 4
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.02767944) else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.963500023)
                            else 16
                        )
                        if state == 15:
                            return 0.0214788914
                        if state == 16:
                            return -0.0265574381
                    if state == 8:
                        return -0.0722103193
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.1620007)
                        else 10
                    )
                    if state == 9:
                        return 0.0266625155
                    if state == 10:
                        return -0.0236824118
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.2172508)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.969249964)
                        else 12
                    )
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.705500007)
                            else 18
                        )
                        if state == 17:
                            return -0.0473538302
                        if state == 18:
                            state = (
                                23
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.873250008)
                                else 24
                            )
                            if state == 23:
                                return 0.0381906256
                            if state == 24:
                                return -0.0207932629
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 44.583744)
                            else 20
                        )
                        if state == 19:
                            return 0.0768126622
                        if state == 20:
                            return -0.0300118849
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 34.1575165)
                        else 14
                    )
                    if state == 13:
                        state = (
                            21 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.9689815) else 22
                        )
                        if state == 21:
                            return 0.0257741325
                        if state == 22:
                            return -0.0659723654
                    if state == 14:
                        return 0.0435276367
    elif num_booster == 32:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < -0.128979683) else 2
            if state == 1:
                state = 3 if x["sgscore1_med"] < 0.0502291508 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.188343)
                        else 8
                    )
                    if state == 7:
                        return 0.0689270273
                    if state == 8:
                        return -0.015792802
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 29.3721104)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["col_det"]) or (x["col_det"] < -0.235022545)
                            else 20
                        )
                        if state == 19:
                            state = 31 if x["sgscore1_med"] < 0.199092001 else 32
                            if state == 31:
                                return -0.00311149773
                            if state == 32:
                                return -0.0608173944
                        if state == 20:
                            return 0.016231617
                    if state == 10:
                        state = 21 if x["neargaia_med"] < 54.6856689 else 22
                        if state == 21:
                            return 0.0582993776
                        if state == 22:
                            return -0.00907900836
            if state == 2:
                state = (
                    5
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 37.7223015)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.00208333135)
                        else 12
                    )
                    if state == 11:
                        return 0.0106165018
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 1.65974498)
                            else 26
                        )
                        if state == 25:
                            state = (
                                33
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.08669972)
                                else 34
                            )
                            if state == 33:
                                return -0.0423604064
                            if state == 34:
                                return 0.0100176344
                        if state == 26:
                            return -0.0865957439
                if state == 6:
                    state = 13 if x["sgscore1_med"] < 0.280372024 else 14
                    if state == 13:
                        state = 27 if x["sgscore1_med"] < 0.0218333155 else 28
                        if state == 27:
                            return -0.00979452021
                        if state == 28:
                            return 0.0351053551
                    if state == 14:
                        return -0.0221326966
    elif num_booster == 33:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.664720297) else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["col_det"]) or (x["col_det"] < 0.638313293) else 4
                )
                if state == 3:
                    return -0.0700182542
                if state == 4:
                    return 0.0023168996
            if state == 2:
                state = 5 if x["col_det"] < 0.194000244 else 6
                if state == 5:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 18.6779251)
                        else 8
                    )
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.618071496)
                            else 12
                        )
                        if state == 11:
                            state = 19 if x["col_det"] < 0.0699329376 else 20
                            if state == 19:
                                return 0.0562803671
                            if state == 20:
                                return -0.0226747934
                        if state == 12:
                            return -0.0321138948
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 2.34409142)
                            else 14
                        )
                        if state == 13:
                            state = (
                                21
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.81069541)
                                else 22
                            )
                            if state == 21:
                                return -0.0371900536
                            if state == 22:
                                return 0.0139945541
                        if state == 14:
                            state = (
                                23
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.93175)
                                else 24
                            )
                            if state == 23:
                                return 0.00397946686
                            if state == 24:
                                return -0.0902163684
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 17.1026344)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 1.57487869)
                            else 16
                        )
                        if state == 15:
                            state = 25 if x["sgscore1_med"] < 0.0171874855 else 26
                            if state == 25:
                                return 0.0258792266
                            if state == 26:
                                return -0.074560903
                        if state == 16:
                            state = 27 if x["col_det"] < 0.324761391 else 28
                            if state == 27:
                                return -0.0293203164
                            if state == 28:
                                return 0.0429996178
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 4.35700893)
                            else 18
                        )
                        if state == 17:
                            return 0.0638660789
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 5.62652969)
                                else 30
                            )
                            if state == 29:
                                return -0.0193530787
                            if state == 30:
                                return 0.0241871122
    elif num_booster == 34:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.775749981)
                else 2
            )
            if state == 1:
                return -0.0699469224
            if state == 2:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.2672997) else 4
                )
                if state == 3:
                    state = 5 if x["neargaia_med"] < 37.5809135 else 6
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.98570609)
                            else 10
                        )
                        if state == 9:
                            return -0.0783319622
                        if state == 10:
                            state = (
                                17
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.6970501)
                                else 18
                            )
                            if state == 17:
                                return -0.0190839805
                            if state == 18:
                                return 0.0208606906
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.956499994)
                            else 12
                        )
                        if state == 11:
                            return -0.0308941063
                        if state == 12:
                            return 0.0465365537
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.97260427)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.594178498)
                            else 14
                        )
                        if state == 13:
                            state = 19 if x["sgscore1_med"] < 0.00889583491 else 20
                            if state == 19:
                                return 0.00404808251
                            if state == 20:
                                return 0.0781648979
                        if state == 14:
                            return -0.0180949047
                    if state == 8:
                        state = 15 if x["sgscore1_med"] < 0.0987591445 else 16
                        if state == 15:
                            return 0.0377094373
                        if state == 16:
                            return -0.0416422412
    elif num_booster == 35:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 0.527322352 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 42.4055023)
                    else 4
                )
                if state == 3:
                    state = 7 if x["neargaia_med"] < 0.215192646 else 8
                    if state == 7:
                        return 0.00885210279
                    if state == 8:
                        return -0.0696675256
                if state == 4:
                    return 0.0259416867
            if state == 2:
                state = (
                    5 if np.isnan(x["col_det"]) or (x["col_det"] < -0.133877754) else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.662871957)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.6080513)
                            else 16
                        )
                        if state == 15:
                            state = 23 if x["sgscore1_med"] < 0.00300000003 else 24
                            if state == 23:
                                return -0.00364630576
                            if state == 24:
                                return 0.0839892775
                        if state == 16:
                            return -0.0211037006
                    if state == 10:
                        return -0.0349454917
                if state == 6:
                    state = 11 if x["col_det"] < 0.00978469849 else 12
                    if state == 11:
                        state = 19 if x["neargaia_med"] < 11.8189907 else 20
                        if state == 19:
                            return 0.00160771888
                        if state == 20:
                            return -0.0655332804
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.7939491)
                            else 22
                        )
                        if state == 21:
                            return -0.0463017896
                        if state == 22:
                            state = (
                                27
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0205832999)
                                else 28
                            )
                            if state == 27:
                                return -0.0158326849
                            if state == 28:
                                return 0.0678629577
    elif num_booster == 36:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 2.06142569 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.912999988)
                    else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.876071393) else 8
                    )
                    if state == 7:
                        return -0.060389813
                    if state == 8:
                        return 0.00223637535
                if state == 4:
                    state = 9 if x["distpsnr1_med"] < 0.160719007 else 10
                    if state == 9:
                        state = (
                            13
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.8922501)
                            else 14
                        )
                        if state == 13:
                            return 0.0245225225
                        if state == 14:
                            return -0.0707001165
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 15.3315001)
                            else 16
                        )
                        if state == 15:
                            return -0.024349751
                        if state == 16:
                            state = 19 if x["distpsnr1_med"] < 1.49658179 else 20
                            if state == 19:
                                return 0.0661981404
                            if state == 20:
                                return 0.00406999746
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.760500014)
                    else 6
                )
                if state == 5:
                    return -0.0471840948
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 15.6583652)
                        else 12
                    )
                    if state == 11:
                        return 0.0771265849
                    if state == 12:
                        return -0.00756739965
    elif num_booster == 37:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.897249997)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["col_det"]) or (x["col_det"] < 0.0924901962) else 4
                )
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.01501179) else 8
                    if state == 7:
                        return -0.0682616383
                    if state == 8:
                        return -0.00296573085
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.698571503)
                        else 10
                    )
                    if state == 9:
                        return -0.0313043483
                    if state == 10:
                        return 0.0369549207
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.6685009) else 6
                )
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.90786457) else 12
                    )
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.920000017)
                            else 18
                        )
                        if state == 17:
                            state = (
                                21
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.689166546)
                                else 22
                            )
                            if state == 21:
                                return -0.0088202972
                            if state == 22:
                                return -0.0598284565
                        if state == 18:
                            return 0.0341702402
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.9264259)
                            else 20
                        )
                        if state == 19:
                            return -0.00732823974
                        if state == 20:
                            return 0.048478879
                if state == 6:
                    return 0.0659166649
    elif num_booster == 38:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 0.540593863 else 2
            if state == 1:
                state = 3 if x["neargaia_med"] < 0.225907996 else 4
                if state == 3:
                    return 0.0244837236
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 26.1113663)
                        else 8
                    )
                    if state == 7:
                        return -0.0760282949
                    if state == 8:
                        return 0.00890156813
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 3.29315615)
                    else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.74995375)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 0.955478907)
                            else 16
                        )
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.673115611)
                                else 24
                            )
                            if state == 23:
                                return -0.0261575077
                            if state == 24:
                                return 0.056636598
                        if state == 16:
                            state = 25 if x["neargaia_med"] < 35.8311882 else 26
                            if state == 25:
                                return -0.055802349
                            if state == 26:
                                return 0.013440487
                    if state == 10:
                        state = 17 if x["neargaia_med"] < 10.1527023 else 18
                        if state == 17:
                            state = 27 if x["distpsnr1_med"] < 2.72651196 else 28
                            if state == 27:
                                return 0.0220548157
                            if state == 28:
                                return -0.0285739508
                        if state == 18:
                            return 0.0610486828
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.00546288)
                        else 12
                    )
                    if state == 11:
                        state = 19 if x["neargaia_med"] < 40.2368164 else 20
                        if state == 19:
                            return -0.0626654923
                        if state == 20:
                            return 0.0134659559
                    if state == 12:
                        return 0.0262974929
    elif num_booster == 39:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5176125) else 2
            if state == 1:
                state = 3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.8146) else 4
                if state == 3:
                    state = 7 if x["distpsnr1_med"] < 7.62608957 else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.9799995)
                            else 14
                        )
                        if state == 13:
                            state = 21 if x["distpsnr1_med"] < 1.37964988 else 22
                            if state == 21:
                                return -0.0322928429
                            if state == 22:
                                return 0.0272341594
                        if state == 14:
                            return -0.0622173548
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.809)
                            else 16
                        )
                        if state == 15:
                            return 0.0270623099
                        if state == 16:
                            return -0.023572024
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.6350002)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["distpsnr1_med"] < 0.25751704 else 18
                        if state == 17:
                            state = (
                                23
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7693996)
                                else 24
                            )
                            if state == 23:
                                return 0.0219627488
                            if state == 24:
                                return -0.0198962986
                        if state == 18:
                            return 0.0809819847
                    if state == 10:
                        state = 19 if x["distpsnr1_med"] < 11.2860069 else 20
                        if state == 19:
                            return -0.0425204858
                        if state == 20:
                            return 0.0300342403
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 5.95431328)
                    else 6
                )
                if state == 5:
                    return -0.0949078798
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7462425)
                        else 12
                    )
                    if state == 11:
                        return 0.0384595543
                    if state == 12:
                        return -0.0304905735
    elif num_booster == 40:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 3.13579035) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.790250003)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 18.6732712)
                        else 8
                    )
                    if state == 7:
                        return -0.0621187165
                    if state == 8:
                        state = 13 if x["maggaia_med"] < 19.371273 else 14
                        if state == 13:
                            return 0.0393751077
                        if state == 14:
                            return -0.0314789452
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.595927)
                        else 10
                    )
                    if state == 9:
                        state = 15 if x["maggaia_med"] < 17.3711052 else 16
                        if state == 15:
                            state = 21 if x["neargaia_med"] < 31.6950607 else 22
                            if state == 21:
                                return -0.0301651154
                            if state == 22:
                                return 0.015308572
                        if state == 16:
                            state = (
                                23
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.16763306)
                                else 24
                            )
                            if state == 23:
                                return 0.060398072
                            if state == 24:
                                return -0.0135039575
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 12.8971672)
                            else 18
                        )
                        if state == 17:
                            return -0.05065028
                        if state == 18:
                            state = (
                                25
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.637426376)
                                else 26
                            )
                            if state == 25:
                                return -0.0177781451
                            if state == 26:
                                return 0.0223978274
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.0409583524 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.957249999)
                        else 12
                    )
                    if state == 11:
                        return -0.0235258806
                    if state == 12:
                        return 0.0250441898
                if state == 6:
                    return -0.0827554315
    elif num_booster == 41:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.790250003)
                else 2
            )
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.04123259) else 4
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.04048038) else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 25.1105022)
                            else 14
                        )
                        if state == 13:
                            return -0.0393639356
                        if state == 14:
                            return 0.0082928529
                    if state == 8:
                        return 0.0264276899
                if state == 4:
                    return -0.0565315187
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.6467476)
                    else 6
                )
                if state == 5:
                    state = 9 if x["neargaia_med"] < 6.9923172 else 10
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.97724998)
                            else 16
                        )
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.3752518)
                                else 24
                            )
                            if state == 23:
                                return 0.00654723728
                            if state == 24:
                                return -0.04667034
                        if state == 16:
                            return 0.029095985
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.635414481)
                            else 18
                        )
                        if state == 17:
                            state = 27 if x["neargaia_med"] < 25.6365089 else 28
                            if state == 27:
                                return -0.0238659084
                            if state == 28:
                                return 0.0287154652
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 27.4741096)
                                else 30
                            )
                            if state == 29:
                                return 0.0670225248
                            if state == 30:
                                return 0.0128718251
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 10.2602558)
                        else 12
                    )
                    if state == 11:
                        return 0.0235708468
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 2.3325541)
                            else 22
                        )
                        if state == 21:
                            return -0.050210841
                        if state == 22:
                            return 0.00485702511
    elif num_booster == 42:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5919151) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.3045006)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.3214989)
                        else 8
                    )
                    if state == 7:
                        return -0.0423922241
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.981250048)
                            else 14
                        )
                        if state == 13:
                            return 0.0733400211
                        if state == 14:
                            state = (
                                17
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.7757492)
                                else 18
                            )
                            if state == 17:
                                return 0.0456722528
                            if state == 18:
                                return -0.0230951216
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.00193286)
                        else 10
                    )
                    if state == 9:
                        return -0.0506249033
                    if state == 10:
                        return 0.0179115534
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.00994778) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.760500014)
                        else 12
                    )
                    if state == 11:
                        return -0.0223615952
                    if state == 12:
                        return 0.0400605239
                if state == 6:
                    return -0.0750272945
    elif num_booster == 43:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6509857) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.554510474)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.2046623)
                        else 8
                    )
                    if state == 7:
                        state = 9 if x["sgscore1_med"] < 0.380916476 else 10
                        if state == 9:
                            state = (
                                13
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.08743644)
                                else 14
                            )
                            if state == 13:
                                return -0.0429023691
                            if state == 14:
                                return 0.0171389766
                        if state == 10:
                            return 0.0376547016
                    if state == 8:
                        state = (
                            11
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.769249976)
                            else 12
                        )
                        if state == 11:
                            return -0.00208379468
                        if state == 12:
                            return 0.0710624978
                if state == 4:
                    return -0.0638230965
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.619455993) else 6
                if state == 5:
                    return 0.0265852436
                if state == 6:
                    return -0.070366554
    elif num_booster == 44:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6089268) else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.47495961) else 4
                if state == 3:
                    return -0.0409100913
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.669193029)
                        else 10
                    )
                    if state == 9:
                        state = 11 if x["neargaia_med"] < 1.39869297 else 12
                        if state == 11:
                            state = 15 if x["maggaia_med"] < 17.3315735 else 16
                            if state == 15:
                                return -0.0229316205
                            if state == 16:
                                return 0.0390194654
                        if state == 12:
                            return 0.066413112
                    if state == 10:
                        state = (
                            13
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.08267355)
                            else 14
                        )
                        if state == 13:
                            return 0.00957628805
                        if state == 14:
                            return -0.0490304716
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 0.581747711) else 6
                if state == 5:
                    return -0.00327916467
                if state == 6:
                    return -0.0752557591
    elif num_booster == 45:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.8400002) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.5022507)
                    else 4
                )
                if state == 3:
                    state = 7 if x["distpsnr1_med"] < 3.04839945 else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.306591988)
                            else 16
                        )
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.97449064)
                                else 28
                            )
                            if state == 27:
                                return -0.0510149039
                            if state == 28:
                                return 0.00906604063
                        if state == 16:
                            return 0.00603237841
                    if state == 8:
                        return 0.0352331065
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 5.19899559)
                        else 10
                    )
                    if state == 9:
                        return 0.0582998991
                    if state == 10:
                        return -0.0151657481
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 6.66882801)
                    else 6
                )
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.98511004) else 12
                    )
                    if state == 11:
                        return 0.0087366458
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.97697926)
                            else 22
                        )
                        if state == 21:
                            return -0.0605759732
                        if state == 22:
                            state = (
                                33
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.01729727)
                                else 34
                            )
                            if state == 33:
                                return 0.0168395117
                            if state == 34:
                                return -0.0312132109
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.0812492)
                        else 14
                    )
                    if state == 13:
                        return 0.0351128653
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.9344997)
                            else 26
                        )
                        if state == 25:
                            return -0.0400535055
                        if state == 26:
                            return 0.0231890921
    elif num_booster == 46:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.796547651) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.3610001)
                    else 4
                )
                if state == 3:
                    return -0.037955299
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.7397499)
                        else 10
                    )
                    if state == 9:
                        return 0.0586068146
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.9127502)
                            else 16
                        )
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.994751)
                                else 24
                            )
                            if state == 23:
                                return 0.00719609903
                            if state == 24:
                                return -0.0392977819
                        if state == 16:
                            return 0.0370436907
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.948214173) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.2457504)
                        else 12
                    )
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.52243638)
                            else 18
                        )
                        if state == 17:
                            return 0.00293032709
                        if state == 18:
                            return -0.0879879147
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.97844911)
                            else 20
                        )
                        if state == 19:
                            return -0.0211279336
                        if state == 20:
                            return 0.0376026779
                if state == 6:
                    return 0.0327331796
    elif num_booster == 47:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.1499996) else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.97335625) else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["col_det"]) or (x["col_det"] < 0.420744896)
                        else 8
                    )
                    if state == 7:
                        return -0.0748393163
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.13845491)
                            else 16
                        )
                        if state == 15:
                            return -0.0236490034
                        if state == 16:
                            return 0.0190639254
                if state == 4:
                    return 0.0378148928
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8746986) else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 9.16888237)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["col_det"] < -0.25304985 else 18
                        if state == 17:
                            return -0.00446737325
                        if state == 18:
                            return 0.0538971871
                    if state == 10:
                        return -0.0379867293
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.97225)
                        else 12
                    )
                    if state == 11:
                        return -0.0808294863
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.377364159)
                            else 20
                        )
                        if state == 19:
                            state = (
                                23
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < -0.182621002)
                                else 24
                            )
                            if state == 23:
                                return 0.0152726686
                            if state == 24:
                                return -0.0330135897
                        if state == 20:
                            return 0.039411664
    elif num_booster == 48:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.100562349)
                else 2
            )
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.494642973) else 4
                if state == 3:
                    return -0.0404116102
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.685500026)
                        else 10
                    )
                    if state == 9:
                        return -0.0180605892
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.911071539)
                            else 16
                        )
                        if state == 15:
                            state = (
                                21
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.0616377518)
                                else 22
                            )
                            if state == 21:
                                return 0.00566547457
                            if state == 22:
                                return 0.0605601072
                        if state == 16:
                            state = (
                                23
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.970999956)
                                else 24
                            )
                            if state == 23:
                                return -0.028588213
                            if state == 24:
                                return 0.0299015939
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.53171825)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.758333206)
                        else 12
                    )
                    if state == 11:
                        return -0.0700303838
                    if state == 12:
                        return 0.00119062478
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 4.19795036)
                        else 14
                    )
                    if state == 13:
                        state = 19 if x["sgscore1_med"] < 0.172418743 else 20
                        if state == 19:
                            return -0.00407722173
                        if state == 20:
                            return 0.0569004864
                    if state == 14:
                        return -0.0538584217
    elif num_booster == 49:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5742683) else 2
            if state == 1:
                state = 3 if x["maggaia_med"] < 17.3315735 else 4
                if state == 3:
                    state = 7 if x["distpsnr1_med"] < 1.41102707 else 8
                    if state == 7:
                        return -0.0555162691
                    if state == 8:
                        return 0.0133905457
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 4.73937988)
                        else 10
                    )
                    if state == 9:
                        state = 13 if x["distpsnr1_med"] < 0.0906085819 else 14
                        if state == 13:
                            return -0.0265223347
                        if state == 14:
                            return 0.0623719096
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 18.7727661)
                            else 16
                        )
                        if state == 15:
                            state = (
                                19
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.421524)
                                else 20
                            )
                            if state == 19:
                                return 0.0491062477
                            if state == 20:
                                return -0.0196667947
                        if state == 16:
                            state = (
                                21
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.92534733)
                                else 22
                            )
                            if state == 21:
                                return 0.00774162216
                            if state == 22:
                                return -0.0493827425
            if state == 2:
                state = (
                    5
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 1.39267933)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["t_predetect"])
                        or (x["t_predetect"] < 0.564681709)
                        else 12
                    )
                    if state == 11:
                        return -0.0295959767
                    if state == 12:
                        return 0.0368112661
                if state == 6:
                    return -0.0742325708
    elif num_booster == 50:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.46034801)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 15.8921165)
                    else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.817500234) else 8
                    )
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4304619)
                            else 12
                        )
                        if state == 11:
                            return -0.0649907961
                        if state == 12:
                            state = (
                                17
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.6469994)
                                else 18
                            )
                            if state == 17:
                                return 0.0220807288
                            if state == 18:
                                return -0.0192092992
                    if state == 8:
                        return 0.00921222661
                if state == 4:
                    state = 9 if x["sgscore1_med"] < 0.00438690465 else 10
                    if state == 9:
                        return -0.0266205035
                    if state == 10:
                        state = 15 if x["distpsnr1_med"] < 0.25751704 else 16
                        if state == 15:
                            state = 19 if x["maggaia_med"] < 18.8798599 else 20
                            if state == 19:
                                return 0.0146119809
                            if state == 20:
                                return -0.0330800861
                        if state == 16:
                            state = (
                                21
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.127726495)
                                else 22
                            )
                            if state == 21:
                                return 0.0588289201
                            if state == 22:
                                return 0.00550588407
            if state == 2:
                state = 5 if x["maggaia_med"] < 20.1981621 else 6
                if state == 5:
                    return -0.0799997523
                if state == 6:
                    return 0.0343746319
    elif num_booster == 51:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < 0.176815987) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 4.92926741)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 2.53812885)
                        else 8
                    )
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.8427505)
                            else 12
                        )
                        if state == 11:
                            state = (
                                19
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 16.0830002)
                                else 20
                            )
                            if state == 19:
                                return -0.0186947007
                            if state == 20:
                                return 0.0399557725
                        if state == 12:
                            state = (
                                21
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.582618892)
                                else 22
                            )
                            if state == 21:
                                return 0.0173313189
                            if state == 22:
                                return -0.0350134782
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.690952301)
                            else 14
                        )
                        if state == 13:
                            return 0.0102355154
                        if state == 14:
                            return -0.0720167533
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.0812492)
                        else 10
                    )
                    if state == 9:
                        return 0.0583267473
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.9127502)
                            else 18
                        )
                        if state == 17:
                            return -0.0325834379
                        if state == 18:
                            return 0.0355287902
            if state == 2:
                return -0.056965135
    elif num_booster == 52:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.976750016)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.0273784511)
                    else 4
                )
                if state == 3:
                    return 0.0415727161
                if state == 4:
                    state = 7 if x["col_det"] < -0.0398607254 else 8
                    if state == 7:
                        state = 11 if x["col_det"] < -0.263000011 else 12
                        if state == 11:
                            return -0.021254573
                        if state == 12:
                            return 0.0276648141
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.7317009)
                            else 14
                        )
                        if state == 13:
                            state = (
                                19
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.99115181)
                                else 20
                            )
                            if state == 19:
                                return -0.00349018537
                            if state == 20:
                                return -0.0689613596
                        if state == 14:
                            state = (
                                21
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.728250027)
                                else 22
                            )
                            if state == 21:
                                return -0.0212386101
                            if state == 22:
                                return 0.0279189851
            if state == 2:
                state = (
                    5
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.06264472)
                    else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.1286011)
                        else 10
                    )
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["col_det"]) or (x["col_det"] < -0.295884609)
                            else 16
                        )
                        if state == 15:
                            return -0.02527426
                        if state == 16:
                            return 0.0253995061
                    if state == 10:
                        return 0.059273798
                if state == 6:
                    return -0.0470099673
    elif num_booster == 53:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.740799) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.31632948)
                    else 4
                )
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 1.45814812)
                        else 6
                    )
                    if state == 5:
                        return -0.0568618029
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.1323738)
                            else 12
                        )
                        if state == 11:
                            return -0.0190139953
                        if state == 12:
                            state = (
                                17
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.877250016)
                                else 18
                            )
                            if state == 17:
                                return -0.00772535894
                            if state == 18:
                                return 0.0433758013
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.975250006)
                        else 8
                    )
                    if state == 7:
                        return 0.0748013332
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 2.57868671)
                            else 14
                        )
                        if state == 13:
                            return 0.0488936417
                        if state == 14:
                            state = (
                                19
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.985249996)
                                else 20
                            )
                            if state == 19:
                                return -0.0451778658
                            if state == 20:
                                return 0.034427397
            if state == 2:
                return -0.0663745105
    elif num_booster == 54:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.844944) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 17.8401489) else 4
                )
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.91608214)
                        else 6
                    )
                    if state == 5:
                        return 0.0150289787
                    if state == 6:
                        return -0.0429055877
                if state == 4:
                    state = 7 if x["maggaia_med"] < 15.8921165 else 8
                    if state == 7:
                        state = (
                            9
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1364937)
                            else 10
                        )
                        if state == 9:
                            return -0.0510486029
                        if state == 10:
                            return 0.0317514762
                    if state == 8:
                        state = (
                            11
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 3.1063714)
                            else 12
                        )
                        if state == 11:
                            state = (
                                13
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < 0.579547882)
                                else 14
                            )
                            if state == 13:
                                return 0.0576655231
                            if state == 14:
                                return -0.0132167321
                        if state == 12:
                            return -0.0257183425
            if state == 2:
                return -0.060561154
    elif num_booster == 55:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.7136904) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0788002) else 4
                )
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.94351864) else 8
                    if state == 7:
                        return -0.0685531721
                    if state == 8:
                        return 0.0145126432
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1028996)
                        else 10
                    )
                    if state == 9:
                        state = (
                            13
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.5755081)
                            else 14
                        )
                        if state == 13:
                            state = (
                                21
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.20868397)
                                else 22
                            )
                            if state == 21:
                                return 0.0244450513
                            if state == 22:
                                return -0.026424069
                        if state == 14:
                            return 0.0416613631
                    if state == 10:
                        state = 15 if x["neargaia_med"] < 9.3370533 else 16
                        if state == 15:
                            return 0.0316833258
                        if state == 16:
                            state = 25 if x["neargaia_med"] < 59.0798683 else 26
                            if state == 25:
                                return -0.0392087325
                            if state == 26:
                                return 0.00240196893
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.00751162) else 6
                if state == 5:
                    return 0.0658626705
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9729004)
                        else 12
                    )
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.03065395)
                            else 18
                        )
                        if state == 17:
                            return -0.00714772567
                        if state == 18:
                            return 0.0455519147
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5001488)
                            else 20
                        )
                        if state == 19:
                            return -0.0415340327
                        if state == 20:
                            return 0.020614326
    elif num_booster == 56:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 2.06142569 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 54.5914001)
                    else 4
                )
                if state == 3:
                    state = 7 if x["neargaia_med"] < 0.197839886 else 8
                    if state == 7:
                        return 0.00283292891
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 20.2148666)
                            else 14
                        )
                        if state == 13:
                            return -0.0730554089
                        if state == 14:
                            return -0.00100100832
                if state == 4:
                    return 0.00843847357
            if state == 2:
                state = 5 if x["maggaia_med"] < 19.4438782 else 6
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0774994)
                        else 10
                    )
                    if state == 9:
                        state = 15 if x["col_det"] < -0.247120857 else 16
                        if state == 15:
                            return 0.022556508
                        if state == 16:
                            return -0.0308950171
                    if state == 10:
                        state = 17 if x["neargaia_med"] < 47.0292664 else 18
                        if state == 17:
                            return 0.0611385629
                        if state == 18:
                            return -0.0162732545
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 2.35421658)
                        else 12
                    )
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1516628)
                            else 20
                        )
                        if state == 19:
                            return 0.0281363409
                        if state == 20:
                            return -0.0198017657
                    if state == 12:
                        state = 21 if x["distpsnr1_med"] < 7.77214432 else 22
                        if state == 21:
                            return -0.0617874712
                        if state == 22:
                            return 0.00531804841
    elif num_booster == 57:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 0.25751704 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.594496489)
                    else 4
                )
                if state == 3:
                    return 0.00456483755
                if state == 4:
                    return -0.049669452
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.692250013)
                    else 6
                )
                if state == 5:
                    return -0.0375162996
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.955776989)
                        else 10
                    )
                    if state == 9:
                        state = (
                            11
                            if np.isnan(x["col_det"]) or (x["col_det"] < -0.125032425)
                            else 12
                        )
                        if state == 11:
                            return 0.0632562935
                        if state == 12:
                            state = 15 if x["sgscore1_med"] < 0.00931250025 else 16
                            if state == 15:
                                return -0.0387210064
                            if state == 16:
                                return 0.0320177674
                    if state == 10:
                        return -0.0370180868
    elif num_booster == 58:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 19.2434654 else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.915357232) else 4
                if state == 3:
                    state = 7 if x["neargaia_med"] < 38.4298553 else 8
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.7401619)
                            else 12
                        )
                        if state == 11:
                            state = 17 if x["neargaia_med"] < 16.4778595 else 18
                            if state == 17:
                                return -0.0242505912
                            if state == 18:
                                return 0.0262446273
                        if state == 12:
                            state = 19 if x["maggaia_med"] < 15.3532276 else 20
                            if state == 19:
                                return 0.00612633629
                            if state == 20:
                                return -0.080353789
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8496437)
                            else 14
                        )
                        if state == 13:
                            return 0.0266011395
                        if state == 14:
                            return -0.0176050812
                if state == 4:
                    return 0.0427116081
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7425117) else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 4.73731518)
                        else 10
                    )
                    if state == 9:
                        return 0.06864281
                    if state == 10:
                        return -0.0191599205
                if state == 6:
                    return -0.0321913362
    elif num_booster == 59:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.99584484) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 0.202489927)
                    else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.455833256) else 8
                    )
                    if state == 7:
                        return -0.025985539
                    if state == 8:
                        return 0.0433278009
                if state == 4:
                    state = 9 if x["neargaia_med"] < 35.9335899 else 10
                    if state == 9:
                        state = (
                            13
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.434523523)
                            else 14
                        )
                        if state == 13:
                            return 0.00950899627
                        if state == 14:
                            return -0.0456118807
                    if state == 10:
                        return 0.0119546875
            if state == 2:
                state = 5 if x["neargaia_med"] < 54.5220413 else 6
                if state == 5:
                    return 0.0462094955
                if state == 6:
                    return -0.00312706223
    elif num_booster == 60:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.740799) else 2
            if state == 1:
                state = 3 if x["maggaia_med"] < 17.7785263 else 4
                if state == 3:
                    state = (
                        5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.738333344) else 6
                    )
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1609058)
                            else 10
                        )
                        if state == 9:
                            state = (
                                17
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.50000006)
                                else 18
                            )
                            if state == 17:
                                return 0.00175488449
                            if state == 18:
                                return -0.0817850381
                        if state == 10:
                            return 0.0270333905
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.3912888)
                            else 12
                        )
                        if state == 11:
                            return 0.0422123894
                        if state == 12:
                            return -0.0405251011
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 2.909832)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.221755996)
                            else 14
                        )
                        if state == 13:
                            return -0.0140305953
                        if state == 14:
                            state = (
                                19
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.04255199)
                                else 20
                            )
                            if state == 19:
                                return 0.0613176525
                            if state == 20:
                                return -0.00842323899
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 19.2518845)
                            else 16
                        )
                        if state == 15:
                            return 0.0388776585
                        if state == 16:
                            return -0.038804844
            if state == 2:
                return -0.0568186902
    elif num_booster == 61:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.0366249979 else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["col_det"]) or (x["col_det"] < -0.0502796173) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5493011)
                        else 8
                    )
                    if state == 7:
                        return 0.0551626682
                    if state == 8:
                        return -0.000790613296
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.7712498)
                        else 10
                    )
                    if state == 9:
                        return 0.0203824937
                    if state == 10:
                        return -0.0219492503
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 4.24282312)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.53171825)
                        else 12
                    )
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.2629013)
                            else 18
                        )
                        if state == 17:
                            return -0.0503665581
                        if state == 18:
                            state = (
                                25
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.743149042)
                                else 26
                            )
                            if state == 25:
                                return -0.0343738794
                            if state == 26:
                                return 0.029642975
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.0747604)
                            else 20
                        )
                        if state == 19:
                            state = (
                                27
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 3.3190968)
                                else 28
                            )
                            if state == 27:
                                return 0.0500673503
                            if state == 28:
                                return -0.000633295043
                        if state == 20:
                            state = (
                                29
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3405628)
                                else 30
                            )
                            if state == 29:
                                return -0.0297593772
                            if state == 30:
                                return 0.0143548911
                if state == 6:
                    state = 13 if x["sgscore1_med"] < 0.804780006 else 14
                    if state == 13:
                        return -0.0968422666
                    if state == 14:
                        state = (
                            21
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.90398252)
                            else 22
                        )
                        if state == 21:
                            return 0.0215411857
                        if state == 22:
                            return -0.0334207267
    elif num_booster == 62:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.97054982)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.91377902)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"])
                        or (x["t_predetect"] < 0.041979149)
                        else 8
                    )
                    if state == 7:
                        return 0.0290720053
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0146666504)
                            else 18
                        )
                        if state == 17:
                            state = (
                                25
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 37.1749191)
                                else 26
                            )
                            if state == 25:
                                return 0.0244758651
                            if state == 26:
                                return -0.0215939451
                        if state == 18:
                            return -0.0502760075
                if state == 4:
                    state = 9 if x["sgscore1_med"] < 0.554510474 else 10
                    if state == 9:
                        return 0.0635000542
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.93515635)
                            else 20
                        )
                        if state == 19:
                            return 0.0230873097
                        if state == 20:
                            return -0.0328381211
            if state == 2:
                state = 5 if x["maggaia_med"] < 17.4557076 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.00608333526)
                        else 12
                    )
                    if state == 11:
                        return -0.0160480924
                    if state == 12:
                        return 0.0330470949
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.7747726)
                        else 14
                    )
                    if state == 13:
                        state = (
                            21
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 1.78636336)
                            else 22
                        )
                        if state == 21:
                            state = (
                                29
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.97987843)
                                else 30
                            )
                            if state == 29:
                                return -0.0349221788
                            if state == 30:
                                return 0.0230213758
                        if state == 22:
                            return -0.0794493258
                    if state == 14:
                        return 0.00431021443
    elif num_booster == 63:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1473503) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.92793417)
                    else 4
                )
                if state == 3:
                    return -0.0669286698
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 44.0109863)
                        else 8
                    )
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.3267498)
                            else 12
                        )
                        if state == 11:
                            state = (
                                15
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 16.7002487)
                                else 16
                            )
                            if state == 15:
                                return -0.0101219593
                            if state == 16:
                                return 0.0486842915
                        if state == 12:
                            return -0.015813956
                    if state == 8:
                        return -0.0452729501
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.989062488 else 6
                if state == 5:
                    state = 9 if x["neargaia_med"] < 5.03945971 else 10
                    if state == 9:
                        return -0.00833601225
                    if state == 10:
                        return 0.0411666669
                if state == 6:
                    return -0.0334202014
    elif num_booster == 64:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 4.70649767) else 2
            )
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 1.90092158 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.970999956)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.290936053)
                            else 14
                        )
                        if state == 13:
                            return 0.00755418837
                        if state == 14:
                            state = (
                                23
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < 0.106790066)
                                else 24
                            )
                            if state == 23:
                                return -0.0596279129
                            if state == 24:
                                return 0.00856967643
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.983250022)
                            else 16
                        )
                        if state == 15:
                            return 0.0399318002
                        if state == 16:
                            return -0.0328272469
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.9877472)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["distpsnr1_med"] < 24.6093864 else 18
                        if state == 17:
                            return 0.0487451106
                        if state == 18:
                            return -0.00679808343
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.978250027)
                            else 20
                        )
                        if state == 19:
                            return -0.0260882042
                        if state == 20:
                            return 0.0211880673
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 8.01439953)
                    else 6
                )
                if state == 5:
                    return -0.0827728137
                if state == 6:
                    state = 11 if x["distpsnr1_med"] < 8.82945633 else 12
                    if state == 11:
                        return 0.0371429808
                    if state == 12:
                        return -0.0158943366
    elif num_booster == 65:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 5.23551655) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 11.4434614)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.50956106)
                        else 8
                    )
                    if state == 7:
                        state = 11 if x["neargaia_med"] < 0.215192646 else 12
                        if state == 11:
                            return 0.0122204851
                        if state == 12:
                            return -0.0405426435
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 2.51801729)
                            else 14
                        )
                        if state == 13:
                            return 0.044595588
                        if state == 14:
                            state = (
                                21
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.01616335)
                                else 22
                            )
                            if state == 21:
                                return -0.037790969
                            if state == 22:
                                return 0.0207093209
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5493011)
                        else 10
                    )
                    if state == 9:
                        return 0.0468488447
                    if state == 10:
                        return -0.0137256281
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.58917236) else 6
                if state == 5:
                    return -0.0645145625
                if state == 6:
                    return 0.00189128483
    elif num_booster == 66:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 3.03814507) else 2
            )
            if state == 1:
                state = 3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.97225) else 4
                if state == 3:
                    state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.96255779) else 6
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.380298615)
                            else 10
                        )
                        if state == 9:
                            return 0.0118158059
                        if state == 10:
                            return -0.0754247904
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.761940718)
                            else 12
                        )
                        if state == 11:
                            return -0.0172645487
                        if state == 12:
                            return 0.025438739
                if state == 4:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.01093149) else 8
                    if state == 7:
                        return 0.0365965366
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.497500002)
                            else 14
                        )
                        if state == 13:
                            return 0.017022226
                        if state == 14:
                            return -0.0289052259
            if state == 2:
                return 0.0318608433
    elif num_booster == 67:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5017433) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.141321495)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 35.0104523)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.900714159)
                            else 16
                        )
                        if state == 15:
                            return 0.0635954216
                        if state == 16:
                            return -0.00478582038
                    if state == 8:
                        state = 17 if x["neargaia_med"] < 37.0518074 else 18
                        if state == 17:
                            return -0.0376530588
                        if state == 18:
                            return 0.028793484
                if state == 4:
                    state = 9 if x["neargaia_med"] < 28.5065651 else 10
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 16.2623215)
                            else 20
                        )
                        if state == 19:
                            return 0.0076726377
                        if state == 20:
                            state = 25 if x["neargaia_med"] < 6.42273617 else 26
                            if state == 25:
                                return -0.00753996475
                            if state == 26:
                                return -0.0622940846
                    if state == 10:
                        state = 21 if x["distpsnr1_med"] < 1.07735133 else 22
                        if state == 21:
                            return -0.0194774605
                        if state == 22:
                            return 0.0353763588
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 7.41306114 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 36.4083328)
                        else 12
                    )
                    if state == 11:
                        return -0.0756205618
                    if state == 12:
                        return -0.00621518958
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 9.79686928)
                        else 14
                    )
                    if state == 13:
                        return 0.027154984
                    if state == 14:
                        return -0.0236958656
    elif num_booster == 68:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.04274321) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.0947495)
                    else 4
                )
                if state == 3:
                    return 0.0222168099
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.5909996)
                        else 8
                    )
                    if state == 7:
                        state = 13 if x["col_det"] < -0.168275833 else 14
                        if state == 13:
                            return 0.00717901159
                        if state == 14:
                            return -0.0682203025
                    if state == 8:
                        return 0.0166577119
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.53171825)
                    else 6
                )
                if state == 5:
                    state = 9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.045434) else 10
                    if state == 9:
                        return 0.0245858189
                    if state == 10:
                        return -0.0382872373
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 4.79718781)
                        else 12
                    )
                    if state == 11:
                        return 0.0578855313
                    if state == 12:
                        state = (
                            17
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 3.01434612)
                            else 18
                        )
                        if state == 17:
                            return -0.0259055123
                        if state == 18:
                            return 0.0224388018
    elif num_booster == 69:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.1507244) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.976500034)
                    else 4
                )
                if state == 3:
                    return -0.0649801418
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.982749999)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 6.19732761)
                            else 14
                        )
                        if state == 13:
                            return 0.0296680126
                        if state == 14:
                            return -0.0167286582
                    if state == 8:
                        return -0.0359389856
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.949000001)
                    else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["distpsnr1_med"])
                        or (x["distpsnr1_med"] < 0.878977299)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.722061276)
                            else 18
                        )
                        if state == 17:
                            return -0.0197119806
                        if state == 18:
                            return 0.0592691489
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.7712517)
                            else 20
                        )
                        if state == 19:
                            return -0.0485975221
                        if state == 20:
                            return 0.00696480274
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 2.35124779)
                        else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 2.24931622)
                            else 22
                        )
                        if state == 21:
                            return 0.034409523
                        if state == 22:
                            return -0.0291996989
                    if state == 12:
                        return 0.0542622283
    elif num_booster == 70:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7425117) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0335999) else 4
                )
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 17.7322216)
                        else 6
                    )
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.8877487)
                            else 10
                        )
                        if state == 9:
                            state = (
                                15
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 15.7012501)
                                else 16
                            )
                            if state == 15:
                                return -0.0216350406
                            if state == 16:
                                return 0.0210214872
                        if state == 10:
                            return -0.0646778643
                    if state == 6:
                        return 0.0171103105
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.2000618)
                        else 8
                    )
                    if state == 7:
                        state = 11 if x["neargaia_med"] < 19.1574688 else 12
                        if state == 11:
                            return -0.0298123304
                        if state == 12:
                            return 0.0161186438
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6089268)
                            else 14
                        )
                        if state == 13:
                            return 0.066492185
                        if state == 14:
                            state = (
                                17
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.6618557)
                                else 18
                            )
                            if state == 17:
                                return -0.0231584907
                            if state == 18:
                                return 0.027530428
            if state == 2:
                return -0.0540103503
    elif num_booster == 71:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5176125) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.3107491) else 4
                )
                if state == 3:
                    return -0.0370348915
                if state == 4:
                    state = 7 if x["neargaia_med"] < 6.99131298 else 8
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.7776985)
                            else 12
                        )
                        if state == 11:
                            return -0.0288506169
                        if state == 12:
                            return 0.0107877143
                    if state == 8:
                        return 0.0690493062
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.5267487)
                    else 6
                )
                if state == 5:
                    return -0.0554335974
                if state == 6:
                    return 0.00691743428
    elif num_booster == 72:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.0973331481 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 29.7798843)
                    else 4
                )
                if state == 3:
                    state = 7 if x["neargaia_med"] < 0.540806413 else 8
                    if state == 7:
                        return -0.014966663
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5255508)
                            else 16
                        )
                        if state == 15:
                            return 0.0690991879
                        if state == 16:
                            return -0.00455655111
                if state == 4:
                    state = 9 if x["sgscore1_med"] < 0.00417857524 else 10
                    if state == 9:
                        return 0.0234204382
                    if state == 10:
                        return -0.0447244048
            if state == 2:
                state = (
                    5
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 18.309433)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7398987)
                        else 12
                    )
                    if state == 11:
                        state = 17 if x["neargaia_med"] < 4.51670456 else 18
                        if state == 17:
                            return 0.00489531038
                        if state == 18:
                            return -0.0697232038
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9973507)
                            else 20
                        )
                        if state == 19:
                            return 0.0204801466
                        if state == 20:
                            state = 25 if x["sgscore1_med"] < 0.180335 else 26
                            if state == 25:
                                return 0.0150115965
                            if state == 26:
                                return -0.0321684442
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 1.11543989)
                        else 14
                    )
                    if state == 13:
                        return -0.0129078198
                    if state == 14:
                        state = (
                            21
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 3.00234365)
                            else 22
                        )
                        if state == 21:
                            return 0.046476081
                        if state == 22:
                            return -0.0089249583
    elif num_booster == 73:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.554510474)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.782000005)
                    else 4
                )
                if state == 3:
                    return -0.0365412608
                if state == 4:
                    state = 7 if x["maggaia_med"] < 15.6930904 else 8
                    if state == 7:
                        return -0.0162043106
                    if state == 8:
                        state = (
                            11
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.453928322)
                            else 12
                        )
                        if state == 11:
                            state = (
                                13
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.417856991)
                                else 14
                            )
                            if state == 13:
                                return 0.0167944413
                            if state == 14:
                                return -0.028096227
                        if state == 12:
                            state = (
                                15
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.04528904)
                                else 16
                            )
                            if state == 15:
                                return 0.0560991168
                            if state == 16:
                                return -0.00468291435
            if state == 2:
                state = 5 if x["maggaia_med"] < 18.1494026 else 6
                if state == 5:
                    return 0.0114530027
                if state == 6:
                    return -0.0447941348
    elif num_booster == 74:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 27.0345192)
                else 2
            )
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 0.540593863 else 4
                if state == 3:
                    return -0.051251512
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.790250003)
                        else 8
                    )
                    if state == 7:
                        return -0.0377819575
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.983749986)
                            else 14
                        )
                        if state == 13:
                            state = (
                                17
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.564535499)
                                else 18
                            )
                            if state == 17:
                                return 0.058775004
                            if state == 18:
                                return -0.00560765248
                        if state == 14:
                            state = (
                                19
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 10.8004208)
                                else 20
                            )
                            if state == 19:
                                return 0.014253133
                            if state == 20:
                                return -0.0396804214
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.866317749 else 6
                if state == 5:
                    state = 9 if x["sgscore1_med"] < 0.00481249997 else 10
                    if state == 9:
                        return 0.0301866662
                    if state == 10:
                        return -0.0168793984
                if state == 6:
                    return -0.0765615404
    elif num_booster == 75:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.381388485)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.9019699) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 1.43571091)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.4592495)
                            else 14
                        )
                        if state == 13:
                            return -0.0309650507
                        if state == 14:
                            return 0.0225393884
                    if state == 8:
                        return 0.0653982833
                if state == 4:
                    state = 9 if x["col_det"] < -0.224200726 else 10
                    if state == 9:
                        return 0.0181564167
                    if state == 10:
                        return -0.045722995
            if state == 2:
                state = 5 if x["neargaia_med"] < 14.0211868 else 6
                if state == 5:
                    return -0.0736175627
                if state == 6:
                    state = 11 if x["col_det"] < 0.377419472 else 12
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.5979996)
                            else 18
                        )
                        if state == 17:
                            return -0.0456521064
                        if state == 18:
                            return 0.0145670706
                    if state == 12:
                        return 0.0409367159
    elif num_booster == 76:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.07957172) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.2107716) else 4
                )
                if state == 3:
                    return -0.0199154355
                if state == 4:
                    return 0.054164052
            if state == 2:
                state = (
                    5
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.9865222)
                    else 6
                )
                if state == 5:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.95852447)
                        else 8
                    )
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 35.4490509)
                            else 12
                        )
                        if state == 11:
                            state = (
                                17
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.976999998)
                                else 18
                            )
                            if state == 17:
                                return -0.0541887432
                            if state == 18:
                                return 0.00346618076
                        if state == 12:
                            state = (
                                19
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 4.52956009)
                                else 20
                            )
                            if state == 19:
                                return 0.0277832318
                            if state == 20:
                                return -0.0100178896
                    if state == 8:
                        return 0.030594226
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.00176525)
                        else 10
                    )
                    if state == 9:
                        return -0.0709984675
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.96891785)
                            else 16
                        )
                        if state == 15:
                            return -0.0401601195
                        if state == 16:
                            state = (
                                21
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8959007)
                                else 22
                            )
                            if state == 21:
                                return 0.0340848118
                            if state == 22:
                                return -0.0134860761
    elif num_booster == 77:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 3.02903771 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.9818916)
                    else 4
                )
                if state == 3:
                    state = 7 if x["maggaia_med"] < 19.3796501 else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.9712486)
                            else 16
                        )
                        if state == 15:
                            return -0.04358951
                        if state == 16:
                            state = (
                                21
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8257751)
                                else 22
                            )
                            if state == 21:
                                return 0.0371822268
                            if state == 22:
                                return -0.0268206447
                    if state == 8:
                        return -0.070929423
                if state == 4:
                    return 0.0125093032
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0774994) else 6
                )
                if state == 5:
                    state = 11 if x["maggaia_med"] < 19.4049454 else 12
                    if state == 11:
                        return -0.027980648
                    if state == 12:
                        return 0.0132417101
                if state == 6:
                    state = 13 if x["maggaia_med"] < 14.9078999 else 14
                    if state == 13:
                        return -0.010295623
                    if state == 14:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5398006)
                            else 20
                        )
                        if state == 19:
                            return 0.0608872846
                        if state == 20:
                            return -0.0056247185
    elif num_booster == 78:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 3.25184655) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.0223312)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"])
                        or (x["t_predetect"] < 0.138275445)
                        else 8
                    )
                    if state == 7:
                        return -0.0145916045
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.422795862)
                            else 16
                        )
                        if state == 15:
                            return -0.0065445439
                        if state == 16:
                            return 0.0474035032
                if state == 4:
                    state = 9 if x["maggaia_med"] < 19.8980904 else 10
                    if state == 9:
                        return -0.0361290462
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.9821353)
                            else 18
                        )
                        if state == 17:
                            return 0.0271079913
                        if state == 18:
                            return -0.0161740948
            if state == 2:
                return -0.0697310045
    elif num_booster == 79:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.592701) else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 4.03782415) else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 0.495296508)
                        else 8
                    )
                    if state == 7:
                        return 0.0133029157
                    if state == 8:
                        return -0.055453077
                if state == 4:
                    state = 9 if x["maggaia_med"] < 18.5034637 else 10
                    if state == 9:
                        return -0.0125568593
                    if state == 10:
                        return 0.0280332845
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.98236704) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.6723995)
                        else 12
                    )
                    if state == 11:
                        return 0.0587696955
                    if state == 12:
                        return -0.00347743277
                if state == 6:
                    return -0.0447065756
    elif num_booster == 80:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 18.8066826 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.979154229)
                    else 4
                )
                if state == 3:
                    return -0.0259104762
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 7.20519066)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0156874992)
                            else 14
                        )
                        if state == 13:
                            return -0.0033943865
                        if state == 14:
                            return 0.0514802076
                    if state == 8:
                        return -0.0172332954
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.38816488)
                    else 6
                )
                if state == 5:
                    return -0.00307244621
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.94443297)
                        else 12
                    )
                    if state == 11:
                        return 0.00050427852
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.98144102)
                            else 22
                        )
                        if state == 21:
                            return -0.0544550642
                        if state == 22:
                            state = (
                                27
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.215125054)
                                else 28
                            )
                            if state == 27:
                                return 0.0200822391
                            if state == 28:
                                return -0.0287231393
    elif num_booster == 81:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 4.63255072) else 2
            )
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 1.33154464 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["col_det"]) or (x["col_det"] < 0.0742740631)
                        else 8
                    )
                    if state == 7:
                        return -0.0559662245
                    if state == 8:
                        return 0.00390074938
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.1612892)
                        else 10
                    )
                    if state == 9:
                        state = 15 if x["distpsnr1_med"] < 23.8271675 else 16
                        if state == 15:
                            return 0.0484694988
                        if state == 16:
                            return -0.00630083121
                    if state == 10:
                        state = 17 if x["maggaia_med"] < 19.7812519 else 18
                        if state == 17:
                            return -0.0494279526
                        if state == 18:
                            return 0.0187728219
            if state == 2:
                return -0.0738718286
    elif num_booster == 82:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5265446) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.7755013) else 4
                )
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.98659706) else 8
                    if state == 7:
                        return -0.0445526391
                    if state == 8:
                        return 0.0238171946
                if state == 4:
                    return 0.073463127
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 2.98666239)
                    else 6
                )
                if state == 5:
                    return -0.0575278364
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7287388)
                        else 12
                    )
                    if state == 11:
                        return 0.0359866619
                    if state == 12:
                        return -0.028293021
    elif num_booster == 83:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.100562349)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.968500018)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.967000008)
                        else 8
                    )
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.80825001)
                            else 12
                        )
                        if state == 11:
                            state = 17 if x["sgscore1_med"] < 0.0672916993 else 18
                            if state == 17:
                                return -0.0303798672
                            if state == 18:
                                return 0.00861286838
                        if state == 12:
                            return 0.0263616238
                    if state == 8:
                        return -0.0372814946
                if state == 4:
                    return 0.0416039042
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 8.24716759 else 6
                if state == 5:
                    state = (
                        9 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.84535718) else 10
                    )
                    if state == 9:
                        return -0.0608649068
                    if state == 10:
                        return 0.00972744729
                if state == 6:
                    return 0.0279334188
    elif num_booster == 84:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.945714355) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["col_det"]) or (x["col_det"] < 0.0742740631) else 4
                )
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.9554996)
                        else 6
                    )
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.9562988)
                            else 10
                        )
                        if state == 9:
                            return 0.00796592422
                        if state == 10:
                            state = (
                                13
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 16.8424988)
                                else 14
                            )
                            if state == 13:
                                return -0.00419693021
                            if state == 14:
                                return -0.0818449706
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.8400002)
                            else 12
                        )
                        if state == 11:
                            return 0.0346556045
                        if state == 12:
                            state = (
                                15
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.6869507)
                                else 16
                            )
                            if state == 15:
                                return -0.0452062897
                            if state == 16:
                                return 0.00626806822
                if state == 4:
                    return 0.0172545612
            if state == 2:
                return 0.0266958401
    elif num_booster == 85:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.09987259) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.977899253)
                    else 4
                )
                if state == 3:
                    return 0.0253899824
                if state == 4:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.95704865) else 8
                    if state == 7:
                        return -0.0546801761
                    if state == 8:
                        state = (
                            11
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.01360512)
                            else 12
                        )
                        if state == 11:
                            return 0.0288535897
                        if state == 12:
                            state = (
                                17
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.00151634)
                                else 18
                            )
                            if state == 17:
                                return -0.0282913633
                            if state == 18:
                                return 0.0127384774
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.02367496) else 6
                if state == 5:
                    return 0.0404419713
                if state == 6:
                    return -0.00809597038
    elif num_booster == 86:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.04723978) else 2
            if state == 1:
                state = 3 if x["neargaia_med"] < 11.0867825 else 4
                if state == 3:
                    return -0.0166078135
                if state == 4:
                    return 0.0498570018
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 4.06462955) else 6
                if state == 5:
                    return -0.0502885766
                if state == 6:
                    state = 13 if x["sgscore1_med"] < 0.558104038 else 14
                    if state == 13:
                        return 0.0307011977
                    if state == 14:
                        return -0.0385392122
    elif num_booster == 87:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.96961856) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.711214542)
                    else 4
                )
                if state == 3:
                    return -0.0114893746
                if state == 4:
                    return 0.047037635
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.15697908) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 17.3014812)
                        else 12
                    )
                    if state == 11:
                        return 0.00254730973
                    if state == 12:
                        return -0.0740669072
                if state == 6:
                    return 0.0280949641
    elif num_booster == 88:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8252144) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0645504) else 4
                )
                if state == 3:
                    state = 5 if x["col_det"] < -0.13114357 else 6
                    if state == 5:
                        return 0.0230365675
                    if state == 6:
                        return -0.043046739
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6370144)
                        else 8
                    )
                    if state == 7:
                        return 0.0600405857
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.04718161)
                            else 14
                        )
                        if state == 13:
                            return 0.0233663172
                        if state == 14:
                            return -0.029607011
            if state == 2:
                return -0.0518098809
    elif num_booster == 89:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.2458496) else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.684999824) else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.3772507)
                        else 8
                    )
                    if state == 7:
                        return 0.026015928
                    if state == 8:
                        return -0.0248230398
                if state == 4:
                    return -0.0442656092
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8316002) else 6
                )
                if state == 5:
                    return 0.0387019999
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9281006)
                        else 12
                    )
                    if state == 11:
                        return -0.0396697409
                    if state == 12:
                        state = (
                            15
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0714166462)
                            else 16
                        )
                        if state == 15:
                            state = (
                                17
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.715833306)
                                else 18
                            )
                            if state == 17:
                                return -0.0251267403
                            if state == 18:
                                return 0.0177729893
                        if state == 16:
                            return 0.0368683413
    elif num_booster == 90:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.46034801)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 2.89367938)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.48232317)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.430788994)
                            else 16
                        )
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 0.139837831)
                                else 24
                            )
                            if state == 23:
                                return 0.0177595355
                            if state == 24:
                                return -0.0332591794
                        if state == 16:
                            return 0.0248855725
                    if state == 8:
                        return -0.0573716238
                if state == 4:
                    state = 9 if x["sgscore1_med"] < 0.00318749994 else 10
                    if state == 9:
                        return -0.0167295765
                    if state == 10:
                        return 0.0452513695
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 3.25184655)
                    else 6
                )
                if state == 5:
                    state = 11 if x["sgscore1_med"] < 0.554510474 else 12
                    if state == 11:
                        return 0.0100699645
                    if state == 12:
                        return -0.034701772
                if state == 6:
                    return -0.0739012212
    elif num_booster == 91:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4928131) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.0366249979)
                    else 4
                )
                if state == 3:
                    return 0.0501150787
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.6644325)
                        else 8
                    )
                    if state == 7:
                        state = 11 if x["sgscore1_med"] < 0.834416509 else 12
                        if state == 11:
                            state = 15 if x["sgscore1_med"] < 0.194077 else 16
                            if state == 15:
                                return -0.0038549325
                            if state == 16:
                                return 0.0454245508
                        if state == 12:
                            return -0.0154404696
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0137138)
                            else 14
                        )
                        if state == 13:
                            return -0.0497492887
                        if state == 14:
                            state = (
                                17
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.2774315)
                                else 18
                            )
                            if state == 17:
                                return 0.0236029588
                            if state == 18:
                                return -0.0279220603
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.00266666501 else 6
                if state == 5:
                    return 0.00761566637
                if state == 6:
                    return -0.0544503629
    elif num_booster == 92:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.00577545) else 2
            if state == 1:
                return 0.0499373153
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5919151) else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.704999804)
                        else 10
                    )
                    if state == 9:
                        state = (
                            11
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.8709278)
                            else 12
                        )
                        if state == 11:
                            state = (
                                15
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.05531216)
                                else 16
                            )
                            if state == 15:
                                return -0.0449611358
                            if state == 16:
                                return 0.0262100808
                        if state == 12:
                            state = (
                                17
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.00785303)
                                else 18
                            )
                            if state == 17:
                                return 0.0357256569
                            if state == 18:
                                return -0.0104061766
                    if state == 10:
                        return 0.0413658544
                if state == 6:
                    return -0.0619233362
    elif num_booster == 93:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < -0.300900459) else 2
            if state == 1:
                state = 3 if x["maggaia_med"] < 16.412178 else 4
                if state == 3:
                    return -0.0140969604
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.0536766)
                        else 8
                    )
                    if state == 7:
                        return 0.0331969149
                    if state == 8:
                        return -0.0122361323
            if state == 2:
                state = (
                    5
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.9223099)
                    else 6
                )
                if state == 5:
                    state = 9 if x["maggaia_med"] < 16.8467484 else 10
                    if state == 9:
                        return 0.0030878731
                    if state == 10:
                        return -0.0668363348
                if state == 6:
                    return 0.0116134081
    elif num_booster == 94:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < -0.547867775) else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.01983213) else 4
                if state == 3:
                    return 0.00656612078
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.97874999)
                        else 10
                    )
                    if state == 9:
                        return -0.0567684956
                    if state == 10:
                        return 0.00428973557
            if state == 2:
                state = 5 if x["neargaia_med"] < 10.3445396 else 6
                if state == 5:
                    return -0.028108865
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.687999964)
                        else 14
                    )
                    if state == 13:
                        return -0.0207415186
                    if state == 14:
                        state = (
                            17
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 43.7015533)
                            else 18
                        )
                        if state == 17:
                            return 0.0451814495
                        if state == 18:
                            return -0.00717822369
    elif num_booster == 95:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.1377487) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.97758102)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.21715283)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.266271234)
                            else 14
                        )
                        if state == 13:
                            return 0.0211370867
                        if state == 14:
                            return -0.0168043058
                    if state == 8:
                        return 0.0549931042
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.79408216)
                        else 10
                    )
                    if state == 9:
                        return 0.0159507785
                    if state == 10:
                        return -0.0371911116
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.9237499)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.6702499)
                        else 12
                    )
                    if state == 11:
                        state = 15 if x["sgscore1_med"] < 0.581967473 else 16
                        if state == 15:
                            return 0.0123727601
                        if state == 16:
                            return -0.0275294408
                    if state == 12:
                        return -0.0533795208
                if state == 6:
                    return 0.0223127007
    elif num_booster == 96:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.956295) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.7800007)
                    else 4
                )
                if state == 3:
                    state = 7 if x["distpsnr1_med"] < 0.090156436 else 8
                    if state == 7:
                        return -0.0187829137
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.5662498)
                            else 14
                        )
                        if state == 13:
                            return -0.007979705
                        if state == 14:
                            return 0.0528178103
                if state == 4:
                    return -0.0426064469
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.9354992)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.30057979)
                        else 12
                    )
                    if state == 11:
                        state = (
                            15
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 0.561861396)
                            else 16
                        )
                        if state == 15:
                            return -0.0192312431
                        if state == 16:
                            return 0.0185241178
                    if state == 12:
                        state = 17 if x["distpsnr1_med"] < 8.6641407 else 18
                        if state == 17:
                            return -0.0717218816
                        if state == 18:
                            return 0.00472225575
                if state == 6:
                    return 0.0187539887
    elif num_booster == 97:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 6.82107115 else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4356995) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.0857086)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.55864596)
                            else 16
                        )
                        if state == 15:
                            return -0.0232891124
                        if state == 16:
                            return 0.01573967
                    if state == 8:
                        return -0.0538195819
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7306519)
                        else 10
                    )
                    if state == 9:
                        return 0.0397810303
                    if state == 10:
                        return -0.0326278396
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.96818876) else 6
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.49697351) else 12
                    )
                    if state == 11:
                        return 0.0148652904
                    if state == 12:
                        return -0.0320518836
                if state == 6:
                    return 0.0317879394
    elif num_booster == 98:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 19.9058151 else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["col_det"]) or (x["col_det"] < 0.119239807) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.00176525)
                        else 8
                    )
                    if state == 7:
                        state = 13 if x["neargaia_med"] < 47.2691078 else 14
                        if state == 13:
                            state = 17 if x["maggaia_med"] < 15.7893572 else 18
                            if state == 17:
                                return -0.00393828331
                            if state == 18:
                                return -0.0670370385
                        if state == 14:
                            return 0.012113533
                    if state == 8:
                        return 0.00886385702
                if state == 4:
                    state = 9 if x["maggaia_med"] < 17.3772469 else 10
                    if state == 9:
                        return -0.0176491458
                    if state == 10:
                        return 0.0374940336
            if state == 2:
                state = (
                    5 if np.isnan(x["col_det"]) or (x["col_det"] < -1.22711658) else 6
                )
                if state == 5:
                    return -0.00704222266
                if state == 6:
                    return 0.0430396609
    elif num_booster == 99:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 19.4237633 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.620527923)
                    else 4
                )
                if state == 3:
                    return -0.0115861055
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.97936916)
                        else 10
                    )
                    if state == 9:
                        return 0.0373165533
                    if state == 10:
                        return -0.00374992215
            if state == 2:
                state = 5 if x["col_det"] < -0.318695068 else 6
                if state == 5:
                    return 0.00537678599
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.37620234)
                        else 12
                    )
                    if state == 11:
                        return -0.000314992038
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.88531828)
                            else 20
                        )
                        if state == 19:
                            return 0.00114398834
                        if state == 20:
                            return -0.0655479431


def xgb_tree_5(x, num_booster):
    if num_booster == 0:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.96449995)
                else 2
            )
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.9844327) else 4
                if state == 3:
                    return 0.0651697367
                if state == 4:
                    return -0.142300591
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.3803997) else 6
                )
                if state == 5:
                    return -0.116247855
                if state == 6:
                    return 0.135288715
    elif num_booster == 1:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4891624) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.581894517)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.0839996)
                        else 8
                    )
                    if state == 7:
                        return -0.0536556318
                    if state == 8:
                        return 0.147601694
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["col_det"]) or (x["col_det"] < 0.178128093)
                        else 10
                    )
                    if state == 9:
                        return -0.125332713
                    if state == 10:
                        return 0.0760487244
            if state == 2:
                return -0.151927382
    elif num_booster == 2:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 0.558070302)
                else 2
            )
            if state == 1:
                return -0.126421392
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.961499989)
                    else 6
                )
                if state == 5:
                    state = 11 if x["col_det"] < 0.569972992 else 12
                    if state == 11:
                        return 0.0115520004
                    if state == 12:
                        return -0.13452284
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.712363005)
                        else 14
                    )
                    if state == 13:
                        return 0.136421144
                    if state == 14:
                        return -0.103614427
    elif num_booster == 3:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.966500044)
                else 2
            )
            if state == 1:
                return -0.109120183
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.150603831 else 6
                if state == 5:
                    return -0.116290443
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.464999825)
                        else 12
                    )
                    if state == 11:
                        return -0.0484573729
                    if state == 12:
                        return 0.12874262
    elif num_booster == 4:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1329155) else 2
            if state == 1:
                state = 3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.396801) else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 17.6403618)
                        else 8
                    )
                    if state == 7:
                        return 0.0700382814
                    if state == 8:
                        return -0.133932263
                if state == 4:
                    return 0.133503184
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.95669556) else 6
                if state == 5:
                    return 0.0270685088
                if state == 6:
                    return -0.129142359
    elif num_booster == 5:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.6124992) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.96449995)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 22.6038666)
                        else 8
                    )
                    if state == 7:
                        return -0.0986008719
                    if state == 8:
                        return 0.0215356089
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.551373482)
                        else 10
                    )
                    if state == 9:
                        return 0.127693146
                    if state == 10:
                        return -0.0547450855
            if state == 2:
                return -0.109902926
    elif num_booster == 6:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6131096) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.0955009)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.0325012)
                        else 8
                    )
                    if state == 7:
                        return -0.0166470278
                    if state == 8:
                        return 0.13232477
                if state == 4:
                    state = 9 if x["distpsnr1_med"] < 6.38270855 else 10
                    if state == 9:
                        return -0.133153558
                    if state == 10:
                        return 0.0404631011
            if state == 2:
                return -0.129137933
    elif num_booster == 7:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.950500011)
                else 2
            )
            if state == 1:
                return -0.0985110924
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.518345058 else 6
                if state == 5:
                    return -0.0740070641
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.5634995)
                        else 14
                    )
                    if state == 13:
                        return 0.104366139
                    if state == 14:
                        return -0.0243030284
    elif num_booster == 8:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 0.557975292)
                else 2
            )
            if state == 1:
                return -0.0929355621
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.958092511)
                    else 6
                )
                if state == 5:
                    return 0.0561008304
                if state == 6:
                    return -0.105033062
    elif num_booster == 9:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.948500037)
                else 2
            )
            if state == 1:
                return -0.0893436
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.6625004)
                    else 6
                )
                if state == 5:
                    return 0.0926467776
                if state == 6:
                    return -0.0362189002
    elif num_booster == 10:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6989975) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.4130001) else 4
                )
                if state == 3:
                    return -0.0849138796
                if state == 4:
                    return 0.110551633
            if state == 2:
                return -0.122006267
    elif num_booster == 11:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6989975) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.0664315522)
                    else 4
                )
                if state == 3:
                    return 0.113366552
                if state == 4:
                    return -0.0194200445
            if state == 2:
                return -0.12387725
    elif num_booster == 12:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.950999975)
                else 2
            )
            if state == 1:
                return -0.0886675194
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.518345058 else 6
                if state == 5:
                    return -0.0833819434
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.1365013)
                        else 14
                    )
                    if state == 13:
                        return 0.0984439924
                    if state == 14:
                        return -0.0699566975
    elif num_booster == 13:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8676834) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6391487) else 4
                )
                if state == 3:
                    return -0.0831130818
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0440121)
                        else 8
                    )
                    if state == 7:
                        return 0.0908405632
                    if state == 8:
                        return -0.0145121496
            if state == 2:
                return -0.112819791
    elif num_booster == 14:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4572525) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.592790008)
                    else 4
                )
                if state == 3:
                    return 0.0676382631
                if state == 4:
                    return -0.0818464234
            if state == 2:
                return -0.0862690434
    elif num_booster == 15:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.6300011) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.96449995)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 36.3773804)
                        else 8
                    )
                    if state == 7:
                        return -0.0725828633
                    if state == 8:
                        return 0.0876189768
                if state == 4:
                    return 0.071096614
            if state == 2:
                return -0.0894400328
    elif num_booster == 16:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4603462) else 2
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 0.558070302 else 4
                if state == 3:
                    return -0.059043061
                if state == 4:
                    return 0.0675380901
            if state == 2:
                return -0.0942251086
    elif num_booster == 17:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4603462) else 2
            if state == 1:
                state = 3 if x["col_det"] < -0.113627434 else 4
                if state == 3:
                    return -0.0526724309
                if state == 4:
                    state = 9 if x["distpsnr1_med"] < 0.559864759 else 10
                    if state == 9:
                        return -0.0234441254
                    if state == 10:
                        return 0.103655055
            if state == 2:
                return -0.0880610943
    elif num_booster == 18:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 0.663554788 else 2
            if state == 1:
                return -0.0602431111
            if state == 2:
                return 0.044594802
    elif num_booster == 19:
        return -0.00798542239
    elif num_booster == 20:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0251579) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.5594997)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.5514984)
                        else 8
                    )
                    if state == 7:
                        return -0.0788872018
                    if state == 8:
                        return 0.0846453756
                if state == 4:
                    return -0.049375657
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.95751143) else 6
                if state == 5:
                    return 0.0437248312
                if state == 6:
                    return -0.102135539
    elif num_booster == 21:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < -0.219305992) else 2
            if state == 1:
                return -0.038545046
            if state == 2:
                return 0.0473859943
    elif num_booster == 22:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5885353) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.6300011)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.7244987)
                        else 8
                    )
                    if state == 7:
                        return -0.0405115671
                    if state == 8:
                        return 0.0975272208
                if state == 4:
                    return -0.0487495214
            if state == 2:
                return -0.087670967
    elif num_booster == 23:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6989975) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6707001) else 4
                )
                if state == 3:
                    return -0.0603543036
                if state == 4:
                    return 0.0765775219
            if state == 2:
                return -0.0851880163
    elif num_booster == 24:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4572525) else 2
            if state == 1:
                return 0.0289560724
            if state == 2:
                return -0.0864620507
    elif num_booster == 25:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5965843) else 2
            if state == 1:
                return 0.0383316018
            if state == 2:
                return -0.0871782601
    elif num_booster == 26:
        return 0.00376298488
    elif num_booster == 27:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0440121) else 2
            if state == 1:
                return 0.0445533134
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.99805546) else 6
                if state == 5:
                    return 0.0245943274
                if state == 6:
                    return -0.113317981
    elif num_booster == 28:
        return -0.00797367468
    elif num_booster == 29:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.3080006) else 2
            )
            if state == 1:
                return 0.0312157422
            if state == 2:
                return -0.0655558407
    elif num_booster == 30:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6131096) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.4111004) else 4
                )
                if state == 3:
                    return -0.0505213663
                if state == 4:
                    return 0.0601334684
            if state == 2:
                return -0.092268981
    elif num_booster == 31:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.5419998) else 2
            )
            if state == 1:
                return 0.042823825
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7719994) else 6
                )
                if state == 5:
                    return -0.114564389
                if state == 6:
                    return 0.0367061011
    elif num_booster == 32:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 20.8607178 else 2
            if state == 1:
                return -0.0483790524
            if state == 2:
                return 0.0387703218
    elif num_booster == 33:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.592790008)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8676834) else 4
                )
                if state == 3:
                    return 0.0391783267
                if state == 4:
                    return -0.08062426
            if state == 2:
                return -0.0911832005
    elif num_booster == 34:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4603462) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 16.1098213)
                    else 4
                )
                if state == 3:
                    return -0.0352346934
                if state == 4:
                    return 0.0786282346
            if state == 2:
                return -0.0748637393
    elif num_booster == 35:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0440121) else 2
            if state == 1:
                return 0.0426297411
            if state == 2:
                return -0.0616884008
    elif num_booster == 36:
        return -0.0102496147
    elif num_booster == 37:
        return -0.00452727592
    elif num_booster == 38:
        return -0.00714477105
    elif num_booster == 39:
        return -0.00385377812
    elif num_booster == 40:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.432251) else 2
            if state == 1:
                return -0.0612713285
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8546333) else 6
                )
                if state == 5:
                    return 0.0662767813
                if state == 6:
                    return -0.072279267
    elif num_booster == 41:
        return -0.00254667015
    elif num_booster == 42:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 0.559864759)
                else 2
            )
            if state == 1:
                return -0.0754910707
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7378502) else 6
                )
                if state == 5:
                    return -0.0240812376
                if state == 6:
                    return 0.08901117
    elif num_booster == 43:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.3803997) else 2
            if state == 1:
                return -0.0856672078
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6989975) else 6
                )
                if state == 5:
                    return 0.0463102572
                if state == 6:
                    return -0.0804303586
    elif num_booster == 44:
        return -0.000929037342
    elif num_booster == 45:
        return 0.00179992686
    elif num_booster == 46:
        return -0.00902916119
    elif num_booster == 47:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1229591) else 2
            if state == 1:
                return 0.0358196348
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.98107052) else 6
                if state == 5:
                    return 0.0457966924
                if state == 6:
                    return -0.102421455
    elif num_booster == 48:
        return -0.00296659814
    elif num_booster == 49:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.2595005) else 2
            )
            if state == 1:
                return 0.0416271389
            if state == 2:
                return -0.0524076037
    elif num_booster == 50:
        return -0.00116707175
    elif num_booster == 51:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0396252) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6357498) else 4
                )
                if state == 3:
                    return -0.0602464452
                if state == 4:
                    return 0.0763392448
            if state == 2:
                return -0.0618480407
    elif num_booster == 52:
        return 0.0110316658
    elif num_booster == 53:
        return 0.00239605061
    elif num_booster == 54:
        return 0.00484522711
    elif num_booster == 55:
        return 0.00382902636
    elif num_booster == 56:
        return -0.00550113386
    elif num_booster == 57:
        return -0.0102518918
    elif num_booster == 58:
        return 0.00949648023
    elif num_booster == 59:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5965843) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.6628456) else 4
                )
                if state == 3:
                    return -0.0357944518
                if state == 4:
                    return 0.0810425654
            if state == 2:
                return -0.083692722
    elif num_booster == 60:
        return -0.0129194204
    elif num_booster == 61:
        return 0.00450024335
    elif num_booster == 62:
        return -0.00364363636
    elif num_booster == 63:
        return -0.00249904348
    elif num_booster == 64:
        return 0.00901014637
    elif num_booster == 65:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.581894517)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8546333) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.5909996)
                        else 8
                    )
                    if state == 7:
                        return -0.0442666635
                    if state == 8:
                        return 0.0883783624
                if state == 4:
                    return -0.0696710646
            if state == 2:
                return -0.0821272358
    elif num_booster == 66:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.694907546 else 2
            if state == 1:
                return 0.0399776734
            if state == 2:
                return -0.0944480598
    elif num_booster == 67:
        return -0.00355870207
    elif num_booster == 68:
        return 0.0102090733
    elif num_booster == 69:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7378502) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.6300011)
                    else 4
                )
                if state == 3:
                    return 0.00838955306
                if state == 4:
                    return -0.124353044
            if state == 2:
                return 0.0361783989
    elif num_booster == 70:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 3.60880518) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.969500005)
                    else 4
                )
                if state == 3:
                    return -0.0566272847
                if state == 4:
                    return 0.0594542883
            if state == 2:
                return -0.0674635023
    elif num_booster == 71:
        return 0.00101508456
    elif num_booster == 72:
        return -0.00835336372
    elif num_booster == 73:
        return -0.00388330431
    elif num_booster == 74:
        return 0.00372876064
    elif num_booster == 75:
        return -0.0229102559
    elif num_booster == 76:
        return -0.00761121884
    elif num_booster == 77:
        return 0.000625280023
    elif num_booster == 78:
        return 0.0293479133
    elif num_booster == 79:
        return -0.00160821236
    elif num_booster == 80:
        return -0.00674609793
    elif num_booster == 81:
        return 0.00408967584
    elif num_booster == 82:
        return 0.00225300738
    elif num_booster == 83:
        return 0.00895153731
    elif num_booster == 84:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.123661) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.5514984)
                    else 4
                )
                if state == 3:
                    return -0.0848776698
                if state == 4:
                    return 0.0652463064
            if state == 2:
                return -0.0534815527
    elif num_booster == 85:
        return -0.0063914177
    elif num_booster == 86:
        return 0.00699905772
    elif num_booster == 87:
        return 0.00526861334
    elif num_booster == 88:
        return -0.0135363303
    elif num_booster == 89:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7378502) else 2
            if state == 1:
                return -0.0464114733
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.820507) else 6
                )
                if state == 5:
                    return 0.0944278091
                if state == 6:
                    return -0.0642760694
    elif num_booster == 90:
        return 0.00449450687
    elif num_booster == 91:
        return 0.00845856778
    elif num_booster == 92:
        return -0.00380213722
    elif num_booster == 93:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.4099998) else 2
            )
            if state == 1:
                return 0.0371621773
            if state == 2:
                return -0.0944893882
    elif num_booster == 94:
        return -0.0252280049
    elif num_booster == 95:
        return 0.0108787492
    elif num_booster == 96:
        return -0.00940213911
    elif num_booster == 97:
        return -0.00276811863
    elif num_booster == 98:
        return 0.00522190612
    elif num_booster == 99:
        return -0.00886895228


def xgb_tree_6(x, num_booster):
    if num_booster == 0:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.2905006) else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5546989) else 4
                )
                if state == 3:
                    return 0.269924372
                if state == 4:
                    return -0.0538417846
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.196327001 else 6
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 9.01804924) else 12
                    )
                    if state == 11:
                        return 0.147576466
                    if state == 12:
                        return -0.112000003
                if state == 6:
                    return -0.183182701
    elif num_booster == 1:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.680069) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.9635506) else 4
                )
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.983250022)
                        else 6
                    )
                    if state == 5:
                        return -0.135921791
                    if state == 6:
                        return 0.0682295188
                if state == 4:
                    return 0.237486452
            if state == 2:
                return -0.28277728
    elif num_booster == 2:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.3388634) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.3045006)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"])
                        or (x["t_predetect"] < 0.0223900005)
                        else 8
                    )
                    if state == 7:
                        return -0.0717599913
                    if state == 8:
                        return 0.237809107
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.1280708)
                        else 10
                    )
                    if state == 9:
                        return -0.21623072
                    if state == 10:
                        return 0.0962165147
            if state == 2:
                return -0.204130337
    elif num_booster == 3:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.3564987) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.846000016)
                    else 4
                )
                if state == 3:
                    return -0.138272285
                if state == 4:
                    return 0.171681136
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 9.49050236)
                    else 6
                )
                if state == 5:
                    return -0.20659861
                if state == 6:
                    return 0.0298757516
    elif num_booster == 4:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1568947) else 2
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 0.26211834 else 4
                if state == 3:
                    return -0.0994315073
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.646656)
                        else 10
                    )
                    if state == 9:
                        return 0.210591406
                    if state == 10:
                        return -0.0309014432
            if state == 2:
                return -0.171347752
    elif num_booster == 5:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1678238) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.3101997) else 4
                )
                if state == 3:
                    return -0.0652310997
                if state == 4:
                    return 0.166431665
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.06449652) else 6
                if state == 5:
                    return 0.0660126284
                if state == 6:
                    return -0.169108465
    elif num_booster == 6:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6807938) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6517487) else 4
                )
                if state == 3:
                    return -0.158821777
                if state == 4:
                    state = 9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 8.97694397) else 10
                    if state == 9:
                        return 0.187467858
                    if state == 10:
                        return -0.0115162497
            if state == 2:
                return -0.169545934
    elif num_booster == 7:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5434341) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6517487) else 4
                )
                if state == 3:
                    return -0.136162087
                if state == 4:
                    return 0.181715518
            if state == 2:
                return -0.15367192
    elif num_booster == 8:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1155777) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.2869987)
                    else 4
                )
                if state == 3:
                    return 0.1424357
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.5750008)
                        else 10
                    )
                    if state == 9:
                        return -0.14382717
                    if state == 10:
                        return 0.0901303291
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.0521934) else 6
                if state == 5:
                    return 0.0682429224
                if state == 6:
                    return -0.178667411
    elif num_booster == 9:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1179466) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.4130001) else 4
                )
                if state == 3:
                    return -0.118060142
                if state == 4:
                    return 0.151949048
            if state == 2:
                return -0.115059353
    elif num_booster == 10:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1179466) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.5052795) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 17.3182087)
                        else 8
                    )
                    if state == 7:
                        return 0.0872673094
                    if state == 8:
                        return -0.150047168
                if state == 4:
                    return 0.130866781
            if state == 2:
                return -0.0953470394
    elif num_booster == 11:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5304394) else 2
            if state == 1:
                state = 3 if x["col_det"] < -0.294500351 else 4
                if state == 3:
                    return -0.114100941
                if state == 4:
                    return 0.072401613
            if state == 2:
                return -0.125672489
    elif num_booster == 12:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6925507) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.5548573) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.4432507)
                        else 8
                    )
                    if state == 7:
                        return 0.0676068217
                    if state == 8:
                        return -0.159255803
                if state == 4:
                    return 0.17138733
            if state == 2:
                return -0.125575066
    elif num_booster == 13:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.3402061) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0102501) else 4
                )
                if state == 3:
                    return -0.115080282
                if state == 4:
                    return 0.146271825
            if state == 2:
                return -0.113143481
    elif num_booster == 14:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.95888901)
                else 2
            )
            if state == 1:
                return -0.0525405742
            if state == 2:
                return 0.108652093
    elif num_booster == 15:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.6469994) else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6378059) else 4
                )
                if state == 3:
                    return 0.118016064
                if state == 4:
                    return -0.0734183565
            if state == 2:
                return -0.128470913
    elif num_booster == 16:
        return -0.0164706204
    elif num_booster == 17:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.69119674) else 2
            )
            if state == 1:
                return -0.117413253
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 2.82120371)
                    else 6
                )
                if state == 5:
                    return 0.105085164
                if state == 6:
                    return -0.0790800229
    elif num_booster == 18:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.714881003) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 17.9785824) else 4
                )
                if state == 3:
                    return 0.0978270099
                if state == 4:
                    return -0.120131887
            if state == 2:
                return 0.0852219164
    elif num_booster == 19:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.3439999) else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.0947285) else 4
                )
                if state == 3:
                    return 0.129002005
                if state == 4:
                    return -0.081948638
            if state == 2:
                return -0.119610563
    elif num_booster == 20:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 0.80899632)
                else 2
            )
            if state == 1:
                return -0.105627738
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 9.35255814)
                    else 6
                )
                if state == 5:
                    return 0.140956685
                if state == 6:
                    return -0.0810006335
    elif num_booster == 21:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 17.6617317 else 2
            if state == 1:
                return -0.0958292186
            if state == 2:
                return 0.0745636225
    elif num_booster == 22:
        return -0.00591739081
    elif num_booster == 23:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.5548573) else 2
            if state == 1:
                return -0.0855949
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.683815) else 6
                )
                if state == 5:
                    return 0.150001749
                if state == 6:
                    return -0.071314007
    elif num_booster == 24:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.3137493) else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.683815) else 4
                )
                if state == 3:
                    return 0.147300124
                if state == 4:
                    return -0.0966665894
            if state == 2:
                return -0.0942993388
    elif num_booster == 25:
        return -0.0610839389
    elif num_booster == 26:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.3564987) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.033605352)
                    else 4
                )
                if state == 3:
                    return -0.118259139
                if state == 4:
                    return 0.112541407
            if state == 2:
                return -0.082437247
    elif num_booster == 27:
        return 0.0173840486
    elif num_booster == 28:
        return -0.0137669342
    elif num_booster == 29:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.796000004)
                else 2
            )
            if state == 1:
                return -0.112494506
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 2.5174222)
                    else 6
                )
                if state == 5:
                    return 0.108820528
                if state == 6:
                    return -0.0481212921
    elif num_booster == 30:
        return -0.0299332403
    elif num_booster == 31:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.110199) else 2
            if state == 1:
                return -0.0463110656
            if state == 2:
                return 0.121581234
    elif num_booster == 32:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6925507) else 2
            if state == 1:
                state = 3 if x["col_det"] < -0.364562035 else 4
                if state == 3:
                    return -0.0916763395
                if state == 4:
                    state = 5 if x["sgscore1_med"] < 0.00197916501 else 6
                    if state == 5:
                        return -0.0888242945
                    if state == 6:
                        return 0.145433575
            if state == 2:
                return -0.120618418
    elif num_booster == 33:
        return -0.0226008538
    elif num_booster == 34:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7165985) else 2
            if state == 1:
                return -0.109628566
            if state == 2:
                return 0.0619295761
    elif num_booster == 35:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 5.86610603)
                else 2
            )
            if state == 1:
                return -0.0615650937
            if state == 2:
                return 0.103803232
    elif num_booster == 36:
        return -0.0111932009
    elif num_booster == 37:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 17.9812202)
                else 2
            )
            if state == 1:
                return -0.0752962306
            if state == 2:
                return 0.0835058391
    elif num_booster == 38:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.5655003) else 2
            )
            if state == 1:
                return 0.0880023539
            if state == 2:
                return -0.0864682272
    elif num_booster == 39:
        return 0.0598164871
    elif num_booster == 40:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 17.6617317 else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.823571384) else 4
                if state == 3:
                    return -0.116279088
                if state == 4:
                    return 0.0976522416
            if state == 2:
                return 0.073854588
    elif num_booster == 41:
        return -0.0162062403
    elif num_booster == 42:
        return -0.0137762707
    elif num_booster == 43:
        return 0.00121934025
    elif num_booster == 44:
        return -0.00781527162
    elif num_booster == 45:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.89681149)
                else 2
            )
            if state == 1:
                return -0.10126812
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.281283259 else 6
                if state == 5:
                    return -0.106973276
                if state == 6:
                    return 0.08381062
    elif num_booster == 46:
        return -0.0273006279
    elif num_booster == 47:
        return 0.0154025238
    elif num_booster == 48:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.06312466) else 2
            if state == 1:
                return 0.0887083337
            if state == 2:
                state = 5 if x["maggaia_med"] < 19.4579659 else 6
                if state == 5:
                    return 0.0582580976
                if state == 6:
                    return -0.137891144
    elif num_booster == 49:
        return 0.0187371876
    elif num_booster == 50:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 18.3722324 else 2
            if state == 1:
                return -0.0892078429
            if state == 2:
                return 0.0857759342
    elif num_booster == 51:
        return -0.0183906984
    elif num_booster == 52:
        return -0.00790819526
    elif num_booster == 53:
        return 0.0053420458
    elif num_booster == 54:
        return -0.0334258154
    elif num_booster == 55:
        return -0.0418654829
    elif num_booster == 56:
        return -0.0126272487
    elif num_booster == 57:
        return 0.0254097022
    elif num_booster == 58:
        return 0.052768968
    elif num_booster == 59:
        return 0.00478773797
    elif num_booster == 60:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.141321495 else 2
            if state == 1:
                return 0.0696159154
            if state == 2:
                return -0.10070093
    elif num_booster == 61:
        return -0.00433511147
    elif num_booster == 62:
        return 0.0696593672
    elif num_booster == 63:
        return 0.00535036903
    elif num_booster == 64:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.884249985)
                else 2
            )
            if state == 1:
                return -0.114180125
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 9.13675213)
                    else 6
                )
                if state == 5:
                    return 0.0848845616
                if state == 6:
                    return -0.1126706
    elif num_booster == 65:
        return -0.0371376164
    elif num_booster == 66:
        return -0.0289328676
    elif num_booster == 67:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 18.2437363)
                else 2
            )
            if state == 1:
                return -0.106977642
            if state == 2:
                return 0.0889995694
    elif num_booster == 68:
        return -0.015534902
    elif num_booster == 69:
        return 0.0385794826
    elif num_booster == 70:
        return 0.00562887173
    elif num_booster == 71:
        return -0.0132018793
    elif num_booster == 72:
        return -0.0165516511
    elif num_booster == 73:
        return -0.0183648802
    elif num_booster == 74:
        return 0.0246146973
    elif num_booster == 75:
        return -0.00319018355
    elif num_booster == 76:
        return -0.00840744376
    elif num_booster == 77:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 6.38250256)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.958999991)
                    else 4
                )
                if state == 3:
                    return -0.117832452
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 2.82120371)
                        else 10
                    )
                    if state == 9:
                        return 0.103965797
                    if state == 10:
                        return -0.107943788
            if state == 2:
                return 0.0910205171
    elif num_booster == 78:
        return 0.0615085922
    elif num_booster == 79:
        return -0.0108953509
    elif num_booster == 80:
        return -0.0014861424
    elif num_booster == 81:
        return -0.0251574721
    elif num_booster == 82:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7382317) else 2
            if state == 1:
                state = 3 if x["col_det"] < -0.296922296 else 4
                if state == 3:
                    return -0.0875169188
                if state == 4:
                    return 0.114642978
            if state == 2:
                return -0.097974889
    elif num_booster == 83:
        return 0.00828569289
    elif num_booster == 84:
        return -0.0270721875
    elif num_booster == 85:
        return -0.0456252508
    elif num_booster == 86:
        return -0.00779013149
    elif num_booster == 87:
        return 0.0295684133
    elif num_booster == 88:
        return -0.0266155079
    elif num_booster == 89:
        return -0.00752876047
    elif num_booster == 90:
        return -0.0330437124
    elif num_booster == 91:
        return 0.0006165331
    elif num_booster == 92:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1022987) else 2
            if state == 1:
                return 0.0560696907
            if state == 2:
                return -0.111052789
    elif num_booster == 93:
        return 0.00936372299
    elif num_booster == 94:
        return -0.0329455435
    elif num_booster == 95:
        return 0.00690229516
    elif num_booster == 96:
        return -0.0096888775
    elif num_booster == 97:
        return 0.0261620712
    elif num_booster == 98:
        return 0.0131703401
    elif num_booster == 99:
        return -0.0126535939


def xgb_tree_100(x, num_booster):
    if num_booster == 0:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 57.0089569) else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.921428561) else 4
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.396666765) else 8
                    )
                    if state == 7:
                        state = (
                            15 if np.isnan(x["t_lc"]) or (x["t_lc"] < 48.907814) else 16
                        )
                        if state == 15:
                            state = (
                                31
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.9549999)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    61
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.560709774)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        119
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.1404495)
                                        else 120
                                    )
                                    if state == 119:
                                        state = (
                                            211
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.4029999)
                                            else 212
                                        )
                                        if state == 211:
                                            state = (
                                                339
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 17.6315651)
                                                else 340
                                            )
                                            if state == 339:
                                                return -0.629999995
                                            if state == 340:
                                                return -0.18703945
                                        if state == 212:
                                            return 0.683968604
                                    if state == 120:
                                        state = (
                                            213
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.0839996)
                                            else 214
                                        )
                                        if state == 213:
                                            state = (
                                                341
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.2133331)
                                                else 342
                                            )
                                            if state == 341:
                                                return 0.420859694
                                            if state == 342:
                                                return -0.604504466
                                        if state == 214:
                                            state = (
                                                343
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6306877)
                                                else 344
                                            )
                                            if state == 343:
                                                return 0.688046098
                                            if state == 344:
                                                state = (
                                                    495
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 6.18797016)
                                                    else 496
                                                )
                                                if state == 495:
                                                    state = (
                                                        669
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.1365013)
                                                        else 670
                                                    )
                                                    if state == 669:
                                                        return 0.289490968
                                                    if state == 670:
                                                        return -0.64394933
                                                if state == 496:
                                                    return 0.149760351
                                if state == 62:
                                    return -0.718666673
                            if state == 32:
                                state = 63 if x["sgscore1_med"] < 0.656391025 else 64
                                if state == 63:
                                    state = (
                                        121
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.2493)
                                        else 122
                                    )
                                    if state == 121:
                                        state = (
                                            215
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.0335007)
                                            else 216
                                        )
                                        if state == 215:
                                            return 0.659892678
                                        if state == 216:
                                            return -0.377999991
                                    if state == 122:
                                        state = (
                                            217
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.2939987)
                                            else 218
                                        )
                                        if state == 217:
                                            state = (
                                                345
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.2060928)
                                                else 346
                                            )
                                            if state == 345:
                                                state = (
                                                    497
                                                    if x["neargaia_med"] < 44.3732071
                                                    else 498
                                                )
                                                if state == 497:
                                                    return -0.377999991
                                                if state == 498:
                                                    return 0.660283804
                                            if state == 346:
                                                state = (
                                                    499
                                                    if x["neargaia_med"] < 156.691086
                                                    else 500
                                                )
                                                if state == 499:
                                                    return -0.741103411
                                                if state == 500:
                                                    state = (
                                                        671
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.2234993)
                                                        else 672
                                                    )
                                                    if state == 671:
                                                        return -0.651701093
                                                    if state == 672:
                                                        return 0.53889519
                                        if state == 218:
                                            return -0.726596117
                                if state == 64:
                                    state = (
                                        123
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.85075)
                                        else 124
                                    )
                                    if state == 123:
                                        state = (
                                            219
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.0195007)
                                            else 220
                                        )
                                        if state == 219:
                                            state = (
                                                347
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.8217506)
                                                else 348
                                            )
                                            if state == 347:
                                                return 0.300778478
                                            if state == 348:
                                                return -0.252000004
                                        if state == 220:
                                            return -0.324000001
                                    if state == 124:
                                        state = (
                                            221
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.8435001)
                                            else 222
                                        )
                                        if state == 221:
                                            state = (
                                                349
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.8670998)
                                                else 350
                                            )
                                            if state == 349:
                                                return 0.491816014
                                            if state == 350:
                                                return -0.746946096
                                        if state == 222:
                                            state = (
                                                351
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.1560211)
                                                else 352
                                            )
                                            if state == 351:
                                                return 0.418664843
                                            if state == 352:
                                                return -0.658451617
                        if state == 16:
                            return -0.62692821
                    if state == 8:
                        state = (
                            17 if np.isnan(x["t_lc"]) or (x["t_lc"] < 32.932457) else 18
                        )
                        if state == 17:
                            state = (
                                33
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.97925)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    65
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.232765004)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        125
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.696003)
                                        else 126
                                    )
                                    if state == 125:
                                        state = (
                                            223
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 16.9435005)
                                            else 224
                                        )
                                        if state == 223:
                                            state = (
                                                353
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.9321938)
                                                else 354
                                            )
                                            if state == 353:
                                                state = (
                                                    501
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 0.45947364)
                                                    else 502
                                                )
                                                if state == 501:
                                                    state = (
                                                        673
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 16.1222496)
                                                        else 674
                                                    )
                                                    if state == 673:
                                                        return -0.588
                                                    if state == 674:
                                                        state = (
                                                            839
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 16.276001
                                                            )
                                                            else 840
                                                        )
                                                        if state == 839:
                                                            return 0.614528477
                                                        if state == 840:
                                                            return -0.384491891
                                                if state == 502:
                                                    state = (
                                                        675
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 16.8155003)
                                                        else 676
                                                    )
                                                    if state == 675:
                                                        state = (
                                                            841
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 16.1424999
                                                            )
                                                            else 842
                                                        )
                                                        if state == 841:
                                                            return 0.414447635
                                                        if state == 842:
                                                            return 0.658593535
                                                    if state == 676:
                                                        state = (
                                                            843
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 16.8950005
                                                            )
                                                            else 844
                                                        )
                                                        if state == 843:
                                                            return -0.344824612
                                                        if state == 844:
                                                            return -0.0412841998
                                            if state == 354:
                                                state = (
                                                    503
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 0.587639034)
                                                    else 504
                                                )
                                                if state == 503:
                                                    return -0.730153859
                                                if state == 504:
                                                    state = (
                                                        677
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 16.8240013)
                                                        else 678
                                                    )
                                                    if state == 677:
                                                        return 0.495474249
                                                    if state == 678:
                                                        return 0.136605784
                                        if state == 224:
                                            state = (
                                                355
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.0865879)
                                                else 356
                                            )
                                            if state == 355:
                                                state = (
                                                    505
                                                    if x["neargaia_med"] < 0.237839311
                                                    else 506
                                                )
                                                if state == 505:
                                                    state = (
                                                        679
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.6884995)
                                                        else 680
                                                    )
                                                    if state == 679:
                                                        return -0.420000017
                                                    if state == 680:
                                                        return 0.491816014
                                                if state == 506:
                                                    state = (
                                                        681
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.9195004)
                                                        else 682
                                                    )
                                                    if state == 681:
                                                        return 0.697670877
                                                    if state == 682:
                                                        state = (
                                                            845
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.9292488
                                                            )
                                                            else 846
                                                        )
                                                        if state == 845:
                                                            return -0.504000008
                                                        if state == 846:
                                                            return 0.585086226
                                            if state == 356:
                                                state = (
                                                    507
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 17.0376396)
                                                    else 508
                                                )
                                                if state == 507:
                                                    state = (
                                                        683
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.2205009)
                                                        else 684
                                                    )
                                                    if state == 683:
                                                        return -0.565000772
                                                    if state == 684:
                                                        state = (
                                                            847
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.2372494
                                                            )
                                                            else 848
                                                        )
                                                        if state == 847:
                                                            return 0.452156931
                                                        if state == 848:
                                                            return -0.164910883
                                                if state == 508:
                                                    state = (
                                                        685
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.6065006)
                                                        else 686
                                                    )
                                                    if state == 685:
                                                        state = (
                                                            849
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.3800011
                                                            )
                                                            else 850
                                                        )
                                                        if state == 849:
                                                            return 0.456985891
                                                        if state == 850:
                                                            return -0.135279283
                                                    if state == 686:
                                                        return 0.650320351
                                    if state == 126:
                                        state = (
                                            225
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.5672493)
                                            else 226
                                        )
                                        if state == 225:
                                            state = (
                                                357
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.6099625)
                                                else 358
                                            )
                                            if state == 357:
                                                state = (
                                                    509
                                                    if x["neargaia_med"] < 0.114484027
                                                    else 510
                                                )
                                                if state == 509:
                                                    return -0.324000001
                                                if state == 510:
                                                    state = (
                                                        687
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.4517517)
                                                        else 688
                                                    )
                                                    if state == 687:
                                                        return 0.714857876
                                                    if state == 688:
                                                        state = (
                                                            851
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.5144997
                                                            )
                                                            else 852
                                                        )
                                                        if state == 851:
                                                            return 0.0429765619
                                                        if state == 852:
                                                            return -0.252000004
                                            if state == 358:
                                                state = (
                                                    511
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 0.970625877)
                                                    else 512
                                                )
                                                if state == 511:
                                                    state = (
                                                        689
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.3419991)
                                                        else 690
                                                    )
                                                    if state == 689:
                                                        return -0.688554466
                                                    if state == 690:
                                                        state = (
                                                            853
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.3470001
                                                            )
                                                            else 854
                                                        )
                                                        if state == 853:
                                                            return 0.491816014
                                                        if state == 854:
                                                            return -0.671999991
                                                if state == 512:
                                                    state = (
                                                        691
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.4297504)
                                                        else 692
                                                    )
                                                    if state == 691:
                                                        state = (
                                                            855
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 16.9944992
                                                            )
                                                            else 856
                                                        )
                                                        if state == 855:
                                                            return 0.398487389
                                                        if state == 856:
                                                            return -0.0654383451
                                                    if state == 692:
                                                        return -0.658451617
                                        if state == 226:
                                            state = (
                                                359
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.2996788)
                                                else 360
                                            )
                                            if state == 359:
                                                state = (
                                                    513
                                                    if x["neargaia_med"] < 0.445279062
                                                    else 514
                                                )
                                                if state == 513:
                                                    state = (
                                                        693
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.6520004)
                                                        else 694
                                                    )
                                                    if state == 693:
                                                        state = (
                                                            857
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.6310005
                                                            )
                                                            else 858
                                                        )
                                                        if state == 857:
                                                            return -0.481090903
                                                        if state == 858:
                                                            return 0.651079714
                                                    if state == 694:
                                                        return -0.618545413
                                                if state == 514:
                                                    return 0.65680337
                                            if state == 360:
                                                state = (
                                                    515
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 21.116087)
                                                    else 516
                                                )
                                                if state == 515:
                                                    state = (
                                                        695
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.6424999)
                                                        else 696
                                                    )
                                                    if state == 695:
                                                        state = (
                                                            859
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.5944996
                                                            )
                                                            else 860
                                                        )
                                                        if state == 859:
                                                            return 0.491816014
                                                        if state == 860:
                                                            return -0.0963976905
                                                    if state == 696:
                                                        state = (
                                                            861
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.7084999
                                                            )
                                                            else 862
                                                        )
                                                        if state == 861:
                                                            return -0.488757193
                                                        if state == 862:
                                                            return -0.724824727
                                                if state == 516:
                                                    state = (
                                                        697
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.9370003)
                                                        else 698
                                                    )
                                                    if state == 697:
                                                        state = (
                                                            863
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.7649994
                                                            )
                                                            else 864
                                                        )
                                                        if state == 863:
                                                            return -0.420000017
                                                        if state == 864:
                                                            return 0.370035946
                                                    if state == 698:
                                                        return -0.540000021
                                if state == 66:
                                    state = (
                                        127
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 16.8763809)
                                        else 128
                                    )
                                    if state == 127:
                                        state = (
                                            227
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 15.83675)
                                            else 228
                                        )
                                        if state == 227:
                                            return -0.540000021
                                        if state == 228:
                                            return 0.659399211
                                    if state == 128:
                                        state = (
                                            229
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.2514992)
                                            else 230
                                        )
                                        if state == 229:
                                            state = (
                                                361
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 17.5404549)
                                                else 362
                                            )
                                            if state == 361:
                                                return -0.701018155
                                            if state == 362:
                                                state = (
                                                    517
                                                    if x["neargaia_med"] < 0.884213448
                                                    else 518
                                                )
                                                if state == 517:
                                                    return -0.742378354
                                                if state == 518:
                                                    state = (
                                                        699
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 16.5784988)
                                                        else 700
                                                    )
                                                    if state == 699:
                                                        state = (
                                                            865
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 16.1020012
                                                            )
                                                            else 866
                                                        )
                                                        if state == 865:
                                                            return -0.222678825
                                                        if state == 866:
                                                            return 0.487677217
                                                    if state == 700:
                                                        state = (
                                                            867
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 16.8875008
                                                            )
                                                            else 868
                                                        )
                                                        if state == 867:
                                                            return -0.445965111
                                                        if state == 868:
                                                            return -0.0443758257
                                        if state == 230:
                                            state = (
                                                363
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.3507309)
                                                else 364
                                            )
                                            if state == 363:
                                                return 0.704403102
                                            if state == 364:
                                                state = (
                                                    519
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 0.83251071)
                                                    else 520
                                                )
                                                if state == 519:
                                                    return -0.690580904
                                                if state == 520:
                                                    state = (
                                                        701
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.3460007)
                                                        else 702
                                                    )
                                                    if state == 701:
                                                        state = (
                                                            869
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.276001
                                                            )
                                                            else 870
                                                        )
                                                        if state == 869:
                                                            return 0.0429765619
                                                        if state == 870:
                                                            return 0.629247487
                                                    if state == 702:
                                                        state = (
                                                            871
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"] < 17.6945
                                                            )
                                                            else 872
                                                        )
                                                        if state == 871:
                                                            return -0.0324869156
                                                        if state == 872:
                                                            return -0.464757532
                            if state == 34:
                                state = (
                                    67
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.0143125001)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        129
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.8604736)
                                        else 130
                                    )
                                    if state == 129:
                                        state = (
                                            231
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.1704998)
                                            else 232
                                        )
                                        if state == 231:
                                            state = (
                                                365
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.18396)
                                                else 366
                                            )
                                            if state == 365:
                                                state = (
                                                    521
                                                    if x["neargaia_med"] < 55.9580002
                                                    else 522
                                                )
                                                if state == 521:
                                                    state = (
                                                        703
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.7862492)
                                                        else 704
                                                    )
                                                    if state == 703:
                                                        state = (
                                                            873
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.4915009
                                                            )
                                                            else 874
                                                        )
                                                        if state == 873:
                                                            return 0.172653317
                                                        if state == 874:
                                                            return 0.683171391
                                                    if state == 704:
                                                        state = (
                                                            875
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.9775009
                                                            )
                                                            else 876
                                                        )
                                                        if state == 875:
                                                            return -0.479183644
                                                        if state == 876:
                                                            return 0.293678045
                                                if state == 522:
                                                    return 0.682945132
                                            if state == 366:
                                                state = (
                                                    523
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 15.2086697)
                                                    else 524
                                                )
                                                if state == 523:
                                                    state = (
                                                        705
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.0919991)
                                                        else 706
                                                    )
                                                    if state == 705:
                                                        state = (
                                                            877
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.0799999
                                                            )
                                                            else 878
                                                        )
                                                        if state == 877:
                                                            return -0.59684211
                                                        if state == 878:
                                                            return 0.491816014
                                                    if state == 706:
                                                        return -0.649231434
                                                if state == 524:
                                                    state = (
                                                        707
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.2954998)
                                                        else 708
                                                    )
                                                    if state == 707:
                                                        return -0.629999995
                                                    if state == 708:
                                                        state = (
                                                            879
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.4155006
                                                            )
                                                            else 880
                                                        )
                                                        if state == 879:
                                                            return 0.452156931
                                                        if state == 880:
                                                            return 0.0871373862
                                        if state == 232:
                                            state = (
                                                367
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.3383446)
                                                else 368
                                            )
                                            if state == 367:
                                                state = (
                                                    525
                                                    if x["neargaia_med"] < 8.81532288
                                                    else 526
                                                )
                                                if state == 525:
                                                    state = (
                                                        709
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 20.362999)
                                                        else 710
                                                    )
                                                    if state == 709:
                                                        return -0.554400027
                                                    if state == 710:
                                                        state = (
                                                            881
                                                            if np.isnan(x["magnr_med"])
                                                            or (x["magnr_med"] < 21.243)
                                                            else 882
                                                        )
                                                        if state == 881:
                                                            return 0.418664843
                                                        if state == 882:
                                                            return -0.420000017
                                                if state == 526:
                                                    state = (
                                                        711
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.119751)
                                                        else 712
                                                    )
                                                    if state == 711:
                                                        state = (
                                                            883
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.0552502
                                                            )
                                                            else 884
                                                        )
                                                        if state == 883:
                                                            return 0.52198559
                                                        if state == 884:
                                                            return 0.64930743
                                                    if state == 712:
                                                        state = (
                                                            885
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.8397484
                                                            )
                                                            else 886
                                                        )
                                                        if state == 885:
                                                            return -0.440526068
                                                        if state == 886:
                                                            return 0.553195953
                                            if state == 368:
                                                state = (
                                                    527
                                                    if x["neargaia_med"] < 42.0751991
                                                    else 528
                                                )
                                                if state == 527:
                                                    state = (
                                                        713
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.7319984)
                                                        else 714
                                                    )
                                                    if state == 713:
                                                        state = (
                                                            887
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.7254982
                                                            )
                                                            else 888
                                                        )
                                                        if state == 887:
                                                            return -0.106233552
                                                        if state == 888:
                                                            return -0.508686244
                                                    if state == 714:
                                                        state = (
                                                            889
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.9119987
                                                            )
                                                            else 890
                                                        )
                                                        if state == 889:
                                                            return 0.614528477
                                                        if state == 890:
                                                            return -0.109468028
                                                if state == 528:
                                                    return -0.648510516
                                    if state == 130:
                                        state = (
                                            233
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 21.9710007)
                                            else 234
                                        )
                                        if state == 233:
                                            state = (
                                                369
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.219698)
                                                else 370
                                            )
                                            if state == 369:
                                                state = (
                                                    529
                                                    if x["neargaia_med"] < 61.1003342
                                                    else 530
                                                )
                                                if state == 529:
                                                    state = (
                                                        715
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.7924995)
                                                        else 716
                                                    )
                                                    if state == 715:
                                                        state = (
                                                            891
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.7205009
                                                            )
                                                            else 892
                                                        )
                                                        if state == 891:
                                                            return 0.509014726
                                                        if state == 892:
                                                            return -0.135279283
                                                    if state == 716:
                                                        state = (
                                                            893
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.6292496
                                                            )
                                                            else 894
                                                        )
                                                        if state == 893:
                                                            return 0.56490314
                                                        if state == 894:
                                                            return 0.677040815
                                                if state == 530:
                                                    state = (
                                                        717
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.6285)
                                                        else 718
                                                    )
                                                    if state == 717:
                                                        state = (
                                                            895
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.4112511
                                                            )
                                                            else 896
                                                        )
                                                        if state == 895:
                                                            return -0.0151414061
                                                        if state == 896:
                                                            return 0.629247487
                                                    if state == 718:
                                                        state = (
                                                            897
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.4524994
                                                            )
                                                            else 898
                                                        )
                                                        if state == 897:
                                                            return -0.40457803
                                                        if state == 898:
                                                            return 0.31302762
                                            if state == 370:
                                                state = (
                                                    531
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 54.5588875)
                                                    else 532
                                                )
                                                if state == 531:
                                                    state = (
                                                        719
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 21.9414997)
                                                        else 720
                                                    )
                                                    if state == 719:
                                                        state = (
                                                            899
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.3009987
                                                            )
                                                            else 900
                                                        )
                                                        if state == 899:
                                                            return -0.599604368
                                                        if state == 900:
                                                            return -0.682399988
                                                    if state == 720:
                                                        state = (
                                                            901
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.9507484
                                                            )
                                                            else 902
                                                        )
                                                        if state == 901:
                                                            return 0.418664843
                                                        if state == 902:
                                                            return -0.324000001
                                                if state == 532:
                                                    state = (
                                                        721
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 20.5050011)
                                                        else 722
                                                    )
                                                    if state == 721:
                                                        return -0.597429276
                                                    if state == 722:
                                                        state = (
                                                            903
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.0224991
                                                            )
                                                            else 904
                                                        )
                                                        if state == 903:
                                                            return 0.317115545
                                                        if state == 904:
                                                            return -0.664363623
                                        if state == 234:
                                            state = (
                                                371
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.849041)
                                                else 372
                                            )
                                            if state == 371:
                                                state = (
                                                    533
                                                    if x["neargaia_med"] < 21.5129604
                                                    else 534
                                                )
                                                if state == 533:
                                                    return 0.659399211
                                                if state == 534:
                                                    state = (
                                                        723
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.9860001)
                                                        else 724
                                                    )
                                                    if state == 723:
                                                        return -0.420000017
                                                    if state == 724:
                                                        state = (
                                                            905
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 23.1009998
                                                            )
                                                            else 906
                                                        )
                                                        if state == 905:
                                                            return 0.289490968
                                                        if state == 906:
                                                            return -0.252000004
                                            if state == 372:
                                                return -0.707980573
                                if state == 68:
                                    state = (
                                        131
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.8236504)
                                        else 132
                                    )
                                    if state == 131:
                                        state = (
                                            235
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 21.9637489)
                                            else 236
                                        )
                                        if state == 235:
                                            state = (
                                                373
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.4327774)
                                                else 374
                                            )
                                            if state == 373:
                                                state = (
                                                    535
                                                    if x["neargaia_med"] < 14.9684076
                                                    else 536
                                                )
                                                if state == 535:
                                                    state = (
                                                        725
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.7907505)
                                                        else 726
                                                    )
                                                    if state == 725:
                                                        state = (
                                                            907
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.451252
                                                            )
                                                            else 908
                                                        )
                                                        if state == 907:
                                                            return 0.390198708
                                                        if state == 908:
                                                            return 0.625876904
                                                    if state == 726:
                                                        state = (
                                                            909
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.2545013
                                                            )
                                                            else 910
                                                        )
                                                        if state == 909:
                                                            return 0.0755802244
                                                        if state == 910:
                                                            return 0.542499721
                                                if state == 536:
                                                    state = (
                                                        727
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 21.5179996)
                                                        else 728
                                                    )
                                                    if state == 727:
                                                        state = (
                                                            911
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.3969994
                                                            )
                                                            else 912
                                                        )
                                                        if state == 911:
                                                            return 0.687440038
                                                        if state == 912:
                                                            return 0.609149039
                                                    if state == 728:
                                                        state = (
                                                            913
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.5494995
                                                            )
                                                            else 914
                                                        )
                                                        if state == 913:
                                                            return -0.377999991
                                                        if state == 914:
                                                            return 0.486061454
                                            if state == 374:
                                                state = (
                                                    537
                                                    if x["neargaia_med"] < 1.15241003
                                                    else 538
                                                )
                                                if state == 537:
                                                    return -0.58275795
                                                if state == 538:
                                                    state = (
                                                        729
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.3122501)
                                                        else 730
                                                    )
                                                    if state == 729:
                                                        state = (
                                                            915
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.8255005
                                                            )
                                                            else 916
                                                        )
                                                        if state == 915:
                                                            return -0.234991327
                                                        if state == 916:
                                                            return -0.492966026
                                                    if state == 730:
                                                        state = (
                                                            917
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.4744987
                                                            )
                                                            else 918
                                                        )
                                                        if state == 917:
                                                            return 0.317115545
                                                        if state == 918:
                                                            return -0.204335377
                                        if state == 236:
                                            state = (
                                                375
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.0037231)
                                                else 376
                                            )
                                            if state == 375:
                                                state = (
                                                    539
                                                    if x["neargaia_med"] < 18.7216454
                                                    else 540
                                                )
                                                if state == 539:
                                                    state = (
                                                        731
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.2374992)
                                                        else 732
                                                    )
                                                    if state == 731:
                                                        return -0.684000015
                                                    if state == 732:
                                                        state = (
                                                            919
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.4207497
                                                            )
                                                            else 920
                                                        )
                                                        if state == 919:
                                                            return 0.595941901
                                                        if state == 920:
                                                            return -0.334193349
                                                if state == 540:
                                                    state = (
                                                        733
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.9134998)
                                                        else 734
                                                    )
                                                    if state == 733:
                                                        state = (
                                                            921
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.1619987
                                                            )
                                                            else 922
                                                        )
                                                        if state == 921:
                                                            return 0.249997303
                                                        if state == 922:
                                                            return 0.637928247
                                                    if state == 734:
                                                        return -0.420000017
                                            if state == 376:
                                                state = (
                                                    541
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 17.6379318)
                                                    else 542
                                                )
                                                if state == 541:
                                                    state = (
                                                        735
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.8805008)
                                                        else 736
                                                    )
                                                    if state == 735:
                                                        return -0.693528235
                                                    if state == 736:
                                                        state = (
                                                            923
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.9352512
                                                            )
                                                            else 924
                                                        )
                                                        if state == 923:
                                                            return 0.418664843
                                                        if state == 924:
                                                            return -0.252000004
                                                if state == 542:
                                                    state = (
                                                        737
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.8530006)
                                                        else 738
                                                    )
                                                    if state == 737:
                                                        state = (
                                                            925
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.7122498
                                                            )
                                                            else 926
                                                        )
                                                        if state == 925:
                                                            return 0.0251169819
                                                        if state == 926:
                                                            return -0.624521732
                                                    if state == 738:
                                                        state = (
                                                            927
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.9134998
                                                            )
                                                            else 928
                                                        )
                                                        if state == 927:
                                                            return 0.682660401
                                                        if state == 928:
                                                            return -0.566999972
                                    if state == 132:
                                        state = (
                                            237
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.7724991)
                                            else 238
                                        )
                                        if state == 237:
                                            state = (
                                                377
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.3496819)
                                                else 378
                                            )
                                            if state == 377:
                                                state = (
                                                    543
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 4.69022655)
                                                    else 544
                                                )
                                                if state == 543:
                                                    return -0.6517241
                                                if state == 544:
                                                    state = (
                                                        739
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.6205006)
                                                        else 740
                                                    )
                                                    if state == 739:
                                                        state = (
                                                            929
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.9905014
                                                            )
                                                            else 930
                                                        )
                                                        if state == 929:
                                                            return -0.252000004
                                                        if state == 930:
                                                            return 0.538068712
                                                    if state == 740:
                                                        return -0.635039985
                                            if state == 378:
                                                state = (
                                                    545
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 21.1158257)
                                                    else 546
                                                )
                                                if state == 545:
                                                    return -0.738059998
                                                if state == 546:
                                                    state = (
                                                        741
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.4000015)
                                                        else 742
                                                    )
                                                    if state == 741:
                                                        state = (
                                                            931
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.3302498
                                                            )
                                                            else 932
                                                        )
                                                        if state == 931:
                                                            return -0.40457803
                                                        if state == 932:
                                                            return 0.427499801
                                                    if state == 742:
                                                        return -0.716210544
                                        if state == 238:
                                            state = (
                                                379
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.2053852)
                                                else 380
                                            )
                                            if state == 379:
                                                state = (
                                                    547
                                                    if x["neargaia_med"] < 32.3906021
                                                    else 548
                                                )
                                                if state == 547:
                                                    state = (
                                                        743
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 21.1665001)
                                                        else 744
                                                    )
                                                    if state == 743:
                                                        return 0.62834084
                                                    if state == 744:
                                                        state = (
                                                            933
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.2835007
                                                            )
                                                            else 934
                                                        )
                                                        if state == 933:
                                                            return -0.578117669
                                                        if state == 934:
                                                            return 0.500000179
                                                if state == 548:
                                                    return 0.683724701
                                            if state == 380:
                                                state = (
                                                    549
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 7.61352682)
                                                    else 550
                                                )
                                                if state == 549:
                                                    state = (
                                                        745
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.6575012)
                                                        else 746
                                                    )
                                                    if state == 745:
                                                        state = (
                                                            935
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.0029984
                                                            )
                                                            else 936
                                                        )
                                                        if state == 935:
                                                            return -0.534588099
                                                        if state == 936:
                                                            return -0.727036834
                                                    if state == 746:
                                                        state = (
                                                            937
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.8084984
                                                            )
                                                            else 938
                                                        )
                                                        if state == 937:
                                                            return -0.0412841998
                                                        if state == 938:
                                                            return 0.289490968
                                                if state == 550:
                                                    state = (
                                                        747
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.7744999)
                                                        else 748
                                                    )
                                                    if state == 747:
                                                        return 0.418664843
                                                    if state == 748:
                                                        state = (
                                                            939
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.5864983
                                                            )
                                                            else 940
                                                        )
                                                        if state == 939:
                                                            return -0.452383369
                                                        if state == 940:
                                                            return -0.58783859
                        if state == 18:
                            state = (
                                35
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.3374996)
                                else 36
                            )
                            if state == 35:
                                state = 69 if x["sgscore1_med"] < 0.215387002 else 70
                                if state == 69:
                                    state = (
                                        133
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.9664993)
                                        else 134
                                    )
                                    if state == 133:
                                        state = (
                                            239
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 16.1030006)
                                            else 240
                                        )
                                        if state == 239:
                                            return -0.635039985
                                        if state == 240:
                                            state = (
                                                381
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6888962)
                                                else 382
                                            )
                                            if state == 381:
                                                state = (
                                                    551
                                                    if x["neargaia_med"] < 0.566715837
                                                    else 552
                                                )
                                                if state == 551:
                                                    return -0.624521732
                                                if state == 552:
                                                    state = (
                                                        749
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 16.5037498)
                                                        else 750
                                                    )
                                                    if state == 749:
                                                        state = (
                                                            941
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"] < 16.2605
                                                            )
                                                            else 942
                                                        )
                                                        if state == 941:
                                                            return 0.477018893
                                                        if state == 942:
                                                            return -0.540000021
                                                    if state == 750:
                                                        return 0.607585192
                                            if state == 382:
                                                return 0.713419914
                                    if state == 134:
                                        state = (
                                            241
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 16.9624996)
                                            else 242
                                        )
                                        if state == 241:
                                            state = (
                                                383
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.4744339)
                                                else 384
                                            )
                                            if state == 383:
                                                state = (
                                                    553
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 0.649147034)
                                                    else 554
                                                )
                                                if state == 553:
                                                    return -0.669662118
                                                if state == 554:
                                                    state = (
                                                        751
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 16.6474991)
                                                        else 752
                                                    )
                                                    if state == 751:
                                                        return 0.607585192
                                                    if state == 752:
                                                        state = (
                                                            943
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 16.9290009
                                                            )
                                                            else 944
                                                        )
                                                        if state == 943:
                                                            return -0.31826666
                                                        if state == 944:
                                                            return 0.53889519
                                            if state == 384:
                                                state = (
                                                    555
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 0.633628726)
                                                    else 556
                                                )
                                                if state == 555:
                                                    state = (
                                                        753
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 16.7294998)
                                                        else 754
                                                    )
                                                    if state == 753:
                                                        state = (
                                                            945
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 16.5739994
                                                            )
                                                            else 946
                                                        )
                                                        if state == 945:
                                                            return -0.324000001
                                                        if state == 946:
                                                            return 0.289490968
                                                    if state == 754:
                                                        return -0.540000021
                                                if state == 556:
                                                    state = (
                                                        755
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 16.5284996)
                                                        else 756
                                                    )
                                                    if state == 755:
                                                        return 0.149760351
                                                    if state == 756:
                                                        return 0.625603735
                                        if state == 242:
                                            state = (
                                                385
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.0724602)
                                                else 386
                                            )
                                            if state == 385:
                                                state = (
                                                    557
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 1.09516895)
                                                    else 558
                                                )
                                                if state == 557:
                                                    return -0.324000001
                                                if state == 558:
                                                    return 0.289490968
                                            if state == 386:
                                                state = (
                                                    559
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 27.4996929)
                                                    else 560
                                                )
                                                if state == 559:
                                                    return -0.70678556
                                                if state == 560:
                                                    state = (
                                                        757
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.2125015)
                                                        else 758
                                                    )
                                                    if state == 757:
                                                        state = (
                                                            947
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.1075001
                                                            )
                                                            else 948
                                                        )
                                                        if state == 947:
                                                            return -0.00192842365
                                                        if state == 948:
                                                            return -0.554400027
                                                    if state == 758:
                                                        return 0.53889519
                                if state == 70:
                                    state = (
                                        135
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.2447433)
                                        else 136
                                    )
                                    if state == 135:
                                        state = (
                                            243
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.2304993)
                                            else 244
                                        )
                                        if state == 243:
                                            state = (
                                                387
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.4511471)
                                                else 388
                                            )
                                            if state == 387:
                                                state = (
                                                    561
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 24.9808979)
                                                    else 562
                                                )
                                                if state == 561:
                                                    return -0.742378354
                                                if state == 562:
                                                    return 0.452156931
                                            if state == 388:
                                                state = (
                                                    563
                                                    if x["neargaia_med"] < 1.40813589
                                                    else 564
                                                )
                                                if state == 563:
                                                    return -0.59684211
                                                if state == 564:
                                                    return 0.452156931
                                        if state == 244:
                                            state = (
                                                389
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.6903152)
                                                else 390
                                            )
                                            if state == 389:
                                                state = (
                                                    565
                                                    if x["neargaia_med"] < 65.2328644
                                                    else 566
                                                )
                                                if state == 565:
                                                    return 0.289490968
                                                if state == 566:
                                                    return -0.453600019
                                            if state == 390:
                                                return 0.300778478
                                    if state == 136:
                                        return -0.742064536
                            if state == 36:
                                state = (
                                    71
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.504490972)
                                    else 72
                                )
                                if state == 71:
                                    state = (
                                        137
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.5309486)
                                        else 138
                                    )
                                    if state == 137:
                                        state = (
                                            245
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.1009998)
                                            else 246
                                        )
                                        if state == 245:
                                            state = (
                                                391
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6450653)
                                                else 392
                                            )
                                            if state == 391:
                                                state = (
                                                    567
                                                    if x["neargaia_med"] < 1.15343571
                                                    else 568
                                                )
                                                if state == 567:
                                                    state = (
                                                        759
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.691)
                                                        else 760
                                                    )
                                                    if state == 759:
                                                        return -0.671999991
                                                    if state == 760:
                                                        state = (
                                                            949
                                                            if np.isnan(x["magnr_med"])
                                                            or (x["magnr_med"] < 17.757)
                                                            else 950
                                                        )
                                                        if state == 949:
                                                            return 0.452156931
                                                        if state == 950:
                                                            return -0.624521732
                                                if state == 568:
                                                    state = (
                                                        761
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.0634995)
                                                        else 762
                                                    )
                                                    if state == 761:
                                                        state = (
                                                            951
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.9694996
                                                            )
                                                            else 952
                                                        )
                                                        if state == 951:
                                                            return 0.656621456
                                                        if state == 952:
                                                            return 0.389232457
                                                    if state == 762:
                                                        return -0.540733218
                                            if state == 392:
                                                state = (
                                                    569
                                                    if x["neargaia_med"] < 4.53861523
                                                    else 570
                                                )
                                                if state == 569:
                                                    state = (
                                                        763
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.0755005)
                                                        else 764
                                                    )
                                                    if state == 763:
                                                        state = (
                                                            953
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.6665001
                                                            )
                                                            else 954
                                                        )
                                                        if state == 953:
                                                            return 0.498328716
                                                        if state == 954:
                                                            return 0.124124341
                                                    if state == 764:
                                                        return -0.481090903
                                                if state == 570:
                                                    state = (
                                                        765
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.9980011)
                                                        else 766
                                                    )
                                                    if state == 765:
                                                        return 0.738578081
                                                    if state == 766:
                                                        state = (
                                                            955
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.0709991
                                                            )
                                                            else 956
                                                        )
                                                        if state == 955:
                                                            return -0.377999991
                                                        if state == 956:
                                                            return 0.418664843
                                        if state == 246:
                                            state = (
                                                393
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.2176647)
                                                else 394
                                            )
                                            if state == 393:
                                                state = (
                                                    571
                                                    if x["neargaia_med"] < 0.175528288
                                                    else 572
                                                )
                                                if state == 571:
                                                    state = (
                                                        767
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.2919998)
                                                        else 768
                                                    )
                                                    if state == 767:
                                                        return 0.289490968
                                                    if state == 768:
                                                        return -0.540000021
                                                if state == 572:
                                                    return 0.685477793
                                            if state == 394:
                                                state = (
                                                    573
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 4.54170322)
                                                    else 574
                                                )
                                                if state == 573:
                                                    return -0.639692307
                                                if state == 574:
                                                    state = (
                                                        769
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.0524998)
                                                        else 770
                                                    )
                                                    if state == 769:
                                                        state = (
                                                            957
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.3227501
                                                            )
                                                            else 958
                                                        )
                                                        if state == 957:
                                                            return 0.0429765619
                                                        if state == 958:
                                                            return 0.63328898
                                                    if state == 770:
                                                        state = (
                                                            959
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.5629997
                                                            )
                                                            else 960
                                                        )
                                                        if state == 959:
                                                            return -0.253331572
                                                        if state == 960:
                                                            return 0.422358334
                                    if state == 138:
                                        state = (
                                            247
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.6735001)
                                            else 248
                                        )
                                        if state == 247:
                                            state = (
                                                395
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.2362061)
                                                else 396
                                            )
                                            if state == 395:
                                                state = (
                                                    575
                                                    if x["neargaia_med"] < 0.476167977
                                                    else 576
                                                )
                                                if state == 575:
                                                    state = (
                                                        771
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.6380005)
                                                        else 772
                                                    )
                                                    if state == 771:
                                                        state = (
                                                            961
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.6310005
                                                            )
                                                            else 962
                                                        )
                                                        if state == 961:
                                                            return -0.618545413
                                                        if state == 962:
                                                            return 0.491816014
                                                    if state == 772:
                                                        return -0.713999987
                                                if state == 576:
                                                    state = (
                                                        773
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.9195004)
                                                        else 774
                                                    )
                                                    if state == 773:
                                                        return 0.704684496
                                                    if state == 774:
                                                        state = (
                                                            963
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.9377499
                                                            )
                                                            else 964
                                                        )
                                                        if state == 963:
                                                            return -0.377999991
                                                        if state == 964:
                                                            return 0.576774716
                                            if state == 396:
                                                state = (
                                                    577
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 0.937549353)
                                                    else 578
                                                )
                                                if state == 577:
                                                    state = (
                                                        775
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.3962498)
                                                        else 776
                                                    )
                                                    if state == 775:
                                                        state = (
                                                            965
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.4440002
                                                            )
                                                            else 966
                                                        )
                                                        if state == 965:
                                                            return -0.344824612
                                                        if state == 966:
                                                            return -0.709165156
                                                    if state == 776:
                                                        state = (
                                                            967
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.4007492
                                                            )
                                                            else 968
                                                        )
                                                        if state == 967:
                                                            return 0.491816014
                                                        if state == 968:
                                                            return -0.5509938
                                                if state == 578:
                                                    state = (
                                                        777
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.5644989)
                                                        else 778
                                                    )
                                                    if state == 777:
                                                        state = (
                                                            969
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.0185013
                                                            )
                                                            else 970
                                                        )
                                                        if state == 969:
                                                            return 0.294175476
                                                        if state == 970:
                                                            return 0.0382660106
                                                    if state == 778:
                                                        return -0.606995046
                                        if state == 248:
                                            state = (
                                                397
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6978912)
                                                else 398
                                            )
                                            if state == 397:
                                                state = (
                                                    579
                                                    if x["neargaia_med"] < 3.40450907
                                                    else 580
                                                )
                                                if state == 579:
                                                    return -0.664363623
                                                if state == 580:
                                                    state = (
                                                        779
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 21.1152496)
                                                        else 780
                                                    )
                                                    if state == 779:
                                                        return 0.671477437
                                                    if state == 780:
                                                        state = (
                                                            971
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.1295013
                                                            )
                                                            else 972
                                                        )
                                                        if state == 971:
                                                            return -0.324000001
                                                        if state == 972:
                                                            return 0.516273677
                                            if state == 398:
                                                state = (
                                                    581
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 3.39827061)
                                                    else 582
                                                )
                                                if state == 581:
                                                    state = (
                                                        781
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 20.699501)
                                                        else 782
                                                    )
                                                    if state == 781:
                                                        return -0.730684996
                                                    if state == 782:
                                                        state = (
                                                            973
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.7154999
                                                            )
                                                            else 974
                                                        )
                                                        if state == 973:
                                                            return 0.491816014
                                                        if state == 974:
                                                            return -0.632064044
                                                if state == 582:
                                                    state = (
                                                        783
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 21.4500008)
                                                        else 784
                                                    )
                                                    if state == 783:
                                                        state = (
                                                            975
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.7965012
                                                            )
                                                            else 976
                                                        )
                                                        if state == 975:
                                                            return 0.262809366
                                                        if state == 976:
                                                            return -0.0847112164
                                                    if state == 784:
                                                        state = (
                                                            977
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.8134995
                                                            )
                                                            else 978
                                                        )
                                                        if state == 977:
                                                            return -0.555787802
                                                        if state == 978:
                                                            return 0.383820385
                                if state == 72:
                                    state = (
                                        139
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.77285)
                                        else 140
                                    )
                                    if state == 139:
                                        state = (
                                            249
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.1464996)
                                            else 250
                                        )
                                        if state == 249:
                                            return -0.721241355
                                        if state == 250:
                                            state = (
                                                399
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6883545)
                                                else 400
                                            )
                                            if state == 399:
                                                return 0.742363989
                                            if state == 400:
                                                state = (
                                                    583
                                                    if x["neargaia_med"] < 6.75078964
                                                    else 584
                                                )
                                                if state == 583:
                                                    return -0.629999995
                                                if state == 584:
                                                    state = (
                                                        785
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 21.5450001)
                                                        else 786
                                                    )
                                                    if state == 785:
                                                        return 0.535618067
                                                    if state == 786:
                                                        state = (
                                                            979
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.27425
                                                            )
                                                            else 980
                                                        )
                                                        if state == 979:
                                                            return -0.213060737
                                                        if state == 980:
                                                            return 0.232692346
                                    if state == 140:
                                        state = (
                                            251
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.5769997)
                                            else 252
                                        )
                                        if state == 251:
                                            state = (
                                                401
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.4589272)
                                                else 402
                                            )
                                            if state == 401:
                                                return 0.491816014
                                            if state == 402:
                                                return -0.751722753
                                        if state == 252:
                                            state = (
                                                403
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6974545)
                                                else 404
                                            )
                                            if state == 403:
                                                state = (
                                                    585
                                                    if x["neargaia_med"] < 17.867115
                                                    else 586
                                                )
                                                if state == 585:
                                                    return -0.635039985
                                                if state == 586:
                                                    state = (
                                                        787
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.7110004)
                                                        else 788
                                                    )
                                                    if state == 787:
                                                        state = (
                                                            981
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.8795013
                                                            )
                                                            else 982
                                                        )
                                                        if state == 981:
                                                            return 0.641192317
                                                        if state == 982:
                                                            return 0.216263786
                                                    if state == 788:
                                                        return -0.377999991
                                            if state == 404:
                                                return -0.720421493
                if state == 4:
                    state = (
                        9 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.94428587) else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 11.9129686)
                            else 20
                        )
                        if state == 19:
                            state = (
                                37
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 22.4204998)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    73
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.547758996)
                                    else 74
                                )
                                if state == 73:
                                    state = (
                                        141
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.0625)
                                        else 142
                                    )
                                    if state == 141:
                                        state = (
                                            253
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 21.1660004)
                                            else 254
                                        )
                                        if state == 253:
                                            return 0.590087473
                                        if state == 254:
                                            return -0.420000017
                                    if state == 142:
                                        state = (
                                            255
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.8612518)
                                            else 256
                                        )
                                        if state == 255:
                                            state = (
                                                405
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.7835388)
                                                else 406
                                            )
                                            if state == 405:
                                                state = (
                                                    587
                                                    if x["neargaia_med"] < 41.5557747
                                                    else 588
                                                )
                                                if state == 587:
                                                    return 0.651079714
                                                if state == 588:
                                                    return 0.149760351
                                            if state == 406:
                                                state = (
                                                    589
                                                    if x["neargaia_med"] < 39.7689972
                                                    else 590
                                                )
                                                if state == 589:
                                                    return -0.633851409
                                                if state == 590:
                                                    state = (
                                                        789
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.3290005)
                                                        else 790
                                                    )
                                                    if state == 789:
                                                        return 0.289490968
                                                    if state == 790:
                                                        return -0.377999991
                                        if state == 256:
                                            return 0.427499801
                                if state == 74:
                                    return -0.578117669
                            if state == 38:
                                state = 75 if x["sgscore1_med"] < 0.858903527 else 76
                                if state == 75:
                                    state = (
                                        143
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.5205498)
                                        else 144
                                    )
                                    if state == 143:
                                        return -0.377999991
                                    if state == 144:
                                        return 0.289490968
                                if state == 76:
                                    return -0.618545413
                        if state == 20:
                            state = (
                                39
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 20.2595005)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    77
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.561645985)
                                    else 78
                                )
                                if state == 77:
                                    state = (
                                        145
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.3216)
                                        else 146
                                    )
                                    if state == 145:
                                        return 0.698551774
                                    if state == 146:
                                        state = (
                                            257
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.3175011)
                                            else 258
                                        )
                                        if state == 257:
                                            state = (
                                                407
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.5944233)
                                                else 408
                                            )
                                            if state == 407:
                                                return -0.643999994
                                            if state == 408:
                                                return 0.149760351
                                        if state == 258:
                                            state = (
                                                409
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.2154293)
                                                else 410
                                            )
                                            if state == 409:
                                                state = (
                                                    591
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 2.13258028)
                                                    else 592
                                                )
                                                if state == 591:
                                                    state = (
                                                        791
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.8185005)
                                                        else 792
                                                    )
                                                    if state == 791:
                                                        return -0.59684211
                                                    if state == 792:
                                                        state = (
                                                            983
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.9075012
                                                            )
                                                            else 984
                                                        )
                                                        if state == 983:
                                                            return 0.289490968
                                                        if state == 984:
                                                            return -0.252000004
                                                if state == 592:
                                                    state = (
                                                        793
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.875)
                                                        else 794
                                                    )
                                                    if state == 793:
                                                        return 0.666985571
                                                    if state == 794:
                                                        state = (
                                                            987
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.1650009
                                                            )
                                                            else 988
                                                        )
                                                        if state == 987:
                                                            return 0.0429765619
                                                        if state == 988:
                                                            return -0.324000001
                                            if state == 410:
                                                state = (
                                                    593
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 0.639315844)
                                                    else 594
                                                )
                                                if state == 593:
                                                    state = (
                                                        795
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.7080002)
                                                        else 796
                                                    )
                                                    if state == 795:
                                                        state = (
                                                            989
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.6515007
                                                            )
                                                            else 990
                                                        )
                                                        if state == 989:
                                                            return -0.504000008
                                                        if state == 990:
                                                            return 0.491816014
                                                    if state == 796:
                                                        return -0.707061768
                                                if state == 594:
                                                    state = (
                                                        797
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.7745018)
                                                        else 798
                                                    )
                                                    if state == 797:
                                                        state = (
                                                            991
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.5685005
                                                            )
                                                            else 992
                                                        )
                                                        if state == 991:
                                                            return -0.00798400957
                                                        if state == 992:
                                                            return 0.565871239
                                                    if state == 798:
                                                        state = (
                                                            993
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.5084991
                                                            )
                                                            else 994
                                                        )
                                                        if state == 993:
                                                            return -0.118435107
                                                        if state == 994:
                                                            return -0.467138439
                                if state == 78:
                                    return -0.721241355
                            if state == 40:
                                state = (
                                    79
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.892701507)
                                    else 80
                                )
                                if state == 79:
                                    state = (
                                        147
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 17.6988621)
                                        else 148
                                    )
                                    if state == 147:
                                        return -0.566999972
                                    if state == 148:
                                        return 0.634979248
                                if state == 80:
                                    state = (
                                        149
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.8042488)
                                        else 150
                                    )
                                    if state == 149:
                                        return -0.540000021
                                    if state == 150:
                                        return 0.149760351
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 14.9781485)
                            else 22
                        )
                        if state == 21:
                            state = (
                                41
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.4624996)
                                else 42
                            )
                            if state == 41:
                                state = 81 if x["sgscore1_med"] < 0.0421457998 else 82
                                if state == 81:
                                    state = (
                                        151
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.1020508)
                                        else 152
                                    )
                                    if state == 151:
                                        state = (
                                            259
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.2425003)
                                            else 260
                                        )
                                        if state == 259:
                                            state = (
                                                411
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.0764999)
                                                else 412
                                            )
                                            if state == 411:
                                                state = (
                                                    595
                                                    if x["neargaia_med"] < 0.610942602
                                                    else 596
                                                )
                                                if state == 595:
                                                    return 0.300778478
                                                if state == 596:
                                                    state = (
                                                        799
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.1499996)
                                                        else 800
                                                    )
                                                    if state == 799:
                                                        return 0.289490968
                                                    if state == 800:
                                                        return -0.324000001
                                            if state == 412:
                                                return -0.523384631
                                        if state == 260:
                                            state = (
                                                413
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.8854332)
                                                else 414
                                            )
                                            if state == 413:
                                                return 0.418664843
                                            if state == 414:
                                                return -0.252000004
                                    if state == 152:
                                        return -0.59684211
                                if state == 82:
                                    state = (
                                        153
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.6978493)
                                        else 154
                                    )
                                    if state == 153:
                                        state = (
                                            261
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.8789997)
                                            else 262
                                        )
                                        if state == 261:
                                            state = (
                                                415
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.7104416)
                                                else 416
                                            )
                                            if state == 415:
                                                return 0.571732759
                                            if state == 416:
                                                return -0.540000021
                                        if state == 262:
                                            state = (
                                                417
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.9483147)
                                                else 418
                                            )
                                            if state == 417:
                                                return 0.651079714
                                            if state == 418:
                                                return 0.149760351
                                    if state == 154:
                                        state = (
                                            263
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.3234997)
                                            else 264
                                        )
                                        if state == 263:
                                            state = (
                                                419
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.3827896)
                                                else 420
                                            )
                                            if state == 419:
                                                return 0.289490968
                                            if state == 420:
                                                return -0.324000001
                                        if state == 264:
                                            return -0.324000001
                            if state == 42:
                                state = 83 if x["sgscore1_med"] < 0.297289997 else 84
                                if state == 83:
                                    state = (
                                        155
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.6571007)
                                        else 156
                                    )
                                    if state == 155:
                                        state = (
                                            265
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.33325)
                                            else 266
                                        )
                                        if state == 265:
                                            state = (
                                                421
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.1987419)
                                                else 422
                                            )
                                            if state == 421:
                                                state = (
                                                    597
                                                    if x["neargaia_med"] < 10.4141579
                                                    else 598
                                                )
                                                if state == 597:
                                                    state = (
                                                        801
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.5779991)
                                                        else 802
                                                    )
                                                    if state == 801:
                                                        return 0.418664843
                                                    if state == 802:
                                                        state = (
                                                            995
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.4332504
                                                            )
                                                            else 996
                                                        )
                                                        if state == 995:
                                                            return -0.252000004
                                                        if state == 996:
                                                            return 0.300778478
                                                if state == 598:
                                                    return 0.707517087
                                            if state == 422:
                                                state = (
                                                    599
                                                    if x["neargaia_med"] < 0.313736051
                                                    else 600
                                                )
                                                if state == 599:
                                                    return 0.289490968
                                                if state == 600:
                                                    return -0.504000008
                                        if state == 266:
                                            return -0.252000004
                                    if state == 156:
                                        return -0.453600019
                                if state == 84:
                                    state = (
                                        157
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.9743004)
                                        else 158
                                    )
                                    if state == 157:
                                        state = (
                                            267
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.0310001)
                                            else 268
                                        )
                                        if state == 267:
                                            state = (
                                                423
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.584486)
                                                else 424
                                            )
                                            if state == 423:
                                                return 0.491816014
                                            if state == 424:
                                                return -0.504000008
                                        if state == 268:
                                            return -0.540000021
                                    if state == 158:
                                        state = (
                                            269
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.6975002)
                                            else 270
                                        )
                                        if state == 269:
                                            state = (
                                                425
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.6396427)
                                                else 426
                                            )
                                            if state == 425:
                                                return 0.53889519
                                            if state == 426:
                                                return -0.554400027
                                        if state == 270:
                                            return 0.595941901
                        if state == 22:
                            state = (
                                43
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.0599995)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    85
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.167797506)
                                    else 86
                                )
                                if state == 85:
                                    state = (
                                        159
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.8123016)
                                        else 160
                                    )
                                    if state == 159:
                                        return 0.69368118
                                    if state == 160:
                                        state = (
                                            271
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.0125008)
                                            else 272
                                        )
                                        if state == 271:
                                            state = (
                                                427
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.8971767)
                                                else 428
                                            )
                                            if state == 427:
                                                return 0.418664843
                                            if state == 428:
                                                return -0.655200005
                                        if state == 272:
                                            state = (
                                                429
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.3471546)
                                                else 430
                                            )
                                            if state == 429:
                                                state = (
                                                    601
                                                    if x["neargaia_med"] < 19.6158714
                                                    else 602
                                                )
                                                if state == 601:
                                                    return -0.588
                                                if state == 602:
                                                    return 0.705258548
                                            if state == 430:
                                                state = (
                                                    603
                                                    if x["neargaia_med"] < 19.6231976
                                                    else 604
                                                )
                                                if state == 603:
                                                    return -0.690260887
                                                if state == 604:
                                                    return 0.427499801
                                if state == 86:
                                    state = (
                                        161
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.8611984)
                                        else 162
                                    )
                                    if state == 161:
                                        state = (
                                            273
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.0680008)
                                            else 274
                                        )
                                        if state == 273:
                                            return 0.668530405
                                        if state == 274:
                                            state = (
                                                431
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.9794159)
                                                else 432
                                            )
                                            if state == 431:
                                                state = (
                                                    605
                                                    if x["neargaia_med"] < 21.7122765
                                                    else 606
                                                )
                                                if state == 605:
                                                    return -0.554400027
                                                if state == 606:
                                                    return 0.491816014
                                            if state == 432:
                                                state = (
                                                    607
                                                    if x["neargaia_med"] < 21.7122726
                                                    else 608
                                                )
                                                if state == 607:
                                                    return -0.324000001
                                                if state == 608:
                                                    return 0.595941901
                                    if state == 162:
                                        return -0.7072258
                            if state == 44:
                                state = (
                                    87
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.0208749995)
                                    else 88
                                )
                                if state == 87:
                                    state = (
                                        163
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.4706497)
                                        else 164
                                    )
                                    if state == 163:
                                        state = (
                                            275
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.1630001)
                                            else 276
                                        )
                                        if state == 275:
                                            state = (
                                                433
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.1758842)
                                                else 434
                                            )
                                            if state == 433:
                                                state = (
                                                    609
                                                    if x["neargaia_med"] < 6.17582178
                                                    else 610
                                                )
                                                if state == 609:
                                                    return 0.149760351
                                                if state == 610:
                                                    return 0.652593493
                                            if state == 434:
                                                return -0.324000001
                                        if state == 276:
                                            return -0.324000001
                                    if state == 164:
                                        state = (
                                            277
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.7705002)
                                            else 278
                                        )
                                        if state == 277:
                                            state = (
                                                435
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.9438171)
                                                else 436
                                            )
                                            if state == 435:
                                                return 0.418664843
                                            if state == 436:
                                                return -0.588
                                        if state == 278:
                                            return 0.391562223
                                if state == 88:
                                    state = (
                                        165
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 17.7617111)
                                        else 166
                                    )
                                    if state == 165:
                                        return -0.324000001
                                    if state == 166:
                                        return 0.711870134
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.666071415) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.534166694)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 61.8556213)
                            else 24
                        )
                        if state == 23:
                            state = (
                                45
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.6175003)
                                else 46
                            )
                            if state == 45:
                                state = 89 if x["sgscore1_med"] < 0.564113021 else 90
                                if state == 89:
                                    state = (
                                        167
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.8529491)
                                        else 168
                                    )
                                    if state == 167:
                                        return 0.728065133
                                    if state == 168:
                                        state = (
                                            279
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.1189995)
                                            else 280
                                        )
                                        if state == 279:
                                            return -0.540000021
                                        if state == 280:
                                            return 0.452156931
                                if state == 90:
                                    return -0.6517241
                            if state == 46:
                                state = (
                                    91
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.0238853991)
                                    else 92
                                )
                                if state == 91:
                                    state = (
                                        169
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 21.2713013)
                                        else 170
                                    )
                                    if state == 169:
                                        return -0.72348386
                                    if state == 170:
                                        return 0.289490968
                                if state == 92:
                                    state = (
                                        171
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.3380775)
                                        else 172
                                    )
                                    if state == 171:
                                        return 0.629247487
                                    if state == 172:
                                        state = (
                                            281
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.8735008)
                                            else 282
                                        )
                                        if state == 281:
                                            return -0.680399954
                                        if state == 282:
                                            state = (
                                                437
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.466711)
                                                else 438
                                            )
                                            if state == 437:
                                                return -0.664363623
                                            if state == 438:
                                                state = (
                                                    611
                                                    if x["neargaia_med"] < 36.6443329
                                                    else 612
                                                )
                                                if state == 611:
                                                    state = (
                                                        803
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 21.6409988)
                                                        else 804
                                                    )
                                                    if state == 803:
                                                        return 0.427499801
                                                    if state == 804:
                                                        return -0.252000004
                                                if state == 612:
                                                    return -0.252000004
                        if state == 24:
                            state = (
                                47
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.0830002)
                                else 48
                            )
                            if state == 47:
                                return -0.717815459
                            if state == 48:
                                state = 93 if x["sgscore1_med"] < 0.140455499 else 94
                                if state == 93:
                                    state = (
                                        173
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.6963158)
                                        else 174
                                    )
                                    if state == 173:
                                        state = (
                                            283
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.161499)
                                            else 284
                                        )
                                        if state == 283:
                                            state = (
                                                439
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.8254166)
                                                else 440
                                            )
                                            if state == 439:
                                                state = (
                                                    613
                                                    if x["neargaia_med"] < 35.2044296
                                                    else 614
                                                )
                                                if state == 613:
                                                    return -0.523384631
                                                if state == 614:
                                                    return 0.595941901
                                            if state == 440:
                                                state = (
                                                    615
                                                    if x["neargaia_med"] < 49.6750946
                                                    else 616
                                                )
                                                if state == 615:
                                                    state = (
                                                        805
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.2695007)
                                                        else 806
                                                    )
                                                    if state == 805:
                                                        return 0.289490968
                                                    if state == 806:
                                                        return -0.629999995
                                                if state == 616:
                                                    return 0.300778478
                                        if state == 284:
                                            state = (
                                                441
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.9964428)
                                                else 442
                                            )
                                            if state == 441:
                                                state = (
                                                    617
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 18.6138248)
                                                    else 618
                                                )
                                                if state == 617:
                                                    return -0.420000017
                                                if state == 618:
                                                    state = (
                                                        807
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.6710014)
                                                        else 808
                                                    )
                                                    if state == 807:
                                                        return 0.495474249
                                                    if state == 808:
                                                        state = (
                                                            997
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.9570007
                                                            )
                                                            else 998
                                                        )
                                                        if state == 997:
                                                            return -0.377999991
                                                        if state == 998:
                                                            return 0.289490968
                                            if state == 442:
                                                return -0.733432829
                                    if state == 174:
                                        state = (
                                            285
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.9797497)
                                            else 286
                                        )
                                        if state == 285:
                                            return 0.672621787
                                        if state == 286:
                                            state = (
                                                443
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.816494)
                                                else 444
                                            )
                                            if state == 443:
                                                return -0.588
                                            if state == 444:
                                                return 0.418664843
                                if state == 94:
                                    state = (
                                        175
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.2373276)
                                        else 176
                                    )
                                    if state == 175:
                                        state = (
                                            287
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.4659996)
                                            else 288
                                        )
                                        if state == 287:
                                            state = (
                                                445
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6671715)
                                                else 446
                                            )
                                            if state == 445:
                                                state = (
                                                    619
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 22.1888332)
                                                    else 620
                                                )
                                                if state == 619:
                                                    return -0.481090903
                                                if state == 620:
                                                    return 0.491816014
                                            if state == 446:
                                                return 0.427499801
                                        if state == 288:
                                            return -0.420000017
                                    if state == 176:
                                        return -0.729264081
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 86.7832108)
                            else 26
                        )
                        if state == 25:
                            state = (
                                49
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.5559998)
                                else 50
                            )
                            if state == 49:
                                state = 95 if x["sgscore1_med"] < 0.190169498 else 96
                                if state == 95:
                                    state = (
                                        177
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.8690987)
                                        else 178
                                    )
                                    if state == 177:
                                        state = (
                                            289
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 15.8924999)
                                            else 290
                                        )
                                        if state == 289:
                                            return -0.324000001
                                        if state == 290:
                                            return 0.733691871
                                    if state == 178:
                                        state = (
                                            291
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.3164997)
                                            else 292
                                        )
                                        if state == 291:
                                            return -0.699999988
                                        if state == 292:
                                            state = (
                                                447
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.7248478)
                                                else 448
                                            )
                                            if state == 447:
                                                return -0.59684211
                                            if state == 448:
                                                return 0.391562223
                                if state == 96:
                                    return -0.745122254
                            if state == 50:
                                state = 97 if x["sgscore1_med"] < 0.506484985 else 98
                                if state == 97:
                                    state = (
                                        179
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.4595985)
                                        else 180
                                    )
                                    if state == 179:
                                        state = (
                                            293
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.5942497)
                                            else 294
                                        )
                                        if state == 293:
                                            state = (
                                                449
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.1710014)
                                                else 450
                                            )
                                            if state == 449:
                                                state = (
                                                    621
                                                    if x["neargaia_med"] < 2.55302119
                                                    else 622
                                                )
                                                if state == 621:
                                                    return -0.420000017
                                                if state == 622:
                                                    return 0.747633338
                                            if state == 450:
                                                state = (
                                                    623
                                                    if x["neargaia_med"] < 1.62589407
                                                    else 624
                                                )
                                                if state == 623:
                                                    return -0.703862071
                                                if state == 624:
                                                    state = (
                                                        809
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.3374996)
                                                        else 810
                                                    )
                                                    if state == 809:
                                                        state = (
                                                            999
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.050499
                                                            )
                                                            else 1000
                                                        )
                                                        if state == 999:
                                                            return 0.669459581
                                                        if state == 1000:
                                                            return -0.479183644
                                                    if state == 810:
                                                        return 0.741144657
                                        if state == 294:
                                            state = (
                                                451
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.9221611)
                                                else 452
                                            )
                                            if state == 451:
                                                state = (
                                                    625
                                                    if x["neargaia_med"] < 6.49587727
                                                    else 626
                                                )
                                                if state == 625:
                                                    return -0.658451617
                                                if state == 626:
                                                    state = (
                                                        811
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.684)
                                                        else 812
                                                    )
                                                    if state == 811:
                                                        return -0.252000004
                                                    if state == 812:
                                                        state = (
                                                            1001
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.8935013
                                                            )
                                                            else 1002
                                                        )
                                                        if state == 1001:
                                                            return 0.431745946
                                                        if state == 1002:
                                                            return 0.687816739
                                            if state == 452:
                                                state = (
                                                    627
                                                    if x["neargaia_med"] < 8.6652832
                                                    else 628
                                                )
                                                if state == 627:
                                                    state = (
                                                        813
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 20.4985008)
                                                        else 814
                                                    )
                                                    if state == 813:
                                                        return -0.684000015
                                                    if state == 814:
                                                        state = (
                                                            1003
                                                            if np.isnan(x["magnr_med"])
                                                            or (x["magnr_med"] < 20.625)
                                                            else 1004
                                                        )
                                                        if state == 1003:
                                                            return 0.289490968
                                                        if state == 1004:
                                                            return -0.324000001
                                                if state == 628:
                                                    state = (
                                                        815
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 20.2205009)
                                                        else 816
                                                    )
                                                    if state == 815:
                                                        return 0.510719836
                                                    if state == 816:
                                                        state = (
                                                            1005
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.6054993
                                                            )
                                                            else 1006
                                                        )
                                                        if state == 1005:
                                                            return -0.453600019
                                                        if state == 1006:
                                                            return 0.448887914
                                    if state == 180:
                                        state = (
                                            295
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.1715012)
                                            else 296
                                        )
                                        if state == 295:
                                            state = (
                                                453
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.483757)
                                                else 454
                                            )
                                            if state == 453:
                                                return 0.575520575
                                            if state == 454:
                                                state = (
                                                    629
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 4.08345032)
                                                    else 630
                                                )
                                                if state == 629:
                                                    return -0.74064976
                                                if state == 630:
                                                    state = (
                                                        817
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.7185001)
                                                        else 818
                                                    )
                                                    if state == 817:
                                                        state = (
                                                            1007
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.8019981
                                                            )
                                                            else 1008
                                                        )
                                                        if state == 1007:
                                                            return 0.121759027
                                                        if state == 1008:
                                                            return 0.574400663
                                                    if state == 818:
                                                        state = (
                                                            1009
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.6025009
                                                            )
                                                            else 1010
                                                        )
                                                        if state == 1009:
                                                            return -0.350438923
                                                        if state == 1010:
                                                            return -0.626869142
                                        if state == 296:
                                            return 0.699628115
                                if state == 98:
                                    state = (
                                        181
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.6991501)
                                        else 182
                                    )
                                    if state == 181:
                                        state = (
                                            297
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.7770004)
                                            else 298
                                        )
                                        if state == 297:
                                            state = (
                                                455
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.5652294)
                                                else 456
                                            )
                                            if state == 455:
                                                return 0.289490968
                                            if state == 456:
                                                return -0.420000017
                                        if state == 298:
                                            return 0.721592784
                                    if state == 182:
                                        state = (
                                            299
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 21.4584999)
                                            else 300
                                        )
                                        if state == 299:
                                            state = (
                                                457
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.229702)
                                                else 458
                                            )
                                            if state == 457:
                                                return 0.391562223
                                            if state == 458:
                                                state = (
                                                    631
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 31.1357327)
                                                    else 632
                                                )
                                                if state == 631:
                                                    return -0.746117651
                                                if state == 632:
                                                    state = (
                                                        819
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 20.2325001)
                                                        else 820
                                                    )
                                                    if state == 819:
                                                        return 0.418664843
                                                    if state == 820:
                                                        return -0.59684211
                                        if state == 300:
                                            return 0.624396205
                        if state == 26:
                            state = (
                                51
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.5695)
                                else 52
                            )
                            if state == 51:
                                state = 99 if x["sgscore1_med"] < 0.505461514 else 100
                                if state == 99:
                                    state = (
                                        183
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.2766991)
                                        else 184
                                    )
                                    if state == 183:
                                        state = (
                                            301
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.7892494)
                                            else 302
                                        )
                                        if state == 301:
                                            state = (
                                                459
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.5906143)
                                                else 460
                                            )
                                            if state == 459:
                                                return -0.252000004
                                            if state == 460:
                                                return 0.595941901
                                        if state == 302:
                                            return -0.377999991
                                    if state == 184:
                                        state = (
                                            303
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.2915001)
                                            else 304
                                        )
                                        if state == 303:
                                            return -0.618545413
                                        if state == 304:
                                            state = (
                                                461
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.7936897)
                                                else 462
                                            )
                                            if state == 461:
                                                return 0.149760351
                                            if state == 462:
                                                return -0.420000017
                                if state == 100:
                                    return -0.721636355
                            if state == 52:
                                state = (
                                    101
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.501181483)
                                    else 102
                                )
                                if state == 101:
                                    state = (
                                        185
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.9932003)
                                        else 186
                                    )
                                    if state == 185:
                                        return 0.5821383
                                    if state == 186:
                                        state = (
                                            305
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.7789993)
                                            else 306
                                        )
                                        if state == 305:
                                            return 0.391562223
                                        if state == 306:
                                            state = (
                                                463
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.8735218)
                                                else 464
                                            )
                                            if state == 463:
                                                state = (
                                                    633
                                                    if x["neargaia_med"] < 45.42136
                                                    else 634
                                                )
                                                if state == 633:
                                                    return 0.391562223
                                                if state == 634:
                                                    return -0.252000004
                                            if state == 464:
                                                return -0.624521732
                                if state == 102:
                                    return -0.554400027
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.881071508)
                        else 14
                    )
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 78.8748932)
                            else 28
                        )
                        if state == 27:
                            state = (
                                53
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.8190002)
                                else 54
                            )
                            if state == 53:
                                state = (
                                    103
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.502107024)
                                    else 104
                                )
                                if state == 103:
                                    state = (
                                        187
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.1056995)
                                        else 188
                                    )
                                    if state == 187:
                                        state = (
                                            307
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.3525009)
                                            else 308
                                        )
                                        if state == 307:
                                            state = (
                                                465
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.7862625)
                                                else 466
                                            )
                                            if state == 465:
                                                state = (
                                                    635
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 24.4795876)
                                                    else 636
                                                )
                                                if state == 635:
                                                    return -0.592626989
                                                if state == 636:
                                                    return 0.491816014
                                            if state == 466:
                                                state = (
                                                    637
                                                    if x["neargaia_med"] < 4.03751087
                                                    else 638
                                                )
                                                if state == 637:
                                                    state = (
                                                        821
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 16.9780006)
                                                        else 822
                                                    )
                                                    if state == 821:
                                                        return 0.408632368
                                                    if state == 822:
                                                        return -0.344824612
                                                if state == 638:
                                                    return -0.420000017
                                        if state == 308:
                                            state = (
                                                467
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.3969116)
                                                else 468
                                            )
                                            if state == 467:
                                                state = (
                                                    639
                                                    if x["neargaia_med"] < 170.495621
                                                    else 640
                                                )
                                                if state == 639:
                                                    state = (
                                                        823
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.0275002)
                                                        else 824
                                                    )
                                                    if state == 823:
                                                        return 0.718716621
                                                    if state == 824:
                                                        state = (
                                                            1013
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.2342491
                                                            )
                                                            else 1014
                                                        )
                                                        if state == 1013:
                                                            return -0.523384631
                                                        if state == 1014:
                                                            return 0.699628115
                                                if state == 640:
                                                    return -0.377999991
                                            if state == 468:
                                                state = (
                                                    641
                                                    if x["neargaia_med"] < 34.944046
                                                    else 642
                                                )
                                                if state == 641:
                                                    return -0.324000001
                                                if state == 642:
                                                    return 0.289490968
                                    if state == 188:
                                        state = (
                                            309
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.2200012)
                                            else 310
                                        )
                                        if state == 309:
                                            return -0.743240476
                                        if state == 310:
                                            state = (
                                                469
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.2955227)
                                                else 470
                                            )
                                            if state == 469:
                                                state = (
                                                    643
                                                    if x["neargaia_med"] < 1.85738778
                                                    else 644
                                                )
                                                if state == 643:
                                                    return -0.540000021
                                                if state == 644:
                                                    return 0.595941901
                                            if state == 470:
                                                state = (
                                                    645
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 2.57085419)
                                                    else 646
                                                )
                                                if state == 645:
                                                    state = (
                                                        825
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.3117504)
                                                        else 826
                                                    )
                                                    if state == 825:
                                                        state = (
                                                            1015
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.3032494
                                                            )
                                                            else 1016
                                                        )
                                                        if state == 1015:
                                                            return -0.504000008
                                                        if state == 1016:
                                                            return 0.289490968
                                                    if state == 826:
                                                        return -0.751493275
                                                if state == 646:
                                                    state = (
                                                        827
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.9724998)
                                                        else 828
                                                    )
                                                    if state == 827:
                                                        state = (
                                                            1017
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.7364998
                                                            )
                                                            else 1018
                                                        )
                                                        if state == 1017:
                                                            return 0.196850806
                                                        if state == 1018:
                                                            return 0.659399211
                                                    if state == 828:
                                                        state = (
                                                            1019
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.1054993
                                                            )
                                                            else 1020
                                                        )
                                                        if state == 1019:
                                                            return -0.59684211
                                                        if state == 1020:
                                                            return 0.189411059
                                if state == 104:
                                    return -0.748265982
                            if state == 54:
                                state = (
                                    105
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.583249986)
                                    else 106
                                )
                                if state == 105:
                                    state = (
                                        189
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.0313492)
                                        else 190
                                    )
                                    if state == 189:
                                        state = (
                                            311
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.4674988)
                                            else 312
                                        )
                                        if state == 311:
                                            state = (
                                                471
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.0421219)
                                                else 472
                                            )
                                            if state == 471:
                                                state = (
                                                    647
                                                    if x["neargaia_med"] < 4.75427628
                                                    else 648
                                                )
                                                if state == 647:
                                                    return -0.578117669
                                                if state == 648:
                                                    state = (
                                                        829
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.3494987)
                                                        else 830
                                                    )
                                                    if state == 829:
                                                        return 0.705011189
                                                    if state == 830:
                                                        state = (
                                                            1021
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.3564987
                                                            )
                                                            else 1022
                                                        )
                                                        if state == 1021:
                                                            return -0.252000004
                                                        if state == 1022:
                                                            return 0.452156931
                                            if state == 472:
                                                state = (
                                                    649
                                                    if x["neargaia_med"] < 14.0337696
                                                    else 650
                                                )
                                                if state == 649:
                                                    return -0.611999989
                                                if state == 650:
                                                    state = (
                                                        831
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.8759995)
                                                        else 832
                                                    )
                                                    if state == 831:
                                                        state = (
                                                            1023
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.8310013
                                                            )
                                                            else 1024
                                                        )
                                                        if state == 1023:
                                                            return 0.289490968
                                                        if state == 1024:
                                                            return -0.252000004
                                                    if state == 832:
                                                        return 0.616106391
                                        if state == 312:
                                            state = (
                                                473
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.703968)
                                                else 474
                                            )
                                            if state == 473:
                                                state = (
                                                    651
                                                    if x["neargaia_med"] < 2.63730645
                                                    else 652
                                                )
                                                if state == 651:
                                                    return -0.540000021
                                                if state == 652:
                                                    state = (
                                                        833
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.0912514)
                                                        else 834
                                                    )
                                                    if state == 833:
                                                        return 0.721445918
                                                    if state == 834:
                                                        return 0.149760351
                                            if state == 474:
                                                return 0.0429765619
                                    if state == 190:
                                        state = (
                                            313
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.8110008)
                                            else 314
                                        )
                                        if state == 313:
                                            state = (
                                                475
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.2690372)
                                                else 476
                                            )
                                            if state == 475:
                                                state = (
                                                    653
                                                    if x["neargaia_med"] < 20.37187
                                                    else 654
                                                )
                                                if state == 653:
                                                    return -0.566999972
                                                if state == 654:
                                                    return 0.571732759
                                            if state == 476:
                                                state = (
                                                    655
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 14.0962677)
                                                    else 656
                                                )
                                                if state == 655:
                                                    return -0.743053854
                                                if state == 656:
                                                    state = (
                                                        835
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 20.1954994)
                                                        else 836
                                                    )
                                                    if state == 835:
                                                        state = (
                                                            1025
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.1035004
                                                            )
                                                            else 1026
                                                        )
                                                        if state == 1025:
                                                            return -0.262604922
                                                        if state == 1026:
                                                            return 0.651079714
                                                    if state == 836:
                                                        return -0.629999995
                                        if state == 314:
                                            state = (
                                                477
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.5494576)
                                                else 478
                                            )
                                            if state == 477:
                                                return 0.672621787
                                            if state == 478:
                                                state = (
                                                    657
                                                    if x["neargaia_med"] < 21.9515495
                                                    else 658
                                                )
                                                if state == 657:
                                                    return 0.300778478
                                                if state == 658:
                                                    return -0.611999989
                                if state == 106:
                                    state = (
                                        191
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.34935)
                                        else 192
                                    )
                                    if state == 191:
                                        state = (
                                            315
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.0725002)
                                            else 316
                                        )
                                        if state == 315:
                                            state = (
                                                479
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.4091511)
                                                else 480
                                            )
                                            if state == 479:
                                                return 0.571732759
                                            if state == 480:
                                                return -0.420000017
                                        if state == 316:
                                            return -0.611999989
                                    if state == 192:
                                        return -0.728999972
                        if state == 28:
                            state = (
                                55
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.6375008)
                                else 56
                            )
                            if state == 55:
                                state = 107 if x["sgscore1_med"] < 0.504634023 else 108
                                if state == 107:
                                    state = (
                                        193
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.1872711)
                                        else 194
                                    )
                                    if state == 193:
                                        state = (
                                            317
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 16.5514984)
                                            else 318
                                        )
                                        if state == 317:
                                            return -0.566999972
                                        if state == 318:
                                            state = (
                                                481
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.3689613)
                                                else 482
                                            )
                                            if state == 481:
                                                return 0.686824679
                                            if state == 482:
                                                state = (
                                                    659
                                                    if x["neargaia_med"] < 0.880212069
                                                    else 660
                                                )
                                                if state == 659:
                                                    return -0.252000004
                                                if state == 660:
                                                    return 0.300778478
                                    if state == 194:
                                        return -0.721866131
                                if state == 108:
                                    return -0.738418579
                            if state == 56:
                                state = (
                                    109
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.658419967)
                                    else 110
                                )
                                if state == 109:
                                    state = (
                                        195
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.0226498)
                                        else 196
                                    )
                                    if state == 195:
                                        return 0.66421622
                                    if state == 196:
                                        state = (
                                            319
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.5695)
                                            else 320
                                        )
                                        if state == 319:
                                            return -0.673331976
                                        if state == 320:
                                            return 0.571732759
                                if state == 110:
                                    return -0.714575291
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 79.7722931)
                            else 30
                        )
                        if state == 29:
                            state = (
                                57
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.2504997)
                                else 58
                            )
                            if state == 57:
                                state = 111 if x["sgscore1_med"] < 0.881308019 else 112
                                if state == 111:
                                    state = (
                                        197
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.5390015)
                                        else 198
                                    )
                                    if state == 197:
                                        state = (
                                            321
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.9452496)
                                            else 322
                                        )
                                        if state == 321:
                                            return 0.656211495
                                        if state == 322:
                                            state = (
                                                483
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.3058319)
                                                else 484
                                            )
                                            if state == 483:
                                                return 0.418664843
                                            if state == 484:
                                                return -0.252000004
                                    if state == 198:
                                        state = (
                                            323
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.9995003)
                                            else 324
                                        )
                                        if state == 323:
                                            return -0.651450038
                                        if state == 324:
                                            state = (
                                                485
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6350899)
                                                else 486
                                            )
                                            if state == 485:
                                                return 0.289490968
                                            if state == 486:
                                                state = (
                                                    661
                                                    if x["neargaia_med"] < 32.6743546
                                                    else 662
                                                )
                                                if state == 661:
                                                    return -0.588
                                                if state == 662:
                                                    return 0.289490968
                                if state == 112:
                                    state = (
                                        199
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.8759499)
                                        else 200
                                    )
                                    if state == 199:
                                        return 0.625603735
                                    if state == 200:
                                        state = (
                                            325
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.6830006)
                                            else 326
                                        )
                                        if state == 325:
                                            return -0.420000017
                                        if state == 326:
                                            state = (
                                                487
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6213493)
                                                else 488
                                            )
                                            if state == 487:
                                                return -0.377999991
                                            if state == 488:
                                                return 0.53889519
                            if state == 58:
                                state = (
                                    113
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.444018006)
                                    else 114
                                )
                                if state == 113:
                                    state = (
                                        201
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.6360512)
                                        else 202
                                    )
                                    if state == 201:
                                        state = (
                                            327
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.3375015)
                                            else 328
                                        )
                                        if state == 327:
                                            state = (
                                                489
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.3337803)
                                                else 490
                                            )
                                            if state == 489:
                                                return 0.651079714
                                            if state == 490:
                                                return 0.149760351
                                        if state == 328:
                                            state = (
                                                491
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.5817986)
                                                else 492
                                            )
                                            if state == 491:
                                                state = (
                                                    663
                                                    if x["neargaia_med"] < 35.3247337
                                                    else 664
                                                )
                                                if state == 663:
                                                    state = (
                                                        837
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.6064987)
                                                        else 838
                                                    )
                                                    if state == 837:
                                                        state = (
                                                            1027
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.4187508
                                                            )
                                                            else 1028
                                                        )
                                                        if state == 1027:
                                                            return -0.252000004
                                                        if state == 1028:
                                                            return 0.418664843
                                                    if state == 838:
                                                        return -0.252000004
                                                if state == 664:
                                                    return 0.527071834
                                            if state == 492:
                                                state = (
                                                    665
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 7.69851017)
                                                    else 666
                                                )
                                                if state == 665:
                                                    return -0.540000021
                                                if state == 666:
                                                    return 0.300778478
                                    if state == 202:
                                        state = (
                                            329
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.5535011)
                                            else 330
                                        )
                                        if state == 329:
                                            return -0.588
                                        if state == 330:
                                            return 0.289490968
                                if state == 114:
                                    return 0.742845237
                        if state == 30:
                            state = (
                                59
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.4619999)
                                else 60
                            )
                            if state == 59:
                                state = 115 if x["sgscore1_med"] < 0.0460416973 else 116
                                if state == 115:
                                    state = (
                                        203
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.0776501)
                                        else 204
                                    )
                                    if state == 203:
                                        state = (
                                            331
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.6707497)
                                            else 332
                                        )
                                        if state == 331:
                                            return -0.324000001
                                        if state == 332:
                                            state = (
                                                493
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.9422283)
                                                else 494
                                            )
                                            if state == 493:
                                                return 0.571732759
                                            if state == 494:
                                                state = (
                                                    667
                                                    if x["neargaia_med"] < 18.9780807
                                                    else 668
                                                )
                                                if state == 667:
                                                    return -0.453600019
                                                if state == 668:
                                                    return 0.289490968
                                    if state == 204:
                                        state = (
                                            333
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.1345005)
                                            else 334
                                        )
                                        if state == 333:
                                            return -0.624521732
                                        if state == 334:
                                            return 0.149760351
                                if state == 116:
                                    state = (
                                        205
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.5148735)
                                        else 206
                                    )
                                    if state == 205:
                                        return 0.289490968
                                    if state == 206:
                                        return -0.716727257
                            if state == 60:
                                state = (
                                    117
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.28470239)
                                    else 118
                                )
                                if state == 117:
                                    state = (
                                        207
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.7638512)
                                        else 208
                                    )
                                    if state == 207:
                                        state = (
                                            335
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 21.9884987)
                                            else 336
                                        )
                                        if state == 335:
                                            return -0.324000001
                                        if state == 336:
                                            return 0.491816014
                                    if state == 208:
                                        state = (
                                            337
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.5914993)
                                            else 338
                                        )
                                        if state == 337:
                                            return 0.289490968
                                        if state == 338:
                                            return -0.453600019
                                if state == 118:
                                    state = (
                                        209
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.1477013)
                                        else 210
                                    )
                                    if state == 209:
                                        return 0.706499517
                                    if state == 210:
                                        return -0.252000004
    elif num_booster == 1:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.2333336) else 2
            if state == 1:
                state = 3 if x["mag_peak"] < 18.571516 else 4
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 9.90106487) else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.268714905)
                            else 16
                        )
                        if state == 15:
                            state = 31 if x["mag_peak"] < 18.4763298 else 32
                            if state == 31:
                                state = (
                                    57
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 15.2294083)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        95
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 14.6183691)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            149
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.8018494)
                                            else 150
                                        )
                                        if state == 149:
                                            return -0.205231279
                                        if state == 150:
                                            return 0.213186949
                                    if state == 96:
                                        return 0.298246086
                                if state == 58:
                                    state = 97 if x["maggaia_med"] < 16.2583447 else 98
                                    if state == 97:
                                        state = (
                                            151
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 16.7468491)
                                            else 152
                                        )
                                        if state == 151:
                                            return 0.202201501
                                        if state == 152:
                                            return -0.436210066
                                    if state == 98:
                                        return -0.638072968
                            if state == 32:
                                state = 59 if x["maggaia_med"] < 31.1499329 else 60
                                if state == 59:
                                    return -0.309020877
                                if state == 60:
                                    return 0.22112149
                        if state == 16:
                            state = 33 if x["mag_peak"] < 17.6328487 else 34
                            if state == 33:
                                return -0.391951621
                            if state == 34:
                                return 0.357826382
                    if state == 8:
                        state = 17 if x["col_peak"] < -0.341485977 else 18
                        if state == 17:
                            state = 35 if x["mag_peak"] < 18.4236336 else 36
                            if state == 35:
                                state = (
                                    61
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.2473602)
                                    else 62
                                )
                                if state == 61:
                                    return -0.548644722
                                if state == 62:
                                    state = 99 if x["maggaia_med"] < 18.4987164 else 100
                                    if state == 99:
                                        return 0.422576636
                                    if state == 100:
                                        state = (
                                            153
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.1947002)
                                            else 154
                                        )
                                        if state == 153:
                                            state = (
                                                233
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 6.47964668)
                                                else 234
                                            )
                                            if state == 233:
                                                return -0.258982301
                                            if state == 234:
                                                return 0.236952111
                                        if state == 154:
                                            return -0.502481043
                            if state == 36:
                                return -0.604144633
                        if state == 18:
                            state = 37 if x["mag_peak"] < 18.2444611 else 38
                            if state == 37:
                                state = 63 if x["maggaia_med"] < 15.6147394 else 64
                                if state == 63:
                                    state = 101 if x["maggaia_med"] < 15.472537 else 102
                                    if state == 101:
                                        state = (
                                            155
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.7807007)
                                            else 156
                                        )
                                        if state == 155:
                                            state = (
                                                235
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 7.0190506)
                                                else 236
                                            )
                                            if state == 235:
                                                state = (
                                                    331
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 16.8755302)
                                                    else 332
                                                )
                                                if state == 331:
                                                    state = (
                                                        449
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 16.8066502)
                                                        else 450
                                                    )
                                                    if state == 449:
                                                        return -0.553926945
                                                    if state == 450:
                                                        return 0.453492343
                                                if state == 332:
                                                    return -0.53355664
                                            if state == 236:
                                                state = (
                                                    333
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 18.5869999)
                                                    else 334
                                                )
                                                if state == 333:
                                                    return 0.413555682
                                                if state == 334:
                                                    return -0.645955145
                                        if state == 156:
                                            state = (
                                                237
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.99403954)
                                                else 238
                                            )
                                            if state == 237:
                                                state = (
                                                    335
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.4313011)
                                                    else 336
                                                )
                                                if state == 335:
                                                    return -0.421745896
                                                if state == 336:
                                                    return 0.511759579
                                            if state == 238:
                                                return 0.558029592
                                    if state == 102:
                                        return -0.602195442
                                if state == 64:
                                    state = (
                                        103 if x["maggaia_med"] < 17.3352966 else 104
                                    )
                                    if state == 103:
                                        state = (
                                            157
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.0800514)
                                            else 158
                                        )
                                        if state == 157:
                                            state = (
                                                239
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 8.93132496)
                                                else 240
                                            )
                                            if state == 239:
                                                state = (
                                                    337
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 18.9846039)
                                                    else 338
                                                )
                                                if state == 337:
                                                    state = (
                                                        451
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.3013)
                                                        else 452
                                                    )
                                                    if state == 451:
                                                        state = (
                                                            565
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.574202895
                                                            )
                                                            else 566
                                                        )
                                                        if state == 565:
                                                            return -0.024475595
                                                        if state == 566:
                                                            return 0.490420967
                                                    if state == 452:
                                                        state = (
                                                            567
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.324803889
                                                            )
                                                            else 568
                                                        )
                                                        if state == 567:
                                                            return -0.44095856
                                                        if state == 568:
                                                            return 0.341385633
                                                if state == 338:
                                                    return -0.508733869
                                            if state == 240:
                                                return -0.5041399
                                        if state == 158:
                                            state = (
                                                241
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.499878466)
                                                else 242
                                            )
                                            if state == 241:
                                                state = (
                                                    339
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.2651997)
                                                    else 340
                                                )
                                                if state == 339:
                                                    state = (
                                                        453
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.2261009)
                                                        else 454
                                                    )
                                                    if state == 453:
                                                        return 0.302798122
                                                    if state == 454:
                                                        return -0.496724606
                                                if state == 340:
                                                    return 0.4783943
                                            if state == 242:
                                                state = (
                                                    341
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.3125)
                                                    else 342
                                                )
                                                if state == 341:
                                                    state = (
                                                        455
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.1419487)
                                                        else 456
                                                    )
                                                    if state == 455:
                                                        state = (
                                                            569
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.243419886
                                                            )
                                                            else 570
                                                        )
                                                        if state == 569:
                                                            return -0.46699357
                                                        if state == 570:
                                                            return 0.530349851
                                                    if state == 456:
                                                        return -0.383316517
                                                if state == 342:
                                                    return 0.563192844
                                    if state == 104:
                                        state = (
                                            159
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.2032471)
                                            else 160
                                        )
                                        if state == 159:
                                            state = (
                                                243
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 3.49553251)
                                                else 244
                                            )
                                            if state == 243:
                                                state = (
                                                    343
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 16.1934357)
                                                    else 344
                                                )
                                                if state == 343:
                                                    return 0.493492573
                                                if state == 344:
                                                    state = (
                                                        457
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 16.6689491)
                                                        else 458
                                                    )
                                                    if state == 457:
                                                        return -0.669749022
                                                    if state == 458:
                                                        state = (
                                                            571
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 7.33066845
                                                            )
                                                            else 572
                                                        )
                                                        if state == 571:
                                                            return -0.550314724
                                                        if state == 572:
                                                            return 0.33470583
                                            if state == 244:
                                                state = (
                                                    345
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 16.0355091)
                                                    else 346
                                                )
                                                if state == 345:
                                                    return -0.227555469
                                                if state == 346:
                                                    state = (
                                                        459
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 16.7952995)
                                                        else 460
                                                    )
                                                    if state == 459:
                                                        state = (
                                                            573
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 5.99390697
                                                            )
                                                            else 574
                                                        )
                                                        if state == 573:
                                                            return 0.543232381
                                                        if state == 574:
                                                            return -0.519365191
                                                    if state == 460:
                                                        state = (
                                                            575
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 6.91101456
                                                            )
                                                            else 576
                                                        )
                                                        if state == 575:
                                                            return 0.43215552
                                                        if state == 576:
                                                            return -0.384831488
                                        if state == 160:
                                            state = (
                                                245
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.00045714993)
                                                else 246
                                            )
                                            if state == 245:
                                                state = (
                                                    347
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 18.1815987)
                                                    else 348
                                                )
                                                if state == 347:
                                                    return 0.203282088
                                                if state == 348:
                                                    return -0.467288703
                                            if state == 246:
                                                state = (
                                                    349
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 18.2961006)
                                                    else 350
                                                )
                                                if state == 349:
                                                    state = (
                                                        461
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.2839012)
                                                        else 462
                                                    )
                                                    if state == 461:
                                                        state = (
                                                            577
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.349509299
                                                            )
                                                            else 578
                                                        )
                                                        if state == 577:
                                                            return -0.407608926
                                                        if state == 578:
                                                            return 0.511157334
                                                    if state == 462:
                                                        return -0.479352564
                                                if state == 350:
                                                    return 0.537296712
                            if state == 38:
                                state = 65 if x["maggaia_med"] < 17.4241257 else 66
                                if state == 65:
                                    state = (
                                        105 if x["maggaia_med"] < 16.7895546 else 106
                                    )
                                    if state == 105:
                                        state = (
                                            161
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.5664501)
                                            else 162
                                        )
                                        if state == 161:
                                            state = (
                                                247
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.96112275)
                                                else 248
                                            )
                                            if state == 247:
                                                return -0.479705483
                                            if state == 248:
                                                state = (
                                                    351
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.3773499)
                                                    else 352
                                                )
                                                if state == 351:
                                                    state = (
                                                        463
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.8003006)
                                                        else 464
                                                    )
                                                    if state == 463:
                                                        return -0.265490919
                                                    if state == 464:
                                                        state = (
                                                            579
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.511464536
                                                            )
                                                            else 580
                                                        )
                                                        if state == 579:
                                                            return -0.404787868
                                                        if state == 580:
                                                            return 0.462930173
                                                if state == 352:
                                                    return -0.402441323
                                        if state == 162:
                                            state = (
                                                249
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.99534726)
                                                else 250
                                            )
                                            if state == 249:
                                                state = (
                                                    353
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.5335007)
                                                    else 354
                                                )
                                                if state == 353:
                                                    state = (
                                                        465
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.7813168)
                                                        else 466
                                                    )
                                                    if state == 465:
                                                        return -0.306659639
                                                    if state == 466:
                                                        state = (
                                                            581
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.11988282
                                                            )
                                                            else 582
                                                        )
                                                        if state == 581:
                                                            return 0.0507842675
                                                        if state == 582:
                                                            return 0.510800242
                                                if state == 354:
                                                    return -0.495748878
                                            if state == 250:
                                                return 0.513550937
                                    if state == 106:
                                        state = (
                                            163
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.8470497)
                                            else 164
                                        )
                                        if state == 163:
                                            return -0.561661959
                                        if state == 164:
                                            state = (
                                                251
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.96125555)
                                                else 252
                                            )
                                            if state == 251:
                                                state = (
                                                    355
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.2322998)
                                                    else 356
                                                )
                                                if state == 355:
                                                    state = (
                                                        467
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.8606987)
                                                        else 468
                                                    )
                                                    if state == 467:
                                                        return 0.475804001
                                                    if state == 468:
                                                        return -0.444954723
                                                if state == 356:
                                                    return 0.522115052
                                            if state == 252:
                                                return -0.476377547
                                if state == 66:
                                    state = (
                                        107 if x["maggaia_med"] < 17.8799133 else 108
                                    )
                                    if state == 107:
                                        state = (
                                            165
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.2784252)
                                            else 166
                                        )
                                        if state == 165:
                                            return 0.477640241
                                        if state == 166:
                                            state = (
                                                253
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 4.46563053)
                                                else 254
                                            )
                                            if state == 253:
                                                state = (
                                                    357
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.8667507)
                                                    else 358
                                                )
                                                if state == 357:
                                                    state = (
                                                        469
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.4843502)
                                                        else 470
                                                    )
                                                    if state == 469:
                                                        state = (
                                                            583
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.76925969
                                                            )
                                                            else 584
                                                        )
                                                        if state == 583:
                                                            return -0.173706248
                                                        if state == 584:
                                                            return 0.299784303
                                                    if state == 470:
                                                        return -0.440174222
                                                if state == 358:
                                                    return 0.504532635
                                            if state == 254:
                                                return -0.527538776
                                    if state == 108:
                                        state = (
                                            167
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.419651)
                                            else 168
                                        )
                                        if state == 167:
                                            return -0.489314914
                                        if state == 168:
                                            state = (
                                                255
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0480150506)
                                                else 256
                                            )
                                            if state == 255:
                                                state = (
                                                    359
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.6827011)
                                                    else 360
                                                )
                                                if state == 359:
                                                    state = (
                                                        471
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.7013512)
                                                        else 472
                                                    )
                                                    if state == 471:
                                                        return -0.488817692
                                                    if state == 472:
                                                        state = (
                                                            585
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.340728492
                                                            )
                                                            else 586
                                                        )
                                                        if state == 585:
                                                            return -0.39181754
                                                        if state == 586:
                                                            return 0.242882207
                                                if state == 360:
                                                    return 0.505027592
                                            if state == 256:
                                                state = (
                                                    361
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.5115929)
                                                    else 362
                                                )
                                                if state == 361:
                                                    state = (
                                                        473
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.4813499)
                                                        else 474
                                                    )
                                                    if state == 473:
                                                        state = (
                                                            587
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.938137352
                                                            )
                                                            else 588
                                                        )
                                                        if state == 587:
                                                            return 0.282228053
                                                        if state == 588:
                                                            return 0.54210037
                                                    if state == 474:
                                                        state = (
                                                            589
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.541957617
                                                            )
                                                            else 590
                                                        )
                                                        if state == 589:
                                                            return 0.451600701
                                                        if state == 590:
                                                            return -0.756084621
                                                if state == 362:
                                                    state = (
                                                        475
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.0142002)
                                                        else 476
                                                    )
                                                    if state == 475:
                                                        state = (
                                                            591
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.239230886
                                                            )
                                                            else 592
                                                        )
                                                        if state == 591:
                                                            return 0.118960641
                                                        if state == 592:
                                                            return 0.573095918
                                                    if state == 476:
                                                        state = (
                                                            593
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.296631873
                                                            )
                                                            else 594
                                                        )
                                                        if state == 593:
                                                            return -0.464016378
                                                        if state == 594:
                                                            return 0.513529599
                if state == 4:
                    state = 9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 31.0439301) else 10
                    if state == 9:
                        state = 19 if x["col_peak"] < -0.250221252 else 20
                        if state == 19:
                            state = 39 if x["mag_peak"] < 18.6538715 else 40
                            if state == 39:
                                state = 67 if x["maggaia_med"] < 19.6995888 else 68
                                if state == 67:
                                    return 0.39768824
                                if state == 68:
                                    return -0.385524064
                            if state == 40:
                                return -0.726955891
                        if state == 20:
                            state = 41 if x["mag_peak"] < 18.5755768 else 42
                            if state == 41:
                                return -0.511218607
                            if state == 42:
                                state = 69 if x["maggaia_med"] < 18.5135651 else 70
                                if state == 69:
                                    state = (
                                        109 if x["maggaia_med"] < 14.1976433 else 110
                                    )
                                    if state == 109:
                                        state = (
                                            169
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.6517506)
                                            else 170
                                        )
                                        if state == 169:
                                            state = (
                                                257
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.96148157)
                                                else 258
                                            )
                                            if state == 257:
                                                return -0.309523702
                                            if state == 258:
                                                state = (
                                                    363
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.2136497)
                                                    else 364
                                                )
                                                if state == 363:
                                                    return 0.391386658
                                                if state == 364:
                                                    state = (
                                                        477
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.5200005)
                                                        else 478
                                                    )
                                                    if state == 477:
                                                        return -0.427333921
                                                    if state == 478:
                                                        return 0.381476641
                                        if state == 170:
                                            return -0.671338379
                                    if state == 110:
                                        state = (
                                            171
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4859009)
                                            else 172
                                        )
                                        if state == 171:
                                            state = (
                                                259
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 7.91921282)
                                                else 260
                                            )
                                            if state == 259:
                                                state = (
                                                    365
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.3516502)
                                                    else 366
                                                )
                                                if state == 365:
                                                    state = (
                                                        479
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.0137997)
                                                        else 480
                                                    )
                                                    if state == 479:
                                                        state = (
                                                            595
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.500080585
                                                            )
                                                            else 596
                                                        )
                                                        if state == 595:
                                                            return 0.0161088705
                                                        if state == 596:
                                                            return 0.448899418
                                                    if state == 480:
                                                        state = (
                                                            597
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.531132519
                                                            )
                                                            else 598
                                                        )
                                                        if state == 597:
                                                            return -0.529757798
                                                        if state == 598:
                                                            return 0.117315933
                                                if state == 366:
                                                    return 0.472046077
                                            if state == 260:
                                                state = (
                                                    367
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 18.9440308)
                                                    else 368
                                                )
                                                if state == 367:
                                                    state = (
                                                        481
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.8172989)
                                                        else 482
                                                    )
                                                    if state == 481:
                                                        state = (
                                                            599
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.13337755
                                                            )
                                                            else 600
                                                        )
                                                        if state == 599:
                                                            return -0.272084147
                                                        if state == 600:
                                                            return 0.402364403
                                                    if state == 482:
                                                        return 0.461678982
                                                if state == 368:
                                                    state = (
                                                        483
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.1427002)
                                                        else 484
                                                    )
                                                    if state == 483:
                                                        return -0.631091893
                                                    if state == 484:
                                                        state = (
                                                            603
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.85118747
                                                            )
                                                            else 604
                                                        )
                                                        if state == 603:
                                                            return 0.159451202
                                                        if state == 604:
                                                            return -0.203665748
                                        if state == 172:
                                            state = (
                                                261
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 4.04726887)
                                                else 262
                                            )
                                            if state == 261:
                                                state = (
                                                    369
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.7206001)
                                                    else 370
                                                )
                                                if state == 369:
                                                    state = (
                                                        485
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.6881008)
                                                        else 486
                                                    )
                                                    if state == 485:
                                                        state = (
                                                            605
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.224142253
                                                            )
                                                            else 606
                                                        )
                                                        if state == 605:
                                                            return 0.447424233
                                                        if state == 606:
                                                            return -0.0627093092
                                                    if state == 486:
                                                        return -0.59272182
                                                if state == 370:
                                                    state = (
                                                        487
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 21.0990505)
                                                        else 488
                                                    )
                                                    if state == 487:
                                                        state = (
                                                            607
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.75535822
                                                            )
                                                            else 608
                                                        )
                                                        if state == 607:
                                                            return 0.439610779
                                                        if state == 608:
                                                            return -0.155711725
                                                    if state == 488:
                                                        return 0.526906848
                                            if state == 262:
                                                state = (
                                                    371
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.6077003)
                                                    else 372
                                                )
                                                if state == 371:
                                                    return -0.808628917
                                                if state == 372:
                                                    state = (
                                                        489
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.6495018)
                                                        else 490
                                                    )
                                                    if state == 489:
                                                        return 0.388921738
                                                    if state == 490:
                                                        return -0.703304827
                                if state == 70:
                                    state = (
                                        111
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 20.647541)
                                        else 112
                                    )
                                    if state == 111:
                                        state = (
                                            173
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.21035)
                                            else 174
                                        )
                                        if state == 173:
                                            state = (
                                                263
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0922395512)
                                                else 264
                                            )
                                            if state == 263:
                                                state = (
                                                    373
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 18.4398994)
                                                    else 374
                                                )
                                                if state == 373:
                                                    state = (
                                                        491
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.0754509)
                                                        else 492
                                                    )
                                                    if state == 491:
                                                        return -0.182885334
                                                    if state == 492:
                                                        return 0.36735481
                                                if state == 374:
                                                    state = (
                                                        493
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.1283798)
                                                        else 494
                                                    )
                                                    if state == 493:
                                                        return -0.590857208
                                                    if state == 494:
                                                        return 0.300395817
                                            if state == 264:
                                                return 0.480321109
                                        if state == 174:
                                            state = (
                                                265
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 3.49091434)
                                                else 266
                                            )
                                            if state == 265:
                                                state = (
                                                    375
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.4017487)
                                                    else 376
                                                )
                                                if state == 375:
                                                    state = (
                                                        495
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.3443985)
                                                        else 496
                                                    )
                                                    if state == 495:
                                                        state = (
                                                            609
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.188443005
                                                            )
                                                            else 610
                                                        )
                                                        if state == 609:
                                                            return 0.507963836
                                                        if state == 610:
                                                            return 0.189684853
                                                    if state == 496:
                                                        state = (
                                                            611
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.76039356
                                                            )
                                                            else 612
                                                        )
                                                        if state == 611:
                                                            return -0.662225902
                                                        if state == 612:
                                                            return 0.233568549
                                                if state == 376:
                                                    state = (
                                                        497
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.6161995)
                                                        else 498
                                                    )
                                                    if state == 497:
                                                        state = (
                                                            613
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.299039632
                                                            )
                                                            else 614
                                                        )
                                                        if state == 613:
                                                            return 0.0829365924
                                                        if state == 614:
                                                            return 0.476499259
                                                    if state == 498:
                                                        state = (
                                                            615
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.01787591
                                                            )
                                                            else 616
                                                        )
                                                        if state == 615:
                                                            return -0.691302776
                                                        if state == 616:
                                                            return 0.368721634
                                            if state == 266:
                                                state = (
                                                    377
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.1296005)
                                                    else 378
                                                )
                                                if state == 377:
                                                    state = (
                                                        499
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.9260807)
                                                        else 500
                                                    )
                                                    if state == 499:
                                                        state = (
                                                            617
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.987725973
                                                            )
                                                            else 618
                                                        )
                                                        if state == 617:
                                                            return 0.165653631
                                                        if state == 618:
                                                            return 0.370572716
                                                    if state == 500:
                                                        state = (
                                                            619
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.27628338
                                                            )
                                                            else 620
                                                        )
                                                        if state == 619:
                                                            return -0.118320212
                                                        if state == 620:
                                                            return -0.549809277
                                                if state == 378:
                                                    state = (
                                                        501
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.2461014)
                                                        else 502
                                                    )
                                                    if state == 501:
                                                        return 0.511312366
                                                    if state == 502:
                                                        state = (
                                                            621
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.7520113
                                                            )
                                                            else 622
                                                        )
                                                        if state == 621:
                                                            return 0.383104861
                                                        if state == 622:
                                                            return -0.263674557
                                    if state == 112:
                                        state = (
                                            175
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.3602829)
                                            else 176
                                        )
                                        if state == 175:
                                            return 0.458269417
                                        if state == 176:
                                            state = (
                                                267
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.97519684)
                                                else 268
                                            )
                                            if state == 267:
                                                state = (
                                                    379
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.5796509)
                                                    else 380
                                                )
                                                if state == 379:
                                                    state = (
                                                        503
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.8872986)
                                                        else 504
                                                    )
                                                    if state == 503:
                                                        state = (
                                                            623
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.11424899
                                                            )
                                                            else 624
                                                        )
                                                        if state == 623:
                                                            return -0.188471913
                                                        if state == 624:
                                                            return 0.295315146
                                                    if state == 504:
                                                        return 0.381428689
                                                if state == 380:
                                                    return -0.50246346
                                            if state == 268:
                                                return -0.615040779
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.231293678)
                            else 22
                        )
                        if state == 21:
                            state = (
                                43
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 18.7059135)
                                else 44
                            )
                            if state == 43:
                                state = 71 if x["maggaia_med"] < 18.515255 else 72
                                if state == 71:
                                    state = (
                                        113 if x["maggaia_med"] < 15.7226524 else 114
                                    )
                                    if state == 113:
                                        state = (
                                            177
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.6379967)
                                            else 178
                                        )
                                        if state == 177:
                                            return -0.536785662
                                        if state == 178:
                                            state = (
                                                269
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 6.91101837)
                                                else 270
                                            )
                                            if state == 269:
                                                return -0.534122646
                                            if state == 270:
                                                return 0.529149055
                                    if state == 114:
                                        state = (
                                            179
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 21.3224487)
                                            else 180
                                        )
                                        if state == 179:
                                            state = (
                                                271
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 3.95845461)
                                                else 272
                                            )
                                            if state == 271:
                                                state = (
                                                    381
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.4659004)
                                                    else 382
                                                )
                                                if state == 381:
                                                    return -0.554309905
                                                if state == 382:
                                                    state = (
                                                        505
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.505249)
                                                        else 506
                                                    )
                                                    if state == 505:
                                                        return 0.41398102
                                                    if state == 506:
                                                        return -0.408174723
                                            if state == 272:
                                                state = (
                                                    383
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.0025005)
                                                    else 384
                                                )
                                                if state == 383:
                                                    state = (
                                                        507
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.0694427)
                                                        else 508
                                                    )
                                                    if state == 507:
                                                        state = (
                                                            625
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.00795412
                                                            )
                                                            else 626
                                                        )
                                                        if state == 625:
                                                            return -0.240292266
                                                        if state == 626:
                                                            return 0.482863098
                                                    if state == 508:
                                                        state = (
                                                            627
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.34752393
                                                            )
                                                            else 628
                                                        )
                                                        if state == 627:
                                                            return -0.417674959
                                                        if state == 628:
                                                            return 0.413207263
                                                if state == 384:
                                                    state = (
                                                        509
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.9797516)
                                                        else 510
                                                    )
                                                    if state == 509:
                                                        state = (
                                                            629
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.713727415
                                                            )
                                                            else 630
                                                        )
                                                        if state == 629:
                                                            return -0.465156645
                                                        if state == 630:
                                                            return 0.516446292
                                                    if state == 510:
                                                        return -0.534891129
                                        if state == 180:
                                            return 0.572950065
                                if state == 72:
                                    state = (
                                        115 if x["maggaia_med"] < 18.9727898 else 116
                                    )
                                    if state == 115:
                                        state = (
                                            181
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.39505)
                                            else 182
                                        )
                                        if state == 181:
                                            state = (
                                                273
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 5.00370979)
                                                else 274
                                            )
                                            if state == 273:
                                                state = (
                                                    385
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.1745491)
                                                    else 386
                                                )
                                                if state == 385:
                                                    return 0.475850642
                                                if state == 386:
                                                    return -0.402792424
                                            if state == 274:
                                                return -0.495174289
                                        if state == 182:
                                            state = (
                                                275
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.498229206)
                                                else 276
                                            )
                                            if state == 275:
                                                return -0.438247919
                                            if state == 276:
                                                return 0.558032393
                                    if state == 116:
                                        state = (
                                            183
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.1803513)
                                            else 184
                                        )
                                        if state == 183:
                                            state = (
                                                277
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 5.95883656)
                                                else 278
                                            )
                                            if state == 277:
                                                state = (
                                                    387
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.7160988)
                                                    else 388
                                                )
                                                if state == 387:
                                                    state = (
                                                        511
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.2822495)
                                                        else 512
                                                    )
                                                    if state == 511:
                                                        state = (
                                                            631
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.260930926
                                                            )
                                                            else 632
                                                        )
                                                        if state == 631:
                                                            return -0.593806386
                                                        if state == 632:
                                                            return -0.1861334
                                                    if state == 512:
                                                        return -0.573385715
                                                if state == 388:
                                                    state = (
                                                        513
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.7259998)
                                                        else 514
                                                    )
                                                    if state == 513:
                                                        return 0.383520573
                                                    if state == 514:
                                                        state = (
                                                            633
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.35240412
                                                            )
                                                            else 634
                                                        )
                                                        if state == 633:
                                                            return -0.545624793
                                                        if state == 634:
                                                            return 0.108875878
                                            if state == 278:
                                                state = (
                                                    389
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.6218491)
                                                    else 390
                                                )
                                                if state == 389:
                                                    state = (
                                                        515
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.4681492)
                                                        else 516
                                                    )
                                                    if state == 515:
                                                        state = (
                                                            635
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.11622977
                                                            )
                                                            else 636
                                                        )
                                                        if state == 635:
                                                            return -0.533672273
                                                        if state == 636:
                                                            return 0.523507476
                                                    if state == 516:
                                                        return 0.476761907
                                                if state == 390:
                                                    return -0.636986017
                                        if state == 184:
                                            state = (
                                                279
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.98116899)
                                                else 280
                                            )
                                            if state == 279:
                                                return -0.641886175
                                            if state == 280:
                                                state = (
                                                    391
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.4501991)
                                                    else 392
                                                )
                                                if state == 391:
                                                    state = (
                                                        517
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.3026772)
                                                        else 518
                                                    )
                                                    if state == 517:
                                                        state = (
                                                            637
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.50983799
                                                            )
                                                            else 638
                                                        )
                                                        if state == 637:
                                                            return -0.448482245
                                                        if state == 638:
                                                            return 0.522435069
                                                    if state == 518:
                                                        return 0.53637886
                                                if state == 392:
                                                    state = (
                                                        519
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.5970001)
                                                        else 520
                                                    )
                                                    if state == 519:
                                                        return -0.59785831
                                                    if state == 520:
                                                        state = (
                                                            639
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.63621032
                                                            )
                                                            else 640
                                                        )
                                                        if state == 639:
                                                            return -0.395348549
                                                        if state == 640:
                                                            return 0.455985487
                            if state == 44:
                                state = (
                                    73
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.1619759)
                                    else 74
                                )
                                if state == 73:
                                    state = (
                                        117
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 16.3512077)
                                        else 118
                                    )
                                    if state == 117:
                                        state = (
                                            185
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.0883007)
                                            else 186
                                        )
                                        if state == 185:
                                            return -0.397101581
                                        if state == 186:
                                            state = (
                                                281
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.49495375)
                                                else 282
                                            )
                                            if state == 281:
                                                return -0.223694116
                                            if state == 282:
                                                state = (
                                                    393
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.8894005)
                                                    else 394
                                                )
                                                if state == 393:
                                                    state = (
                                                        521
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.2822495)
                                                        else 522
                                                    )
                                                    if state == 521:
                                                        return 0.417471439
                                                    if state == 522:
                                                        return -0.296427995
                                                if state == 394:
                                                    return 0.452009201
                                    if state == 118:
                                        state = (
                                            187
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.4562492)
                                            else 188
                                        )
                                        if state == 187:
                                            state = (
                                                283
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 8.00358772)
                                                else 284
                                            )
                                            if state == 283:
                                                return -0.48546654
                                            if state == 284:
                                                return 0.438521981
                                        if state == 188:
                                            return -0.512976885
                                if state == 74:
                                    state = (
                                        119 if x["maggaia_med"] < 19.0169601 else 120
                                    )
                                    if state == 119:
                                        state = (
                                            189
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.7512512)
                                            else 190
                                        )
                                        if state == 189:
                                            return 0.391477048
                                        if state == 190:
                                            return -0.302007556
                                    if state == 120:
                                        return 0.51884073
                        if state == 22:
                            state = 45 if x["mag_peak"] < 18.5903797 else 46
                            if state == 45:
                                return -0.552807152
                            if state == 46:
                                state = 75 if x["maggaia_med"] < 18.8587227 else 76
                                if state == 75:
                                    state = (
                                        121 if x["maggaia_med"] < 15.7702751 else 122
                                    )
                                    if state == 121:
                                        return 0.401003361
                                    if state == 122:
                                        state = (
                                            191
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.9797497)
                                            else 192
                                        )
                                        if state == 191:
                                            state = (
                                                285
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 3.06095481)
                                                else 286
                                            )
                                            if state == 285:
                                                state = (
                                                    395
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.8287506)
                                                    else 396
                                                )
                                                if state == 395:
                                                    return -0.484035671
                                                if state == 396:
                                                    state = (
                                                        523
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.8743496)
                                                        else 524
                                                    )
                                                    if state == 523:
                                                        return 0.20397462
                                                    if state == 524:
                                                        state = (
                                                            641
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.58923012
                                                            )
                                                            else 642
                                                        )
                                                        if state == 641:
                                                            return -0.472951502
                                                        if state == 642:
                                                            return 0.298168421
                                            if state == 286:
                                                state = (
                                                    397
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.6715508)
                                                    else 398
                                                )
                                                if state == 397:
                                                    return 0.400458574
                                                if state == 398:
                                                    return -0.425981253
                                        if state == 192:
                                            return 0.429051399
                                if state == 76:
                                    state = (
                                        123
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 20.0653973)
                                        else 124
                                    )
                                    if state == 123:
                                        state = (
                                            193
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.7477493)
                                            else 194
                                        )
                                        if state == 193:
                                            state = (
                                                287
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 9.96373272)
                                                else 288
                                            )
                                            if state == 287:
                                                state = (
                                                    399
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.2920494)
                                                    else 400
                                                )
                                                if state == 399:
                                                    state = (
                                                        525
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.1606998)
                                                        else 526
                                                    )
                                                    if state == 525:
                                                        return 0.380816907
                                                    if state == 526:
                                                        return -0.251757085
                                                if state == 400:
                                                    return 0.568547845
                                            if state == 288:
                                                return -0.174019143
                                        if state == 194:
                                            state = (
                                                289
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.5027777)
                                                else 290
                                            )
                                            if state == 289:
                                                return -0.224456087
                                            if state == 290:
                                                return 0.30873704
                                    if state == 124:
                                        state = (
                                            195
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4590492)
                                            else 196
                                        )
                                        if state == 195:
                                            return -0.51767838
                                        if state == 196:
                                            return 0.221796557
            if state == 2:
                state = 5 if x["mag_peak"] < 18.9885292 else 6
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 19.9997406) else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.390076637)
                            else 24
                        )
                        if state == 23:
                            state = 47 if x["mag_peak"] < 18.6350994 else 48
                            if state == 47:
                                state = (
                                    77
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 20.2747879)
                                    else 78
                                )
                                if state == 77:
                                    state = (
                                        125 if x["maggaia_med"] < 15.7499914 else 126
                                    )
                                    if state == 125:
                                        state = (
                                            197
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.0155506)
                                            else 198
                                        )
                                        if state == 197:
                                            return -0.329629809
                                        if state == 198:
                                            state = (
                                                291
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 7.95760393)
                                                else 292
                                            )
                                            if state == 291:
                                                state = (
                                                    401
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.4603004)
                                                    else 402
                                                )
                                                if state == 401:
                                                    return 0.305182427
                                                if state == 402:
                                                    return -0.17300573
                                            if state == 292:
                                                return -0.223545894
                                    if state == 126:
                                        state = (
                                            199
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.7155991)
                                            else 200
                                        )
                                        if state == 199:
                                            return -0.598235786
                                        if state == 200:
                                            state = (
                                                293
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 5.45063066)
                                                else 294
                                            )
                                            if state == 293:
                                                return -0.567937315
                                            if state == 294:
                                                state = (
                                                    403
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.3875999)
                                                    else 404
                                                )
                                                if state == 403:
                                                    return 0.379464626
                                                if state == 404:
                                                    return -0.255177945
                                if state == 78:
                                    state = (
                                        127 if x["maggaia_med"] < 20.2861099 else 128
                                    )
                                    if state == 127:
                                        return 0.471200615
                                    if state == 128:
                                        return -0.489459455
                            if state == 48:
                                state = (
                                    79
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.4891968)
                                    else 80
                                )
                                if state == 79:
                                    state = 129 if x["maggaia_med"] < 16.196146 else 130
                                    if state == 129:
                                        state = (
                                            201
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.7617493)
                                            else 202
                                        )
                                        if state == 201:
                                            return 0.355325818
                                        if state == 202:
                                            return -0.324222773
                                    if state == 130:
                                        state = (
                                            203
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.3836498)
                                            else 204
                                        )
                                        if state == 203:
                                            state = (
                                                295
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 3.5599885)
                                                else 296
                                            )
                                            if state == 295:
                                                state = (
                                                    405
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.1159)
                                                    else 406
                                                )
                                                if state == 405:
                                                    return -0.42168808
                                                if state == 406:
                                                    state = (
                                                        527
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.9748001)
                                                        else 528
                                                    )
                                                    if state == 527:
                                                        state = (
                                                            645
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.359709799
                                                            )
                                                            else 646
                                                        )
                                                        if state == 645:
                                                            return -0.262637615
                                                        if state == 646:
                                                            return 0.25497219
                                                    if state == 528:
                                                        return -0.367614836
                                            if state == 296:
                                                return -0.62275219
                                        if state == 204:
                                            return 0.384222031
                                if state == 80:
                                    state = (
                                        131 if x["maggaia_med"] < 18.8566532 else 132
                                    )
                                    if state == 131:
                                        return 0.709331274
                                    if state == 132:
                                        state = (
                                            205
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.5412998)
                                            else 206
                                        )
                                        if state == 205:
                                            state = (
                                                297
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.95079279)
                                                else 298
                                            )
                                            if state == 297:
                                                state = (
                                                    407
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.324543)
                                                    else 408
                                                )
                                                if state == 407:
                                                    return -0.592670739
                                                if state == 408:
                                                    state = (
                                                        529
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.4900017)
                                                        else 530
                                                    )
                                                    if state == 529:
                                                        return 0.209100291
                                                    if state == 530:
                                                        return -0.296965569
                                            if state == 298:
                                                state = (
                                                    409
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.0135612)
                                                    else 410
                                                )
                                                if state == 409:
                                                    state = (
                                                        531
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.1720505)
                                                        else 532
                                                    )
                                                    if state == 531:
                                                        state = (
                                                            647
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.79838991
                                                            )
                                                            else 648
                                                        )
                                                        if state == 647:
                                                            return 0.473481417
                                                        if state == 648:
                                                            return -0.281908303
                                                    if state == 532:
                                                        state = (
                                                            649
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 7.35573483
                                                            )
                                                            else 650
                                                        )
                                                        if state == 649:
                                                            return 0.0966375247
                                                        if state == 650:
                                                            return -0.328090876
                                                if state == 410:
                                                    return 0.820794225
                                        if state == 206:
                                            state = (
                                                299
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 3.53289938)
                                                else 300
                                            )
                                            if state == 299:
                                                state = (
                                                    411
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.78685)
                                                    else 412
                                                )
                                                if state == 411:
                                                    return -0.325662494
                                                if state == 412:
                                                    return 0.329948664
                                            if state == 300:
                                                return -0.378042072
                        if state == 24:
                            state = 49 if x["mag_peak"] < 18.9417801 else 50
                            if state == 49:
                                state = (
                                    81
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.2617722)
                                    else 82
                                )
                                if state == 81:
                                    return 0.640182018
                                if state == 82:
                                    state = (
                                        133 if x["maggaia_med"] < 18.8479424 else 134
                                    )
                                    if state == 133:
                                        return -0.314412057
                                    if state == 134:
                                        return 0.525869966
                            if state == 50:
                                state = 83 if x["maggaia_med"] < 18.6746254 else 84
                                if state == 83:
                                    return 0.401266575
                                if state == 84:
                                    return -0.34025988
                    if state == 12:
                        state = 25 if x["col_peak"] < -0.46622467 else 26
                        if state == 25:
                            return -0.534476995
                        if state == 26:
                            state = 51 if x["mag_peak"] < 18.8004799 else 52
                            if state == 51:
                                state = (
                                    85
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 17.8212318)
                                    else 86
                                )
                                if state == 85:
                                    state = (
                                        135
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 17.5747604)
                                        else 136
                                    )
                                    if state == 135:
                                        state = (
                                            207
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 21.1697006)
                                            else 208
                                        )
                                        if state == 207:
                                            state = (
                                                301
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 9.94155121)
                                                else 302
                                            )
                                            if state == 301:
                                                state = (
                                                    413
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.8254509)
                                                    else 414
                                                )
                                                if state == 413:
                                                    state = (
                                                        533
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.7671013)
                                                        else 534
                                                    )
                                                    if state == 533:
                                                        state = (
                                                            651
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.418903768
                                                            )
                                                            else 652
                                                        )
                                                        if state == 651:
                                                            return 0.223381132
                                                        if state == 652:
                                                            return 0.537921309
                                                    if state == 534:
                                                        state = (
                                                            653
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.37124491
                                                            )
                                                            else 654
                                                        )
                                                        if state == 653:
                                                            return -0.217146248
                                                        if state == 654:
                                                            return 0.525838554
                                                if state == 414:
                                                    state = (
                                                        535
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.1465988)
                                                        else 536
                                                    )
                                                    if state == 535:
                                                        state = (
                                                            655
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 9.43604946
                                                            )
                                                            else 656
                                                        )
                                                        if state == 655:
                                                            return 0.783878207
                                                        if state == 656:
                                                            return -0.17300573
                                                    if state == 536:
                                                        state = (
                                                            657
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.94465685
                                                            )
                                                            else 658
                                                        )
                                                        if state == 657:
                                                            return 0.259752244
                                                        if state == 658:
                                                            return 0.557567477
                                            if state == 302:
                                                state = (
                                                    415
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 18.4911995)
                                                    else 416
                                                )
                                                if state == 415:
                                                    state = (
                                                        537
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.0953007)
                                                        else 538
                                                    )
                                                    if state == 537:
                                                        return -0.384312332
                                                    if state == 538:
                                                        return 0.54003495
                                                if state == 416:
                                                    return -0.76686424
                                        if state == 208:
                                            return -0.462363392
                                    if state == 136:
                                        state = (
                                            209
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.2807007)
                                            else 210
                                        )
                                        if state == 209:
                                            return 0.526428938
                                        if state == 210:
                                            state = (
                                                303
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0174652506)
                                                else 304
                                            )
                                            if state == 303:
                                                return -0.455541074
                                            if state == 304:
                                                state = (
                                                    417
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.9053993)
                                                    else 418
                                                )
                                                if state == 417:
                                                    state = (
                                                        539
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.6259003)
                                                        else 540
                                                    )
                                                    if state == 539:
                                                        state = (
                                                            659
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.31361389
                                                            )
                                                            else 660
                                                        )
                                                        if state == 659:
                                                            return -0.416264802
                                                        if state == 660:
                                                            return 0.501748681
                                                    if state == 540:
                                                        state = (
                                                            661
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.561546147
                                                            )
                                                            else 662
                                                        )
                                                        if state == 661:
                                                            return -0.461685866
                                                        if state == 662:
                                                            return 0.213005692
                                                if state == 418:
                                                    state = (
                                                        541
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.2549496)
                                                        else 542
                                                    )
                                                    if state == 541:
                                                        state = (
                                                            663
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.31757212
                                                            )
                                                            else 664
                                                        )
                                                        if state == 663:
                                                            return -0.306357116
                                                        if state == 664:
                                                            return 0.511769474
                                                    if state == 542:
                                                        return 0.543109417
                                if state == 86:
                                    state = (
                                        137 if x["maggaia_med"] < 19.3716755 else 138
                                    )
                                    if state == 137:
                                        state = (
                                            211
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.8537006)
                                            else 212
                                        )
                                        if state == 211:
                                            state = (
                                                305
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 9.96636581)
                                                else 306
                                            )
                                            if state == 305:
                                                state = (
                                                    419
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.8250275)
                                                    else 420
                                                )
                                                if state == 419:
                                                    state = (
                                                        543
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 17.8069992)
                                                        else 544
                                                    )
                                                    if state == 543:
                                                        state = (
                                                            665
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 7.12121868
                                                            )
                                                            else 666
                                                        )
                                                        if state == 665:
                                                            return 0.452426851
                                                        if state == 666:
                                                            return -0.341933042
                                                    if state == 544:
                                                        state = (
                                                            667
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.284626663
                                                            )
                                                            else 668
                                                        )
                                                        if state == 667:
                                                            return 0.0319136307
                                                        if state == 668:
                                                            return 0.558248997
                                                if state == 420:
                                                    return -0.438190132
                                            if state == 306:
                                                return -0.433728427
                                        if state == 212:
                                            state = (
                                                307
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0301677994)
                                                else 308
                                            )
                                            if state == 307:
                                                state = (
                                                    421
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.1069489)
                                                    else 422
                                                )
                                                if state == 421:
                                                    return 0.397455931
                                                if state == 422:
                                                    state = (
                                                        545
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.4059486)
                                                        else 546
                                                    )
                                                    if state == 545:
                                                        return -0.225101829
                                                    if state == 546:
                                                        return 0.232484445
                                            if state == 308:
                                                return 0.663798571
                                    if state == 138:
                                        state = (
                                            213
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.9653511)
                                            else 214
                                        )
                                        if state == 213:
                                            state = (
                                                309
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.636678278)
                                                else 310
                                            )
                                            if state == 309:
                                                state = (
                                                    423
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.3343506)
                                                    else 424
                                                )
                                                if state == 423:
                                                    state = (
                                                        547
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.974987)
                                                        else 548
                                                    )
                                                    if state == 547:
                                                        return -0.506102085
                                                    if state == 548:
                                                        return 0.437198222
                                                if state == 424:
                                                    return -0.621865153
                                            if state == 310:
                                                state = (
                                                    425
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.9277496)
                                                    else 426
                                                )
                                                if state == 425:
                                                    state = (
                                                        549
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 17.1935005)
                                                        else 550
                                                    )
                                                    if state == 549:
                                                        state = (
                                                            669
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.75447834
                                                            )
                                                            else 670
                                                        )
                                                        if state == 669:
                                                            return 0.214125708
                                                        if state == 670:
                                                            return -0.216689035
                                                    if state == 550:
                                                        state = (
                                                            671
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.745646596
                                                            )
                                                            else 672
                                                        )
                                                        if state == 671:
                                                            return 0.324416578
                                                        if state == 672:
                                                            return 0.537332952
                                                if state == 426:
                                                    return -0.625766814
                                        if state == 214:
                                            state = (
                                                311
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 9.06408501)
                                                else 312
                                            )
                                            if state == 311:
                                                state = (
                                                    427
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.2759514)
                                                    else 428
                                                )
                                                if state == 427:
                                                    return 0.702635348
                                                if state == 428:
                                                    state = (
                                                        551
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.3115768)
                                                        else 552
                                                    )
                                                    if state == 551:
                                                        state = (
                                                            673
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.692004323
                                                            )
                                                            else 674
                                                        )
                                                        if state == 673:
                                                            return -0.337578386
                                                        if state == 674:
                                                            return 0.304717779
                                                    if state == 552:
                                                        state = (
                                                            675
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.43270278
                                                            )
                                                            else 676
                                                        )
                                                        if state == 675:
                                                            return -0.460861027
                                                        if state == 676:
                                                            return 0.663084984
                                            if state == 312:
                                                return -0.435130715
                            if state == 52:
                                state = (
                                    87
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 14.9478512)
                                    else 88
                                )
                                if state == 87:
                                    state = (
                                        139 if x["maggaia_med"] < 11.9356356 else 140
                                    )
                                    if state == 139:
                                        state = (
                                            215
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.9963989)
                                            else 216
                                        )
                                        if state == 215:
                                            return 0.301952392
                                        if state == 216:
                                            return -0.221524268
                                    if state == 140:
                                        state = (
                                            217
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.3033504)
                                            else 218
                                        )
                                        if state == 217:
                                            state = (
                                                313
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 5.90653324)
                                                else 314
                                            )
                                            if state == 313:
                                                state = (
                                                    429
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.0662003)
                                                    else 430
                                                )
                                                if state == 429:
                                                    return -0.432783991
                                                if state == 430:
                                                    return 0.469032764
                                            if state == 314:
                                                return -0.454256922
                                        if state == 218:
                                            state = (
                                                315
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 8.50903893)
                                                else 316
                                            )
                                            if state == 315:
                                                return -0.588909626
                                            if state == 316:
                                                state = (
                                                    431
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.6054993)
                                                    else 432
                                                )
                                                if state == 431:
                                                    return -0.467472821
                                                if state == 432:
                                                    return 0.451239467
                                if state == 88:
                                    state = (
                                        141 if x["maggaia_med"] < 17.7194023 else 142
                                    )
                                    if state == 141:
                                        state = (
                                            219
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.2432499)
                                            else 220
                                        )
                                        if state == 219:
                                            state = (
                                                317
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 4.49030113)
                                                else 318
                                            )
                                            if state == 317:
                                                state = (
                                                    433
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.0519104)
                                                    else 434
                                                )
                                                if state == 433:
                                                    return -0.26184541
                                                if state == 434:
                                                    return 0.537361741
                                            if state == 318:
                                                state = (
                                                    435
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.0454998)
                                                    else 436
                                                )
                                                if state == 435:
                                                    return -0.395812482
                                                if state == 436:
                                                    return 0.297332138
                                        if state == 220:
                                            state = (
                                                319
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0385300517)
                                                else 320
                                            )
                                            if state == 319:
                                                return 0.536594868
                                            if state == 320:
                                                state = (
                                                    437
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.5149994)
                                                    else 438
                                                )
                                                if state == 437:
                                                    return -0.505632937
                                                if state == 438:
                                                    state = (
                                                        553
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.846199)
                                                        else 554
                                                    )
                                                    if state == 553:
                                                        state = (
                                                            677
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.574182749
                                                            )
                                                            else 678
                                                        )
                                                        if state == 677:
                                                            return -0.360532314
                                                        if state == 678:
                                                            return 0.393805891
                                                    if state == 554:
                                                        state = (
                                                            679
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.820315
                                                            )
                                                            else 680
                                                        )
                                                        if state == 679:
                                                            return -0.51635474
                                                        if state == 680:
                                                            return -0.0981966406
                                    if state == 142:
                                        state = (
                                            221
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.6256504)
                                            else 222
                                        )
                                        if state == 221:
                                            state = (
                                                321
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0222858489)
                                                else 322
                                            )
                                            if state == 321:
                                                return -0.59740603
                                            if state == 322:
                                                state = (
                                                    439
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.3754997)
                                                    else 440
                                                )
                                                if state == 439:
                                                    state = (
                                                        555
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.2766991)
                                                        else 556
                                                    )
                                                    if state == 555:
                                                        return 0.535981297
                                                    if state == 556:
                                                        state = (
                                                            681
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.908984721
                                                            )
                                                            else 682
                                                        )
                                                        if state == 681:
                                                            return -0.127266884
                                                        if state == 682:
                                                            return 0.437937975
                                                if state == 440:
                                                    state = (
                                                        557
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.5413017)
                                                        else 558
                                                    )
                                                    if state == 557:
                                                        state = (
                                                            683
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.17788649
                                                            )
                                                            else 684
                                                        )
                                                        if state == 683:
                                                            return 0.761080921
                                                        if state == 684:
                                                            return 0.045380041
                                                    if state == 558:
                                                        state = (
                                                            685
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.720013142
                                                            )
                                                            else 686
                                                        )
                                                        if state == 685:
                                                            return -0.426884949
                                                        if state == 686:
                                                            return 0.503402233
                                        if state == 222:
                                            state = (
                                                323
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0181134492)
                                                else 324
                                            )
                                            if state == 323:
                                                return 0.626829803
                                            if state == 324:
                                                return -0.561396778
                if state == 6:
                    state = 13 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.0034318) else 14
                    if state == 13:
                        state = 27 if x["col_peak"] < 0.000001 else 28
                        if state == 27:
                            return -0.312185735
                        if state == 28:
                            return -0.144023731
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["col_peak"]) or (x["col_peak"] < 1.01621151)
                            else 30
                        )
                        if state == 29:
                            state = 53 if x["mag_peak"] < 19.0330086 else 54
                            if state == 53:
                                state = 89 if x["maggaia_med"] < 41.5566101 else 90
                                if state == 89:
                                    state = (
                                        143 if x["maggaia_med"] < 18.7353973 else 144
                                    )
                                    if state == 143:
                                        state = (
                                            223
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.16325)
                                            else 224
                                        )
                                        if state == 223:
                                            state = (
                                                325
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.05575216)
                                                else 326
                                            )
                                            if state == 325:
                                                state = (
                                                    441
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.9813995)
                                                    else 442
                                                )
                                                if state == 441:
                                                    state = (
                                                        559
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.565691)
                                                        else 560
                                                    )
                                                    if state == 559:
                                                        state = (
                                                            687
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.21580195
                                                            )
                                                            else 688
                                                        )
                                                        if state == 687:
                                                            return -0.264025271
                                                        if state == 688:
                                                            return 0.355370164
                                                    if state == 560:
                                                        return -0.341699451
                                                if state == 442:
                                                    return 0.585747778
                                            if state == 326:
                                                state = (
                                                    443
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.7691498)
                                                    else 444
                                                )
                                                if state == 443:
                                                    return -0.642482877
                                                if state == 444:
                                                    state = (
                                                        561
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.828701)
                                                        else 562
                                                    )
                                                    if state == 561:
                                                        return 0.546046674
                                                    if state == 562:
                                                        return -0.530564189
                                        if state == 224:
                                            return -0.562763274
                                    if state == 144:
                                        return -0.648854196
                                if state == 90:
                                    return 0.634798527
                            if state == 54:
                                state = (
                                    91
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 15.5714054)
                                    else 92
                                )
                                if state == 91:
                                    state = (
                                        145
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 15.5472965)
                                        else 146
                                    )
                                    if state == 145:
                                        state = (
                                            225
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.2195511)
                                            else 226
                                        )
                                        if state == 225:
                                            state = (
                                                327
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.93255782)
                                                else 328
                                            )
                                            if state == 327:
                                                state = (
                                                    445
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.2096996)
                                                    else 446
                                                )
                                                if state == 445:
                                                    return -0.367861569
                                                if state == 446:
                                                    return 0.471200615
                                            if state == 328:
                                                return -0.470442176
                                        if state == 226:
                                            state = (
                                                329
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.91395259)
                                                else 330
                                            )
                                            if state == 329:
                                                state = (
                                                    447
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.392601)
                                                    else 448
                                                )
                                                if state == 447:
                                                    return -0.581565022
                                                if state == 448:
                                                    state = (
                                                        563
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.4500504)
                                                        else 564
                                                    )
                                                    if state == 563:
                                                        state = (
                                                            689
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.537781179
                                                            )
                                                            else 690
                                                        )
                                                        if state == 689:
                                                            return -0.52493614
                                                        if state == 690:
                                                            return 0.168603331
                                                    if state == 564:
                                                        state = (
                                                            691
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.31713414
                                                            )
                                                            else 692
                                                        )
                                                        if state == 691:
                                                            return -0.569329739
                                                        if state == 692:
                                                            return -0.330995113
                                            if state == 330:
                                                return -0.587504745
                                    if state == 146:
                                        state = (
                                            227
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.6380997)
                                            else 228
                                        )
                                        if state == 227:
                                            return 0.519510508
                                        if state == 228:
                                            return -0.268288851
                                if state == 92:
                                    state = (
                                        147 if x["maggaia_med"] < 19.9117813 else 148
                                    )
                                    if state == 147:
                                        state = (
                                            229
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.7711411)
                                            else 230
                                        )
                                        if state == 229:
                                            return -0.646457553
                                        if state == 230:
                                            return -0.575553715
                                    if state == 148:
                                        state = (
                                            231
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.7649002)
                                            else 232
                                        )
                                        if state == 231:
                                            return -0.725782037
                                        if state == 232:
                                            return -0.599227369
                        if state == 30:
                            state = 55 if x["mag_peak"] < 19.1389503 else 56
                            if state == 55:
                                state = 93 if x["maggaia_med"] < 18.5148582 else 94
                                if state == 93:
                                    return -0.185356468
                                if state == 94:
                                    return 0.391483545
                            if state == 56:
                                return -0.530146062
    elif num_booster == 2:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 61.9227905) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["col_last"]) or (x["col_last"] < 0.584667206) else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.916428685) else 8
                    )
                    if state == 7:
                        state = 15 if x["col_last"] < -0.250517845 else 16
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 18.0312099)
                                else 30
                            )
                            if state == 29:
                                state = 51 if x["mag_peak"] < 18.3106995 else 52
                                if state == 51:
                                    state = (
                                        93
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 17.3262157)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            153
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.1439495)
                                            else 154
                                        )
                                        if state == 153:
                                            return -0.196933493
                                        if state == 154:
                                            return 0.0452220738
                                    if state == 94:
                                        return -0.500818074
                                if state == 52:
                                    state = (
                                        95
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.9469414)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            155
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.5791512)
                                            else 156
                                        )
                                        if state == 155:
                                            state = (
                                                241
                                                if x["col_last"] < -0.3116045
                                                else 242
                                            )
                                            if state == 241:
                                                return -0.316236854
                                            if state == 242:
                                                return 0.147211716
                                        if state == 156:
                                            state = (
                                                243
                                                if x["col_last"] < -0.366863728
                                                else 244
                                            )
                                            if state == 243:
                                                return -0.305347204
                                            if state == 244:
                                                state = (
                                                    333
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.7423935)
                                                    else 334
                                                )
                                                if state == 333:
                                                    return 0.432637841
                                                if state == 334:
                                                    state = (
                                                        443
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9169693)
                                                        else 444
                                                    )
                                                    if state == 443:
                                                        return -0.0277130809
                                                    if state == 444:
                                                        return 0.209048852
                                    if state == 96:
                                        state = (
                                            157
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4272995)
                                            else 158
                                        )
                                        if state == 157:
                                            state = (
                                                245
                                                if x["col_last"] < -0.737627029
                                                else 246
                                            )
                                            if state == 245:
                                                return 0.372895569
                                            if state == 246:
                                                state = (
                                                    335
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.325737)
                                                    else 336
                                                )
                                                if state == 335:
                                                    state = (
                                                        445
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0334358)
                                                        else 446
                                                    )
                                                    if state == 445:
                                                        return -0.353343576
                                                    if state == 446:
                                                        state = (
                                                            559
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.706428409
                                                            )
                                                            else 560
                                                        )
                                                        if state == 559:
                                                            return -0.20742783
                                                        if state == 560:
                                                            return 0.442025036
                                                if state == 336:
                                                    return -0.466680884
                                        if state == 158:
                                            return -0.487790942
                            if state == 30:
                                state = 53 if x["mag_peak"] < 17.7057343 else 54
                                if state == 53:
                                    state = (
                                        97
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.3380318)
                                        else 98
                                    )
                                    if state == 97:
                                        return -0.320274979
                                    if state == 98:
                                        return 0.306123108
                                if state == 54:
                                    state = (
                                        99
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.710928)
                                        else 100
                                    )
                                    if state == 99:
                                        state = (
                                            159
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.5930004)
                                            else 160
                                        )
                                        if state == 159:
                                            return -0.418390244
                                        if state == 160:
                                            state = (
                                                247
                                                if x["col_last"] < -0.310107231
                                                else 248
                                            )
                                            if state == 247:
                                                return -0.301797986
                                            if state == 248:
                                                return 0.273821265
                                    if state == 100:
                                        return -0.475015849
                        if state == 16:
                            state = (
                                31
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 17.9502544)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    55
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 18.9521446)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        101
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.0284595)
                                        else 102
                                    )
                                    if state == 101:
                                        state = (
                                            161
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.9268494)
                                            else 162
                                        )
                                        if state == 161:
                                            state = (
                                                249
                                                if x["col_last"] < -0.18018198
                                                else 250
                                            )
                                            if state == 249:
                                                state = (
                                                    337
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 17.6963692)
                                                    else 338
                                                )
                                                if state == 337:
                                                    return 0.158217743
                                                if state == 338:
                                                    return -0.393205673
                                            if state == 250:
                                                state = (
                                                    339
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 17.3935204)
                                                    else 340
                                                )
                                                if state == 339:
                                                    state = (
                                                        447
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 16.4494896)
                                                        else 448
                                                    )
                                                    if state == 447:
                                                        state = (
                                                            561
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.526547551
                                                            )
                                                            else 562
                                                        )
                                                        if state == 561:
                                                            return 0.315526128
                                                        if state == 562:
                                                            return 0.0974359065
                                                    if state == 448:
                                                        state = (
                                                            563
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.600000024
                                                            )
                                                            else 564
                                                        )
                                                        if state == 563:
                                                            return -0.213841647
                                                        if state == 564:
                                                            return 0.452214599
                                                if state == 340:
                                                    state = (
                                                        449
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.8172188)
                                                        else 450
                                                    )
                                                    if state == 449:
                                                        state = (
                                                            565
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.718809724
                                                            )
                                                            else 566
                                                        )
                                                        if state == 565:
                                                            return -0.0209257212
                                                        if state == 566:
                                                            return -0.413245946
                                                    if state == 450:
                                                        state = (
                                                            567
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.571666718
                                                            )
                                                            else 568
                                                        )
                                                        if state == 567:
                                                            return -0.0394030698
                                                        if state == 568:
                                                            return -0.643618047
                                        if state == 162:
                                            state = (
                                                251
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.193426132)
                                                else 252
                                            )
                                            if state == 251:
                                                state = (
                                                    341
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.554285)
                                                    else 342
                                                )
                                                if state == 341:
                                                    state = (
                                                        451
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.7870941)
                                                        else 452
                                                    )
                                                    if state == 451:
                                                        state = (
                                                            569
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.831071496
                                                            )
                                                            else 570
                                                        )
                                                        if state == 569:
                                                            return 0.503220379
                                                        if state == 570:
                                                            return 0.120132074
                                                    if state == 452:
                                                        return 0.406772047
                                                if state == 342:
                                                    state = (
                                                        453
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9886951)
                                                        else 454
                                                    )
                                                    if state == 453:
                                                        state = (
                                                            573
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.746071219
                                                            )
                                                            else 574
                                                        )
                                                        if state == 573:
                                                            return 0.266090423
                                                        if state == 574:
                                                            return 0.403937787
                                                    if state == 454:
                                                        state = (
                                                            575
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.243333012
                                                            )
                                                            else 576
                                                        )
                                                        if state == 575:
                                                            return -0.372201562
                                                        if state == 576:
                                                            return 0.0547544323
                                            if state == 252:
                                                state = (
                                                    343
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.7873459)
                                                    else 344
                                                )
                                                if state == 343:
                                                    return 0.376688838
                                                if state == 344:
                                                    state = (
                                                        455
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.8913765)
                                                        else 456
                                                    )
                                                    if state == 455:
                                                        state = (
                                                            577
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.729166508
                                                            )
                                                            else 578
                                                        )
                                                        if state == 577:
                                                            return -0.291287899
                                                        if state == 578:
                                                            return -0.0339922719
                                                    if state == 456:
                                                        return 0.258116454
                                    if state == 102:
                                        state = (
                                            163
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.8389511)
                                            else 164
                                        )
                                        if state == 163:
                                            state = (
                                                253
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.389616013)
                                                else 254
                                            )
                                            if state == 253:
                                                state = (
                                                    345
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.3015251)
                                                    else 346
                                                )
                                                if state == 345:
                                                    state = (
                                                        457
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2793274)
                                                        else 458
                                                    )
                                                    if state == 457:
                                                        state = (
                                                            581
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.721428573
                                                            )
                                                            else 582
                                                        )
                                                        if state == 581:
                                                            return -0.226593852
                                                        if state == 582:
                                                            return -0.028710667
                                                    if state == 458:
                                                        state = (
                                                            583
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.694999754
                                                            )
                                                            else 584
                                                        )
                                                        if state == 583:
                                                            return -0.297151774
                                                        if state == 584:
                                                            return 0.457552999
                                                if state == 346:
                                                    state = (
                                                        459
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.3777866)
                                                        else 460
                                                    )
                                                    if state == 459:
                                                        state = (
                                                            585
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.811785698
                                                            )
                                                            else 586
                                                        )
                                                        if state == 585:
                                                            return -0.283700228
                                                        if state == 586:
                                                            return -0.544906139
                                                    if state == 460:
                                                        return 0.234172896
                                            if state == 254:
                                                state = (
                                                    347
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.5064812)
                                                    else 348
                                                )
                                                if state == 347:
                                                    state = (
                                                        461
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4388008)
                                                        else 462
                                                    )
                                                    if state == 461:
                                                        state = (
                                                            587
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.862857163
                                                            )
                                                            else 588
                                                        )
                                                        if state == 587:
                                                            return 0.137132958
                                                        if state == 588:
                                                            return -0.214447305
                                                    if state == 462:
                                                        return 0.392862082
                                                if state == 348:
                                                    return -0.276704878
                                        if state == 164:
                                            state = (
                                                255
                                                if x["col_last"] < -0.125971317
                                                else 256
                                            )
                                            if state == 255:
                                                state = (
                                                    349
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.3704567)
                                                    else 350
                                                )
                                                if state == 349:
                                                    state = (
                                                        463
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.355648)
                                                        else 464
                                                    )
                                                    if state == 463:
                                                        state = (
                                                            589
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.586190462
                                                            )
                                                            else 590
                                                        )
                                                        if state == 589:
                                                            return -0.291257441
                                                        if state == 590:
                                                            return 0.0674164146
                                                    if state == 464:
                                                        return 0.548780501
                                                if state == 350:
                                                    return -0.45168224
                                            if state == 256:
                                                state = (
                                                    351
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.6430206)
                                                    else 352
                                                )
                                                if state == 351:
                                                    state = (
                                                        465
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.6415215)
                                                        else 466
                                                    )
                                                    if state == 465:
                                                        state = (
                                                            591
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.907499969
                                                            )
                                                            else 592
                                                        )
                                                        if state == 591:
                                                            return -0.339907795
                                                        if state == 592:
                                                            return 0.0180453118
                                                    if state == 466:
                                                        return 0.466390997
                                                if state == 352:
                                                    return -0.482021004
                                if state == 56:
                                    state = (
                                        103
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.3617821)
                                        else 104
                                    )
                                    if state == 103:
                                        state = (
                                            165
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.7569504)
                                            else 166
                                        )
                                        if state == 165:
                                            return -0.682604253
                                        if state == 166:
                                            state = (
                                                257
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.149350166)
                                                else 258
                                            )
                                            if state == 257:
                                                state = (
                                                    353
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.1970654)
                                                    else 354
                                                )
                                                if state == 353:
                                                    state = (
                                                        467
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1615505)
                                                        else 468
                                                    )
                                                    if state == 467:
                                                        state = (
                                                            593
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.675833225
                                                            )
                                                            else 594
                                                        )
                                                        if state == 593:
                                                            return 0.167633206
                                                        if state == 594:
                                                            return -0.320019335
                                                    if state == 468:
                                                        return -0.474860728
                                                if state == 354:
                                                    state = (
                                                        469
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3094654)
                                                        else 470
                                                    )
                                                    if state == 469:
                                                        state = (
                                                            595
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.709166646
                                                            )
                                                            else 596
                                                        )
                                                        if state == 595:
                                                            return 0.333857417
                                                        if state == 596:
                                                            return -0.170801193
                                                    if state == 470:
                                                        return -0.378970742
                                            if state == 258:
                                                return 0.408275932
                                    if state == 104:
                                        return -0.4872967
                            if state == 32:
                                state = 57 if x["mag_peak"] < 18.9886951 else 58
                                if state == 57:
                                    state = (
                                        105
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 21.0125999)
                                        else 106
                                    )
                                    if state == 105:
                                        state = (
                                            167
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.0306969)
                                            else 168
                                        )
                                        if state == 167:
                                            state = (
                                                259
                                                if x["col_last"] < 0.0377197266
                                                else 260
                                            )
                                            if state == 259:
                                                return -0.446393877
                                            if state == 260:
                                                state = (
                                                    355
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 17.1521912)
                                                    else 356
                                                )
                                                if state == 355:
                                                    state = (
                                                        471
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 16.0670815)
                                                        else 472
                                                    )
                                                    if state == 471:
                                                        state = (
                                                            597
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.420714289
                                                            )
                                                            else 598
                                                        )
                                                        if state == 597:
                                                            return 0.0603999346
                                                        if state == 598:
                                                            return 0.409801513
                                                    if state == 472:
                                                        state = (
                                                            599
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.481428564
                                                            )
                                                            else 600
                                                        )
                                                        if state == 599:
                                                            return -0.327888757
                                                        if state == 600:
                                                            return 0.372044206
                                                if state == 356:
                                                    state = (
                                                        473
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.2811813)
                                                        else 474
                                                    )
                                                    if state == 473:
                                                        return -0.47934711
                                                    if state == 474:
                                                        state = (
                                                            601
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"] < 0.50690484
                                                            )
                                                            else 602
                                                        )
                                                        if state == 601:
                                                            return -0.31873396
                                                        if state == 602:
                                                            return 0.0636858121
                                        if state == 168:
                                            state = (
                                                261
                                                if x["col_last"] < -0.1696105
                                                else 262
                                            )
                                            if state == 261:
                                                state = (
                                                    357
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 17.7954216)
                                                    else 358
                                                )
                                                if state == 357:
                                                    state = (
                                                        475
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 16.7841949)
                                                        else 476
                                                    )
                                                    if state == 475:
                                                        return 0.286922365
                                                    if state == 476:
                                                        state = (
                                                            603
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.780833364
                                                            )
                                                            else 604
                                                        )
                                                        if state == 603:
                                                            return 0.228213817
                                                        if state == 604:
                                                            return -0.201989561
                                                if state == 358:
                                                    state = (
                                                        477
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.6538506)
                                                        else 478
                                                    )
                                                    if state == 477:
                                                        return -0.516664863
                                                    if state == 478:
                                                        state = (
                                                            605
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.569999814
                                                            )
                                                            else 606
                                                        )
                                                        if state == 605:
                                                            return 0.172645763
                                                        if state == 606:
                                                            return -0.136828929
                                            if state == 262:
                                                state = (
                                                    359
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.2522259)
                                                    else 360
                                                )
                                                if state == 359:
                                                    state = (
                                                        479
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 16.131916)
                                                        else 480
                                                    )
                                                    if state == 479:
                                                        state = (
                                                            607
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.511309743
                                                            )
                                                            else 608
                                                        )
                                                        if state == 607:
                                                            return -0.174122483
                                                        if state == 608:
                                                            return 0.3972826
                                                    if state == 480:
                                                        state = (
                                                            609
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.485000014
                                                            )
                                                            else 610
                                                        )
                                                        if state == 609:
                                                            return 0.145354375
                                                        if state == 610:
                                                            return 0.428290308
                                                if state == 360:
                                                    state = (
                                                        481
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.546524)
                                                        else 482
                                                    )
                                                    if state == 481:
                                                        state = (
                                                            611
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.762261987
                                                            )
                                                            else 612
                                                        )
                                                        if state == 611:
                                                            return 0.286791384
                                                        if state == 612:
                                                            return 0.382119387
                                                    if state == 482:
                                                        state = (
                                                            613
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.276666909
                                                            )
                                                            else 614
                                                        )
                                                        if state == 613:
                                                            return -0.176271811
                                                        if state == 614:
                                                            return 0.373412043
                                    if state == 106:
                                        state = (
                                            169
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.2288799)
                                            else 170
                                        )
                                        if state == 169:
                                            return -0.312898844
                                        if state == 170:
                                            return -0.00317890919
                                if state == 58:
                                    state = (
                                        107
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.9599438)
                                        else 108
                                    )
                                    if state == 107:
                                        state = (
                                            171
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.1792488)
                                            else 172
                                        )
                                        if state == 171:
                                            state = (
                                                263
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < -0.156650543)
                                                else 264
                                            )
                                            if state == 263:
                                                state = (
                                                    361
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.8155403)
                                                    else 362
                                                )
                                                if state == 361:
                                                    state = (
                                                        483
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.795105)
                                                        else 484
                                                    )
                                                    if state == 483:
                                                        state = (
                                                            615
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.683095098
                                                            )
                                                            else 616
                                                        )
                                                        if state == 615:
                                                            return 0.0351735465
                                                        if state == 616:
                                                            return -0.119792461
                                                    if state == 484:
                                                        return 0.289964974
                                                if state == 362:
                                                    state = (
                                                        485
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.8827095)
                                                        else 486
                                                    )
                                                    if state == 485:
                                                        return -0.430731893
                                                    if state == 486:
                                                        state = (
                                                            617
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.655833364
                                                            )
                                                            else 618
                                                        )
                                                        if state == 617:
                                                            return 0.288274169
                                                        if state == 618:
                                                            return -0.435366303
                                            if state == 264:
                                                state = (
                                                    363
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.051239)
                                                    else 364
                                                )
                                                if state == 363:
                                                    state = (
                                                        487
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.9099655)
                                                        else 488
                                                    )
                                                    if state == 487:
                                                        state = (
                                                            619
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.436071515
                                                            )
                                                            else 620
                                                        )
                                                        if state == 619:
                                                            return 0.0108167101
                                                        if state == 620:
                                                            return 0.365454823
                                                    if state == 488:
                                                        state = (
                                                            621
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.716904759
                                                            )
                                                            else 622
                                                        )
                                                        if state == 621:
                                                            return -0.0416189171
                                                        if state == 622:
                                                            return 0.251083225
                                                if state == 364:
                                                    state = (
                                                        489
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9350052)
                                                        else 490
                                                    )
                                                    if state == 489:
                                                        state = (
                                                            623
                                                            if np.isnan(x["rb_med"])
                                                            or (x["rb_med"] < 0.7900002)
                                                            else 624
                                                        )
                                                        if state == 623:
                                                            return 0.0668972656
                                                        if state == 624:
                                                            return -0.301308811
                                                    if state == 490:
                                                        return 0.357025892
                                        if state == 172:
                                            state = (
                                                265
                                                if x["col_last"] < -0.112904072
                                                else 266
                                            )
                                            if state == 265:
                                                state = (
                                                    365
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 17.7781334)
                                                    else 366
                                                )
                                                if state == 365:
                                                    return 0.246576652
                                                if state == 366:
                                                    return -0.117006488
                                            if state == 266:
                                                state = (
                                                    367
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.9471283)
                                                    else 368
                                                )
                                                if state == 367:
                                                    return 0.399905592
                                                if state == 368:
                                                    state = (
                                                        493
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9590874)
                                                        else 494
                                                    )
                                                    if state == 493:
                                                        return -0.0822368562
                                                    if state == 494:
                                                        return 0.147989318
                                    if state == 108:
                                        state = (
                                            173
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 21.5148506)
                                            else 174
                                        )
                                        if state == 173:
                                            state = (
                                                267
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.12106514)
                                                else 268
                                            )
                                            if state == 267:
                                                state = (
                                                    369
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.1441841)
                                                    else 370
                                                )
                                                if state == 369:
                                                    state = (
                                                        495
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1406879)
                                                        else 496
                                                    )
                                                    if state == 495:
                                                        state = (
                                                            625
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.675357163
                                                            )
                                                            else 626
                                                        )
                                                        if state == 625:
                                                            return -0.252768129
                                                        if state == 626:
                                                            return -0.515017092
                                                    if state == 496:
                                                        state = (
                                                            627
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.555118918
                                                            )
                                                            else 628
                                                        )
                                                        if state == 627:
                                                            return 0.165542826
                                                        if state == 628:
                                                            return -0.0593885109
                                                if state == 370:
                                                    return -0.490507483
                                            if state == 268:
                                                state = (
                                                    371
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.5532761)
                                                    else 372
                                                )
                                                if state == 371:
                                                    state = (
                                                        497
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0658474)
                                                        else 498
                                                    )
                                                    if state == 497:
                                                        state = (
                                                            629
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.659999967
                                                            )
                                                            else 630
                                                        )
                                                        if state == 629:
                                                            return 0.350914955
                                                        if state == 630:
                                                            return -0.203863472
                                                    if state == 498:
                                                        state = (
                                                            631
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.673333347
                                                            )
                                                            else 632
                                                        )
                                                        if state == 631:
                                                            return -0.0277992692
                                                        if state == 632:
                                                            return -0.502671957
                                                if state == 372:
                                                    return -0.492970794
                                        if state == 174:
                                            return 0.591547966
                    if state == 8:
                        state = 17 if x["col_last"] < -0.180171013 else 18
                        if state == 17:
                            state = (
                                33
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 12.0608616)
                                else 34
                            )
                            if state == 33:
                                state = 59 if x["mag_peak"] < 39.1976013 else 60
                                if state == 59:
                                    return -0.476139486
                                if state == 60:
                                    state = (
                                        109
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.1536274)
                                        else 110
                                    )
                                    if state == 109:
                                        return 0.431192249
                                    if state == 110:
                                        return -0.172687605
                            if state == 34:
                                state = (
                                    61
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 17.7593231)
                                    else 62
                                )
                                if state == 61:
                                    return -0.527920663
                                if state == 62:
                                    state = (
                                        111
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.6675758)
                                        else 112
                                    )
                                    if state == 111:
                                        return 0.153195962
                                    if state == 112:
                                        state = (
                                            175
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.4164791)
                                            else 176
                                        )
                                        if state == 175:
                                            return 0.17184864
                                        if state == 176:
                                            return -0.385038048
                        if state == 18:
                            state = (
                                35
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 11.9153004)
                                else 36
                            )
                            if state == 35:
                                state = 63 if x["mag_peak"] < 40.0704041 else 64
                                if state == 63:
                                    state = (
                                        113
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.1537399)
                                        else 114
                                    )
                                    if state == 113:
                                        state = (
                                            177
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.3928986)
                                            else 178
                                        )
                                        if state == 177:
                                            return -0.378223032
                                        if state == 178:
                                            return 0.312817305
                                    if state == 114:
                                        state = (
                                            179
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.6553497)
                                            else 180
                                        )
                                        if state == 179:
                                            return -0.497626781
                                        if state == 180:
                                            state = (
                                                269
                                                if x["col_last"] < 0.374606192
                                                else 270
                                            )
                                            if state == 269:
                                                return -0.265041858
                                            if state == 270:
                                                return 0.0783160776
                                if state == 64:
                                    state = (
                                        115
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.0838356)
                                        else 116
                                    )
                                    if state == 115:
                                        state = (
                                            181
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.687851)
                                            else 182
                                        )
                                        if state == 181:
                                            state = (
                                                271
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < -0.0866265297)
                                                else 272
                                            )
                                            if state == 271:
                                                state = (
                                                    373
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.0287971)
                                                    else 374
                                                )
                                                if state == 373:
                                                    return 0.504177511
                                                if state == 374:
                                                    return -0.176383764
                                            if state == 272:
                                                state = (
                                                    375
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.7730675)
                                                    else 376
                                                )
                                                if state == 375:
                                                    return 0.446499735
                                                if state == 376:
                                                    state = (
                                                        499
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.8108139)
                                                        else 500
                                                    )
                                                    if state == 499:
                                                        return -0.299696863
                                                    if state == 500:
                                                        state = (
                                                            633
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.960714281
                                                            )
                                                            else 634
                                                        )
                                                        if state == 633:
                                                            return 0.368180364
                                                        if state == 634:
                                                            return -0.38105455
                                        if state == 182:
                                            state = (
                                                273
                                                if x["col_last"] < 0.22366333
                                                else 274
                                            )
                                            if state == 273:
                                                return -0.217116371
                                            if state == 274:
                                                return 0.328485221
                                    if state == 116:
                                        state = (
                                            183
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.3246498)
                                            else 184
                                        )
                                        if state == 183:
                                            return -0.517583132
                                        if state == 184:
                                            state = (
                                                275
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.30065155)
                                                else 276
                                            )
                                            if state == 275:
                                                state = (
                                                    377
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.2190475)
                                                    else 378
                                                )
                                                if state == 377:
                                                    state = (
                                                        501
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1573601)
                                                        else 502
                                                    )
                                                    if state == 501:
                                                        return -0.12616916
                                                    if state == 502:
                                                        return 0.152526557
                                                if state == 378:
                                                    return -0.313846231
                                            if state == 276:
                                                return 0.337015271
                            if state == 36:
                                state = 65 if x["mag_peak"] < 18.6718082 else 66
                                if state == 65:
                                    state = (
                                        117
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.6846962)
                                        else 118
                                    )
                                    if state == 117:
                                        state = (
                                            185
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.4662514)
                                            else 186
                                        )
                                        if state == 185:
                                            state = (
                                                277
                                                if x["col_last"] < 1.10641575
                                                else 278
                                            )
                                            if state == 277:
                                                state = (
                                                    379
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 17.6389084)
                                                    else 380
                                                )
                                                if state == 379:
                                                    return 0.424327284
                                                if state == 380:
                                                    return 0.0173422955
                                            if state == 278:
                                                state = (
                                                    381
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 17.6190929)
                                                    else 382
                                                )
                                                if state == 381:
                                                    return 0.375789165
                                                if state == 382:
                                                    return -0.407574683
                                        if state == 186:
                                            state = (
                                                279
                                                if x["col_last"] < -0.130079746
                                                else 280
                                            )
                                            if state == 279:
                                                return 0.0788201019
                                            if state == 280:
                                                return 0.475832403
                                    if state == 118:
                                        state = (
                                            187
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.5630989)
                                            else 188
                                        )
                                        if state == 187:
                                            state = (
                                                281
                                                if x["col_last"] < 0.289990425
                                                else 282
                                            )
                                            if state == 281:
                                                return -0.450507045
                                            if state == 282:
                                                state = (
                                                    383
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.0949974)
                                                    else 384
                                                )
                                                if state == 383:
                                                    state = (
                                                        503
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9343796)
                                                        else 504
                                                    )
                                                    if state == 503:
                                                        state = (
                                                            635
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.948571444
                                                            )
                                                            else 636
                                                        )
                                                        if state == 635:
                                                            return -0.0664869174
                                                        if state == 636:
                                                            return 0.278532594
                                                    if state == 504:
                                                        return 0.25900799
                                                if state == 384:
                                                    state = (
                                                        505
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4548397)
                                                        else 506
                                                    )
                                                    if state == 505:
                                                        return -0.413402796
                                                    if state == 506:
                                                        state = (
                                                            637
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.945357084
                                                            )
                                                            else 638
                                                        )
                                                        if state == 637:
                                                            return -0.14041847
                                                        if state == 638:
                                                            return 0.229221657
                                        if state == 188:
                                            state = (
                                                283
                                                if x["col_last"] < -0.0956583023
                                                else 284
                                            )
                                            if state == 283:
                                                state = (
                                                    385
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.0308685)
                                                    else 386
                                                )
                                                if state == 385:
                                                    return -0.2518318
                                                if state == 386:
                                                    return 0.245453164
                                            if state == 284:
                                                return 0.449258864
                                if state == 66:
                                    state = (
                                        119
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.1434422)
                                        else 120
                                    )
                                    if state == 119:
                                        state = (
                                            189
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.0679512)
                                            else 190
                                        )
                                        if state == 189:
                                            state = (
                                                285
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < -0.0693087578)
                                                else 286
                                            )
                                            if state == 285:
                                                state = (
                                                    387
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.6157131)
                                                    else 388
                                                )
                                                if state == 387:
                                                    return 0.48976633
                                                if state == 388:
                                                    state = (
                                                        509
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.8792915)
                                                        else 510
                                                    )
                                                    if state == 509:
                                                        state = (
                                                            639
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.935000002
                                                            )
                                                            else 640
                                                        )
                                                        if state == 639:
                                                            return -0.325040668
                                                        if state == 640:
                                                            return 0.0779598132
                                                    if state == 510:
                                                        state = (
                                                            641
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.926071405
                                                            )
                                                            else 642
                                                        )
                                                        if state == 641:
                                                            return -0.359612048
                                                        if state == 642:
                                                            return 0.273011327
                                            if state == 286:
                                                state = (
                                                    389
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.829319)
                                                    else 390
                                                )
                                                if state == 389:
                                                    return 0.497803211
                                                if state == 390:
                                                    state = (
                                                        511
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9700737)
                                                        else 512
                                                    )
                                                    if state == 511:
                                                        state = (
                                                            643
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.951428652
                                                            )
                                                            else 644
                                                        )
                                                        if state == 643:
                                                            return -0.0337243788
                                                        if state == 644:
                                                            return -0.27170226
                                                    if state == 512:
                                                        state = (
                                                            645
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.944642901
                                                            )
                                                            else 646
                                                        )
                                                        if state == 645:
                                                            return -0.0300395805
                                                        if state == 646:
                                                            return 0.385841429
                                        if state == 190:
                                            state = (
                                                287
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.195560932)
                                                else 288
                                            )
                                            if state == 287:
                                                state = (
                                                    391
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.6363602)
                                                    else 392
                                                )
                                                if state == 391:
                                                    return 0.457047641
                                                if state == 392:
                                                    state = (
                                                        513
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9982033)
                                                        else 514
                                                    )
                                                    if state == 513:
                                                        state = (
                                                            647
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.940357089
                                                            )
                                                            else 648
                                                        )
                                                        if state == 647:
                                                            return 0.330771625
                                                        if state == 648:
                                                            return 0.00680618919
                                                    if state == 514:
                                                        state = (
                                                            649
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.929285526
                                                            )
                                                            else 650
                                                        )
                                                        if state == 649:
                                                            return -0.197766572
                                                        if state == 650:
                                                            return 0.0550417677
                                            if state == 288:
                                                state = (
                                                    393
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.0070419)
                                                    else 394
                                                )
                                                if state == 393:
                                                    state = (
                                                        515
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.6364746)
                                                        else 516
                                                    )
                                                    if state == 515:
                                                        state = (
                                                            651
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.928928614
                                                            )
                                                            else 652
                                                        )
                                                        if state == 651:
                                                            return 0.151447222
                                                        if state == 652:
                                                            return -0.178272665
                                                    if state == 516:
                                                        state = (
                                                            653
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"] < 0.92749989
                                                            )
                                                            else 654
                                                        )
                                                        if state == 653:
                                                            return -0.123045705
                                                        if state == 654:
                                                            return 0.317143887
                                                if state == 394:
                                                    return -0.267330825
                                    if state == 120:
                                        state = (
                                            191
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.5183487)
                                            else 192
                                        )
                                        if state == 191:
                                            state = (
                                                289
                                                if x["col_last"] < 0.962895453
                                                else 290
                                            )
                                            if state == 289:
                                                state = (
                                                    395
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.5124454)
                                                    else 396
                                                )
                                                if state == 395:
                                                    state = (
                                                        517
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3117104)
                                                        else 518
                                                    )
                                                    if state == 517:
                                                        return -0.192954555
                                                    if state == 518:
                                                        return 0.294759959
                                                if state == 396:
                                                    return -0.496746123
                                            if state == 290:
                                                state = (
                                                    397
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 20.1219978)
                                                    else 398
                                                )
                                                if state == 397:
                                                    state = (
                                                        519
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3991966)
                                                        else 520
                                                    )
                                                    if state == 519:
                                                        return 0.366342545
                                                    if state == 520:
                                                        state = (
                                                            655
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.943214297
                                                            )
                                                            else 656
                                                        )
                                                        if state == 655:
                                                            return 0.207413614
                                                        if state == 656:
                                                            return -0.14611201
                                                if state == 398:
                                                    return -0.441832423
                                        if state == 192:
                                            state = (
                                                291
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.417310715)
                                                else 292
                                            )
                                            if state == 291:
                                                state = (
                                                    399
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.894537)
                                                    else 400
                                                )
                                                if state == 399:
                                                    state = (
                                                        521
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.8645802)
                                                        else 522
                                                    )
                                                    if state == 521:
                                                        state = (
                                                            657
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"] < 0.95035702
                                                            )
                                                            else 658
                                                        )
                                                        if state == 657:
                                                            return -0.281285048
                                                        if state == 658:
                                                            return -0.499212444
                                                    if state == 522:
                                                        state = (
                                                            659
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.933571458
                                                            )
                                                            else 660
                                                        )
                                                        if state == 659:
                                                            return 0.236398116
                                                        if state == 660:
                                                            return -0.265135765
                                                if state == 400:
                                                    return -0.463614076
                                            if state == 292:
                                                state = (
                                                    401
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.3285561)
                                                    else 402
                                                )
                                                if state == 401:
                                                    return -0.302416116
                                                if state == 402:
                                                    state = (
                                                        523
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.6044712)
                                                        else 524
                                                    )
                                                    if state == 523:
                                                        return 0.486887455
                                                    if state == 524:
                                                        state = (
                                                            661
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.939999998
                                                            )
                                                            else 662
                                                        )
                                                        if state == 661:
                                                            return -0.206193626
                                                        if state == 662:
                                                            return 0.0759093538
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.566190362)
                        else 10
                    )
                    if state == 9:
                        state = 19 if x["col_last"] < 1.03971076 else 20
                        if state == 19:
                            state = (
                                37
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 27.0422401)
                                else 38
                            )
                            if state == 37:
                                state = 67 if x["mag_peak"] < 17.9903488 else 68
                                if state == 67:
                                    state = (
                                        121
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.2325478)
                                        else 122
                                    )
                                    if state == 121:
                                        return -0.230737865
                                    if state == 122:
                                        return 0.192980349
                                if state == 68:
                                    return -0.478068113
                            if state == 38:
                                state = (
                                    69
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 18.9825935)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        123
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.7085686)
                                        else 124
                                    )
                                    if state == 123:
                                        state = (
                                            193
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.0254002)
                                            else 194
                                        )
                                        if state == 193:
                                            state = (
                                                293
                                                if x["col_last"] < 0.935561776
                                                else 294
                                            )
                                            if state == 293:
                                                state = (
                                                    403
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 16.8377419)
                                                    else 404
                                                )
                                                if state == 403:
                                                    return 0.22725971
                                                if state == 404:
                                                    return -0.211853012
                                            if state == 294:
                                                return -0.440149397
                                        if state == 194:
                                            state = (
                                                295
                                                if x["col_last"] < 0.959545135
                                                else 296
                                            )
                                            if state == 295:
                                                return 0.425872743
                                            if state == 296:
                                                state = (
                                                    405
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.401474)
                                                    else 406
                                                )
                                                if state == 405:
                                                    return 0.143521652
                                                if state == 406:
                                                    state = (
                                                        525
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2095375)
                                                        else 526
                                                    )
                                                    if state == 525:
                                                        return -0.434796065
                                                    if state == 526:
                                                        return -0.0351130068
                                    if state == 124:
                                        state = (
                                            195
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.4389496)
                                            else 196
                                        )
                                        if state == 195:
                                            state = (
                                                297
                                                if x["col_last"] < 0.808534622
                                                else 298
                                            )
                                            if state == 297:
                                                state = (
                                                    407
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 20.1214981)
                                                    else 408
                                                )
                                                if state == 407:
                                                    return 0.329249799
                                                if state == 408:
                                                    return -0.277405292
                                            if state == 298:
                                                return 0.403335452
                                        if state == 196:
                                            state = (
                                                299
                                                if x["col_last"] < 0.89304924
                                                else 300
                                            )
                                            if state == 299:
                                                state = (
                                                    409
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 20.15555)
                                                    else 410
                                                )
                                                if state == 409:
                                                    return -0.485777825
                                                if state == 410:
                                                    state = (
                                                        527
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.1686497)
                                                        else 528
                                                    )
                                                    if state == 527:
                                                        return 0.164474875
                                                    if state == 528:
                                                        state = (
                                                            663
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.463333338
                                                            )
                                                            else 664
                                                        )
                                                        if state == 663:
                                                            return -0.300828367
                                                        if state == 664:
                                                            return 0.150216803
                                            if state == 300:
                                                state = (
                                                    411
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 20.1228027)
                                                    else 412
                                                )
                                                if state == 411:
                                                    return -0.261745661
                                                if state == 412:
                                                    return 0.394200325
                                if state == 70:
                                    return -0.509738624
                        if state == 20:
                            state = (
                                39
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 50.4201202)
                                else 40
                            )
                            if state == 39:
                                state = 71 if x["mag_peak"] < 19.0009899 else 72
                                if state == 71:
                                    state = (
                                        125
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 16.881424)
                                        else 126
                                    )
                                    if state == 125:
                                        return -0.164499208
                                    if state == 126:
                                        state = (
                                            197
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4927998)
                                            else 198
                                        )
                                        if state == 197:
                                            return 0.431551158
                                        if state == 198:
                                            return -0.220137179
                                if state == 72:
                                    return -0.279350907
                            if state == 40:
                                state = 73 if x["mag_peak"] < 18.3038139 else 74
                                if state == 73:
                                    return 0.0740704387
                                if state == 74:
                                    return -0.288237303
                    if state == 10:
                        state = 21 if x["col_last"] < 0.776522636 else 22
                        if state == 21:
                            state = (
                                41
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 23.8591194)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    75
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 18.9447136)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        127
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.6759186)
                                        else 128
                                    )
                                    if state == 127:
                                        state = (
                                            199
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.7175503)
                                            else 200
                                        )
                                        if state == 199:
                                            state = (
                                                301
                                                if x["col_last"] < 0.7169981
                                                else 302
                                            )
                                            if state == 301:
                                                state = (
                                                    413
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 17.5546494)
                                                    else 414
                                                )
                                                if state == 413:
                                                    return 0.0212649908
                                                if state == 414:
                                                    state = (
                                                        529
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2286148)
                                                        else 530
                                                    )
                                                    if state == 529:
                                                        return 0.478962034
                                                    if state == 530:
                                                        state = (
                                                            665
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.742499948
                                                            )
                                                            else 666
                                                        )
                                                        if state == 665:
                                                            return -0.142667338
                                                        if state == 666:
                                                            return 0.264748365
                                            if state == 302:
                                                state = (
                                                    415
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.4459419)
                                                    else 416
                                                )
                                                if state == 415:
                                                    state = (
                                                        531
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.4152527)
                                                        else 532
                                                    )
                                                    if state == 531:
                                                        return 0.153611585
                                                    if state == 532:
                                                        return -0.372887075
                                                if state == 416:
                                                    return 0.162861183
                                        if state == 200:
                                            return -0.404547513
                                    if state == 128:
                                        state = (
                                            201
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.138649)
                                            else 202
                                        )
                                        if state == 201:
                                            state = (
                                                303
                                                if x["col_last"] < 0.694607735
                                                else 304
                                            )
                                            if state == 303:
                                                return 0.244277492
                                            if state == 304:
                                                return -0.121776558
                                        if state == 202:
                                            state = (
                                                305
                                                if x["col_last"] < 0.700554848
                                                else 306
                                            )
                                            if state == 305:
                                                return -0.402623326
                                            if state == 306:
                                                state = (
                                                    417
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 20.3886757)
                                                    else 418
                                                )
                                                if state == 417:
                                                    return -0.196643531
                                                if state == 418:
                                                    return 0.258806944
                                if state == 76:
                                    return -0.440194875
                            if state == 42:
                                state = 77 if x["mag_peak"] < 18.9913063 else 78
                                if state == 77:
                                    return 0.457075447
                                if state == 78:
                                    state = (
                                        129
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.9415131)
                                        else 130
                                    )
                                    if state == 129:
                                        return 0.33582136
                                    if state == 130:
                                        state = (
                                            203
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.9912987)
                                            else 204
                                        )
                                        if state == 203:
                                            state = (
                                                307
                                                if x["col_last"] < 0.586733818
                                                else 308
                                            )
                                            if state == 307:
                                                return 0.519343555
                                            if state == 308:
                                                state = (
                                                    419
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.2435684)
                                                    else 420
                                                )
                                                if state == 419:
                                                    state = (
                                                        533
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1476059)
                                                        else 534
                                                    )
                                                    if state == 533:
                                                        return -0.392608345
                                                    if state == 534:
                                                        return 0.2509377
                                                if state == 420:
                                                    return -0.517808557
                                        if state == 204:
                                            state = (
                                                309
                                                if x["col_last"] < 0.673748016
                                                else 310
                                            )
                                            if state == 309:
                                                return 0.511705399
                                            if state == 310:
                                                return -0.128271952
                        if state == 22:
                            state = (
                                43
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 24.087429)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    79
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 19.0237961)
                                    else 80
                                )
                                if state == 79:
                                    state = (
                                        131
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.9787407)
                                        else 132
                                    )
                                    if state == 131:
                                        return 0.475581497
                                    if state == 132:
                                        state = (
                                            205
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4519501)
                                            else 206
                                        )
                                        if state == 205:
                                            state = (
                                                311
                                                if x["col_last"] < 1.11039162
                                                else 312
                                            )
                                            if state == 311:
                                                state = (
                                                    421
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.1529007)
                                                    else 422
                                                )
                                                if state == 421:
                                                    return 0.346460581
                                                if state == 422:
                                                    state = (
                                                        535
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2741089)
                                                        else 536
                                                    )
                                                    if state == 535:
                                                        return -0.408343196
                                                    if state == 536:
                                                        state = (
                                                            667
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"] < 0.85857141
                                                            )
                                                            else 668
                                                        )
                                                        if state == 667:
                                                            return -0.0374047533
                                                        if state == 668:
                                                            return 0.42751652
                                            if state == 312:
                                                state = (
                                                    423
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.2462273)
                                                    else 424
                                                )
                                                if state == 423:
                                                    state = (
                                                        537
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.196991)
                                                        else 538
                                                    )
                                                    if state == 537:
                                                        return 0.15974912
                                                    if state == 538:
                                                        return -0.136484265
                                                if state == 424:
                                                    return 0.526041806
                                        if state == 206:
                                            return -0.498705894
                                if state == 80:
                                    return -0.399427593
                            if state == 44:
                                state = 81 if x["mag_peak"] < 18.9153938 else 82
                                if state == 81:
                                    state = (
                                        133
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 16.9297867)
                                        else 134
                                    )
                                    if state == 133:
                                        state = (
                                            207
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.1202507)
                                            else 208
                                        )
                                        if state == 207:
                                            return 0.334986806
                                        if state == 208:
                                            return -0.570331573
                                    if state == 134:
                                        state = (
                                            209
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.8436508)
                                            else 210
                                        )
                                        if state == 209:
                                            state = (
                                                313
                                                if x["col_last"] < 1.47346735
                                                else 314
                                            )
                                            if state == 313:
                                                return 0.458650082
                                            if state == 314:
                                                return 0.274630725
                                        if state == 210:
                                            return 0.528070629
                                if state == 82:
                                    state = (
                                        135
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.4243088)
                                        else 136
                                    )
                                    if state == 135:
                                        state = (
                                            211
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.3392506)
                                            else 212
                                        )
                                        if state == 211:
                                            state = (
                                                315
                                                if x["col_last"] < 0.970758438
                                                else 316
                                            )
                                            if state == 315:
                                                state = (
                                                    425
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.7590675)
                                                    else 426
                                                )
                                                if state == 425:
                                                    return 0.254172474
                                                if state == 426:
                                                    state = (
                                                        539
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4094315)
                                                        else 540
                                                    )
                                                    if state == 539:
                                                        state = (
                                                            669
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.905000091
                                                            )
                                                            else 670
                                                        )
                                                        if state == 669:
                                                            return -0.346920103
                                                        if state == 670:
                                                            return 0.145509452
                                                    if state == 540:
                                                        return 0.159048885
                                            if state == 316:
                                                return -0.30190286
                                        if state == 212:
                                            state = (
                                                317
                                                if x["col_last"] < 1.10990047
                                                else 318
                                            )
                                            if state == 317:
                                                return 0.482350886
                                            if state == 318:
                                                return -0.128863707
                                    if state == 136:
                                        state = (
                                            213
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.5745506)
                                            else 214
                                        )
                                        if state == 213:
                                            state = (
                                                319
                                                if x["col_last"] < 0.855822563
                                                else 320
                                            )
                                            if state == 319:
                                                state = (
                                                    427
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 20.8157997)
                                                    else 428
                                                )
                                                if state == 427:
                                                    state = (
                                                        541
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.0874062)
                                                        else 542
                                                    )
                                                    if state == 541:
                                                        return -0.364434659
                                                    if state == 542:
                                                        state = (
                                                            671
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.615952373
                                                            )
                                                            else 672
                                                        )
                                                        if state == 671:
                                                            return 0.17467466
                                                        if state == 672:
                                                            return -0.212009579
                                                if state == 428:
                                                    return 0.300409168
                                            if state == 320:
                                                return -0.528693438
                                        if state == 214:
                                            state = (
                                                321
                                                if x["col_last"] < 1.04658055
                                                else 322
                                            )
                                            if state == 321:
                                                return -0.351191282
                                            if state == 322:
                                                state = (
                                                    429
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 20.0997677)
                                                    else 430
                                                )
                                                if state == 429:
                                                    return -0.175678
                                                if state == 430:
                                                    state = (
                                                        543
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.5310688)
                                                        else 544
                                                    )
                                                    if state == 543:
                                                        return 0.472259462
                                                    if state == 544:
                                                        return -0.163428575
            if state == 2:
                state = (
                    5 if np.isnan(x["col_last"]) or (x["col_last"] < 0.372454643) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.666071415)
                        else 12
                    )
                    if state == 11:
                        state = 23 if x["col_last"] < 0.156485558 else 24
                        if state == 23:
                            return -0.455729157
                        if state == 24:
                            state = (
                                45
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 67.9135895)
                                else 46
                            )
                            if state == 45:
                                state = 83 if x["mag_peak"] < 18.7529678 else 84
                                if state == 83:
                                    state = (
                                        137
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.7848415)
                                        else 138
                                    )
                                    if state == 137:
                                        state = (
                                            215
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.9275513)
                                            else 216
                                        )
                                        if state == 215:
                                            return -0.167151064
                                        if state == 216:
                                            return 0.235292971
                                    if state == 138:
                                        state = (
                                            217
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.0893555)
                                            else 218
                                        )
                                        if state == 217:
                                            return 0.0321353637
                                        if state == 218:
                                            return 0.444781631
                                if state == 84:
                                    state = (
                                        139
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.8369904)
                                        else 140
                                    )
                                    if state == 139:
                                        state = (
                                            219
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.97365)
                                            else 220
                                        )
                                        if state == 219:
                                            return -0.263464272
                                        if state == 220:
                                            return 0.392209619
                                    if state == 140:
                                        return -0.468797892
                            if state == 46:
                                state = 85 if x["mag_peak"] < 18.9526997 else 86
                                if state == 85:
                                    state = (
                                        141
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.4228573)
                                        else 142
                                    )
                                    if state == 141:
                                        state = (
                                            221
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 16.855547)
                                            else 222
                                        )
                                        if state == 221:
                                            return 0.332413793
                                        if state == 222:
                                            state = (
                                                323
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.231473446)
                                                else 324
                                            )
                                            if state == 323:
                                                state = (
                                                    431
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 17.0181847)
                                                    else 432
                                                )
                                                if state == 431:
                                                    return 0.324304938
                                                if state == 432:
                                                    state = (
                                                        545
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.3114319)
                                                        else 546
                                                    )
                                                    if state == 545:
                                                        state = (
                                                            673
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.549166679
                                                            )
                                                            else 674
                                                        )
                                                        if state == 673:
                                                            return -0.396224856
                                                        if state == 674:
                                                            return 0.0744587705
                                                    if state == 546:
                                                        return -0.366500169
                                            if state == 324:
                                                return 0.289824665
                                    if state == 142:
                                        state = (
                                            223
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.1093998)
                                            else 224
                                        )
                                        if state == 223:
                                            return 0.246701941
                                        if state == 224:
                                            state = (
                                                325
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.309915543)
                                                else 326
                                            )
                                            if state == 325:
                                                state = (
                                                    433
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.674099)
                                                    else 434
                                                )
                                                if state == 433:
                                                    state = (
                                                        547
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2244759)
                                                        else 548
                                                    )
                                                    if state == 547:
                                                        return 0.426701486
                                                    if state == 548:
                                                        return 0.280632913
                                                if state == 434:
                                                    return 0.475158602
                                            if state == 326:
                                                return -0.138955638
                                if state == 86:
                                    state = (
                                        143
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.9065208)
                                        else 144
                                    )
                                    if state == 143:
                                        state = (
                                            225
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.3565502)
                                            else 226
                                        )
                                        if state == 225:
                                            return -0.393411487
                                        if state == 226:
                                            return 0.423774362
                                    if state == 144:
                                        return -0.492154777
                    if state == 12:
                        state = 25 if x["col_last"] < 0.211855412 else 26
                        if state == 25:
                            return -0.441984832
                        if state == 26:
                            state = (
                                47
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 75.9271088)
                                else 48
                            )
                            if state == 47:
                                state = 87 if x["mag_peak"] < 18.7970295 else 88
                                if state == 87:
                                    state = (
                                        145
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.3282204)
                                        else 146
                                    )
                                    if state == 145:
                                        state = (
                                            227
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.1867504)
                                            else 228
                                        )
                                        if state == 227:
                                            return 0.199438781
                                        if state == 228:
                                            state = (
                                                327
                                                if x["col_last"] < 0.338297844
                                                else 328
                                            )
                                            if state == 327:
                                                return 0.0713671371
                                            if state == 328:
                                                state = (
                                                    435
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.2093315)
                                                    else 436
                                                )
                                                if state == 435:
                                                    return -0.291280895
                                                if state == 436:
                                                    state = (
                                                        549
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.4120255)
                                                        else 550
                                                    )
                                                    if state == 549:
                                                        state = (
                                                            675
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.686666727
                                                            )
                                                            else 676
                                                        )
                                                        if state == 675:
                                                            return 0.272740304
                                                        if state == 676:
                                                            return -0.0456305817
                                                    if state == 550:
                                                        state = (
                                                            677
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.692857146
                                                            )
                                                            else 678
                                                        )
                                                        if state == 677:
                                                            return 0.26572448
                                                        if state == 678:
                                                            return -0.194776431
                                    if state == 146:
                                        state = (
                                            229
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.383049)
                                            else 230
                                        )
                                        if state == 229:
                                            state = (
                                                329
                                                if x["col_last"] < 0.344808578
                                                else 330
                                            )
                                            if state == 329:
                                                return -0.253464758
                                            if state == 330:
                                                state = (
                                                    437
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.997345)
                                                    else 438
                                                )
                                                if state == 437:
                                                    state = (
                                                        551
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.5629215)
                                                        else 552
                                                    )
                                                    if state == 551:
                                                        state = (
                                                            679
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.946428537
                                                            )
                                                            else 680
                                                        )
                                                        if state == 679:
                                                            return 0.298340321
                                                        if state == 680:
                                                            return -0.1710805
                                                    if state == 552:
                                                        return 0.379804283
                                                if state == 438:
                                                    state = (
                                                        553
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.0069275)
                                                        else 554
                                                    )
                                                    if state == 553:
                                                        return -0.346015692
                                                    if state == 554:
                                                        state = (
                                                            683
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.708809495
                                                            )
                                                            else 684
                                                        )
                                                        if state == 683:
                                                            return -0.146668911
                                                        if state == 684:
                                                            return 0.337899089
                                        if state == 230:
                                            return 0.508770287
                                if state == 88:
                                    state = (
                                        147
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.4099426)
                                        else 148
                                    )
                                    if state == 147:
                                        state = (
                                            231
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.9337006)
                                            else 232
                                        )
                                        if state == 231:
                                            return -0.246908724
                                        if state == 232:
                                            return 0.299923599
                                    if state == 148:
                                        return -0.48380965
                            if state == 48:
                                state = 89 if x["mag_peak"] < 18.0661545 else 90
                                if state == 89:
                                    state = (
                                        149
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.2039299)
                                        else 150
                                    )
                                    if state == 149:
                                        state = (
                                            233
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.9856491)
                                            else 234
                                        )
                                        if state == 233:
                                            return 0.37135011
                                        if state == 234:
                                            return -0.222099289
                                    if state == 150:
                                        return 0.432719558
                                if state == 90:
                                    state = (
                                        151
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.2940483)
                                        else 152
                                    )
                                    if state == 151:
                                        state = (
                                            237
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.0435486)
                                            else 238
                                        )
                                        if state == 237:
                                            return 0.13687785
                                        if state == 238:
                                            return -0.300929934
                                    if state == 152:
                                        state = (
                                            239
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.0711498)
                                            else 240
                                        )
                                        if state == 239:
                                            return -0.220507756
                                        if state == 240:
                                            state = (
                                                331
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.281835318)
                                                else 332
                                            )
                                            if state == 331:
                                                state = (
                                                    439
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.3664284)
                                                    else 440
                                                )
                                                if state == 439:
                                                    state = (
                                                        555
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3648682)
                                                        else 556
                                                    )
                                                    if state == 555:
                                                        state = (
                                                            685
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.943571448
                                                            )
                                                            else 686
                                                        )
                                                        if state == 685:
                                                            return -0.405555129
                                                        if state == 686:
                                                            return 0.1847561
                                                    if state == 556:
                                                        return 0.188286111
                                                if state == 440:
                                                    return -0.463937342
                                            if state == 332:
                                                state = (
                                                    441
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.5238361)
                                                    else 442
                                                )
                                                if state == 441:
                                                    state = (
                                                        557
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2172928)
                                                        else 558
                                                    )
                                                    if state == 557:
                                                        return -0.126422778
                                                    if state == 558:
                                                        return 0.249470785
                                                if state == 442:
                                                    return -0.353422076
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.439166486)
                        else 14
                    )
                    if state == 13:
                        return -0.314084381
                    if state == 14:
                        state = 27 if x["col_last"] < 1.39204121 else 28
                        if state == 27:
                            return 0.367569327
                        if state == 28:
                            state = (
                                49
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 69.3949738)
                                else 50
                            )
                            if state == 49:
                                state = 91 if x["mag_peak"] < 17.4543953 else 92
                                if state == 91:
                                    return -0.237042353
                                if state == 92:
                                    return 0.148151428
                            if state == 50:
                                return -0.527462006
    elif num_booster == 3:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_last"]) or (x["col_last"] < 0.616479874) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.3788338) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.286679745)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.9480152)
                            else 16
                        )
                        if state == 15:
                            state = (
                                31
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.4967499)
                                else 32
                            )
                            if state == 31:
                                state = 61 if x["col_det"] < 0.599760532 else 62
                                if state == 61:
                                    state = (
                                        113 if x["distpsnr1_med"] < 1.04677176 else 114
                                    )
                                    if state == 113:
                                        state = (
                                            197
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.8835201)
                                            else 198
                                        )
                                        if state == 197:
                                            state = (
                                                321
                                                if x["col_det"] < 0.160914421
                                                else 322
                                            )
                                            if state == 321:
                                                state = (
                                                    481
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.60571444)
                                                    else 482
                                                )
                                                if state == 481:
                                                    return -0.359950304
                                                if state == 482:
                                                    state = (
                                                        671
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.3899231)
                                                        else 672
                                                    )
                                                    if state == 671:
                                                        return 0.41053912
                                                    if state == 672:
                                                        return 0.129034072
                                            if state == 322:
                                                state = (
                                                    483
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.929285765)
                                                    else 484
                                                )
                                                if state == 483:
                                                    return -0.399646163
                                                if state == 484:
                                                    return 0.300444096
                                        if state == 198:
                                            return -0.448690325
                                    if state == 114:
                                        state = (
                                            199
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 16.4106827)
                                            else 200
                                        )
                                        if state == 199:
                                            return -0.349865288
                                        if state == 200:
                                            return 0.375976533
                                if state == 62:
                                    state = (
                                        115
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 1.24073291)
                                        else 116
                                    )
                                    if state == 115:
                                        state = (
                                            201
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.2062531)
                                            else 202
                                        )
                                        if state == 201:
                                            return -0.40398699
                                        if state == 202:
                                            return -0.501380444
                                    if state == 116:
                                        state = (
                                            203
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.7244663)
                                            else 204
                                        )
                                        if state == 203:
                                            state = (
                                                323
                                                if x["col_det"] < 1.29060078
                                                else 324
                                            )
                                            if state == 323:
                                                return -0.116207041
                                            if state == 324:
                                                state = (
                                                    485
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.261428505)
                                                    else 486
                                                )
                                                if state == 485:
                                                    return -0.18658483
                                                if state == 486:
                                                    return 0.443721175
                                        if state == 204:
                                            return -0.111747555
                            if state == 32:
                                state = 63 if x["col_det"] < -0.298604965 else 64
                                if state == 63:
                                    state = (
                                        117
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.413359761)
                                        else 118
                                    )
                                    if state == 117:
                                        return -0.493567556
                                    if state == 118:
                                        state = (
                                            205
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 17.7851734)
                                            else 206
                                        )
                                        if state == 205:
                                            state = (
                                                325
                                                if x["col_det"] < -0.328598976
                                                else 326
                                            )
                                            if state == 325:
                                                return 0.139754191
                                            if state == 326:
                                                return -0.294871539
                                        if state == 206:
                                            state = (
                                                327
                                                if x["col_det"] < -0.321150303
                                                else 328
                                            )
                                            if state == 327:
                                                state = (
                                                    487
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.744047642)
                                                    else 488
                                                )
                                                if state == 487:
                                                    state = (
                                                        673
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.6801643)
                                                        else 674
                                                    )
                                                    if state == 673:
                                                        return -0.0324447975
                                                    if state == 674:
                                                        return 0.280608624
                                                if state == 488:
                                                    return 0.4559201
                                            if state == 328:
                                                state = (
                                                    489
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.91107136)
                                                    else 490
                                                )
                                                if state == 489:
                                                    state = (
                                                        675
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.7435951)
                                                        else 676
                                                    )
                                                    if state == 675:
                                                        state = (
                                                            897
                                                            if x["col_peak"]
                                                            < -0.300398827
                                                            else 898
                                                        )
                                                        if state == 897:
                                                            return 0.132560238
                                                        if state == 898:
                                                            return -0.246109992
                                                    if state == 676:
                                                        return 0.29650858
                                                if state == 490:
                                                    return -0.539771497
                                if state == 64:
                                    state = (
                                        119 if x["distpsnr1_med"] < 0.217572317 else 120
                                    )
                                    if state == 119:
                                        state = (
                                            207
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 17.8309784)
                                            else 208
                                        )
                                        if state == 207:
                                            state = (
                                                329
                                                if x["col_det"] < 0.17444706
                                                else 330
                                            )
                                            if state == 329:
                                                state = (
                                                    491
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.932857275)
                                                    else 492
                                                )
                                                if state == 491:
                                                    return -0.196718425
                                                if state == 492:
                                                    return 0.117506474
                                            if state == 330:
                                                return -0.581473231
                                        if state == 208:
                                            state = (
                                                331
                                                if x["col_det"] < -0.151412964
                                                else 332
                                            )
                                            if state == 331:
                                                return -0.546256304
                                            if state == 332:
                                                state = (
                                                    493
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.940357447)
                                                    else 494
                                                )
                                                if state == 493:
                                                    state = (
                                                        677
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.8140411)
                                                        else 678
                                                    )
                                                    if state == 677:
                                                        state = (
                                                            899
                                                            if x["col_peak"] < 0.000001
                                                            else 900
                                                        )
                                                        if state == 899:
                                                            return -0.336625636
                                                        if state == 900:
                                                            return -0.11692334
                                                    if state == 678:
                                                        return -0.337852001
                                                if state == 494:
                                                    state = (
                                                        679
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.477829)
                                                        else 680
                                                    )
                                                    if state == 679:
                                                        return 0.407048285
                                                    if state == 680:
                                                        return 0.0095706908
                                    if state == 120:
                                        state = (
                                            209
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.5515785)
                                            else 210
                                        )
                                        if state == 209:
                                            return 0.420864969
                                        if state == 210:
                                            state = (
                                                333
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.537599564)
                                                else 334
                                            )
                                            if state == 333:
                                                state = (
                                                    495
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.906071305)
                                                    else 496
                                                )
                                                if state == 495:
                                                    state = (
                                                        681
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.7830887)
                                                        else 682
                                                    )
                                                    if state == 681:
                                                        return 0.361741096
                                                    if state == 682:
                                                        state = (
                                                            901
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.322686195
                                                            )
                                                            else 902
                                                        )
                                                        if state == 901:
                                                            return 0.305433184
                                                        if state == 902:
                                                            return -0.151111022
                                                if state == 496:
                                                    state = (
                                                        683
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.7050781)
                                                        else 684
                                                    )
                                                    if state == 683:
                                                        state = (
                                                            903
                                                            if x["col_peak"] < 0.000001
                                                            else 904
                                                        )
                                                        if state == 903:
                                                            return -0.224982008
                                                        if state == 904:
                                                            return 0.357939631
                                                    if state == 684:
                                                        state = (
                                                            905
                                                            if x["col_peak"] < 0.000001
                                                            else 906
                                                        )
                                                        if state == 905:
                                                            return -0.213361636
                                                        if state == 906:
                                                            return 0.185683295
                                            if state == 334:
                                                state = (
                                                    497
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.790357232)
                                                    else 498
                                                )
                                                if state == 497:
                                                    return -0.406166524
                                                if state == 498:
                                                    return 0.116242386
                        if state == 16:
                            state = (
                                33
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.7574997)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    65
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.381807327)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        121
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.57477808)
                                        else 122
                                    )
                                    if state == 121:
                                        return -0.424410015
                                    if state == 122:
                                        state = (
                                            211
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.2551441)
                                            else 212
                                        )
                                        if state == 211:
                                            state = (
                                                335
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.0347146988)
                                                else 336
                                            )
                                            if state == 335:
                                                state = (
                                                    499
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.241547793)
                                                    else 500
                                                )
                                                if state == 499:
                                                    return -0.540158153
                                                if state == 500:
                                                    state = (
                                                        685
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2418804)
                                                        else 686
                                                    )
                                                    if state == 685:
                                                        return 0.172959536
                                                    if state == 686:
                                                        return 0.53558135
                                            if state == 336:
                                                state = (
                                                    501
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.837857127)
                                                    else 502
                                                )
                                                if state == 501:
                                                    state = (
                                                        687
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.223053)
                                                        else 688
                                                    )
                                                    if state == 687:
                                                        return -0.552254379
                                                    if state == 688:
                                                        return 0.112473488
                                                if state == 502:
                                                    state = (
                                                        689
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2062836)
                                                        else 690
                                                    )
                                                    if state == 689:
                                                        return 0.205359772
                                                    if state == 690:
                                                        return -0.120809026
                                        if state == 212:
                                            state = (
                                                337
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.15147686)
                                                else 338
                                            )
                                            if state == 337:
                                                state = (
                                                    503
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.633452415)
                                                    else 504
                                                )
                                                if state == 503:
                                                    state = (
                                                        691
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3382301)
                                                        else 692
                                                    )
                                                    if state == 691:
                                                        return -0.635457397
                                                    if state == 692:
                                                        state = (
                                                            909
                                                            if x["col_peak"] < 0.000001
                                                            else 910
                                                        )
                                                        if state == 909:
                                                            return 0.258937359
                                                        if state == 910:
                                                            return -0.274805933
                                                if state == 504:
                                                    state = (
                                                        693
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2785454)
                                                        else 694
                                                    )
                                                    if state == 693:
                                                        return -0.398469955
                                                    if state == 694:
                                                        state = (
                                                            911
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.3625741
                                                            )
                                                            else 912
                                                        )
                                                        if state == 911:
                                                            return -0.0702316537
                                                        if state == 912:
                                                            return 0.20586732
                                            if state == 338:
                                                return -0.452982754
                                if state == 66:
                                    state = (
                                        123 if x["distpsnr1_med"] < 1.45543242 else 124
                                    )
                                    if state == 123:
                                        return -0.41537714
                                    if state == 124:
                                        return 0.385522306
                            if state == 34:
                                state = (
                                    67
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.038684845)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        125 if x["distpsnr1_med"] < 0.372163385 else 126
                                    )
                                    if state == 125:
                                        state = (
                                            213
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.0092983)
                                            else 214
                                        )
                                        if state == 213:
                                            state = (
                                                339
                                                if x["col_det"] < -0.122068405
                                                else 340
                                            )
                                            if state == 339:
                                                return 0.160765961
                                            if state == 340:
                                                state = (
                                                    505
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.663333356)
                                                    else 506
                                                )
                                                if state == 505:
                                                    return 0.178740814
                                                if state == 506:
                                                    state = (
                                                        695
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9910164)
                                                        else 696
                                                    )
                                                    if state == 695:
                                                        return -0.597585559
                                                    if state == 696:
                                                        return 0.237986133
                                        if state == 214:
                                            state = (
                                                341
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.127450943)
                                                else 342
                                            )
                                            if state == 341:
                                                state = (
                                                    507
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.653333306)
                                                    else 508
                                                )
                                                if state == 507:
                                                    return -0.641925514
                                                if state == 508:
                                                    state = (
                                                        697
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3597488)
                                                        else 698
                                                    )
                                                    if state == 697:
                                                        return -0.468407184
                                                    if state == 698:
                                                        return -0.0836761594
                                            if state == 342:
                                                state = (
                                                    509
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.665833354)
                                                    else 510
                                                )
                                                if state == 509:
                                                    return 0.286338985
                                                if state == 510:
                                                    return -0.253967494
                                    if state == 126:
                                        state = (
                                            215
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.0433769)
                                            else 216
                                        )
                                        if state == 215:
                                            state = (
                                                343
                                                if x["col_det"] < -0.394657135
                                                else 344
                                            )
                                            if state == 343:
                                                state = (
                                                    511
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.866428614)
                                                    else 512
                                                )
                                                if state == 511:
                                                    return -0.483516395
                                                if state == 512:
                                                    return 0.251698077
                                            if state == 344:
                                                state = (
                                                    513
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.449166656)
                                                    else 514
                                                )
                                                if state == 513:
                                                    state = (
                                                        699
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0095844)
                                                        else 700
                                                    )
                                                    if state == 699:
                                                        return 0.0999343917
                                                    if state == 700:
                                                        return -0.256243736
                                                if state == 514:
                                                    state = (
                                                        701
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9493866)
                                                        else 702
                                                    )
                                                    if state == 701:
                                                        return -0.389802903
                                                    if state == 702:
                                                        state = (
                                                            913
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.316684723
                                                            )
                                                            else 914
                                                        )
                                                        if state == 913:
                                                            return 0.385287195
                                                        if state == 914:
                                                            return 0.0559516363
                                        if state == 216:
                                            state = (
                                                345
                                                if x["col_det"] < -0.472396374
                                                else 346
                                            )
                                            if state == 345:
                                                return -0.457061112
                                            if state == 346:
                                                state = (
                                                    515
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.372262061)
                                                    else 516
                                                )
                                                if state == 515:
                                                    state = (
                                                        703
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1840019)
                                                        else 704
                                                    )
                                                    if state == 703:
                                                        return -0.104992479
                                                    if state == 704:
                                                        return -0.44823277
                                                if state == 516:
                                                    state = (
                                                        705
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3453293)
                                                        else 706
                                                    )
                                                    if state == 705:
                                                        state = (
                                                            915
                                                            if x["col_peak"]
                                                            < -0.393837929
                                                            else 916
                                                        )
                                                        if state == 915:
                                                            return -0.161199957
                                                        if state == 916:
                                                            return 0.123145618
                                                    if state == 706:
                                                        return 0.310649931
                                if state == 68:
                                    state = (
                                        127 if x["distpsnr1_med"] < 3.09156871 else 128
                                    )
                                    if state == 127:
                                        state = (
                                            217
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.0976105)
                                            else 218
                                        )
                                        if state == 217:
                                            state = (
                                                347
                                                if x["col_det"] < 0.0558605194
                                                else 348
                                            )
                                            if state == 347:
                                                state = (
                                                    517
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.725714266)
                                                    else 518
                                                )
                                                if state == 517:
                                                    return 0.437761217
                                                if state == 518:
                                                    state = (
                                                        707
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0151539)
                                                        else 708
                                                    )
                                                    if state == 707:
                                                        return -0.444217324
                                                    if state == 708:
                                                        return 0.221973032
                                            if state == 348:
                                                state = (
                                                    519
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.748095155)
                                                    else 520
                                                )
                                                if state == 519:
                                                    state = (
                                                        709
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0448532)
                                                        else 710
                                                    )
                                                    if state == 709:
                                                        return -0.0437915437
                                                    if state == 710:
                                                        return 0.270283431
                                                if state == 520:
                                                    state = (
                                                        711
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0708485)
                                                        else 712
                                                    )
                                                    if state == 711:
                                                        return -0.365551651
                                                    if state == 712:
                                                        return 0.191765621
                                        if state == 218:
                                            state = (
                                                349
                                                if x["col_det"] < 0.410056114
                                                else 350
                                            )
                                            if state == 349:
                                                state = (
                                                    521
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.685119033)
                                                    else 522
                                                )
                                                if state == 521:
                                                    state = (
                                                        713
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1595154)
                                                        else 714
                                                    )
                                                    if state == 713:
                                                        return 0.256677061
                                                    if state == 714:
                                                        return -0.0106042707
                                                if state == 522:
                                                    state = (
                                                        715
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2787895)
                                                        else 716
                                                    )
                                                    if state == 715:
                                                        return -0.428823918
                                                    if state == 716:
                                                        return 0.0219858121
                                            if state == 350:
                                                return -0.538371205
                                    if state == 128:
                                        state = (
                                            219
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.1586304)
                                            else 220
                                        )
                                        if state == 219:
                                            state = (
                                                351
                                                if x["col_det"] < 0.0957250595
                                                else 352
                                            )
                                            if state == 351:
                                                state = (
                                                    523
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.925000012)
                                                    else 524
                                                )
                                                if state == 523:
                                                    return -0.852737963
                                                if state == 524:
                                                    state = (
                                                        717
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0920029)
                                                        else 718
                                                    )
                                                    if state == 717:
                                                        return -0.224842712
                                                    if state == 718:
                                                        return 0.0582866073
                                            if state == 352:
                                                state = (
                                                    525
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.786428571)
                                                    else 526
                                                )
                                                if state == 525:
                                                    state = (
                                                        719
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.966589)
                                                        else 720
                                                    )
                                                    if state == 719:
                                                        return 0.12110918
                                                    if state == 720:
                                                        return -0.289615512
                                                if state == 526:
                                                    return 0.280852735
                                        if state == 220:
                                            state = (
                                                353
                                                if x["col_det"] < 0.146383286
                                                else 354
                                            )
                                            if state == 353:
                                                state = (
                                                    527
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.883214295)
                                                    else 528
                                                )
                                                if state == 527:
                                                    return -0.479890108
                                                if state == 528:
                                                    state = (
                                                        721
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2330093)
                                                        else 722
                                                    )
                                                    if state == 721:
                                                        return 0.133499235
                                                    if state == 722:
                                                        return -0.179474488
                                            if state == 354:
                                                state = (
                                                    529
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.663809538)
                                                    else 530
                                                )
                                                if state == 529:
                                                    state = (
                                                        723
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2047977)
                                                        else 724
                                                    )
                                                    if state == 723:
                                                        return -0.0316882916
                                                    if state == 724:
                                                        return 0.293520153
                                                if state == 530:
                                                    state = (
                                                        725
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2820053)
                                                        else 726
                                                    )
                                                    if state == 725:
                                                        return 0.116242386
                                                    if state == 726:
                                                        return -0.20219405
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.7041359)
                            else 18
                        )
                        if state == 17:
                            state = (
                                35
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 16.9290009)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    69
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.431985378)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        129 if x["distpsnr1_med"] < 0.480679572 else 130
                                    )
                                    if state == 129:
                                        state = (
                                            221
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.3996315)
                                            else 222
                                        )
                                        if state == 221:
                                            state = (
                                                355
                                                if x["col_det"] < -0.116334915
                                                else 356
                                            )
                                            if state == 355:
                                                return 0.363859922
                                            if state == 356:
                                                state = (
                                                    531
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.870119095)
                                                    else 532
                                                )
                                                if state == 531:
                                                    state = (
                                                        727
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.3084641)
                                                        else 728
                                                    )
                                                    if state == 727:
                                                        return -0.5275653
                                                    if state == 728:
                                                        state = (
                                                            919
                                                            if x["col_peak"]
                                                            < 0.113992214
                                                            else 920
                                                        )
                                                        if state == 919:
                                                            return -0.287297159
                                                        if state == 920:
                                                            return 0.23100619
                                                if state == 532:
                                                    return 0.118191071
                                        if state == 222:
                                            return -0.550260603
                                    if state == 130:
                                        state = (
                                            223
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 16.946579)
                                            else 224
                                        )
                                        if state == 223:
                                            return -0.423232704
                                        if state == 224:
                                            state = (
                                                357
                                                if x["col_det"] < 0.216386169
                                                else 358
                                            )
                                            if state == 357:
                                                state = (
                                                    533
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.84214282)
                                                    else 534
                                                )
                                                if state == 533:
                                                    state = (
                                                        729
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.0865364)
                                                        else 730
                                                    )
                                                    if state == 729:
                                                        return -0.386517435
                                                    if state == 730:
                                                        return -0.101550505
                                                if state == 534:
                                                    return 0.177307487
                                            if state == 358:
                                                state = (
                                                    535
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.464285702)
                                                    else 536
                                                )
                                                if state == 535:
                                                    return -0.205501378
                                                if state == 536:
                                                    state = (
                                                        731
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.590168)
                                                        else 732
                                                    )
                                                    if state == 731:
                                                        return 0.435746878
                                                    if state == 732:
                                                        state = (
                                                            921
                                                            if x["col_peak"]
                                                            < 0.259336948
                                                            else 922
                                                        )
                                                        if state == 921:
                                                            return 0.122751527
                                                        if state == 922:
                                                            return -0.272828341
                                if state == 70:
                                    return -0.471063048
                            if state == 36:
                                state = 71 if x["col_det"] < -0.362645149 else 72
                                if state == 71:
                                    state = (
                                        131 if x["distpsnr1_med"] < 3.36327362 else 132
                                    )
                                    if state == 131:
                                        state = (
                                            225
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.5422764)
                                            else 226
                                        )
                                        if state == 225:
                                            return 0.285456538
                                        if state == 226:
                                            return -0.755780876
                                    if state == 132:
                                        return 0.316315383
                                if state == 72:
                                    state = (
                                        133 if x["distpsnr1_med"] < 0.218177438 else 134
                                    )
                                    if state == 133:
                                        state = (
                                            227
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.6534538)
                                            else 228
                                        )
                                        if state == 227:
                                            state = (
                                                359
                                                if x["col_det"] < -0.176034927
                                                else 360
                                            )
                                            if state == 359:
                                                return -0.846675396
                                            if state == 360:
                                                state = (
                                                    537
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.942857146)
                                                    else 538
                                                )
                                                if state == 537:
                                                    state = (
                                                        733
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.9455032)
                                                        else 734
                                                    )
                                                    if state == 733:
                                                        return -0.444148093
                                                    if state == 734:
                                                        state = (
                                                            923
                                                            if x["col_peak"]
                                                            < 0.437022209
                                                            else 924
                                                        )
                                                        if state == 923:
                                                            return -0.266229719
                                                        if state == 924:
                                                            return 0.261317879
                                                if state == 538:
                                                    return 0.21085979
                                        if state == 228:
                                            state = (
                                                361
                                                if x["col_det"] < 0.0714350194
                                                else 362
                                            )
                                            if state == 361:
                                                return 0.239156365
                                            if state == 362:
                                                state = (
                                                    539
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.763333321)
                                                    else 540
                                                )
                                                if state == 539:
                                                    return -0.189336732
                                                if state == 540:
                                                    return 0.0907755941
                                    if state == 134:
                                        state = (
                                            229
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 17.7198715)
                                            else 230
                                        )
                                        if state == 229:
                                            return 0.452875733
                                        if state == 230:
                                            state = (
                                                363
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.0716991425)
                                                else 364
                                            )
                                            if state == 363:
                                                state = (
                                                    541
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.500000179)
                                                    else 542
                                                )
                                                if state == 541:
                                                    state = (
                                                        737
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.9162178)
                                                        else 738
                                                    )
                                                    if state == 737:
                                                        state = (
                                                            925
                                                            if x["col_peak"]
                                                            < -0.0413212776
                                                            else 926
                                                        )
                                                        if state == 925:
                                                            return -0.135087371
                                                        if state == 926:
                                                            return 0.13598153
                                                    if state == 738:
                                                        state = (
                                                            927
                                                            if x["col_peak"]
                                                            < -0.275693417
                                                            else 928
                                                        )
                                                        if state == 927:
                                                            return -0.155534938
                                                        if state == 928:
                                                            return 0.294263393
                                                if state == 542:
                                                    state = (
                                                        739
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.7289963)
                                                        else 740
                                                    )
                                                    if state == 739:
                                                        return -0.0297803469
                                                    if state == 740:
                                                        state = (
                                                            929
                                                            if x["col_peak"]
                                                            < -0.207659245
                                                            else 930
                                                        )
                                                        if state == 929:
                                                            return 0.273748368
                                                        if state == 930:
                                                            return 0.433595181
                                            if state == 364:
                                                state = (
                                                    543
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.688809514)
                                                    else 544
                                                )
                                                if state == 543:
                                                    state = (
                                                        741
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.8324318)
                                                        else 742
                                                    )
                                                    if state == 741:
                                                        return -0.0145591432
                                                    if state == 742:
                                                        return 0.431832433
                                                if state == 544:
                                                    state = (
                                                        743
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.7346001)
                                                        else 744
                                                    )
                                                    if state == 743:
                                                        return 0.0129982755
                                                    if state == 744:
                                                        state = (
                                                            931
                                                            if x["col_peak"]
                                                            < -0.100352764
                                                            else 932
                                                        )
                                                        if state == 931:
                                                            return 0.15210703
                                                        if state == 932:
                                                            return 0.361104518
                        if state == 18:
                            state = (
                                37
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.2270012)
                                else 38
                            )
                            if state == 37:
                                state = 73 if x["col_det"] < 0.465084076 else 74
                                if state == 73:
                                    state = (
                                        135 if x["distpsnr1_med"] < 0.663879395 else 136
                                    )
                                    if state == 135:
                                        return -0.381066054
                                    if state == 136:
                                        state = (
                                            231
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.7436447)
                                            else 232
                                        )
                                        if state == 231:
                                            return -0.0247439258
                                        if state == 232:
                                            state = (
                                                365
                                                if x["col_det"] < -0.151802063
                                                else 366
                                            )
                                            if state == 365:
                                                return -0.38455385
                                            if state == 366:
                                                return 0.383632094
                                if state == 74:
                                    state = (
                                        137 if x["distpsnr1_med"] < 0.438700467 else 138
                                    )
                                    if state == 137:
                                        return -0.529362082
                                    if state == 138:
                                        state = (
                                            233
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.7555351)
                                            else 234
                                        )
                                        if state == 233:
                                            return -0.173807368
                                        if state == 234:
                                            return 0.340087593
                            if state == 38:
                                state = 75 if x["col_det"] < -0.332505226 else 76
                                if state == 75:
                                    state = (
                                        139 if x["distpsnr1_med"] < 3.8537426 else 140
                                    )
                                    if state == 139:
                                        state = (
                                            235
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.1818619)
                                            else 236
                                        )
                                        if state == 235:
                                            state = (
                                                367
                                                if x["col_det"] < -0.433548927
                                                else 368
                                            )
                                            if state == 367:
                                                state = (
                                                    545
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.748452425)
                                                    else 546
                                                )
                                                if state == 545:
                                                    state = (
                                                        745
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9684792)
                                                        else 746
                                                    )
                                                    if state == 745:
                                                        return 0.303266793
                                                    if state == 746:
                                                        state = (
                                                            933
                                                            if x["col_peak"]
                                                            < 0.0270490646
                                                            else 934
                                                        )
                                                        if state == 933:
                                                            return -0.32933867
                                                        if state == 934:
                                                            return 0.209227979
                                                if state == 546:
                                                    return 0.359666854
                                            if state == 368:
                                                state = (
                                                    547
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.667261899)
                                                    else 548
                                                )
                                                if state == 547:
                                                    return -0.76699084
                                                if state == 548:
                                                    state = (
                                                        747
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9966755)
                                                        else 748
                                                    )
                                                    if state == 747:
                                                        state = (
                                                            935
                                                            if x["col_peak"]
                                                            < -0.109489441
                                                            else 936
                                                        )
                                                        if state == 935:
                                                            return -0.423184752
                                                        if state == 936:
                                                            return 0.13332805
                                                    if state == 748:
                                                        return 0.163221166
                                        if state == 236:
                                            state = (
                                                369
                                                if x["col_det"] < -0.428199768
                                                else 370
                                            )
                                            if state == 369:
                                                state = (
                                                    549
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.755714059)
                                                    else 550
                                                )
                                                if state == 549:
                                                    return -0.372477919
                                                if state == 550:
                                                    return 0.233964831
                                            if state == 370:
                                                state = (
                                                    551
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.649999976)
                                                    else 552
                                                )
                                                if state == 551:
                                                    return -0.542376995
                                                if state == 552:
                                                    state = (
                                                        749
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2217178)
                                                        else 750
                                                    )
                                                    if state == 749:
                                                        return 0.124147728
                                                    if state == 750:
                                                        state = (
                                                            937
                                                            if x["col_peak"]
                                                            < -0.0534553528
                                                            else 938
                                                        )
                                                        if state == 937:
                                                            return -0.147267669
                                                        if state == 938:
                                                            return 0.037605878
                                    if state == 140:
                                        state = (
                                            237
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.2624016)
                                            else 238
                                        )
                                        if state == 237:
                                            state = (
                                                371
                                                if x["col_det"] < -0.341970444
                                                else 372
                                            )
                                            if state == 371:
                                                return 0.431012034
                                            if state == 372:
                                                return -0.236674756
                                        if state == 238:
                                            state = (
                                                373
                                                if x["col_det"] < -0.346968174
                                                else 374
                                            )
                                            if state == 373:
                                                return 0.115722314
                                            if state == 374:
                                                return -0.303348452
                                if state == 76:
                                    state = (
                                        141
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.364808023)
                                        else 142
                                    )
                                    if state == 141:
                                        state = (
                                            239
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.2609596)
                                            else 240
                                        )
                                        if state == 239:
                                            state = (
                                                375
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.0173101425)
                                                else 376
                                            )
                                            if state == 375:
                                                state = (
                                                    553
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.811428428)
                                                    else 554
                                                )
                                                if state == 553:
                                                    state = (
                                                        751
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0645657)
                                                        else 752
                                                    )
                                                    if state == 751:
                                                        state = (
                                                            939
                                                            if x["col_peak"]
                                                            < -0.20591259
                                                            else 940
                                                        )
                                                        if state == 939:
                                                            return -0.275894016
                                                        if state == 940:
                                                            return 0.187994361
                                                    if state == 752:
                                                        state = (
                                                            941
                                                            if x["col_peak"]
                                                            < -0.0294971466
                                                            else 942
                                                        )
                                                        if state == 941:
                                                            return 0.0419144221
                                                        if state == 942:
                                                            return -0.529191971
                                                if state == 554:
                                                    return -0.546547174
                                            if state == 376:
                                                return 0.329381555
                                        if state == 240:
                                            state = (
                                                377
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.17990303)
                                                else 378
                                            )
                                            if state == 377:
                                                state = (
                                                    555
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.701666653)
                                                    else 556
                                                )
                                                if state == 555:
                                                    state = (
                                                        753
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3598728)
                                                        else 754
                                                    )
                                                    if state == 753:
                                                        state = (
                                                            943
                                                            if x["col_peak"]
                                                            < -0.0272583961
                                                            else 944
                                                        )
                                                        if state == 943:
                                                            return 0.073904179
                                                        if state == 944:
                                                            return -0.403180629
                                                    if state == 754:
                                                        return 0.148695603
                                                if state == 556:
                                                    return -0.449667752
                                            if state == 378:
                                                return 0.172592878
                                    if state == 142:
                                        state = (
                                            241
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.3724594)
                                            else 242
                                        )
                                        if state == 241:
                                            state = (
                                                379
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.0997180939)
                                                else 380
                                            )
                                            if state == 379:
                                                state = (
                                                    559
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.955714345)
                                                    else 560
                                                )
                                                if state == 559:
                                                    state = (
                                                        755
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.7105427)
                                                        else 756
                                                    )
                                                    if state == 755:
                                                        state = (
                                                            945
                                                            if x["col_peak"]
                                                            < 0.0790066719
                                                            else 946
                                                        )
                                                        if state == 945:
                                                            return 0.188456059
                                                        if state == 946:
                                                            return -0.33120656
                                                    if state == 756:
                                                        state = (
                                                            947
                                                            if x["col_peak"]
                                                            < -0.166150093
                                                            else 948
                                                        )
                                                        if state == 947:
                                                            return 0.256200194
                                                        if state == 948:
                                                            return 0.358338624
                                                if state == 560:
                                                    state = (
                                                        757
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.815731)
                                                        else 758
                                                    )
                                                    if state == 757:
                                                        return 0.219564021
                                                    if state == 758:
                                                        state = (
                                                            949
                                                            if x["col_peak"]
                                                            < 0.148665428
                                                            else 950
                                                        )
                                                        if state == 949:
                                                            return -0.745066464
                                                        if state == 950:
                                                            return 0.227250054
                                            if state == 380:
                                                state = (
                                                    561
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.745000005)
                                                    else 562
                                                )
                                                if state == 561:
                                                    state = (
                                                        759
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9271507)
                                                        else 760
                                                    )
                                                    if state == 759:
                                                        state = (
                                                            951
                                                            if x["col_peak"]
                                                            < -0.0960388184
                                                            else 952
                                                        )
                                                        if state == 951:
                                                            return -0.0865878165
                                                        if state == 952:
                                                            return 0.298477173
                                                    if state == 760:
                                                        state = (
                                                            953
                                                            if x["col_peak"]
                                                            < 0.399737358
                                                            else 954
                                                        )
                                                        if state == 953:
                                                            return 0.00240638712
                                                        if state == 954:
                                                            return 0.384090751
                                                if state == 562:
                                                    state = (
                                                        761
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0226097)
                                                        else 762
                                                    )
                                                    if state == 761:
                                                        state = (
                                                            955
                                                            if x["col_peak"]
                                                            < -0.210534096
                                                            else 956
                                                        )
                                                        if state == 955:
                                                            return 0.0712775663
                                                        if state == 956:
                                                            return 0.378282249
                                                    if state == 762:
                                                        state = (
                                                            957
                                                            if x["col_peak"]
                                                            < 0.372321308
                                                            else 958
                                                        )
                                                        if state == 957:
                                                            return 0.177706316
                                                        if state == 958:
                                                            return 0.495718956
                                        if state == 242:
                                            state = (
                                                381
                                                if x["col_det"] < -0.0776430815
                                                else 382
                                            )
                                            if state == 381:
                                                state = (
                                                    563
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.301666737)
                                                    else 564
                                                )
                                                if state == 563:
                                                    return -0.472455978
                                                if state == 564:
                                                    state = (
                                                        763
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3757973)
                                                        else 764
                                                    )
                                                    if state == 763:
                                                        state = (
                                                            959
                                                            if x["col_peak"]
                                                            < -0.044552803
                                                            else 960
                                                        )
                                                        if state == 959:
                                                            return 0.192213938
                                                        if state == 960:
                                                            return -0.0524743497
                                                    if state == 764:
                                                        return -0.155886561
                                            if state == 382:
                                                state = (
                                                    565
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.641666651)
                                                    else 566
                                                )
                                                if state == 565:
                                                    state = (
                                                        765
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3752747)
                                                        else 766
                                                    )
                                                    if state == 765:
                                                        state = (
                                                            961
                                                            if x["col_peak"]
                                                            < -0.0255260468
                                                            else 962
                                                        )
                                                        if state == 961:
                                                            return -0.136294499
                                                        if state == 962:
                                                            return 0.208225876
                                                    if state == 766:
                                                        return 0.304779142
                                                if state == 566:
                                                    state = (
                                                        767
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3749046)
                                                        else 768
                                                    )
                                                    if state == 767:
                                                        return -0.20477663
                                                    if state == 768:
                                                        state = (
                                                            963
                                                            if x["col_peak"]
                                                            < -0.119142532
                                                            else 964
                                                        )
                                                        if state == 963:
                                                            return -0.0959398597
                                                        if state == 964:
                                                            return 0.191477269
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.281188965)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.0352097)
                            else 20
                        )
                        if state == 19:
                            state = (
                                39
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.6814995)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    77
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.406999588)
                                    else 78
                                )
                                if state == 77:
                                    state = (
                                        143
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.460010111)
                                        else 144
                                    )
                                    if state == 143:
                                        state = (
                                            243
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.0217285)
                                            else 244
                                        )
                                        if state == 243:
                                            state = (
                                                383
                                                if x["col_det"] < 0.234882355
                                                else 384
                                            )
                                            if state == 383:
                                                state = (
                                                    567
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.713333368)
                                                    else 568
                                                )
                                                if state == 567:
                                                    return -0.274484694
                                                if state == 568:
                                                    state = (
                                                        769
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.7658806)
                                                        else 770
                                                    )
                                                    if state == 769:
                                                        return -0.0122836949
                                                    if state == 770:
                                                        return 0.409336925
                                            if state == 384:
                                                return -0.467947781
                                        if state == 244:
                                            return 0.169046834
                                    if state == 144:
                                        state = (
                                            245
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.7107449)
                                            else 246
                                        )
                                        if state == 245:
                                            state = (
                                                385
                                                if x["col_det"] < 0.0255565643
                                                else 386
                                            )
                                            if state == 385:
                                                state = (
                                                    569
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.61904788)
                                                    else 570
                                                )
                                                if state == 569:
                                                    return 0.348375589
                                                if state == 570:
                                                    state = (
                                                        773
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4394455)
                                                        else 774
                                                    )
                                                    if state == 773:
                                                        return -0.187118411
                                                    if state == 774:
                                                        state = (
                                                            965
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.437418461
                                                            )
                                                            else 966
                                                        )
                                                        if state == 965:
                                                            return -0.111992948
                                                        if state == 966:
                                                            return 0.296789527
                                            if state == 386:
                                                state = (
                                                    571
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.906785727)
                                                    else 572
                                                )
                                                if state == 571:
                                                    state = (
                                                        775
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4331532)
                                                        else 776
                                                    )
                                                    if state == 775:
                                                        return -0.623034358
                                                    if state == 776:
                                                        return -0.177333802
                                                if state == 572:
                                                    return 0.346134603
                                        if state == 246:
                                            state = (
                                                387
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.00958156586)
                                                else 388
                                            )
                                            if state == 387:
                                                state = (
                                                    573
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.608333349)
                                                    else 574
                                                )
                                                if state == 573:
                                                    state = (
                                                        777
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.90205)
                                                        else 778
                                                    )
                                                    if state == 777:
                                                        return 0.407657236
                                                    if state == 778:
                                                        return -0.184516668
                                                if state == 574:
                                                    state = (
                                                        779
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.7949524)
                                                        else 780
                                                    )
                                                    if state == 779:
                                                        return -0.312887013
                                                    if state == 780:
                                                        state = (
                                                            967
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.437418461
                                                            )
                                                            else 968
                                                        )
                                                        if state == 967:
                                                            return -0.220416099
                                                        if state == 968:
                                                            return 0.327329427
                                            if state == 388:
                                                state = (
                                                    575
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.696666658)
                                                    else 576
                                                )
                                                if state == 575:
                                                    return -0.251609266
                                                if state == 576:
                                                    state = (
                                                        781
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.7243729)
                                                        else 782
                                                    )
                                                    if state == 781:
                                                        return 0.193551391
                                                    if state == 782:
                                                        return -0.0617942438
                                if state == 78:
                                    state = (
                                        145 if x["distpsnr1_med"] < 1.22633433 else 146
                                    )
                                    if state == 145:
                                        return -0.362039328
                                    if state == 146:
                                        return 0.441544622
                            if state == 40:
                                state = 79 if x["col_det"] < -0.43584919 else 80
                                if state == 79:
                                    state = (
                                        147 if x["distpsnr1_med"] < 14.7454967 else 148
                                    )
                                    if state == 147:
                                        state = (
                                            247
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.5495815)
                                            else 248
                                        )
                                        if state == 247:
                                            state = (
                                                389
                                                if x["col_det"] < -0.586216927
                                                else 390
                                            )
                                            if state == 389:
                                                return -0.300089836
                                            if state == 390:
                                                state = (
                                                    577
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.655833364)
                                                    else 578
                                                )
                                                if state == 577:
                                                    return -0.239010841
                                                if state == 578:
                                                    state = (
                                                        783
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4009209)
                                                        else 784
                                                    )
                                                    if state == 783:
                                                        return 0.560497999
                                                    if state == 784:
                                                        return 0.11130739
                                        if state == 248:
                                            return -0.389147937
                                    if state == 148:
                                        return 0.45451799
                                if state == 80:
                                    state = (
                                        149
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.52694571)
                                        else 150
                                    )
                                    if state == 149:
                                        state = (
                                            249
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.510334)
                                            else 250
                                        )
                                        if state == 249:
                                            state = (
                                                391
                                                if x["col_det"] < -0.0876617432
                                                else 392
                                            )
                                            if state == 391:
                                                state = (
                                                    579
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.806785822)
                                                    else 580
                                                )
                                                if state == 579:
                                                    state = (
                                                        785
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4635315)
                                                        else 786
                                                    )
                                                    if state == 785:
                                                        return -0.0373222791
                                                    if state == 786:
                                                        return 0.341267884
                                                if state == 580:
                                                    return -0.339852214
                                            if state == 392:
                                                state = (
                                                    581
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.721666515)
                                                    else 582
                                                )
                                                if state == 581:
                                                    state = (
                                                        787
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4397392)
                                                        else 788
                                                    )
                                                    if state == 787:
                                                        return -0.124238178
                                                    if state == 788:
                                                        return -0.3132523
                                                if state == 582:
                                                    state = (
                                                        789
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4838848)
                                                        else 790
                                                    )
                                                    if state == 789:
                                                        return -0.444104731
                                                    if state == 790:
                                                        return -0.22976546
                                        if state == 250:
                                            return -0.434118479
                                    if state == 150:
                                        state = (
                                            251
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.0321674)
                                            else 252
                                        )
                                        if state == 251:
                                            state = (
                                                393
                                                if x["col_det"] < -0.150790542
                                                else 394
                                            )
                                            if state == 393:
                                                state = (
                                                    583
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.562499762)
                                                    else 584
                                                )
                                                if state == 583:
                                                    return -0.494763464
                                                if state == 584:
                                                    state = (
                                                        791
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.862936)
                                                        else 792
                                                    )
                                                    if state == 791:
                                                        state = (
                                                            971
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.283004761
                                                            )
                                                            else 972
                                                        )
                                                        if state == 971:
                                                            return -0.278950095
                                                        if state == 972:
                                                            return 0.225948319
                                                    if state == 792:
                                                        state = (
                                                            973
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.303849697
                                                            )
                                                            else 974
                                                        )
                                                        if state == 973:
                                                            return -0.152601406
                                                        if state == 974:
                                                            return 0.277879238
                                            if state == 394:
                                                state = (
                                                    585
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.396666765)
                                                    else 586
                                                )
                                                if state == 585:
                                                    state = (
                                                        793
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4832382)
                                                        else 794
                                                    )
                                                    if state == 793:
                                                        return -0.172513977
                                                    if state == 794:
                                                        state = (
                                                            975
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.31315136
                                                            )
                                                            else 976
                                                        )
                                                        if state == 975:
                                                            return -0.426838845
                                                        if state == 976:
                                                            return 0.0778112039
                                                if state == 586:
                                                    state = (
                                                        795
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.8162498)
                                                        else 796
                                                    )
                                                    if state == 795:
                                                        state = (
                                                            977
                                                            if x["col_peak"]
                                                            < -0.322686195
                                                            else 978
                                                        )
                                                        if state == 977:
                                                            return 0.194638476
                                                        if state == 978:
                                                            return -0.151128694
                                                    if state == 796:
                                                        state = (
                                                            979
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.451350212
                                                            )
                                                            else 980
                                                        )
                                                        if state == 979:
                                                            return -0.0269307904
                                                        if state == 980:
                                                            return -0.262224764
                                        if state == 252:
                                            state = (
                                                395
                                                if x["col_det"] < 0.0942354649
                                                else 396
                                            )
                                            if state == 395:
                                                return -0.15802747
                                            if state == 396:
                                                state = (
                                                    587
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.57249999)
                                                    else 588
                                                )
                                                if state == 587:
                                                    return -0.302128673
                                                if state == 588:
                                                    state = (
                                                        797
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.0323448)
                                                        else 798
                                                    )
                                                    if state == 797:
                                                        return 0.427263737
                                                    if state == 798:
                                                        return 0.106601611
                        if state == 20:
                            state = (
                                41
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 22.8969994)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    81
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.70459938)
                                    else 82
                                )
                                if state == 81:
                                    state = (
                                        151
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 1.28521407)
                                        else 152
                                    )
                                    if state == 151:
                                        return -0.438481092
                                    if state == 152:
                                        state = (
                                            253
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.2440147)
                                            else 254
                                        )
                                        if state == 253:
                                            state = (
                                                397
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.083779335)
                                                else 398
                                            )
                                            if state == 397:
                                                state = (
                                                    589
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.601547599)
                                                    else 590
                                                )
                                                if state == 589:
                                                    state = (
                                                        799
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.2009468)
                                                        else 800
                                                    )
                                                    if state == 799:
                                                        state = (
                                                            981
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.363079071
                                                            )
                                                            else 982
                                                        )
                                                        if state == 981:
                                                            return -0.392410159
                                                        if state == 982:
                                                            return -0.0397212952
                                                    if state == 800:
                                                        state = (
                                                            983
                                                            if x["col_peak"] < 0.000001
                                                            else 984
                                                        )
                                                        if state == 983:
                                                            return -0.174103051
                                                        if state == 984:
                                                            return 0.105235279
                                                if state == 590:
                                                    state = (
                                                        801
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.1483231)
                                                        else 802
                                                    )
                                                    if state == 801:
                                                        return -0.109893426
                                                    if state == 802:
                                                        state = (
                                                            987
                                                            if x["col_peak"] < 0.000001
                                                            else 988
                                                        )
                                                        if state == 987:
                                                            return -0.237931043
                                                        if state == 988:
                                                            return 0.249714732
                                            if state == 398:
                                                state = (
                                                    591
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.769285679)
                                                    else 592
                                                )
                                                if state == 591:
                                                    return -0.372219533
                                                if state == 592:
                                                    state = (
                                                        803
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.1671104)
                                                        else 804
                                                    )
                                                    if state == 803:
                                                        return -0.250382334
                                                    if state == 804:
                                                        return 0.108711541
                                        if state == 254:
                                            state = (
                                                399
                                                if x["col_det"] < -0.335191727
                                                else 400
                                            )
                                            if state == 399:
                                                return -0.545551956
                                            if state == 400:
                                                state = (
                                                    593
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.617856979)
                                                    else 594
                                                )
                                                if state == 593:
                                                    state = (
                                                        805
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.3976517)
                                                        else 806
                                                    )
                                                    if state == 805:
                                                        return -0.442802072
                                                    if state == 806:
                                                        state = (
                                                            989
                                                            if x["col_peak"]
                                                            < -0.300398827
                                                            else 990
                                                        )
                                                        if state == 989:
                                                            return -0.0504659489
                                                        if state == 990:
                                                            return -0.360379666
                                                if state == 594:
                                                    state = (
                                                        807
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.3402977)
                                                        else 808
                                                    )
                                                    if state == 807:
                                                        return -0.0501523837
                                                    if state == 808:
                                                        return -0.273633689
                                if state == 82:
                                    state = (
                                        153 if x["distpsnr1_med"] < 4.18415022 else 154
                                    )
                                    if state == 153:
                                        state = (
                                            255
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.7346497)
                                            else 256
                                        )
                                        if state == 255:
                                            state = (
                                                401
                                                if x["col_det"] < 0.739249229
                                                else 402
                                            )
                                            if state == 401:
                                                return 0.162268236
                                            if state == 402:
                                                return -0.212813571
                                        if state == 256:
                                            return 0.311740905
                                    if state == 154:
                                        return -0.327743024
                            if state == 42:
                                state = 83 if x["col_det"] < 0.696999609 else 84
                                if state == 83:
                                    state = (
                                        155 if x["distpsnr1_med"] < 12.4214973 else 156
                                    )
                                    if state == 155:
                                        state = (
                                            257
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.2334614)
                                            else 258
                                        )
                                        if state == 257:
                                            return 0.074986212
                                        if state == 258:
                                            return -0.119747311
                                    if state == 156:
                                        return -0.350058377
                                if state == 84:
                                    state = (
                                        157
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 11.4500446)
                                        else 158
                                    )
                                    if state == 157:
                                        return -0.434652478
                                    if state == 158:
                                        state = (
                                            259
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.1248665)
                                            else 260
                                        )
                                        if state == 259:
                                            return 0.37803185
                                        if state == 260:
                                            return -0.286855817
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8803616)
                            else 22
                        )
                        if state == 21:
                            state = (
                                43
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.4034996)
                                else 44
                            )
                            if state == 43:
                                state = 85 if x["col_det"] < -0.101299286 else 86
                                if state == 85:
                                    state = (
                                        159
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 1.11917031)
                                        else 160
                                    )
                                    if state == 159:
                                        state = (
                                            261
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.7798576)
                                            else 262
                                        )
                                        if state == 261:
                                            state = (
                                                403
                                                if x["col_det"] < -0.244915962
                                                else 404
                                            )
                                            if state == 403:
                                                state = (
                                                    595
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.803571463)
                                                    else 596
                                                )
                                                if state == 595:
                                                    return -0.0819662288
                                                if state == 596:
                                                    return 0.146411091
                                            if state == 404:
                                                return -0.329519093
                                        if state == 262:
                                            state = (
                                                405
                                                if x["col_det"] < -0.187773705
                                                else 406
                                            )
                                            if state == 405:
                                                return 0.277988911
                                            if state == 406:
                                                return -0.115443051
                                    if state == 160:
                                        return 0.488163054
                                if state == 86:
                                    state = (
                                        161
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.490490973)
                                        else 162
                                    )
                                    if state == 161:
                                        state = (
                                            263
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.4466438)
                                            else 264
                                        )
                                        if state == 263:
                                            return -0.570145905
                                        if state == 264:
                                            state = (
                                                407
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.416119576)
                                                else 408
                                            )
                                            if state == 407:
                                                state = (
                                                    597
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.751547515)
                                                    else 598
                                                )
                                                if state == 597:
                                                    state = (
                                                        811
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.5320473)
                                                        else 812
                                                    )
                                                    if state == 811:
                                                        return -0.212211132
                                                    if state == 812:
                                                        return -0.491286337
                                                if state == 598:
                                                    state = (
                                                        813
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4567966)
                                                        else 814
                                                    )
                                                    if state == 813:
                                                        state = (
                                                            995
                                                            if x["col_peak"]
                                                            < -0.0285077095
                                                            else 996
                                                        )
                                                        if state == 995:
                                                            return 0.172893256
                                                        if state == 996:
                                                            return -0.182862729
                                                    if state == 814:
                                                        state = (
                                                            997
                                                            if x["col_peak"]
                                                            < -0.025077248
                                                            else 998
                                                        )
                                                        if state == 997:
                                                            return -0.0735459477
                                                        if state == 998:
                                                            return -0.47615689
                                            if state == 408:
                                                state = (
                                                    599
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.931071401)
                                                    else 600
                                                )
                                                if state == 599:
                                                    state = (
                                                        815
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.5345306)
                                                        else 816
                                                    )
                                                    if state == 815:
                                                        return 0.136276826
                                                    if state == 816:
                                                        return -0.335297167
                                                if state == 600:
                                                    state = (
                                                        817
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.7073479)
                                                        else 818
                                                    )
                                                    if state == 817:
                                                        state = (
                                                            999
                                                            if x["col_peak"]
                                                            < 0.40459919
                                                            else 1000
                                                        )
                                                        if state == 999:
                                                            return -0.306562096
                                                        if state == 1000:
                                                            return 0.277629882
                                                    if state == 818:
                                                        return 0.311189353
                                    if state == 162:
                                        state = (
                                            265
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.4985752)
                                            else 266
                                        )
                                        if state == 265:
                                            state = (
                                                409
                                                if x["col_det"] < 0.00825929642
                                                else 410
                                            )
                                            if state == 409:
                                                return -0.207599714
                                            if state == 410:
                                                state = (
                                                    601
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.681666613)
                                                    else 602
                                                )
                                                if state == 601:
                                                    state = (
                                                        819
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4529724)
                                                        else 820
                                                    )
                                                    if state == 819:
                                                        return -0.38088724
                                                    if state == 820:
                                                        state = (
                                                            1001
                                                            if x["col_peak"]
                                                            < -0.0614318848
                                                            else 1002
                                                        )
                                                        if state == 1001:
                                                            return 0.156256467
                                                        if state == 1002:
                                                            return -0.169730663
                                                if state == 602:
                                                    state = (
                                                        821
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4464512)
                                                        else 822
                                                    )
                                                    if state == 821:
                                                        state = (
                                                            1003
                                                            if x["col_peak"]
                                                            < 0.23445797
                                                            else 1004
                                                        )
                                                        if state == 1003:
                                                            return 0.399997473
                                                        if state == 1004:
                                                            return -0.0958258286
                                                    if state == 822:
                                                        return 0.477263302
                                        if state == 266:
                                            state = (
                                                411
                                                if x["col_det"] < -0.0260272026
                                                else 412
                                            )
                                            if state == 411:
                                                return -0.426127106
                                            if state == 412:
                                                state = (
                                                    603
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.609642744)
                                                    else 604
                                                )
                                                if state == 603:
                                                    state = (
                                                        823
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.6271782)
                                                        else 824
                                                    )
                                                    if state == 823:
                                                        state = (
                                                            1005
                                                            if x["col_peak"]
                                                            < 0.172029495
                                                            else 1006
                                                        )
                                                        if state == 1005:
                                                            return 0.110440984
                                                        if state == 1006:
                                                            return -0.327504545
                                                    if state == 824:
                                                        state = (
                                                            1007
                                                            if x["col_peak"]
                                                            < 0.128613472
                                                            else 1008
                                                        )
                                                        if state == 1007:
                                                            return -0.0383387804
                                                        if state == 1008:
                                                            return -0.578705311
                                                if state == 604:
                                                    state = (
                                                        825
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.5201454)
                                                        else 826
                                                    )
                                                    if state == 825:
                                                        state = (
                                                            1009
                                                            if x["col_peak"]
                                                            < -0.135014534
                                                            else 1010
                                                        )
                                                        if state == 1009:
                                                            return 0.138254017
                                                        if state == 1010:
                                                            return -0.250122309
                                                    if state == 826:
                                                        state = (
                                                            1011
                                                            if x["col_peak"]
                                                            < -0.178267151
                                                            else 1012
                                                        )
                                                        if state == 1011:
                                                            return -0.20771955
                                                        if state == 1012:
                                                            return 0.1585695
                            if state == 44:
                                state = 87 if x["col_det"] < -0.330886841 else 88
                                if state == 87:
                                    state = (
                                        163 if x["distpsnr1_med"] < 1.94025815 else 164
                                    )
                                    if state == 163:
                                        state = (
                                            267
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.646225)
                                            else 268
                                        )
                                        if state == 267:
                                            state = (
                                                413
                                                if x["col_det"] < -0.428199768
                                                else 414
                                            )
                                            if state == 413:
                                                return 0.324935138
                                            if state == 414:
                                                state = (
                                                    605
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.794285715)
                                                    else 606
                                                )
                                                if state == 605:
                                                    return 0.189114705
                                                if state == 606:
                                                    return -0.125663549
                                        if state == 268:
                                            state = (
                                                415
                                                if x["col_det"] < -0.428199768
                                                else 416
                                            )
                                            if state == 415:
                                                state = (
                                                    607
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.751547575)
                                                    else 608
                                                )
                                                if state == 607:
                                                    return -0.134610981
                                                if state == 608:
                                                    return 0.281462818
                                            if state == 416:
                                                return -0.374242127
                                    if state == 164:
                                        state = (
                                            269
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.4707603)
                                            else 270
                                        )
                                        if state == 269:
                                            return -0.529527545
                                        if state == 270:
                                            state = (
                                                417
                                                if x["col_det"] < -0.355449677
                                                else 418
                                            )
                                            if state == 417:
                                                state = (
                                                    609
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.582499862)
                                                    else 610
                                                )
                                                if state == 609:
                                                    return -0.17176114
                                                if state == 610:
                                                    return 0.18144235
                                            if state == 418:
                                                state = (
                                                    611
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.95392859)
                                                    else 612
                                                )
                                                if state == 611:
                                                    return -0.551593304
                                                if state == 612:
                                                    return -0.00207678508
                                if state == 88:
                                    state = (
                                        165 if x["distpsnr1_med"] < 0.973786056 else 166
                                    )
                                    if state == 165:
                                        state = (
                                            271
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.3933907)
                                            else 272
                                        )
                                        if state == 271:
                                            state = (
                                                419
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.0979003906)
                                                else 420
                                            )
                                            if state == 419:
                                                return 0.384863079
                                            if state == 420:
                                                return 0.0598579012
                                        if state == 272:
                                            state = (
                                                421
                                                if x["col_det"] < -0.290787697
                                                else 422
                                            )
                                            if state == 421:
                                                return 0.440737635
                                            if state == 422:
                                                state = (
                                                    613
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.599166751)
                                                    else 614
                                                )
                                                if state == 613:
                                                    state = (
                                                        829
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4257355)
                                                        else 830
                                                    )
                                                    if state == 829:
                                                        return 0.00448034285
                                                    if state == 830:
                                                        return -0.504981816
                                                if state == 614:
                                                    state = (
                                                        831
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.8099022)
                                                        else 832
                                                    )
                                                    if state == 831:
                                                        state = (
                                                            1015
                                                            if x["col_peak"]
                                                            < 0.0396323204
                                                            else 1016
                                                        )
                                                        if state == 1015:
                                                            return 0.0786849335
                                                        if state == 1016:
                                                            return -0.236862063
                                                    if state == 832:
                                                        return -0.326988846
                                    if state == 166:
                                        state = (
                                            273
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.6726646)
                                            else 274
                                        )
                                        if state == 273:
                                            state = (
                                                423
                                                if x["col_det"] < -0.0368366241
                                                else 424
                                            )
                                            if state == 423:
                                                state = (
                                                    615
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.300000012)
                                                    else 616
                                                )
                                                if state == 615:
                                                    return -0.386418432
                                                if state == 616:
                                                    state = (
                                                        833
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3828831)
                                                        else 834
                                                    )
                                                    if state == 833:
                                                        return -0.0887439623
                                                    if state == 834:
                                                        state = (
                                                            1017
                                                            if x["col_peak"]
                                                            < -0.21003437
                                                            else 1018
                                                        )
                                                        if state == 1017:
                                                            return -0.338115424
                                                        if state == 1018:
                                                            return 0.382117629
                                            if state == 424:
                                                state = (
                                                    617
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.432857156)
                                                    else 618
                                                )
                                                if state == 617:
                                                    state = (
                                                        835
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4320908)
                                                        else 836
                                                    )
                                                    if state == 835:
                                                        state = (
                                                            1019
                                                            if x["col_peak"]
                                                            < 0.156803131
                                                            else 1020
                                                        )
                                                        if state == 1019:
                                                            return -0.212213725
                                                        if state == 1020:
                                                            return 0.226997346
                                                    if state == 836:
                                                        return -0.364781618
                                                if state == 618:
                                                    state = (
                                                        837
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.5458984)
                                                        else 838
                                                    )
                                                    if state == 837:
                                                        state = (
                                                            1021
                                                            if x["col_peak"]
                                                            < 0.381103694
                                                            else 1022
                                                        )
                                                        if state == 1021:
                                                            return 0.132574603
                                                        if state == 1022:
                                                            return 0.464119166
                                                    if state == 838:
                                                        state = (
                                                            1023
                                                            if x["col_peak"]
                                                            < 0.313138485
                                                            else 1024
                                                        )
                                                        if state == 1023:
                                                            return 0.203780621
                                                        if state == 1024:
                                                            return 0.453920662
                                        if state == 274:
                                            state = (
                                                425
                                                if x["col_det"] < 0.277018547
                                                else 426
                                            )
                                            if state == 425:
                                                state = (
                                                    619
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.532142878)
                                                    else 620
                                                )
                                                if state == 619:
                                                    state = (
                                                        839
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.8675556)
                                                        else 840
                                                    )
                                                    if state == 839:
                                                        state = (
                                                            1025
                                                            if x["col_peak"]
                                                            < 0.248869419
                                                            else 1026
                                                        )
                                                        if state == 1025:
                                                            return -0.231284827
                                                        if state == 1026:
                                                            return 0.186589807
                                                    if state == 840:
                                                        return 0.310189068
                                                if state == 620:
                                                    state = (
                                                        841
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.8228569)
                                                        else 842
                                                    )
                                                    if state == 841:
                                                        state = (
                                                            1027
                                                            if x["col_peak"]
                                                            < -0.22284317
                                                            else 1028
                                                        )
                                                        if state == 1027:
                                                            return -0.214878947
                                                        if state == 1028:
                                                            return 0.346973896
                                                    if state == 842:
                                                        state = (
                                                            1029
                                                            if x["col_peak"]
                                                            < 0.0744767189
                                                            else 1030
                                                        )
                                                        if state == 1029:
                                                            return 0.0413532853
                                                        if state == 1030:
                                                            return 0.251660705
                                            if state == 426:
                                                state = (
                                                    621
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.876071334)
                                                    else 622
                                                )
                                                if state == 621:
                                                    state = (
                                                        843
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.8037682)
                                                        else 844
                                                    )
                                                    if state == 843:
                                                        state = (
                                                            1031
                                                            if x["col_peak"]
                                                            < 0.570241928
                                                            else 1032
                                                        )
                                                        if state == 1031:
                                                            return -0.189931244
                                                        if state == 1032:
                                                            return 0.372606486
                                                    if state == 844:
                                                        state = (
                                                            1033
                                                            if x["col_peak"]
                                                            < 0.0943522453
                                                            else 1034
                                                        )
                                                        if state == 1033:
                                                            return 0.0283757839
                                                        if state == 1034:
                                                            return 0.204997703
                                                if state == 622:
                                                    return 0.323178738
                        if state == 22:
                            state = (
                                45
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.7110004)
                                else 46
                            )
                            if state == 45:
                                state = 89 if x["col_det"] < 0.20462513 else 90
                                if state == 89:
                                    state = (
                                        167 if x["distpsnr1_med"] < 0.638519526 else 168
                                    )
                                    if state == 167:
                                        state = (
                                            275
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.9662895)
                                            else 276
                                        )
                                        if state == 275:
                                            state = (
                                                427
                                                if x["col_det"] < 0.136050224
                                                else 428
                                            )
                                            if state == 427:
                                                return -0.414105445
                                            if state == 428:
                                                state = (
                                                    623
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.658928573)
                                                    else 624
                                                )
                                                if state == 623:
                                                    return 0.274856389
                                                if state == 624:
                                                    return -0.256344795
                                        if state == 276:
                                            return 0.0939383209
                                    if state == 168:
                                        state = (
                                            277
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.5764809)
                                            else 278
                                        )
                                        if state == 277:
                                            state = (
                                                429
                                                if x["col_det"] < -0.326543808
                                                else 430
                                            )
                                            if state == 429:
                                                state = (
                                                    625
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.779047608)
                                                    else 626
                                                )
                                                if state == 625:
                                                    return -0.352840662
                                                if state == 626:
                                                    state = (
                                                        847
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.0706253)
                                                        else 848
                                                    )
                                                    if state == 847:
                                                        state = (
                                                            1037
                                                            if x["col_peak"]
                                                            < -0.0312307682
                                                            else 1038
                                                        )
                                                        if state == 1037:
                                                            return 0.0287833139
                                                        if state == 1038:
                                                            return 0.222283348
                                                    if state == 848:
                                                        return -0.238466129
                                            if state == 430:
                                                state = (
                                                    627
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.596666694)
                                                    else 628
                                                )
                                                if state == 627:
                                                    state = (
                                                        849
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.0954609)
                                                        else 850
                                                    )
                                                    if state == 849:
                                                        state = (
                                                            1039
                                                            if x["col_peak"]
                                                            < 0.11507988
                                                            else 1040
                                                        )
                                                        if state == 1039:
                                                            return -0.100757487
                                                        if state == 1040:
                                                            return 0.249554217
                                                    if state == 850:
                                                        state = (
                                                            1041
                                                            if x["col_peak"]
                                                            < -0.22433567
                                                            else 1042
                                                        )
                                                        if state == 1041:
                                                            return 0.14525108
                                                        if state == 1042:
                                                            return -0.139041603
                                                if state == 628:
                                                    state = (
                                                        851
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.0117188)
                                                        else 852
                                                    )
                                                    if state == 851:
                                                        state = (
                                                            1043
                                                            if x["col_peak"]
                                                            < 0.105885506
                                                            else 1044
                                                        )
                                                        if state == 1043:
                                                            return 0.191586792
                                                        if state == 1044:
                                                            return -0.127704695
                                                    if state == 852:
                                                        state = (
                                                            1045
                                                            if x["col_peak"]
                                                            < 0.101630852
                                                            else 1046
                                                        )
                                                        if state == 1045:
                                                            return 0.30144313
                                                        if state == 1046:
                                                            return -0.140204519
                                        if state == 278:
                                            state = (
                                                431
                                                if x["col_det"] < 0.0747003555
                                                else 432
                                            )
                                            if state == 431:
                                                state = (
                                                    629
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.596666813)
                                                    else 630
                                                )
                                                if state == 629:
                                                    return -0.299599349
                                                if state == 630:
                                                    state = (
                                                        853
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.6203518)
                                                        else 854
                                                    )
                                                    if state == 853:
                                                        return -0.124127418
                                                    if state == 854:
                                                        state = (
                                                            1047
                                                            if x["col_peak"]
                                                            < 0.0575246811
                                                            else 1048
                                                        )
                                                        if state == 1047:
                                                            return 0.221929118
                                                        if state == 1048:
                                                            return -0.135725155
                                            if state == 432:
                                                state = (
                                                    631
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.439285725)
                                                    else 632
                                                )
                                                if state == 631:
                                                    return 0.422302812
                                                if state == 632:
                                                    state = (
                                                        855
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.6728535)
                                                        else 856
                                                    )
                                                    if state == 855:
                                                        return 0.271983445
                                                    if state == 856:
                                                        state = (
                                                            1049
                                                            if x["col_peak"]
                                                            < -0.142246246
                                                            else 1050
                                                        )
                                                        if state == 1049:
                                                            return 0.123230264
                                                        if state == 1050:
                                                            return -0.204521999
                                if state == 90:
                                    state = (
                                        169
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 4.62056732)
                                        else 170
                                    )
                                    if state == 169:
                                        state = (
                                            279
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.3124504)
                                            else 280
                                        )
                                        if state == 279:
                                            state = (
                                                433
                                                if x["col_det"] < 0.398117065
                                                else 434
                                            )
                                            if state == 433:
                                                state = (
                                                    633
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.903571606)
                                                    else 634
                                                )
                                                if state == 633:
                                                    return -0.466029435
                                                if state == 634:
                                                    return 0.094493933
                                            if state == 434:
                                                state = (
                                                    635
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.56928575)
                                                    else 636
                                                )
                                                if state == 635:
                                                    state = (
                                                        857
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.0821495)
                                                        else 858
                                                    )
                                                    if state == 857:
                                                        return -0.448250711
                                                    if state == 858:
                                                        state = (
                                                            1051
                                                            if x["col_peak"]
                                                            < 0.183010101
                                                            else 1052
                                                        )
                                                        if state == 1051:
                                                            return -0.12186534
                                                        if state == 1052:
                                                            return -0.413181543
                                                if state == 636:
                                                    state = (
                                                        859
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.3065109)
                                                        else 860
                                                    )
                                                    if state == 859:
                                                        state = (
                                                            1053
                                                            if x["col_peak"]
                                                            < 0.574449539
                                                            else 1054
                                                        )
                                                        if state == 1053:
                                                            return -0.20277302
                                                        if state == 1054:
                                                            return 0.170020357
                                                    if state == 860:
                                                        state = (
                                                            1055
                                                            if x["col_peak"]
                                                            < -0.10119915
                                                            else 1056
                                                        )
                                                        if state == 1055:
                                                            return 0.409653574
                                                        if state == 1056:
                                                            return -0.165266916
                                        if state == 280:
                                            state = (
                                                435
                                                if x["col_det"] < 0.371799946
                                                else 436
                                            )
                                            if state == 435:
                                                state = (
                                                    637
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.783571482)
                                                    else 638
                                                )
                                                if state == 637:
                                                    return -0.342564732
                                                if state == 638:
                                                    state = (
                                                        861
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.4079418)
                                                        else 862
                                                    )
                                                    if state == 861:
                                                        return 0.355349809
                                                    if state == 862:
                                                        return 0.0212578643
                                            if state == 436:
                                                state = (
                                                    639
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.630357146)
                                                    else 640
                                                )
                                                if state == 639:
                                                    return -0.468756884
                                                if state == 640:
                                                    state = (
                                                        863
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 21.0784492)
                                                        else 864
                                                    )
                                                    if state == 863:
                                                        state = (
                                                            1057
                                                            if x["col_peak"]
                                                            < -0.0654525757
                                                            else 1058
                                                        )
                                                        if state == 1057:
                                                            return -0.0863914788
                                                        if state == 1058:
                                                            return -0.350019485
                                                    if state == 864:
                                                        return 0.214821681
                                    if state == 170:
                                        state = (
                                            281
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.2047081)
                                            else 282
                                        )
                                        if state == 281:
                                            return 0.2447135
                                        if state == 282:
                                            state = (
                                                437
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.345657349)
                                                else 438
                                            )
                                            if state == 437:
                                                state = (
                                                    641
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.460833251)
                                                    else 642
                                                )
                                                if state == 641:
                                                    return -0.349416971
                                                if state == 642:
                                                    state = (
                                                        865
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.2667332)
                                                        else 866
                                                    )
                                                    if state == 865:
                                                        state = (
                                                            1059
                                                            if x["col_peak"]
                                                            < -0.170535088
                                                            else 1060
                                                        )
                                                        if state == 1059:
                                                            return 0.122763462
                                                        if state == 1060:
                                                            return -0.358132929
                                                    if state == 866:
                                                        state = (
                                                            1061
                                                            if x["col_peak"]
                                                            < -0.153885841
                                                            else 1062
                                                        )
                                                        if state == 1061:
                                                            return 0.422433317
                                                        if state == 1062:
                                                            return -0.0393957086
                                            if state == 438:
                                                return 0.233759776
                            if state == 46:
                                state = 91 if x["col_det"] < -0.199238449 else 92
                                if state == 91:
                                    state = (
                                        171
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 13.1714687)
                                        else 172
                                    )
                                    if state == 171:
                                        state = (
                                            283
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.2224941)
                                            else 284
                                        )
                                        if state == 283:
                                            state = (
                                                439
                                                if x["col_det"] < -0.21089983
                                                else 440
                                            )
                                            if state == 439:
                                                return -0.27481088
                                            if state == 440:
                                                return 0.274443865
                                        if state == 284:
                                            return -0.353685796
                                    if state == 172:
                                        return 0.482553542
                                if state == 92:
                                    state = (
                                        173
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 7.91717052)
                                        else 174
                                    )
                                    if state == 173:
                                        return -0.43277356
                                    if state == 174:
                                        state = (
                                            285
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.1494904)
                                            else 286
                                        )
                                        if state == 285:
                                            state = (
                                                441
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.376859665)
                                                else 442
                                            )
                                            if state == 441:
                                                state = (
                                                    643
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.418928564)
                                                    else 644
                                                )
                                                if state == 643:
                                                    return -0.38696292
                                                if state == 644:
                                                    state = (
                                                        867
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.9014378)
                                                        else 868
                                                    )
                                                    if state == 867:
                                                        return 0.226033926
                                                    if state == 868:
                                                        state = (
                                                            1063
                                                            if x["col_peak"]
                                                            < 0.0357618332
                                                            else 1064
                                                        )
                                                        if state == 1063:
                                                            return -0.270430893
                                                        if state == 1064:
                                                            return 0.0706743896
                                            if state == 442:
                                                return 0.44220838
                                        if state == 286:
                                            state = (
                                                443
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.0295426045)
                                                else 444
                                            )
                                            if state == 443:
                                                state = (
                                                    645
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.652857423)
                                                    else 646
                                                )
                                                if state == 645:
                                                    state = (
                                                        869
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.2805176)
                                                        else 870
                                                    )
                                                    if state == 869:
                                                        state = (
                                                            1065
                                                            if x["col_peak"]
                                                            < 0.0478668213
                                                            else 1066
                                                        )
                                                        if state == 1065:
                                                            return -0.412926376
                                                        if state == 1066:
                                                            return -0.0187383424
                                                    if state == 870:
                                                        state = (
                                                            1067
                                                            if x["col_peak"]
                                                            < 0.000494480133
                                                            else 1068
                                                        )
                                                        if state == 1067:
                                                            return 0.000139337193
                                                        if state == 1068:
                                                            return -0.323026836
                                                if state == 646:
                                                    state = (
                                                        871
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.2839355)
                                                        else 872
                                                    )
                                                    if state == 871:
                                                        return -0.228700012
                                                    if state == 872:
                                                        state = (
                                                            1069
                                                            if x["col_peak"]
                                                            < 0.157594681
                                                            else 1070
                                                        )
                                                        if state == 1069:
                                                            return -0.129528493
                                                        if state == 1070:
                                                            return 0.239760026
                                            if state == 444:
                                                return -0.443232268
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8642082) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.358188152)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 17.3550491)
                            else 24
                        )
                        if state == 23:
                            state = (
                                47
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 20.9664993)
                                else 48
                            )
                            if state == 47:
                                state = (
                                    93
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.471077263)
                                    else 94
                                )
                                if state == 93:
                                    return -0.493598223
                                if state == 94:
                                    return 0.210463241
                            if state == 48:
                                return 0.291619003
                        if state == 24:
                            state = (
                                49
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 16.8982506)
                                else 50
                            )
                            if state == 49:
                                state = 95 if x["col_det"] < 0.259270012 else 96
                                if state == 95:
                                    return 0.354297101
                                if state == 96:
                                    state = (
                                        175 if x["distpsnr1_med"] < 1.52048707 else 176
                                    )
                                    if state == 175:
                                        return -0.477399707
                                    if state == 176:
                                        return 0.0555011965
                            if state == 50:
                                state = 97 if x["col_det"] < -0.210300446 else 98
                                if state == 97:
                                    state = (
                                        177 if x["distpsnr1_med"] < 2.10974836 else 178
                                    )
                                    if state == 177:
                                        state = (
                                            287
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.1865902)
                                            else 288
                                        )
                                        if state == 287:
                                            return -0.339742601
                                        if state == 288:
                                            state = (
                                                445
                                                if x["col_det"] < -0.219550133
                                                else 446
                                            )
                                            if state == 445:
                                                return 0.113373145
                                            if state == 446:
                                                return -0.201353505
                                    if state == 178:
                                        state = (
                                            289
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.302866)
                                            else 290
                                        )
                                        if state == 289:
                                            return 0.195500553
                                        if state == 290:
                                            state = (
                                                447
                                                if x["col_det"] < -0.291963577
                                                else 448
                                            )
                                            if state == 447:
                                                return -0.120708235
                                            if state == 448:
                                                return 0.058838781
                                if state == 98:
                                    state = (
                                        179
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.36029008)
                                        else 180
                                    )
                                    if state == 179:
                                        state = (
                                            291
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.819931)
                                            else 292
                                        )
                                        if state == 291:
                                            state = (
                                                449 if x["col_det"] < 1.7093668 else 450
                                            )
                                            if state == 449:
                                                return -0.413175315
                                            if state == 450:
                                                state = (
                                                    647
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.644166708)
                                                    else 648
                                                )
                                                if state == 647:
                                                    return -0.375299156
                                                if state == 648:
                                                    state = (
                                                        873
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.5304909)
                                                        else 874
                                                    )
                                                    if state == 873:
                                                        return 0.0895321071
                                                    if state == 874:
                                                        return -0.212792262
                                        if state == 292:
                                            return 0.217168078
                                    if state == 180:
                                        state = (
                                            293
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.9733295)
                                            else 294
                                        )
                                        if state == 293:
                                            return 0.438731641
                                        if state == 294:
                                            state = (
                                                451
                                                if x["col_det"] < 0.0193004608
                                                else 452
                                            )
                                            if state == 451:
                                                return 0.422026008
                                            if state == 452:
                                                state = (
                                                    649
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.782500029)
                                                    else 650
                                                )
                                                if state == 649:
                                                    state = (
                                                        875
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0747986)
                                                        else 876
                                                    )
                                                    if state == 875:
                                                        return -0.183344141
                                                    if state == 876:
                                                        return 0.287341267
                                                if state == 650:
                                                    state = (
                                                        877
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.5323238)
                                                        else 878
                                                    )
                                                    if state == 877:
                                                        return 0.210386127
                                                    if state == 878:
                                                        return -0.214922845
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1023026)
                            else 26
                        )
                        if state == 25:
                            state = (
                                51
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 15.6859999)
                                else 52
                            )
                            if state == 51:
                                state = 99 if x["col_det"] < 1.29060078 else 100
                                if state == 99:
                                    return -0.476785928
                                if state == 100:
                                    return -0.0601658598
                            if state == 52:
                                state = 101 if x["col_det"] < -0.352341652 else 102
                                if state == 101:
                                    return -0.0559544712
                                if state == 102:
                                    state = (
                                        181
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.213899165)
                                        else 182
                                    )
                                    if state == 181:
                                        state = (
                                            295
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.7667141)
                                            else 296
                                        )
                                        if state == 295:
                                            state = (
                                                453
                                                if x["col_det"] < 0.261689186
                                                else 454
                                            )
                                            if state == 453:
                                                return 0.225785136
                                            if state == 454:
                                                return -0.314627647
                                        if state == 296:
                                            state = (
                                                455
                                                if x["col_det"] < 0.856881201
                                                else 456
                                            )
                                            if state == 455:
                                                return 0.235830501
                                            if state == 456:
                                                return 0.00551607506
                                    if state == 182:
                                        return 0.43362695
                        if state == 26:
                            state = (
                                53
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.1650009)
                                else 54
                            )
                            if state == 53:
                                return -0.574328125
                            if state == 54:
                                state = 103 if x["col_det"] < -0.332249165 else 104
                                if state == 103:
                                    state = (
                                        183 if x["distpsnr1_med"] < 6.09141827 else 184
                                    )
                                    if state == 183:
                                        state = (
                                            297
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.2788811)
                                            else 298
                                        )
                                        if state == 297:
                                            state = (
                                                457
                                                if x["col_det"] < -0.492249489
                                                else 458
                                            )
                                            if state == 457:
                                                return 0.107909642
                                            if state == 458:
                                                return -0.0584516898
                                        if state == 298:
                                            return 0.222245842
                                    if state == 184:
                                        return -0.306980133
                                if state == 104:
                                    state = (
                                        185 if x["distpsnr1_med"] < 0.445268661 else 186
                                    )
                                    if state == 185:
                                        state = (
                                            299
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.5120068)
                                            else 300
                                        )
                                        if state == 299:
                                            return 0.224874288
                                        if state == 300:
                                            state = (
                                                459
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.045188427)
                                                else 460
                                            )
                                            if state == 459:
                                                return -0.517267883
                                            if state == 460:
                                                return 0.292375684
                                    if state == 186:
                                        state = (
                                            301
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.1083641)
                                            else 302
                                        )
                                        if state == 301:
                                            state = (
                                                461
                                                if x["col_det"] < -0.0997161865
                                                else 462
                                            )
                                            if state == 461:
                                                return 0.180169433
                                            if state == 462:
                                                return -0.201271132
                                        if state == 302:
                                            state = (
                                                463
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.227342129)
                                                else 464
                                            )
                                            if state == 463:
                                                state = (
                                                    651
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.45083344)
                                                    else 652
                                                )
                                                if state == 651:
                                                    state = (
                                                        879
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4460297)
                                                        else 880
                                                    )
                                                    if state == 879:
                                                        return 0.242161542
                                                    if state == 880:
                                                        state = (
                                                            1071
                                                            if x["col_peak"]
                                                            < 0.769884109
                                                            else 1072
                                                        )
                                                        if state == 1071:
                                                            return -0.234453291
                                                        if state == 1072:
                                                            return 0.114971027
                                                if state == 652:
                                                    return 0.37356317
                                            if state == 464:
                                                state = (
                                                    653
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.500833273)
                                                    else 654
                                                )
                                                if state == 653:
                                                    state = (
                                                        881
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.8434887)
                                                        else 882
                                                    )
                                                    if state == 881:
                                                        state = (
                                                            1073
                                                            if x["col_peak"]
                                                            < 0.573672771
                                                            else 1074
                                                        )
                                                        if state == 1073:
                                                            return -0.483553469
                                                        if state == 1074:
                                                            return 0.198967785
                                                    if state == 882:
                                                        return 0.315721393
                                                if state == 654:
                                                    state = (
                                                        883
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2048531)
                                                        else 884
                                                    )
                                                    if state == 883:
                                                        state = (
                                                            1075
                                                            if x["col_peak"]
                                                            < 0.54003334
                                                            else 1076
                                                        )
                                                        if state == 1075:
                                                            return -0.408115536
                                                        if state == 1076:
                                                            return 0.206994474
                                                    if state == 884:
                                                        return 0.363121301
                if state == 6:
                    state = 13 if x["col_peak"] < 0.424826622 else 14
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 21.0759506)
                            else 28
                        )
                        if state == 27:
                            state = (
                                55
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 22.8652496)
                                else 56
                            )
                            if state == 55:
                                state = 105 if x["col_det"] < 0.371950626 else 106
                                if state == 105:
                                    return 0.325897306
                                if state == 106:
                                    state = (
                                        187 if x["distpsnr1_med"] < 1.82704329 else 188
                                    )
                                    if state == 187:
                                        state = (
                                            303
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.7396049)
                                            else 304
                                        )
                                        if state == 303:
                                            state = (
                                                465
                                                if x["col_det"] < 0.534700394
                                                else 466
                                            )
                                            if state == 465:
                                                return 0.175644889
                                            if state == 466:
                                                state = (
                                                    655
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.695833325)
                                                    else 656
                                                )
                                                if state == 655:
                                                    return -0.51050216
                                                if state == 656:
                                                    state = (
                                                        885
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.5450211)
                                                        else 886
                                                    )
                                                    if state == 885:
                                                        return 0.208030209
                                                    if state == 886:
                                                        return -0.121716134
                                        if state == 304:
                                            return 0.258624315
                                    if state == 188:
                                        state = (
                                            305
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.9584007)
                                            else 306
                                        )
                                        if state == 305:
                                            state = (
                                                467
                                                if x["col_det"] < 0.751202643
                                                else 468
                                            )
                                            if state == 467:
                                                return -0.225654483
                                            if state == 468:
                                                state = (
                                                    657
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.494047642)
                                                    else 658
                                                )
                                                if state == 657:
                                                    return -0.239240244
                                                if state == 658:
                                                    return 0.374640793
                                        if state == 306:
                                            return -0.00539165223
                            if state == 56:
                                state = 107 if x["col_det"] < 0.108066559 else 108
                                if state == 107:
                                    return 0.135385841
                                if state == 108:
                                    return -0.209464684
                        if state == 28:
                            return -0.341466218
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.9065704)
                            else 30
                        )
                        if state == 29:
                            state = (
                                57
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.0270004)
                                else 58
                            )
                            if state == 57:
                                return -0.00786446594
                            if state == 58:
                                return -0.441312015
                        if state == 30:
                            state = (
                                59
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 20.6025009)
                                else 60
                            )
                            if state == 59:
                                state = (
                                    109
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.234365463)
                                    else 110
                                )
                                if state == 109:
                                    state = (
                                        189 if x["distpsnr1_med"] < 0.200130776 else 190
                                    )
                                    if state == 189:
                                        state = (
                                            307
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.2487087)
                                            else 308
                                        )
                                        if state == 307:
                                            return 0.318434536
                                        if state == 308:
                                            return -0.267344922
                                    if state == 190:
                                        state = (
                                            309
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.2896519)
                                            else 310
                                        )
                                        if state == 309:
                                            state = (
                                                469 if x["col_det"] < 0.000001 else 470
                                            )
                                            if state == 469:
                                                return -0.21041365
                                            if state == 470:
                                                state = (
                                                    659
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.725000024)
                                                    else 660
                                                )
                                                if state == 659:
                                                    state = (
                                                        887
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.0214996)
                                                        else 888
                                                    )
                                                    if state == 887:
                                                        return -0.359386981
                                                    if state == 888:
                                                        state = (
                                                            1079
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < 0.552100182
                                                            )
                                                            else 1080
                                                        )
                                                        if state == 1079:
                                                            return -0.198716745
                                                        if state == 1080:
                                                            return 0.222110137
                                                if state == 660:
                                                    state = (
                                                        889
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.1395645)
                                                        else 890
                                                    )
                                                    if state == 889:
                                                        return 0.310862005
                                                    if state == 890:
                                                        return -0.277108222
                                        if state == 310:
                                            state = (
                                                471 if x["col_det"] < 0.000001 else 472
                                            )
                                            if state == 471:
                                                return -0.20096226
                                            if state == 472:
                                                state = (
                                                    661
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.569999993)
                                                    else 662
                                                )
                                                if state == 661:
                                                    return -0.298697263
                                                if state == 662:
                                                    state = (
                                                        891
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.3503723)
                                                        else 892
                                                    )
                                                    if state == 891:
                                                        return 0.415208071
                                                    if state == 892:
                                                        state = (
                                                            1081
                                                            if x["col_peak"]
                                                            < 1.96983242
                                                            else 1082
                                                        )
                                                        if state == 1081:
                                                            return -0.153374448
                                                        if state == 1082:
                                                            return 0.118923433
                                if state == 110:
                                    state = (
                                        191
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 1.77674007)
                                        else 192
                                    )
                                    if state == 191:
                                        state = (
                                            311
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.4189186)
                                            else 312
                                        )
                                        if state == 311:
                                            state = (
                                                473
                                                if x["col_det"] < -0.132827282
                                                else 474
                                            )
                                            if state == 473:
                                                return 0.150089562
                                            if state == 474:
                                                state = (
                                                    663
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.800476313)
                                                    else 664
                                                )
                                                if state == 663:
                                                    state = (
                                                        893
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.3641262)
                                                        else 894
                                                    )
                                                    if state == 893:
                                                        return -0.36883688
                                                    if state == 894:
                                                        state = (
                                                            1083
                                                            if x["col_peak"]
                                                            < 0.649535179
                                                            else 1084
                                                        )
                                                        if state == 1083:
                                                            return 0.143517435
                                                        if state == 1084:
                                                            return -0.188203275
                                                if state == 664:
                                                    return 0.100993708
                                        if state == 312:
                                            return 0.136150986
                                    if state == 192:
                                        state = (
                                            313
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.1362228)
                                            else 314
                                        )
                                        if state == 313:
                                            return 0.100157045
                                        if state == 314:
                                            return 0.388884097
                            if state == 60:
                                state = (
                                    111
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.0828766823)
                                    else 112
                                )
                                if state == 111:
                                    state = (
                                        193
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 12.0479488)
                                        else 194
                                    )
                                    if state == 193:
                                        state = (
                                            315
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.9854774)
                                            else 316
                                        )
                                        if state == 315:
                                            return -0.100492649
                                        if state == 316:
                                            state = (
                                                479
                                                if x["col_det"] < -0.260499001
                                                else 480
                                            )
                                            if state == 479:
                                                state = (
                                                    667
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.653214335)
                                                    else 668
                                                )
                                                if state == 667:
                                                    return -0.175145358
                                                if state == 668:
                                                    return 0.104143627
                                            if state == 480:
                                                state = (
                                                    669
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.580833495)
                                                    else 670
                                                )
                                                if state == 669:
                                                    state = (
                                                        895
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.3319054)
                                                        else 896
                                                    )
                                                    if state == 895:
                                                        return -0.102765374
                                                    if state == 896:
                                                        return -0.296895027
                                                if state == 670:
                                                    return -0.592918396
                                    if state == 194:
                                        state = (
                                            317
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.049366)
                                            else 318
                                        )
                                        if state == 317:
                                            return 0.141588598
                                        if state == 318:
                                            return -0.209904164
                                if state == 112:
                                    state = (
                                        195 if x["distpsnr1_med"] < 0.386367679 else 196
                                    )
                                    if state == 195:
                                        return 0.292123199
                                    if state == 196:
                                        state = (
                                            319
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.9706287)
                                            else 320
                                        )
                                        if state == 319:
                                            return 0.195797846
                                        if state == 320:
                                            return -0.276137918
    elif num_booster == 4:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.662215769) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.341485977)
                    else 4
                )
                if state == 3:
                    state = 7 if x["col_peak"] < 0.000001 else 8
                    if state == 7:
                        return -0.452051044
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["col_last"]) or (x["col_last"] < -0.222616196)
                            else 16
                        )
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 0.458658695)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    55
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.978500009)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        105 if x["distpsnr1_med"] < 0.111575499 else 106
                                    )
                                    if state == 105:
                                        state = (
                                            177
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 33.9793396)
                                            else 178
                                        )
                                        if state == 177:
                                            state = (
                                                281
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.955000043)
                                                else 282
                                            )
                                            if state == 281:
                                                state = (
                                                    423
                                                    if x["sgscore1_med"] < 0.00531250006
                                                    else 424
                                                )
                                                if state == 423:
                                                    state = (
                                                        601
                                                        if x["maggaia_med"] < 19.184906
                                                        else 602
                                                    )
                                                    if state == 601:
                                                        return 0.116673522
                                                    if state == 602:
                                                        return -0.132068291
                                                if state == 424:
                                                    return -0.419938862
                                            if state == 282:
                                                state = (
                                                    425
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0441666506
                                                    )
                                                    else 426
                                                )
                                                if state == 425:
                                                    return -0.36819914
                                                if state == 426:
                                                    state = (
                                                        603
                                                        if x["maggaia_med"] < 17.9223328
                                                        else 604
                                                    )
                                                    if state == 603:
                                                        return -0.300841272
                                                    if state == 604:
                                                        state = (
                                                            793
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.25995332
                                                            )
                                                            else 794
                                                        )
                                                        if state == 793:
                                                            return -0.195970833
                                                        if state == 794:
                                                            return 0.402420282
                                        if state == 178:
                                            return -0.412012786
                                    if state == 106:
                                        state = (
                                            179
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 6.04597235)
                                            else 180
                                        )
                                        if state == 179:
                                            state = (
                                                283
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.932999969)
                                                else 284
                                            )
                                            if state == 283:
                                                return -0.277750015
                                            if state == 284:
                                                state = (
                                                    427
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.191496998)
                                                    else 428
                                                )
                                                if state == 427:
                                                    return 0.331505656
                                                if state == 428:
                                                    return -0.135112002
                                        if state == 180:
                                            state = (
                                                285
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.972500026)
                                                else 286
                                            )
                                            if state == 285:
                                                return -0.430423826
                                            if state == 286:
                                                state = (
                                                    429
                                                    if x["sgscore1_med"] < 0.00270833494
                                                    else 430
                                                )
                                                if state == 429:
                                                    state = (
                                                        605
                                                        if x["maggaia_med"] < 19.5795746
                                                        else 606
                                                    )
                                                    if state == 605:
                                                        state = (
                                                            795
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.315792829
                                                            )
                                                            else 796
                                                        )
                                                        if state == 795:
                                                            return -0.160578787
                                                        if state == 796:
                                                            return 0.315303981
                                                    if state == 606:
                                                        return -0.275061011
                                                if state == 430:
                                                    state = (
                                                        607
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 19.3416023
                                                        )
                                                        else 608
                                                    )
                                                    if state == 607:
                                                        return -0.450383097
                                                    if state == 608:
                                                        state = (
                                                            797
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.263262957
                                                            )
                                                            else 798
                                                        )
                                                        if state == 797:
                                                            return -0.365439832
                                                        if state == 798:
                                                            return 0.103668302
                                if state == 56:
                                    state = (
                                        107 if x["distpsnr1_med"] < 0.414753854 else 108
                                    )
                                    if state == 107:
                                        state = (
                                            181
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 34.8761444)
                                            else 182
                                        )
                                        if state == 181:
                                            state = (
                                                287
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.983749986)
                                                else 288
                                            )
                                            if state == 287:
                                                state = (
                                                    431
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.102083504)
                                                    else 432
                                                )
                                                if state == 431:
                                                    state = (
                                                        609
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 19.5629501
                                                        )
                                                        else 610
                                                    )
                                                    if state == 609:
                                                        state = (
                                                            799
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.205589756
                                                            )
                                                            else 800
                                                        )
                                                        if state == 799:
                                                            return 0.503620386
                                                        if state == 800:
                                                            return 0.215914637
                                                    if state == 610:
                                                        state = (
                                                            801
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.263793916
                                                            )
                                                            else 802
                                                        )
                                                        if state == 801:
                                                            return -0.251539648
                                                        if state == 802:
                                                            return 0.295146167
                                                if state == 432:
                                                    state = (
                                                        611
                                                        if x["maggaia_med"] < 17.6926365
                                                        else 612
                                                    )
                                                    if state == 611:
                                                        state = (
                                                            803
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.144402623
                                                            )
                                                            else 804
                                                        )
                                                        if state == 803:
                                                            return 0.207228139
                                                        if state == 804:
                                                            return -0.2687262
                                                    if state == 612:
                                                        return -0.487445891
                                            if state == 288:
                                                state = (
                                                    433
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0158333499
                                                    )
                                                    else 434
                                                )
                                                if state == 433:
                                                    return 0.32152018
                                                if state == 434:
                                                    state = (
                                                        613
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 18.7483711
                                                        )
                                                        else 614
                                                    )
                                                    if state == 613:
                                                        return -0.465150833
                                                    if state == 614:
                                                        state = (
                                                            805
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.417206407
                                                            )
                                                            else 806
                                                        )
                                                        if state == 805:
                                                            return -0.239243582
                                                        if state == 806:
                                                            return 0.134902179
                                        if state == 182:
                                            state = (
                                                289
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.983250022)
                                                else 290
                                            )
                                            if state == 289:
                                                state = (
                                                    435
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0118055493
                                                    )
                                                    else 436
                                                )
                                                if state == 435:
                                                    state = (
                                                        615
                                                        if x["maggaia_med"] < 19.8722496
                                                        else 616
                                                    )
                                                    if state == 615:
                                                        state = (
                                                            807
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.37490505
                                                            )
                                                            else 808
                                                        )
                                                        if state == 807:
                                                            return 0.46993196
                                                        if state == 808:
                                                            return -0.260114223
                                                    if state == 616:
                                                        state = (
                                                            809
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.187836558
                                                            )
                                                            else 810
                                                        )
                                                        if state == 809:
                                                            return -0.102569237
                                                        if state == 810:
                                                            return -0.520526052
                                                if state == 436:
                                                    return -0.457230449
                                            if state == 290:
                                                return -0.445512205
                                    if state == 108:
                                        state = (
                                            183
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 23.0225868)
                                            else 184
                                        )
                                        if state == 183:
                                            return 0.412922949
                                        if state == 184:
                                            state = (
                                                291
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.980749965)
                                                else 292
                                            )
                                            if state == 291:
                                                return -0.307944983
                                            if state == 292:
                                                state = (
                                                    437
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0899078324
                                                    )
                                                    else 438
                                                )
                                                if state == 437:
                                                    state = (
                                                        617
                                                        if x["maggaia_med"] < 40.8837357
                                                        else 618
                                                    )
                                                    if state == 617:
                                                        return 0.477250993
                                                    if state == 618:
                                                        return -0.432189047
                                                if state == 438:
                                                    return -0.278955549
                            if state == 30:
                                state = (
                                    57
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.971750021)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        109 if x["distpsnr1_med"] < 0.47179538 else 110
                                    )
                                    if state == 109:
                                        state = (
                                            185
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 11.9376507)
                                            else 186
                                        )
                                        if state == 185:
                                            return 0.108839534
                                        if state == 186:
                                            state = (
                                                293
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.959500015)
                                                else 294
                                            )
                                            if state == 293:
                                                return -0.353061289
                                            if state == 294:
                                                return 0.058870852
                                    if state == 110:
                                        state = (
                                            187
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 8.42804909)
                                            else 188
                                        )
                                        if state == 187:
                                            state = (
                                                295
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.791000009)
                                                else 296
                                            )
                                            if state == 295:
                                                return -0.317721874
                                            if state == 296:
                                                state = (
                                                    439
                                                    if x["sgscore1_med"] < 0.00643750001
                                                    else 440
                                                )
                                                if state == 439:
                                                    return 0.277537584
                                                if state == 440:
                                                    state = (
                                                        619
                                                        if x["maggaia_med"] < 19.9951115
                                                        else 620
                                                    )
                                                    if state == 619:
                                                        return 0.142137364
                                                    if state == 620:
                                                        return -0.192818299
                                        if state == 188:
                                            return -0.452195376
                                if state == 58:
                                    state = (
                                        111 if x["distpsnr1_med"] < 0.461672843 else 112
                                    )
                                    if state == 111:
                                        state = (
                                            189
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 12.0160999)
                                            else 190
                                        )
                                        if state == 189:
                                            return 0.0133150034
                                        if state == 190:
                                            return 0.440064698
                                    if state == 112:
                                        state = (
                                            191
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 84.8763123)
                                            else 192
                                        )
                                        if state == 191:
                                            state = (
                                                297
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.985000014)
                                                else 298
                                            )
                                            if state == 297:
                                                state = (
                                                    441
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.742905021)
                                                    else 442
                                                )
                                                if state == 441:
                                                    state = (
                                                        621
                                                        if x["maggaia_med"] < 18.8586731
                                                        else 622
                                                    )
                                                    if state == 621:
                                                        return 0.435580641
                                                    if state == 622:
                                                        state = (
                                                            811
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.405107498
                                                            )
                                                            else 812
                                                        )
                                                        if state == 811:
                                                            return 0.396263659
                                                        if state == 812:
                                                            return -0.0209846403
                                                if state == 442:
                                                    return -0.50787586
                                            if state == 298:
                                                return -0.415998101
                                        if state == 192:
                                            state = (
                                                299
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.976500034)
                                                else 300
                                            )
                                            if state == 299:
                                                return -0.319235146
                                            if state == 300:
                                                state = (
                                                    443
                                                    if x["sgscore1_med"] < 0.55092001
                                                    else 444
                                                )
                                                if state == 443:
                                                    return 0.400869459
                                                if state == 444:
                                                    return -0.175644338
                        if state == 16:
                            state = 31 if x["distpsnr1_med"] < 0.466277361 else 32
                            if state == 31:
                                state = (
                                    59
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.979750037)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        113 if x["distpsnr1_med"] < 0.120393373 else 114
                                    )
                                    if state == 113:
                                        state = (
                                            193
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 18.5085602)
                                            else 194
                                        )
                                        if state == 193:
                                            state = (
                                                301
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.899249971)
                                                else 302
                                            )
                                            if state == 301:
                                                return -0.256189704
                                            if state == 302:
                                                state = (
                                                    445
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00343749998
                                                    )
                                                    else 446
                                                )
                                                if state == 445:
                                                    state = (
                                                        623
                                                        if x["maggaia_med"] < 41.0079117
                                                        else 624
                                                    )
                                                    if state == 623:
                                                        state = (
                                                            813
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.304249495
                                                            )
                                                            else 814
                                                        )
                                                        if state == 813:
                                                            return -0.120600991
                                                        if state == 814:
                                                            return 0.300930977
                                                    if state == 624:
                                                        return -0.197130665
                                                if state == 446:
                                                    state = (
                                                        625
                                                        if x["maggaia_med"] < 19.0405216
                                                        else 626
                                                    )
                                                    if state == 625:
                                                        return 0.526308477
                                                    if state == 626:
                                                        state = (
                                                            815
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.110479251
                                                            )
                                                            else 816
                                                        )
                                                        if state == 815:
                                                            return 0.198374301
                                                        if state == 816:
                                                            return -0.169413671
                                        if state == 194:
                                            state = (
                                                303
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.975749969)
                                                else 304
                                            )
                                            if state == 303:
                                                return -0.423920006
                                            if state == 304:
                                                state = (
                                                    447
                                                    if x["sgscore1_med"] < 0.0454166867
                                                    else 448
                                                )
                                                if state == 447:
                                                    return 0.358161688
                                                if state == 448:
                                                    return -0.332130164
                                    if state == 114:
                                        state = (
                                            195
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 9.00850677)
                                            else 196
                                        )
                                        if state == 195:
                                            state = (
                                                305
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.940750003)
                                                else 306
                                            )
                                            if state == 305:
                                                return -0.373451173
                                            if state == 306:
                                                state = (
                                                    449
                                                    if x["sgscore1_med"] < 0.0296250004
                                                    else 450
                                                )
                                                if state == 449:
                                                    state = (
                                                        627
                                                        if x["maggaia_med"] < 18.7766075
                                                        else 628
                                                    )
                                                    if state == 627:
                                                        return 0.342452705
                                                    if state == 628:
                                                        state = (
                                                            817
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.282190055
                                                            )
                                                            else 818
                                                        )
                                                        if state == 817:
                                                            return 0.160197616
                                                        if state == 818:
                                                            return -0.349091679
                                                if state == 450:
                                                    return -0.19423756
                                        if state == 196:
                                            state = (
                                                307
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.957000017)
                                                else 308
                                            )
                                            if state == 307:
                                                return -0.431225985
                                            if state == 308:
                                                state = (
                                                    451
                                                    if x["sgscore1_med"] < 0.0292082988
                                                    else 452
                                                )
                                                if state == 451:
                                                    state = (
                                                        629
                                                        if x["maggaia_med"] < 19.5454025
                                                        else 630
                                                    )
                                                    if state == 629:
                                                        state = (
                                                            819
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.264846474
                                                            )
                                                            else 820
                                                        )
                                                        if state == 819:
                                                            return -0.177694425
                                                        if state == 820:
                                                            return 0.153590247
                                                    if state == 630:
                                                        return -0.447752684
                                                if state == 452:
                                                    state = (
                                                        631
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 20.5134926
                                                        )
                                                        else 632
                                                    )
                                                    if state == 631:
                                                        return -0.4625597
                                                    if state == 632:
                                                        return 0.145972729
                                if state == 60:
                                    state = (
                                        115 if x["distpsnr1_med"] < 0.366317987 else 116
                                    )
                                    if state == 115:
                                        state = (
                                            197
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 19.050787)
                                            else 198
                                        )
                                        if state == 197:
                                            state = (
                                                309
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.988499999)
                                                else 310
                                            )
                                            if state == 309:
                                                state = (
                                                    453
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.39703548)
                                                    else 454
                                                )
                                                if state == 453:
                                                    state = (
                                                        633
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 19.7091026
                                                        )
                                                        else 634
                                                    )
                                                    if state == 633:
                                                        state = (
                                                            821
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.180928275
                                                            )
                                                            else 822
                                                        )
                                                        if state == 821:
                                                            return 0.118918419
                                                        if state == 822:
                                                            return 0.407425344
                                                    if state == 634:
                                                        state = (
                                                            823
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.293838501
                                                            )
                                                            else 824
                                                        )
                                                        if state == 823:
                                                            return 0.108622581
                                                        if state == 824:
                                                            return -0.186584488
                                                if state == 454:
                                                    return -0.455068499
                                            if state == 310:
                                                return -0.159615368
                                        if state == 198:
                                            state = (
                                                311
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.980250001)
                                                else 312
                                            )
                                            if state == 311:
                                                state = (
                                                    455
                                                    if x["sgscore1_med"] < 0.0467470028
                                                    else 456
                                                )
                                                if state == 455:
                                                    state = (
                                                        635
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 19.3066139
                                                        )
                                                        else 636
                                                    )
                                                    if state == 635:
                                                        return 0.411636114
                                                    if state == 636:
                                                        return -0.132268041
                                                if state == 456:
                                                    return -0.22848168
                                            if state == 312:
                                                state = (
                                                    457
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00857638475
                                                    )
                                                    else 458
                                                )
                                                if state == 457:
                                                    state = (
                                                        637
                                                        if x["maggaia_med"] < 19.3701878
                                                        else 638
                                                    )
                                                    if state == 637:
                                                        state = (
                                                            825
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.231004983
                                                            )
                                                            else 826
                                                        )
                                                        if state == 825:
                                                            return 0.487304509
                                                        if state == 826:
                                                            return 0.0682765469
                                                    if state == 638:
                                                        state = (
                                                            827
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.250380158
                                                            )
                                                            else 828
                                                        )
                                                        if state == 827:
                                                            return -0.398826569
                                                        if state == 828:
                                                            return 0.0931360573
                                                if state == 458:
                                                    return -0.450091273
                                    if state == 116:
                                        state = (
                                            199
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 22.5400524)
                                            else 200
                                        )
                                        if state == 199:
                                            return 0.416643858
                                        if state == 200:
                                            state = (
                                                313
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.98300004)
                                                else 314
                                            )
                                            if state == 313:
                                                return -0.156487882
                                            if state == 314:
                                                state = (
                                                    459
                                                    if x["sgscore1_med"] < 0.321612984
                                                    else 460
                                                )
                                                if state == 459:
                                                    return 0.124910027
                                                if state == 460:
                                                    return -0.13898617
                            if state == 32:
                                state = (
                                    61
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.965250015)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        117 if x["distpsnr1_med"] < 0.469395876 else 118
                                    )
                                    if state == 117:
                                        return 0.269596785
                                    if state == 118:
                                        return -0.455300033
                                if state == 62:
                                    state = (
                                        119 if x["distpsnr1_med"] < 4.00273657 else 120
                                    )
                                    if state == 119:
                                        state = (
                                            201
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 6.56340885)
                                            else 202
                                        )
                                        if state == 201:
                                            state = (
                                                315
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.979750037)
                                                else 316
                                            )
                                            if state == 315:
                                                return 0.551480174
                                            if state == 316:
                                                return 0.0317594744
                                        if state == 202:
                                            state = (
                                                317
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.980250001)
                                                else 318
                                            )
                                            if state == 317:
                                                state = (
                                                    463
                                                    if x["sgscore1_med"] < 0.0354583487
                                                    else 464
                                                )
                                                if state == 463:
                                                    state = (
                                                        639
                                                        if x["maggaia_med"] < 20.0893631
                                                        else 640
                                                    )
                                                    if state == 639:
                                                        return -0.507418752
                                                    if state == 640:
                                                        state = (
                                                            829
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.552672148
                                                            )
                                                            else 830
                                                        )
                                                        if state == 829:
                                                            return 0.19829905
                                                        if state == 830:
                                                            return -0.238753319
                                                if state == 464:
                                                    state = (
                                                        641
                                                        if x["maggaia_med"] < 19.9772739
                                                        else 642
                                                    )
                                                    if state == 641:
                                                        return -0.284916043
                                                    if state == 642:
                                                        state = (
                                                            831
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.309335947
                                                            )
                                                            else 832
                                                        )
                                                        if state == 831:
                                                            return 0.30157727
                                                        if state == 832:
                                                            return -0.0339897685
                                            if state == 318:
                                                state = (
                                                    465
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.660017967)
                                                    else 466
                                                )
                                                if state == 465:
                                                    state = (
                                                        643
                                                        if x["maggaia_med"] < 20.7329617
                                                        else 644
                                                    )
                                                    if state == 643:
                                                        state = (
                                                            833
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.443078041
                                                            )
                                                            else 834
                                                        )
                                                        if state == 833:
                                                            return 0.394646436
                                                        if state == 834:
                                                            return 0.217452362
                                                    if state == 644:
                                                        return -0.119382381
                                                if state == 466:
                                                    return -0.38239634
                                    if state == 120:
                                        state = (
                                            203
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 14.0205383)
                                            else 204
                                        )
                                        if state == 203:
                                            state = (
                                                319
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.978500009)
                                                else 320
                                            )
                                            if state == 319:
                                                return -0.240827098
                                            if state == 320:
                                                state = (
                                                    467
                                                    if x["sgscore1_med"] < 0.398872018
                                                    else 468
                                                )
                                                if state == 467:
                                                    return -0.0658196285
                                                if state == 468:
                                                    return 0.262845188
                                        if state == 204:
                                            return 0.487523735
                if state == 4:
                    state = 9 if x["col_peak"] < -0.00965261459 else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["col_last"]) or (x["col_last"] < 0.18517065)
                            else 18
                        )
                        if state == 17:
                            state = (
                                33
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 0.35718286)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    63
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.979250014)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        121
                                        if x["distpsnr1_med"] < 0.0462844223
                                        else 122
                                    )
                                    if state == 121:
                                        return 0.346002996
                                    if state == 122:
                                        state = (
                                            205
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 66.7807388)
                                            else 206
                                        )
                                        if state == 205:
                                            return -0.415757835
                                        if state == 206:
                                            state = (
                                                321
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.963999987)
                                                else 322
                                            )
                                            if state == 321:
                                                return -0.405463576
                                            if state == 322:
                                                state = (
                                                    469
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0325625017
                                                    )
                                                    else 470
                                                )
                                                if state == 469:
                                                    state = (
                                                        645
                                                        if x["maggaia_med"] < 19.3501339
                                                        else 646
                                                    )
                                                    if state == 645:
                                                        return 0.415468305
                                                    if state == 646:
                                                        return -0.350986272
                                                if state == 470:
                                                    return -0.366980225
                                if state == 64:
                                    state = (
                                        123
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.142331824)
                                        else 124
                                    )
                                    if state == 123:
                                        state = (
                                            207
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 31.465498)
                                            else 208
                                        )
                                        if state == 207:
                                            state = (
                                                323
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981750011)
                                                else 324
                                            )
                                            if state == 323:
                                                return 0.434599012
                                            if state == 324:
                                                state = (
                                                    471
                                                    if x["sgscore1_med"] < 1.53146505
                                                    else 472
                                                )
                                                if state == 471:
                                                    return -0.322991014
                                                if state == 472:
                                                    state = (
                                                        647
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 19.2017269
                                                        )
                                                        else 648
                                                    )
                                                    if state == 647:
                                                        return 0.369712234
                                                    if state == 648:
                                                        return 0.082647346
                                        if state == 208:
                                            return -0.465414226
                                    if state == 124:
                                        state = (
                                            209
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 78.4614868)
                                            else 210
                                        )
                                        if state == 209:
                                            state = (
                                                325
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.980250001)
                                                else 326
                                            )
                                            if state == 325:
                                                return -0.25488019
                                            if state == 326:
                                                state = (
                                                    473
                                                    if x["sgscore1_med"]
                                                    < 0.000937499979
                                                    else 474
                                                )
                                                if state == 473:
                                                    return -0.268526286
                                                if state == 474:
                                                    return 0.47247535
                                        if state == 210:
                                            return -0.150957838
                            if state == 34:
                                state = (
                                    65
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.952250004)
                                    else 66
                                )
                                if state == 65:
                                    return -0.395364642
                                if state == 66:
                                    state = (
                                        125 if x["distpsnr1_med"] < 9.52335548 else 126
                                    )
                                    if state == 125:
                                        state = (
                                            211
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 16.9503632)
                                            else 212
                                        )
                                        if state == 211:
                                            state = (
                                                327
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.983500004)
                                                else 328
                                            )
                                            if state == 327:
                                                state = (
                                                    475
                                                    if x["sgscore1_med"] < 0.00312499981
                                                    else 476
                                                )
                                                if state == 475:
                                                    state = (
                                                        649
                                                        if x["maggaia_med"] < 18.7002354
                                                        else 650
                                                    )
                                                    if state == 649:
                                                        return 0.179987401
                                                    if state == 650:
                                                        return -0.204892367
                                                if state == 476:
                                                    return -0.354695231
                                            if state == 328:
                                                state = (
                                                    477
                                                    if x["sgscore1_med"] < 0.351518005
                                                    else 478
                                                )
                                                if state == 477:
                                                    return 0.222398341
                                                if state == 478:
                                                    return -0.221869037
                                        if state == 212:
                                            state = (
                                                329
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.980749965)
                                                else 330
                                            )
                                            if state == 329:
                                                state = (
                                                    479
                                                    if x["sgscore1_med"] < 0.0320000015
                                                    else 480
                                                )
                                                if state == 479:
                                                    state = (
                                                        651
                                                        if x["maggaia_med"] < 20.6577206
                                                        else 652
                                                    )
                                                    if state == 651:
                                                        state = (
                                                            839
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.462865412
                                                            )
                                                            else 840
                                                        )
                                                        if state == 839:
                                                            return 0.182590559
                                                        if state == 840:
                                                            return 0.428261995
                                                    if state == 652:
                                                        return -0.264741689
                                                if state == 480:
                                                    state = (
                                                        653
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 18.6359215
                                                        )
                                                        else 654
                                                    )
                                                    if state == 653:
                                                        return -0.496310472
                                                    if state == 654:
                                                        state = (
                                                            841
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.483311534
                                                            )
                                                            else 842
                                                        )
                                                        if state == 841:
                                                            return 0.383209586
                                                        if state == 842:
                                                            return 0.0732689127
                                            if state == 330:
                                                state = (
                                                    481
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00124999997
                                                    )
                                                    else 482
                                                )
                                                if state == 481:
                                                    return -0.20975402
                                                if state == 482:
                                                    state = (
                                                        655
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 20.7329617
                                                        )
                                                        else 656
                                                    )
                                                    if state == 655:
                                                        state = (
                                                            843
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.641602397
                                                            )
                                                            else 844
                                                        )
                                                        if state == 843:
                                                            return 0.453275532
                                                        if state == 844:
                                                            return -0.127383694
                                                    if state == 656:
                                                        return -0.120564245
                                    if state == 126:
                                        state = (
                                            213
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 26.0042591)
                                            else 214
                                        )
                                        if state == 213:
                                            return 0.0395650156
                                        if state == 214:
                                            return 0.419733793
                        if state == 18:
                            state = 35 if x["distpsnr1_med"] < 0.745071769 else 36
                            if state == 35:
                                state = (
                                    67
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.979249954)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        127 if x["distpsnr1_med"] < 0.245727628 else 128
                                    )
                                    if state == 127:
                                        state = (
                                            215
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 20.0026169)
                                            else 216
                                        )
                                        if state == 215:
                                            return 0.351854861
                                        if state == 216:
                                            state = (
                                                331
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.914999962)
                                                else 332
                                            )
                                            if state == 331:
                                                return -0.18203178
                                            if state == 332:
                                                state = (
                                                    483
                                                    if x["sgscore1_med"] < 0.0325625017
                                                    else 484
                                                )
                                                if state == 483:
                                                    return 0.323581129
                                                if state == 484:
                                                    state = (
                                                        657
                                                        if x["maggaia_med"] < 18.4211197
                                                        else 658
                                                    )
                                                    if state == 657:
                                                        return -0.222841188
                                                    if state == 658:
                                                        return 0.0620841049
                                    if state == 128:
                                        state = (
                                            217
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 38.0160065)
                                            else 218
                                        )
                                        if state == 217:
                                            state = (
                                                333
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.978500009)
                                                else 334
                                            )
                                            if state == 333:
                                                state = (
                                                    485
                                                    if x["sgscore1_med"] < 0.00312499981
                                                    else 486
                                                )
                                                if state == 485:
                                                    state = (
                                                        659
                                                        if x["maggaia_med"] < 18.7662239
                                                        else 660
                                                    )
                                                    if state == 659:
                                                        state = (
                                                            845
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.430559486
                                                            )
                                                            else 846
                                                        )
                                                        if state == 845:
                                                            return -0.124489136
                                                        if state == 846:
                                                            return 0.193439171
                                                    if state == 660:
                                                        return -0.196041837
                                                if state == 486:
                                                    return -0.309316784
                                            if state == 334:
                                                return 0.161939517
                                        if state == 218:
                                            return -0.451830626
                                if state == 68:
                                    state = (
                                        129 if x["distpsnr1_med"] < 0.521248341 else 130
                                    )
                                    if state == 129:
                                        state = (
                                            219
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 19.4376793)
                                            else 220
                                        )
                                        if state == 219:
                                            return -0.151276484
                                        if state == 220:
                                            return 0.445989668
                                    if state == 130:
                                        state = (
                                            221
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 32.4784889)
                                            else 222
                                        )
                                        if state == 221:
                                            return 0.189186484
                                        if state == 222:
                                            return -0.157804161
                            if state == 36:
                                state = (
                                    69
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.978500009)
                                    else 70
                                )
                                if state == 69:
                                    return -0.27763471
                                if state == 70:
                                    return 0.414444596
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["col_last"]) or (x["col_last"] < 0.67671299)
                            else 20
                        )
                        if state == 19:
                            state = (
                                37
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 3.43033791)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    71
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.974250019)
                                    else 72
                                )
                                if state == 71:
                                    return -0.464645803
                                if state == 72:
                                    state = (
                                        131 if x["distpsnr1_med"] < 0.176378861 else 132
                                    )
                                    if state == 131:
                                        state = (
                                            223
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 28.0319214)
                                            else 224
                                        )
                                        if state == 223:
                                            state = (
                                                335
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.976500034)
                                                else 336
                                            )
                                            if state == 335:
                                                state = (
                                                    487
                                                    if x["sgscore1_med"] < 0.0047083348
                                                    else 488
                                                )
                                                if state == 487:
                                                    return -0.125710666
                                                if state == 488:
                                                    return 0.416368663
                                            if state == 336:
                                                state = (
                                                    489
                                                    if x["sgscore1_med"] < 0.00462500006
                                                    else 490
                                                )
                                                if state == 489:
                                                    return 0.347624838
                                                if state == 490:
                                                    state = (
                                                        661
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 18.8051186
                                                        )
                                                        else 662
                                                    )
                                                    if state == 661:
                                                        return -0.436146587
                                                    if state == 662:
                                                        state = (
                                                            847
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.215292484
                                                            )
                                                            else 848
                                                        )
                                                        if state == 847:
                                                            return -0.244811177
                                                        if state == 848:
                                                            return 0.361464739
                                        if state == 224:
                                            state = (
                                                337
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982749999)
                                                else 338
                                            )
                                            if state == 337:
                                                state = (
                                                    491
                                                    if x["sgscore1_med"] < 0.00354166492
                                                    else 492
                                                )
                                                if state == 491:
                                                    return 0.345458388
                                                if state == 492:
                                                    state = (
                                                        663
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 19.5678082
                                                        )
                                                        else 664
                                                    )
                                                    if state == 663:
                                                        return -0.572948515
                                                    if state == 664:
                                                        state = (
                                                            849
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.484591305
                                                            )
                                                            else 850
                                                        )
                                                        if state == 849:
                                                            return -0.370711505
                                                        if state == 850:
                                                            return 0.279831976
                                            if state == 338:
                                                state = (
                                                    493
                                                    if x["sgscore1_med"] < 0.0857648998
                                                    else 494
                                                )
                                                if state == 493:
                                                    return 0.315582931
                                                if state == 494:
                                                    state = (
                                                        665
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 19.1488876
                                                        )
                                                        else 666
                                                    )
                                                    if state == 665:
                                                        return -0.48511219
                                                    if state == 666:
                                                        return 0.216584787
                                    if state == 132:
                                        state = (
                                            225
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 58.8229866)
                                            else 226
                                        )
                                        if state == 225:
                                            state = (
                                                339
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.985000014)
                                                else 340
                                            )
                                            if state == 339:
                                                state = (
                                                    495
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0763065517
                                                    )
                                                    else 496
                                                )
                                                if state == 495:
                                                    state = (
                                                        667
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 19.7447166
                                                        )
                                                        else 668
                                                    )
                                                    if state == 667:
                                                        return 0.384135157
                                                    if state == 668:
                                                        state = (
                                                            851
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.579672098
                                                            )
                                                            else 852
                                                        )
                                                        if state == 851:
                                                            return -0.578263581
                                                        if state == 852:
                                                            return -0.155528188
                                                if state == 496:
                                                    state = (
                                                        669
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 20.0688515
                                                        )
                                                        else 670
                                                    )
                                                    if state == 669:
                                                        state = (
                                                            853
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.494945586
                                                            )
                                                            else 854
                                                        )
                                                        if state == 853:
                                                            return -0.548745811
                                                        if state == 854:
                                                            return 0.127702758
                                                    if state == 670:
                                                        return 0.217821956
                                            if state == 340:
                                                return -0.357759744
                                        if state == 226:
                                            state = (
                                                341
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982749999)
                                                else 342
                                            )
                                            if state == 341:
                                                return -0.38383311
                                            if state == 342:
                                                state = (
                                                    499
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0517470017
                                                    )
                                                    else 500
                                                )
                                                if state == 499:
                                                    return 0.368217587
                                                if state == 500:
                                                    return -0.351990402
                            if state == 38:
                                state = (
                                    73
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.977500021)
                                    else 74
                                )
                                if state == 73:
                                    return -0.243500695
                                if state == 74:
                                    state = (
                                        133 if x["distpsnr1_med"] < 5.80923557 else 134
                                    )
                                    if state == 133:
                                        return 0.398648977
                                    if state == 134:
                                        state = (
                                            227
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 72.9200974)
                                            else 228
                                        )
                                        if state == 227:
                                            return 0.239284635
                                        if state == 228:
                                            state = (
                                                343
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982499957)
                                                else 344
                                            )
                                            if state == 343:
                                                state = (
                                                    501
                                                    if x["sgscore1_med"] < 0.642395973
                                                    else 502
                                                )
                                                if state == 501:
                                                    return 0.140066877
                                                if state == 502:
                                                    return -0.307332933
                                            if state == 344:
                                                return 0.205084741
                        if state == 20:
                            state = 39 if x["distpsnr1_med"] < 0.246225387 else 40
                            if state == 39:
                                state = (
                                    75
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.982499957)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        135 if x["distpsnr1_med"] < 0.128005907 else 136
                                    )
                                    if state == 135:
                                        return 0.173420295
                                    if state == 136:
                                        state = (
                                            231
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 22.001812)
                                            else 232
                                        )
                                        if state == 231:
                                            state = (
                                                345
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.962000012)
                                                else 346
                                            )
                                            if state == 345:
                                                return 0.16413115
                                            if state == 346:
                                                return -0.220984504
                                        if state == 232:
                                            return -0.483909905
                                if state == 76:
                                    return 0.319126785
                            if state == 40:
                                state = (
                                    77
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.979750037)
                                    else 78
                                )
                                if state == 77:
                                    return -0.503945112
                                if state == 78:
                                    return 0.432936788
            if state == 2:
                state = (
                    5
                    if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.209345818)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.21724382)
                        else 12
                    )
                    if state == 11:
                        state = 21 if x["col_last"] < 0.386386871 else 22
                        if state == 21:
                            state = (
                                41
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 0.293748617)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    79
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.982749999)
                                    else 80
                                )
                                if state == 79:
                                    return -0.437783599
                                if state == 80:
                                    state = (
                                        139 if x["distpsnr1_med"] < 0.273694813 else 140
                                    )
                                    if state == 139:
                                        return -0.299943209
                                    if state == 140:
                                        return 0.268513054
                            if state == 42:
                                state = (
                                    81
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.977750003)
                                    else 82
                                )
                                if state == 81:
                                    state = (
                                        141 if x["distpsnr1_med"] < 0.621376932 else 142
                                    )
                                    if state == 141:
                                        state = (
                                            233
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 13.5310249)
                                            else 234
                                        )
                                        if state == 233:
                                            state = (
                                                347
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.957000017)
                                                else 348
                                            )
                                            if state == 347:
                                                return -0.365385592
                                            if state == 348:
                                                return 0.0845693871
                                        if state == 234:
                                            state = (
                                                349
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.945500016)
                                                else 350
                                            )
                                            if state == 349:
                                                state = (
                                                    503
                                                    if x["sgscore1_med"] < 0.00499999989
                                                    else 504
                                                )
                                                if state == 503:
                                                    return 0.109469838
                                                if state == 504:
                                                    return -0.285324663
                                            if state == 350:
                                                state = (
                                                    505
                                                    if x["sgscore1_med"] < 0.327806503
                                                    else 506
                                                )
                                                if state == 505:
                                                    state = (
                                                        671
                                                        if x["maggaia_med"] < 19.2398911
                                                        else 672
                                                    )
                                                    if state == 671:
                                                        return 0.412620395
                                                    if state == 672:
                                                        return -0.146904916
                                                if state == 506:
                                                    state = (
                                                        673
                                                        if x["maggaia_med"] < 18.4717026
                                                        else 674
                                                    )
                                                    if state == 673:
                                                        return 0.165855274
                                                    if state == 674:
                                                        state = (
                                                            855
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.721763372
                                                            )
                                                            else 856
                                                        )
                                                        if state == 855:
                                                            return 0.0869600996
                                                        if state == 856:
                                                            return -0.271585613
                                    if state == 142:
                                        state = (
                                            235
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 6.04294586)
                                            else 236
                                        )
                                        if state == 235:
                                            state = (
                                                351
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.966750026)
                                                else 352
                                            )
                                            if state == 351:
                                                state = (
                                                    507
                                                    if x["sgscore1_med"] < 0.0109374998
                                                    else 508
                                                )
                                                if state == 507:
                                                    state = (
                                                        675
                                                        if x["maggaia_med"] < 19.0430298
                                                        else 676
                                                    )
                                                    if state == 675:
                                                        state = (
                                                            857
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.25550246
                                                            )
                                                            else 858
                                                        )
                                                        if state == 857:
                                                            return -0.000191251689
                                                        if state == 858:
                                                            return -0.25402233
                                                    if state == 676:
                                                        state = (
                                                            859
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.57926226
                                                            )
                                                            else 860
                                                        )
                                                        if state == 859:
                                                            return 0.746881604
                                                        if state == 860:
                                                            return -0.14619042
                                                if state == 508:
                                                    state = (
                                                        677
                                                        if x["maggaia_med"] < 14.4958763
                                                        else 678
                                                    )
                                                    if state == 677:
                                                        state = (
                                                            861
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 6.53408432
                                                            )
                                                            else 862
                                                        )
                                                        if state == 861:
                                                            return -0.143771276
                                                        if state == 862:
                                                            return 0.225088283
                                                    if state == 678:
                                                        state = (
                                                            863
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.02899528
                                                            )
                                                            else 864
                                                        )
                                                        if state == 863:
                                                            return -0.0923440084
                                                        if state == 864:
                                                            return -0.394848347
                                            if state == 352:
                                                state = (
                                                    509
                                                    if x["sgscore1_med"] < 0.965755999
                                                    else 510
                                                )
                                                if state == 509:
                                                    state = (
                                                        679
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 20.6050434
                                                        )
                                                        else 680
                                                    )
                                                    if state == 679:
                                                        state = (
                                                            865
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.927832007
                                                            )
                                                            else 866
                                                        )
                                                        if state == 865:
                                                            return -0.152717009
                                                        if state == 866:
                                                            return 0.417901427
                                                    if state == 680:
                                                        return -0.273009688
                                                if state == 510:
                                                    return -0.340293944
                                        if state == 236:
                                            state = (
                                                353
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.976000011)
                                                else 354
                                            )
                                            if state == 353:
                                                state = (
                                                    511
                                                    if x["sgscore1_med"] < 0.0101666497
                                                    else 512
                                                )
                                                if state == 511:
                                                    state = (
                                                        681
                                                        if x["maggaia_med"] < 18.5983868
                                                        else 682
                                                    )
                                                    if state == 681:
                                                        state = (
                                                            867
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.09910846
                                                            )
                                                            else 868
                                                        )
                                                        if state == 867:
                                                            return -0.106169291
                                                        if state == 868:
                                                            return -0.483736068
                                                    if state == 682:
                                                        state = (
                                                            869
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.13142002
                                                            )
                                                            else 870
                                                        )
                                                        if state == 869:
                                                            return -0.407123893
                                                        if state == 870:
                                                            return -0.0156117696
                                                if state == 512:
                                                    state = (
                                                        683
                                                        if x["maggaia_med"] < 15.0291739
                                                        else 684
                                                    )
                                                    if state == 683:
                                                        state = (
                                                            871
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.76173997
                                                            )
                                                            else 872
                                                        )
                                                        if state == 871:
                                                            return -0.441745698
                                                        if state == 872:
                                                            return -0.0516521037
                                                    if state == 684:
                                                        state = (
                                                            873
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.45398712
                                                            )
                                                            else 874
                                                        )
                                                        if state == 873:
                                                            return -0.267839581
                                                        if state == 874:
                                                            return -0.426228493
                                            if state == 354:
                                                state = (
                                                    513
                                                    if x["sgscore1_med"] < 0.0495624989
                                                    else 514
                                                )
                                                if state == 513:
                                                    state = (
                                                        685
                                                        if x["maggaia_med"] < 19.4643631
                                                        else 686
                                                    )
                                                    if state == 685:
                                                        state = (
                                                            875
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.06904399
                                                            )
                                                            else 876
                                                        )
                                                        if state == 875:
                                                            return -0.154217213
                                                        if state == 876:
                                                            return 0.174618945
                                                    if state == 686:
                                                        state = (
                                                            877
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.01187325
                                                            )
                                                            else 878
                                                        )
                                                        if state == 877:
                                                            return -0.355140626
                                                        if state == 878:
                                                            return -0.0890852362
                                                if state == 514:
                                                    state = (
                                                        687
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 18.5491829
                                                        )
                                                        else 688
                                                    )
                                                    if state == 687:
                                                        state = (
                                                            879
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.868855238
                                                            )
                                                            else 880
                                                        )
                                                        if state == 879:
                                                            return 0.0370058194
                                                        if state == 880:
                                                            return -0.525261164
                                                    if state == 688:
                                                        state = (
                                                            881
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 4.41864586
                                                            )
                                                            else 882
                                                        )
                                                        if state == 881:
                                                            return 0.016119536
                                                        if state == 882:
                                                            return -0.284998477
                                if state == 82:
                                    state = (
                                        143 if x["distpsnr1_med"] < 0.822793841 else 144
                                    )
                                    if state == 143:
                                        state = (
                                            237
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 7.46664906)
                                            else 238
                                        )
                                        if state == 237:
                                            return 0.487314105
                                        if state == 238:
                                            state = (
                                                355
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982249975)
                                                else 356
                                            )
                                            if state == 355:
                                                state = (
                                                    515
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00231250003
                                                    )
                                                    else 516
                                                )
                                                if state == 515:
                                                    state = (
                                                        689
                                                        if x["maggaia_med"] < 18.6832218
                                                        else 690
                                                    )
                                                    if state == 689:
                                                        state = (
                                                            883
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.793124378
                                                            )
                                                            else 884
                                                        )
                                                        if state == 883:
                                                            return 0.179425225
                                                        if state == 884:
                                                            return -0.139903069
                                                    if state == 690:
                                                        return -0.452785403
                                                if state == 516:
                                                    return 0.313757867
                                            if state == 356:
                                                state = (
                                                    517
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0119375149
                                                    )
                                                    else 518
                                                )
                                                if state == 517:
                                                    state = (
                                                        691
                                                        if x["maggaia_med"] < 19.7387333
                                                        else 692
                                                    )
                                                    if state == 691:
                                                        state = (
                                                            885
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.799969554
                                                            )
                                                            else 886
                                                        )
                                                        if state == 885:
                                                            return -0.423519433
                                                        if state == 886:
                                                            return 0.163189843
                                                    if state == 692:
                                                        return 0.236762881
                                                if state == 518:
                                                    return 0.40384087
                                    if state == 144:
                                        state = (
                                            239
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 31.8261642)
                                            else 240
                                        )
                                        if state == 239:
                                            state = (
                                                357
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981750011)
                                                else 358
                                            )
                                            if state == 357:
                                                state = (
                                                    519
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00104166649
                                                    )
                                                    else 520
                                                )
                                                if state == 519:
                                                    state = (
                                                        693
                                                        if x["maggaia_med"] < 19.9288979
                                                        else 694
                                                    )
                                                    if state == 693:
                                                        state = (
                                                            887
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.5522157
                                                            )
                                                            else 888
                                                        )
                                                        if state == 887:
                                                            return 0.176395237
                                                        if state == 888:
                                                            return -0.0944394767
                                                    if state == 694:
                                                        return -0.675318182
                                                if state == 520:
                                                    state = (
                                                        695
                                                        if x["maggaia_med"] < 15.603734
                                                        else 696
                                                    )
                                                    if state == 695:
                                                        state = (
                                                            889
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.28627956
                                                            )
                                                            else 890
                                                        )
                                                        if state == 889:
                                                            return 0.191834658
                                                        if state == 890:
                                                            return -0.752860665
                                                    if state == 696:
                                                        state = (
                                                            891
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.97127509
                                                            )
                                                            else 892
                                                        )
                                                        if state == 891:
                                                            return 0.147525564
                                                        if state == 892:
                                                            return -0.103023961
                                            if state == 358:
                                                state = (
                                                    521
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.664931536)
                                                    else 522
                                                )
                                                if state == 521:
                                                    state = (
                                                        697
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 20.6092453
                                                        )
                                                        else 698
                                                    )
                                                    if state == 697:
                                                        state = (
                                                            893
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 11.679039
                                                            )
                                                            else 894
                                                        )
                                                        if state == 893:
                                                            return 0.350530624
                                                        if state == 894:
                                                            return 0.0404819176
                                                    if state == 698:
                                                        state = (
                                                            895
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.36816633
                                                            )
                                                            else 896
                                                        )
                                                        if state == 895:
                                                            return -0.326788723
                                                        if state == 896:
                                                            return 0.187233657
                                                if state == 522:
                                                    state = (
                                                        699
                                                        if x["maggaia_med"] < 19.5308075
                                                        else 700
                                                    )
                                                    if state == 699:
                                                        state = (
                                                            897
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 13.9351587
                                                            )
                                                            else 898
                                                        )
                                                        if state == 897:
                                                            return -0.467335761
                                                        if state == 898:
                                                            return 0.183410645
                                                    if state == 700:
                                                        state = (
                                                            899
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 6.97697878
                                                            )
                                                            else 900
                                                        )
                                                        if state == 899:
                                                            return 0.239641249
                                                        if state == 900:
                                                            return -0.245247036
                                        if state == 240:
                                            state = (
                                                359
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.98150003)
                                                else 360
                                            )
                                            if state == 359:
                                                state = (
                                                    523
                                                    if x["sgscore1_med"] < 0.0286250003
                                                    else 524
                                                )
                                                if state == 523:
                                                    return 0.277279228
                                                if state == 524:
                                                    state = (
                                                        701
                                                        if x["maggaia_med"] < 19.545908
                                                        else 702
                                                    )
                                                    if state == 701:
                                                        state = (
                                                            901
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.35546184
                                                            )
                                                            else 902
                                                        )
                                                        if state == 901:
                                                            return -0.200465858
                                                        if state == 902:
                                                            return 0.129438281
                                                    if state == 702:
                                                        return 0.186753422
                                            if state == 360:
                                                state = (
                                                    525
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.876729488)
                                                    else 526
                                                )
                                                if state == 525:
                                                    return 0.421227157
                                                if state == 526:
                                                    return -0.229648039
                        if state == 22:
                            state = 43 if x["distpsnr1_med"] < 26.2245712 else 44
                            if state == 43:
                                state = (
                                    83
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.979000032)
                                    else 84
                                )
                                if state == 83:
                                    state = (
                                        145 if x["distpsnr1_med"] < 0.686598718 else 146
                                    )
                                    if state == 145:
                                        state = (
                                            241
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 24.0081482)
                                            else 242
                                        )
                                        if state == 241:
                                            state = (
                                                361
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.963500023)
                                                else 362
                                            )
                                            if state == 361:
                                                return -0.341965109
                                            if state == 362:
                                                state = (
                                                    527
                                                    if x["sgscore1_med"] < 0.274765015
                                                    else 528
                                                )
                                                if state == 527:
                                                    state = (
                                                        703
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 20.0407982
                                                        )
                                                        else 704
                                                    )
                                                    if state == 703:
                                                        state = (
                                                            903
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.782161474
                                                            )
                                                            else 904
                                                        )
                                                        if state == 903:
                                                            return 0.246740803
                                                        if state == 904:
                                                            return -0.105320357
                                                    if state == 704:
                                                        return -0.155936062
                                                if state == 528:
                                                    state = (
                                                        705
                                                        if x["maggaia_med"] < 19.8202362
                                                        else 706
                                                    )
                                                    if state == 705:
                                                        return -0.450104475
                                                    if state == 706:
                                                        state = (
                                                            905
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.70060205
                                                            )
                                                            else 906
                                                        )
                                                        if state == 905:
                                                            return -0.156050295
                                                        if state == 906:
                                                            return 0.220318794
                                        if state == 242:
                                            state = (
                                                363
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.962499976)
                                                else 364
                                            )
                                            if state == 363:
                                                state = (
                                                    529
                                                    if x["sgscore1_med"] < 0.0151875
                                                    else 530
                                                )
                                                if state == 529:
                                                    state = (
                                                        707
                                                        if x["maggaia_med"] < 19.6913605
                                                        else 708
                                                    )
                                                    if state == 707:
                                                        state = (
                                                            907
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.740921021
                                                            )
                                                            else 908
                                                        )
                                                        if state == 907:
                                                            return 0.0419652015
                                                        if state == 908:
                                                            return 0.469387531
                                                    if state == 708:
                                                        return -0.234296322
                                                if state == 530:
                                                    return -0.412313223
                                            if state == 364:
                                                state = (
                                                    531
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00312499981
                                                    )
                                                    else 532
                                                )
                                                if state == 531:
                                                    return -0.194528043
                                                if state == 532:
                                                    state = (
                                                        709
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 19.8077297
                                                        )
                                                        else 710
                                                    )
                                                    if state == 709:
                                                        return 0.399175972
                                                    if state == 710:
                                                        return -0.171258181
                                    if state == 146:
                                        state = (
                                            243
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 45.9382477)
                                            else 244
                                        )
                                        if state == 243:
                                            state = (
                                                365
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.966750026)
                                                else 366
                                            )
                                            if state == 365:
                                                state = (
                                                    533
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00995833427
                                                    )
                                                    else 534
                                                )
                                                if state == 533:
                                                    state = (
                                                        711
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 19.1128731
                                                        )
                                                        else 712
                                                    )
                                                    if state == 711:
                                                        return -0.446025223
                                                    if state == 712:
                                                        state = (
                                                            909
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.48540115
                                                            )
                                                            else 910
                                                        )
                                                        if state == 909:
                                                            return -0.446181685
                                                        if state == 910:
                                                            return -0.0991399735
                                                if state == 534:
                                                    state = (
                                                        713
                                                        if x["maggaia_med"] < 20.4053593
                                                        else 714
                                                    )
                                                    if state == 713:
                                                        state = (
                                                            911
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.95889807
                                                            )
                                                            else 912
                                                        )
                                                        if state == 911:
                                                            return -0.265814036
                                                        if state == 912:
                                                            return -0.40062964
                                                    if state == 714:
                                                        state = (
                                                            913
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.40863609
                                                            )
                                                            else 914
                                                        )
                                                        if state == 913:
                                                            return 0.0851583406
                                                        if state == 914:
                                                            return -0.443619817
                                            if state == 366:
                                                state = (
                                                    535
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00170833501
                                                    )
                                                    else 536
                                                )
                                                if state == 535:
                                                    state = (
                                                        715
                                                        if x["maggaia_med"] < 19.8697224
                                                        else 716
                                                    )
                                                    if state == 715:
                                                        state = (
                                                            915
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.737303913
                                                            )
                                                            else 916
                                                        )
                                                        if state == 915:
                                                            return 0.313402981
                                                        if state == 916:
                                                            return -0.348901093
                                                    if state == 716:
                                                        return -0.516051233
                                                if state == 536:
                                                    state = (
                                                        717
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 15.5322838
                                                        )
                                                        else 718
                                                    )
                                                    if state == 717:
                                                        state = (
                                                            917
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.56731939
                                                            )
                                                            else 918
                                                        )
                                                        if state == 917:
                                                            return 0.00614512293
                                                        if state == 918:
                                                            return -0.541543186
                                                    if state == 718:
                                                        state = (
                                                            919
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.27525163
                                                            )
                                                            else 920
                                                        )
                                                        if state == 919:
                                                            return 0.103261285
                                                        if state == 920:
                                                            return -0.0804829374
                                        if state == 244:
                                            state = (
                                                367
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.928249955)
                                                else 368
                                            )
                                            if state == 367:
                                                state = (
                                                    537
                                                    if x["sgscore1_med"] < 0.00104166649
                                                    else 538
                                                )
                                                if state == 537:
                                                    return 0.145846963
                                                if state == 538:
                                                    return -0.450005531
                                            if state == 368:
                                                state = (
                                                    539
                                                    if x["sgscore1_med"] < 0.0513124987
                                                    else 540
                                                )
                                                if state == 539:
                                                    state = (
                                                        719
                                                        if x["maggaia_med"] < 18.9392776
                                                        else 720
                                                    )
                                                    if state == 719:
                                                        state = (
                                                            921
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.24652433
                                                            )
                                                            else 922
                                                        )
                                                        if state == 921:
                                                            return 0.421248287
                                                        if state == 922:
                                                            return -0.00275766267
                                                    if state == 720:
                                                        state = (
                                                            923
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.9442687
                                                            )
                                                            else 924
                                                        )
                                                        if state == 923:
                                                            return -0.300801307
                                                        if state == 924:
                                                            return 0.127831429
                                                if state == 540:
                                                    state = (
                                                        721
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 20.1139393
                                                        )
                                                        else 722
                                                    )
                                                    if state == 721:
                                                        state = (
                                                            925
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.89928508
                                                            )
                                                            else 926
                                                        )
                                                        if state == 925:
                                                            return -0.248259589
                                                        if state == 926:
                                                            return 0.128861248
                                                    if state == 722:
                                                        return -0.43856284
                                if state == 84:
                                    state = (
                                        147 if x["distpsnr1_med"] < 0.261100531 else 148
                                    )
                                    if state == 147:
                                        state = (
                                            245
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 18.9582291)
                                            else 246
                                        )
                                        if state == 245:
                                            state = (
                                                369
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.979500055)
                                                else 370
                                            )
                                            if state == 369:
                                                return 0.16003713
                                            if state == 370:
                                                state = (
                                                    541
                                                    if x["sgscore1_med"] < 0.00206249999
                                                    else 542
                                                )
                                                if state == 541:
                                                    return 0.15837349
                                                if state == 542:
                                                    return -0.351691753
                                        if state == 246:
                                            state = (
                                                371
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.979500055)
                                                else 372
                                            )
                                            if state == 371:
                                                return 0.026160676
                                            if state == 372:
                                                return -0.428964227
                                    if state == 148:
                                        state = (
                                            247
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 25.9603004)
                                            else 248
                                        )
                                        if state == 247:
                                            state = (
                                                373
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981250048)
                                                else 374
                                            )
                                            if state == 373:
                                                state = (
                                                    543
                                                    if x["sgscore1_med"] < 0.00170833501
                                                    else 544
                                                )
                                                if state == 543:
                                                    state = (
                                                        723
                                                        if x["maggaia_med"] < 20.1059494
                                                        else 724
                                                    )
                                                    if state == 723:
                                                        state = (
                                                            927
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.74755287
                                                            )
                                                            else 928
                                                        )
                                                        if state == 927:
                                                            return -0.645915449
                                                        if state == 928:
                                                            return 0.113330111
                                                    if state == 724:
                                                        return 0.00978071988
                                                if state == 544:
                                                    state = (
                                                        725
                                                        if x["maggaia_med"] < 17.4514027
                                                        else 726
                                                    )
                                                    if state == 725:
                                                        state = (
                                                            929
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.90588498
                                                            )
                                                            else 930
                                                        )
                                                        if state == 929:
                                                            return 0.390962541
                                                        if state == 930:
                                                            return -0.221114129
                                                    if state == 726:
                                                        state = (
                                                            931
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.34782076
                                                            )
                                                            else 932
                                                        )
                                                        if state == 931:
                                                            return 0.113561139
                                                        if state == 932:
                                                            return -0.0530802235
                                            if state == 374:
                                                state = (
                                                    545
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.695366025)
                                                    else 546
                                                )
                                                if state == 545:
                                                    state = (
                                                        727
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 20.6092453
                                                        )
                                                        else 728
                                                    )
                                                    if state == 727:
                                                        state = (
                                                            933
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 11.6859713
                                                            )
                                                            else 934
                                                        )
                                                        if state == 933:
                                                            return 0.349516809
                                                        if state == 934:
                                                            return -0.148252591
                                                    if state == 728:
                                                        state = (
                                                            935
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.30194247
                                                            )
                                                            else 936
                                                        )
                                                        if state == 935:
                                                            return 0.176866293
                                                        if state == 936:
                                                            return -0.295107275
                                                if state == 546:
                                                    state = (
                                                        729
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 16.8707771
                                                        )
                                                        else 730
                                                    )
                                                    if state == 729:
                                                        state = (
                                                            937
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.99381417
                                                            )
                                                            else 938
                                                        )
                                                        if state == 937:
                                                            return -0.168990865
                                                        if state == 938:
                                                            return 0.237369105
                                                    if state == 730:
                                                        state = (
                                                            939
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.17847753
                                                            )
                                                            else 940
                                                        )
                                                        if state == 939:
                                                            return 0.188244507
                                                        if state == 940:
                                                            return -0.502005398
                                        if state == 248:
                                            state = (
                                                375
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.993000031)
                                                else 376
                                            )
                                            if state == 375:
                                                state = (
                                                    547
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.992118001)
                                                    else 548
                                                )
                                                if state == 547:
                                                    state = (
                                                        731
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 20.6092453
                                                        )
                                                        else 732
                                                    )
                                                    if state == 731:
                                                        state = (
                                                            941
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 10.6455898
                                                            )
                                                            else 942
                                                        )
                                                        if state == 941:
                                                            return 0.395834625
                                                        if state == 942:
                                                            return 0.138780072
                                                    if state == 732:
                                                        state = (
                                                            943
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.10396814
                                                            )
                                                            else 944
                                                        )
                                                        if state == 943:
                                                            return -0.182919234
                                                        if state == 944:
                                                            return 0.387765318
                                                if state == 548:
                                                    state = (
                                                        733
                                                        if x["maggaia_med"] < 16.6144867
                                                        else 734
                                                    )
                                                    if state == 733:
                                                        state = (
                                                            945
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.97598743
                                                            )
                                                            else 946
                                                        )
                                                        if state == 945:
                                                            return -0.250059724
                                                        if state == 946:
                                                            return 0.179849356
                                                    if state == 734:
                                                        return -0.453720719
                                            if state == 376:
                                                return -0.310820401
                            if state == 44:
                                state = (
                                    85
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.980250001)
                                    else 86
                                )
                                if state == 85:
                                    return -0.44030422
                                if state == 86:
                                    state = (
                                        149
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 26.9947968)
                                        else 150
                                    )
                                    if state == 149:
                                        return 0.507719874
                                    if state == 150:
                                        return -0.271472245
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["col_last"]) or (x["col_last"] < 0.89393425)
                            else 24
                        )
                        if state == 23:
                            state = 45 if x["distpsnr1_med"] < 1.65855837 else 46
                            if state == 45:
                                state = (
                                    87
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.97874999)
                                    else 88
                                )
                                if state == 87:
                                    state = (
                                        151 if x["distpsnr1_med"] < 0.759191334 else 152
                                    )
                                    if state == 151:
                                        return 0.0551329628
                                    if state == 152:
                                        return -0.686561465
                                if state == 88:
                                    state = (
                                        153 if x["distpsnr1_med"] < 0.759778738 else 154
                                    )
                                    if state == 153:
                                        return 0.163234144
                                    if state == 154:
                                        return -1.55965102
                            if state == 46:
                                state = (
                                    89
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.982499957)
                                    else 90
                                )
                                if state == 89:
                                    return -0.372169793
                                if state == 90:
                                    return 0.226690486
                        if state == 24:
                            return 0.0158915725
                if state == 6:
                    state = 13 if x["col_peak"] < 0.0447359085 else 14
                    if state == 13:
                        state = 25 if x["col_last"] < 0.241648674 else 26
                        if state == 25:
                            state = (
                                47
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 0.551776171)
                                else 48
                            )
                            if state == 47:
                                return -0.341620237
                            if state == 48:
                                state = (
                                    91
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.980749965)
                                    else 92
                                )
                                if state == 91:
                                    state = (
                                        155 if x["distpsnr1_med"] < 1.40450227 else 156
                                    )
                                    if state == 155:
                                        state = (
                                            249
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 15.9591141)
                                            else 250
                                        )
                                        if state == 249:
                                            return -0.319078207
                                        if state == 250:
                                            state = (
                                                377
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.973749995)
                                                else 378
                                            )
                                            if state == 377:
                                                return -0.344123513
                                            if state == 378:
                                                state = (
                                                    549
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.261333346)
                                                    else 550
                                                )
                                                if state == 549:
                                                    state = (
                                                        735
                                                        if x["maggaia_med"] < 17.4201145
                                                        else 736
                                                    )
                                                    if state == 735:
                                                        return 0.105234504
                                                    if state == 736:
                                                        return -0.319645226
                                                if state == 550:
                                                    return 0.483787984
                                    if state == 156:
                                        state = (
                                            251
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 25.0007973)
                                            else 252
                                        )
                                        if state == 251:
                                            return -0.486056477
                                        if state == 252:
                                            state = (
                                                379
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.971750021)
                                                else 380
                                            )
                                            if state == 379:
                                                state = (
                                                    551
                                                    if x["sgscore1_med"] < 0.00166666496
                                                    else 552
                                                )
                                                if state == 551:
                                                    return 0.461416572
                                                if state == 552:
                                                    return -0.279588699
                                            if state == 380:
                                                state = (
                                                    553
                                                    if x["sgscore1_med"] < 0.00718749966
                                                    else 554
                                                )
                                                if state == 553:
                                                    return 0.1112727
                                                if state == 554:
                                                    return -0.384013087
                                if state == 92:
                                    state = (
                                        157 if x["distpsnr1_med"] < 3.91546059 else 158
                                    )
                                    if state == 157:
                                        state = (
                                            253
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 13.5078182)
                                            else 254
                                        )
                                        if state == 253:
                                            state = (
                                                381
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.983500004)
                                                else 382
                                            )
                                            if state == 381:
                                                return -0.358507931
                                            if state == 382:
                                                return 0.162838221
                                        if state == 254:
                                            return 0.383241177
                                    if state == 158:
                                        state = (
                                            255
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 9.60682869)
                                            else 256
                                        )
                                        if state == 255:
                                            return -0.255358458
                                        if state == 256:
                                            state = (
                                                383
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.98150003)
                                                else 384
                                            )
                                            if state == 383:
                                                state = (
                                                    555
                                                    if x["sgscore1_med"] < 0.0302083492
                                                    else 556
                                                )
                                                if state == 555:
                                                    return -0.552208185
                                                if state == 556:
                                                    state = (
                                                        737
                                                        if x["maggaia_med"] < 19.1352139
                                                        else 738
                                                    )
                                                    if state == 737:
                                                        return 0.121180221
                                                    if state == 738:
                                                        return -0.178810641
                                            if state == 384:
                                                state = (
                                                    557
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.983479023)
                                                    else 558
                                                )
                                                if state == 557:
                                                    state = (
                                                        739
                                                        if x["maggaia_med"] < 17.7719688
                                                        else 740
                                                    )
                                                    if state == 739:
                                                        state = (
                                                            951
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 5.59309816
                                                            )
                                                            else 952
                                                        )
                                                        if state == 951:
                                                            return 0.0585835204
                                                        if state == 952:
                                                            return 0.387998641
                                                    if state == 740:
                                                        return 0.371547788
                                                if state == 558:
                                                    return -0.172593877
                        if state == 26:
                            state = (
                                49
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 0.375177532)
                                else 50
                            )
                            if state == 49:
                                state = (
                                    93
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.982499957)
                                    else 94
                                )
                                if state == 93:
                                    return -0.448507547
                                if state == 94:
                                    state = (
                                        159 if x["distpsnr1_med"] < 0.235147297 else 160
                                    )
                                    if state == 159:
                                        return -0.276199222
                                    if state == 160:
                                        return 0.184928358
                            if state == 50:
                                state = (
                                    95
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.974750042)
                                    else 96
                                )
                                if state == 95:
                                    state = (
                                        161 if x["distpsnr1_med"] < 0.893445969 else 162
                                    )
                                    if state == 161:
                                        state = (
                                            257
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 59.003418)
                                            else 258
                                        )
                                        if state == 257:
                                            return -0.376001179
                                        if state == 258:
                                            return 0.255129367
                                    if state == 162:
                                        state = (
                                            259
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 48.4385376)
                                            else 260
                                        )
                                        if state == 259:
                                            state = (
                                                385
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.973249972)
                                                else 386
                                            )
                                            if state == 385:
                                                state = (
                                                    559
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0191249996
                                                    )
                                                    else 560
                                                )
                                                if state == 559:
                                                    return -0.515342176
                                                if state == 560:
                                                    state = (
                                                        741
                                                        if x["maggaia_med"] < 18.2111435
                                                        else 742
                                                    )
                                                    if state == 741:
                                                        state = (
                                                            955
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.46803379
                                                            )
                                                            else 956
                                                        )
                                                        if state == 955:
                                                            return 0.125819772
                                                        if state == 956:
                                                            return -0.328024209
                                                    if state == 742:
                                                        state = (
                                                            957
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.19538546
                                                            )
                                                            else 958
                                                        )
                                                        if state == 957:
                                                            return -0.293196112
                                                        if state == 958:
                                                            return -0.518286109
                                            if state == 386:
                                                state = (
                                                    561
                                                    if x["sgscore1_med"] < 0.00818749983
                                                    else 562
                                                )
                                                if state == 561:
                                                    state = (
                                                        743
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 16.4094124
                                                        )
                                                        else 744
                                                    )
                                                    if state == 743:
                                                        return -0.285117656
                                                    if state == 744:
                                                        return 0.429888099
                                                if state == 562:
                                                    return -0.460732609
                                        if state == 260:
                                            state = (
                                                387
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.952499986)
                                                else 388
                                            )
                                            if state == 387:
                                                return -0.379034907
                                            if state == 388:
                                                return 0.256833106
                                if state == 96:
                                    state = (
                                        163 if x["distpsnr1_med"] < 0.84098947 else 164
                                    )
                                    if state == 163:
                                        state = (
                                            261
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 35.9309502)
                                            else 262
                                        )
                                        if state == 261:
                                            state = (
                                                389
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982749999)
                                                else 390
                                            )
                                            if state == 389:
                                                state = (
                                                    563
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00393750006
                                                    )
                                                    else 564
                                                )
                                                if state == 563:
                                                    state = (
                                                        745
                                                        if x["maggaia_med"] < 20.1588383
                                                        else 746
                                                    )
                                                    if state == 745:
                                                        return -0.951295197
                                                    if state == 746:
                                                        return -0.00919506792
                                                if state == 564:
                                                    state = (
                                                        747
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 14.2103062
                                                        )
                                                        else 748
                                                    )
                                                    if state == 747:
                                                        return -0.375142246
                                                    if state == 748:
                                                        return 0.323750705
                                            if state == 390:
                                                return 0.391739577
                                        if state == 262:
                                            state = (
                                                391
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.98150003)
                                                else 392
                                            )
                                            if state == 391:
                                                return 0.140696257
                                            if state == 392:
                                                return 0.43909663
                                    if state == 164:
                                        state = (
                                            263
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 26.8785419)
                                            else 264
                                        )
                                        if state == 263:
                                            state = (
                                                393
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981250048)
                                                else 394
                                            )
                                            if state == 393:
                                                state = (
                                                    565
                                                    if x["sgscore1_med"] < 0.718437493
                                                    else 566
                                                )
                                                if state == 565:
                                                    state = (
                                                        749
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"] < 18.204092
                                                        )
                                                        else 750
                                                    )
                                                    if state == 749:
                                                        state = (
                                                            963
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.15793586
                                                            )
                                                            else 964
                                                        )
                                                        if state == 963:
                                                            return 0.143542528
                                                        if state == 964:
                                                            return -0.60982275
                                                    if state == 750:
                                                        state = (
                                                            965
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.29459286
                                                            )
                                                            else 966
                                                        )
                                                        if state == 965:
                                                            return 0.315214992
                                                        if state == 966:
                                                            return -0.272496611
                                                if state == 566:
                                                    state = (
                                                        751
                                                        if x["maggaia_med"] < 19.0660248
                                                        else 752
                                                    )
                                                    if state == 751:
                                                        state = (
                                                            967
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.89691806
                                                            )
                                                            else 968
                                                        )
                                                        if state == 967:
                                                            return -0.115310401
                                                        if state == 968:
                                                            return 0.199339598
                                                    if state == 752:
                                                        return -0.530391872
                                            if state == 394:
                                                state = (
                                                    567
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.983021021)
                                                    else 568
                                                )
                                                if state == 567:
                                                    state = (
                                                        753
                                                        if x["maggaia_med"] < 19.8138218
                                                        else 754
                                                    )
                                                    if state == 753:
                                                        state = (
                                                            969
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.4714607
                                                            )
                                                            else 970
                                                        )
                                                        if state == 969:
                                                            return 0.417896837
                                                        if state == 970:
                                                            return 0.246175677
                                                    if state == 754:
                                                        state = (
                                                            971
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.841229737
                                                            )
                                                            else 972
                                                        )
                                                        if state == 971:
                                                            return 0.0408021435
                                                        if state == 972:
                                                            return 0.404231966
                                                if state == 568:
                                                    return -0.324675441
                                        if state == 264:
                                            state = (
                                                395
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981250048)
                                                else 396
                                            )
                                            if state == 395:
                                                state = (
                                                    569
                                                    if x["sgscore1_med"] < 0.00145833497
                                                    else 570
                                                )
                                                if state == 569:
                                                    return 0.458451509
                                                if state == 570:
                                                    state = (
                                                        755
                                                        if x["maggaia_med"] < 14.873332
                                                        else 756
                                                    )
                                                    if state == 755:
                                                        return -0.62707305
                                                    if state == 756:
                                                        state = (
                                                            973
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.91403913
                                                            )
                                                            else 974
                                                        )
                                                        if state == 973:
                                                            return 0.362009257
                                                        if state == 974:
                                                            return 0.125099257
                                            if state == 396:
                                                state = (
                                                    571
                                                    if x["sgscore1_med"] < 0.00104166649
                                                    else 572
                                                )
                                                if state == 571:
                                                    state = (
                                                        757
                                                        if x["maggaia_med"] < 17.4620934
                                                        else 758
                                                    )
                                                    if state == 757:
                                                        state = (
                                                            975
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.36321509
                                                            )
                                                            else 976
                                                        )
                                                        if state == 975:
                                                            return 0.240126759
                                                        if state == 976:
                                                            return -0.743454993
                                                    if state == 758:
                                                        return 0.358172953
                                                if state == 572:
                                                    state = (
                                                        759
                                                        if x["maggaia_med"] < 14.33218
                                                        else 760
                                                    )
                                                    if state == 759:
                                                        state = (
                                                            977
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.20239544
                                                            )
                                                            else 978
                                                        )
                                                        if state == 977:
                                                            return -0.359752864
                                                        if state == 978:
                                                            return 0.373342037
                                                    if state == 760:
                                                        state = (
                                                            979
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.7323789
                                                            )
                                                            else 980
                                                        )
                                                        if state == 979:
                                                            return 0.0378214419
                                                        if state == 980:
                                                            return 0.441091269
                    if state == 14:
                        state = 27 if x["col_last"] < 0.294130325 else 28
                        if state == 27:
                            state = 51 if x["distpsnr1_med"] < 5.29996014 else 52
                            if state == 51:
                                state = (
                                    97
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.974750042)
                                    else 98
                                )
                                if state == 97:
                                    return -0.430671424
                                if state == 98:
                                    state = (
                                        165 if x["distpsnr1_med"] < 2.27698421 else 166
                                    )
                                    if state == 165:
                                        state = (
                                            265
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 18.9456596)
                                            else 266
                                        )
                                        if state == 265:
                                            state = (
                                                397
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981750011)
                                                else 398
                                            )
                                            if state == 397:
                                                state = (
                                                    573
                                                    if x["sgscore1_med"] < 0.00427083485
                                                    else 574
                                                )
                                                if state == 573:
                                                    return 0.227440298
                                                if state == 574:
                                                    state = (
                                                        761
                                                        if x["maggaia_med"] < 19.0357361
                                                        else 762
                                                    )
                                                    if state == 761:
                                                        return 0.0746240616
                                                    if state == 762:
                                                        return -0.314636737
                                            if state == 398:
                                                return -0.644637644
                                        if state == 266:
                                            state = (
                                                399
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982749999)
                                                else 400
                                            )
                                            if state == 399:
                                                state = (
                                                    575
                                                    if x["sgscore1_med"] < 0.0057857153
                                                    else 576
                                                )
                                                if state == 575:
                                                    state = (
                                                        763
                                                        if x["maggaia_med"] < 14.9945736
                                                        else 764
                                                    )
                                                    if state == 763:
                                                        return -0.270493895
                                                    if state == 764:
                                                        state = (
                                                            983
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.2217803
                                                            )
                                                            else 984
                                                        )
                                                        if state == 983:
                                                            return 0.580542505
                                                        if state == 984:
                                                            return -0.169975981
                                                if state == 576:
                                                    state = (
                                                        765
                                                        if x["maggaia_med"] < 17.9205284
                                                        else 766
                                                    )
                                                    if state == 765:
                                                        return 0.0252088234
                                                    if state == 766:
                                                        state = (
                                                            985
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.1670202
                                                            )
                                                            else 986
                                                        )
                                                        if state == 985:
                                                            return -0.0424310379
                                                        if state == 986:
                                                            return -0.80068481
                                            if state == 400:
                                                state = (
                                                    577
                                                    if x["sgscore1_med"] < 0.768005967
                                                    else 578
                                                )
                                                if state == 577:
                                                    return 0.311420768
                                                if state == 578:
                                                    return -0.165517136
                                    if state == 166:
                                        state = (
                                            267
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 11.5279455)
                                            else 268
                                        )
                                        if state == 267:
                                            return -0.143415585
                                        if state == 268:
                                            state = (
                                                401
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981250048)
                                                else 402
                                            )
                                            if state == 401:
                                                state = (
                                                    579
                                                    if x["sgscore1_med"] < 0.0022499999
                                                    else 580
                                                )
                                                if state == 579:
                                                    return 0.150968507
                                                if state == 580:
                                                    state = (
                                                        767
                                                        if x["maggaia_med"] < 17.7226219
                                                        else 768
                                                    )
                                                    if state == 767:
                                                        return 0.0343338214
                                                    if state == 768:
                                                        return -0.327353299
                                            if state == 402:
                                                return 0.38980186
                            if state == 52:
                                state = (
                                    99
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.980250001)
                                    else 100
                                )
                                if state == 99:
                                    return -0.491253436
                                if state == 100:
                                    state = (
                                        167 if x["distpsnr1_med"] < 6.81295919 else 168
                                    )
                                    if state == 167:
                                        return -0.306559443
                                    if state == 168:
                                        state = (
                                            269
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 19.5133038)
                                            else 270
                                        )
                                        if state == 269:
                                            return 0.207592726
                                        if state == 270:
                                            state = (
                                                403
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981250048)
                                                else 404
                                            )
                                            if state == 403:
                                                return -0.347759247
                                            if state == 404:
                                                return 0.228427723
                        if state == 28:
                            state = (
                                53
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 6.15241909)
                                else 54
                            )
                            if state == 53:
                                state = (
                                    101
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.966000021)
                                    else 102
                                )
                                if state == 101:
                                    state = (
                                        169
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 1.70309496)
                                        else 170
                                    )
                                    if state == 169:
                                        return -0.459538072
                                    if state == 170:
                                        state = (
                                            271
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 51.9394722)
                                            else 272
                                        )
                                        if state == 271:
                                            state = (
                                                405
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.942749977)
                                                else 406
                                            )
                                            if state == 405:
                                                return -0.44220382
                                            if state == 406:
                                                state = (
                                                    581
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0549166501
                                                    )
                                                    else 582
                                                )
                                                if state == 581:
                                                    return -0.453453869
                                                if state == 582:
                                                    state = (
                                                        769
                                                        if x["maggaia_med"] < 41.1780396
                                                        else 770
                                                    )
                                                    if state == 769:
                                                        state = (
                                                            987
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.47193491
                                                            )
                                                            else 988
                                                        )
                                                        if state == 987:
                                                            return 0.335685283
                                                        if state == 988:
                                                            return -0.46703136
                                                    if state == 770:
                                                        return 0.590591073
                                        if state == 272:
                                            state = (
                                                407
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.912)
                                                else 408
                                            )
                                            if state == 407:
                                                return -0.34995681
                                            if state == 408:
                                                state = (
                                                    583
                                                    if x["sgscore1_med"] < 0.00842262059
                                                    else 584
                                                )
                                                if state == 583:
                                                    return -0.463750124
                                                if state == 584:
                                                    state = (
                                                        771
                                                        if x["maggaia_med"] < 18.0192223
                                                        else 772
                                                    )
                                                    if state == 771:
                                                        return -0.154297829
                                                    if state == 772:
                                                        return 0.502285779
                                if state == 102:
                                    state = (
                                        171
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 6.07301712)
                                        else 172
                                    )
                                    if state == 171:
                                        state = (
                                            273
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 44.9696045)
                                            else 274
                                        )
                                        if state == 273:
                                            state = (
                                                409
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.980749965)
                                                else 410
                                            )
                                            if state == 409:
                                                state = (
                                                    585
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00364583498
                                                    )
                                                    else 586
                                                )
                                                if state == 585:
                                                    state = (
                                                        773
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 18.3336143
                                                        )
                                                        else 774
                                                    )
                                                    if state == 773:
                                                        return -0.573411107
                                                    if state == 774:
                                                        state = (
                                                            989
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.770906091
                                                            )
                                                            else 990
                                                        )
                                                        if state == 989:
                                                            return -0.0346595831
                                                        if state == 990:
                                                            return -0.372822762
                                                if state == 586:
                                                    state = (
                                                        775
                                                        if x["maggaia_med"] < 18.2212448
                                                        else 776
                                                    )
                                                    if state == 775:
                                                        state = (
                                                            991
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.47656202
                                                            )
                                                            else 992
                                                        )
                                                        if state == 991:
                                                            return -0.459855884
                                                        if state == 992:
                                                            return -0.0551246703
                                                    if state == 776:
                                                        state = (
                                                            993
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.96334124
                                                            )
                                                            else 994
                                                        )
                                                        if state == 993:
                                                            return 0.290428072
                                                        if state == 994:
                                                            return -0.459964722
                                            if state == 410:
                                                state = (
                                                    587
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.58594346)
                                                    else 588
                                                )
                                                if state == 587:
                                                    state = (
                                                        777
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 17.6501312
                                                        )
                                                        else 778
                                                    )
                                                    if state == 777:
                                                        state = (
                                                            995
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.64853203
                                                            )
                                                            else 996
                                                        )
                                                        if state == 995:
                                                            return 0.408266962
                                                        if state == 996:
                                                            return -0.0873765722
                                                    if state == 778:
                                                        state = (
                                                            997
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.733114004
                                                            )
                                                            else 998
                                                        )
                                                        if state == 997:
                                                            return -0.345885873
                                                        if state == 998:
                                                            return 0.358398557
                                                if state == 588:
                                                    state = (
                                                        779
                                                        if x["maggaia_med"] < 17.8144264
                                                        else 780
                                                    )
                                                    if state == 779:
                                                        return 0.255057335
                                                    if state == 780:
                                                        return -0.880610824
                                        if state == 274:
                                            state = (
                                                411
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.979249954)
                                                else 412
                                            )
                                            if state == 411:
                                                state = (
                                                    589
                                                    if x["sgscore1_med"] < 0.00104166649
                                                    else 590
                                                )
                                                if state == 589:
                                                    return 0.403876007
                                                if state == 590:
                                                    state = (
                                                        781
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 15.9789343
                                                        )
                                                        else 782
                                                    )
                                                    if state == 781:
                                                        state = (
                                                            999
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.08016658
                                                            )
                                                            else 1000
                                                        )
                                                        if state == 999:
                                                            return 0.10423848
                                                        if state == 1000:
                                                            return 0.425811261
                                                    if state == 782:
                                                        state = (
                                                            1001
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 4.80619383
                                                            )
                                                            else 1002
                                                        )
                                                        if state == 1001:
                                                            return 0.0883200616
                                                        if state == 1002:
                                                            return -0.373040468
                                            if state == 412:
                                                state = (
                                                    591
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.683812499)
                                                    else 592
                                                )
                                                if state == 591:
                                                    state = (
                                                        783
                                                        if x["maggaia_med"] < 19.4420853
                                                        else 784
                                                    )
                                                    if state == 783:
                                                        state = (
                                                            1003
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 5.11548996
                                                            )
                                                            else 1004
                                                        )
                                                        if state == 1003:
                                                            return 0.441738039
                                                        if state == 1004:
                                                            return -0.165835649
                                                    if state == 784:
                                                        state = (
                                                            1005
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.25304043
                                                            )
                                                            else 1006
                                                        )
                                                        if state == 1005:
                                                            return 0.0661046207
                                                        if state == 1006:
                                                            return 0.366390675
                                                if state == 592:
                                                    return -0.258132428
                                    if state == 172:
                                        return -0.44424808
                            if state == 54:
                                state = (
                                    103
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.978249967)
                                    else 104
                                )
                                if state == 103:
                                    state = (
                                        173 if x["distpsnr1_med"] < 7.05253696 else 174
                                    )
                                    if state == 173:
                                        state = (
                                            275
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 26.8826962)
                                            else 276
                                        )
                                        if state == 275:
                                            return -0.128095165
                                        if state == 276:
                                            state = (
                                                415
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.977750003)
                                                else 416
                                            )
                                            if state == 415:
                                                return 0.319938987
                                            if state == 416:
                                                return -0.125270769
                                    if state == 174:
                                        state = (
                                            277
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 57.4232178)
                                            else 278
                                        )
                                        if state == 277:
                                            return -0.395020336
                                        if state == 278:
                                            state = (
                                                417
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.958500028)
                                                else 418
                                            )
                                            if state == 417:
                                                return -0.343794703
                                            if state == 418:
                                                state = (
                                                    593
                                                    if x["sgscore1_med"] < 0.319027007
                                                    else 594
                                                )
                                                if state == 593:
                                                    state = (
                                                        785
                                                        if x["maggaia_med"] < 20.0716934
                                                        else 786
                                                    )
                                                    if state == 785:
                                                        return -0.336635172
                                                    if state == 786:
                                                        return 0.332906604
                                                if state == 594:
                                                    return -0.277239829
                                if state == 104:
                                    state = (
                                        175 if x["distpsnr1_med"] < 22.2224808 else 176
                                    )
                                    if state == 175:
                                        state = (
                                            279
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 20.0818691)
                                            else 280
                                        )
                                        if state == 279:
                                            state = (
                                                419
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981250048)
                                                else 420
                                            )
                                            if state == 419:
                                                state = (
                                                    595
                                                    if x["sgscore1_med"] < 0.229802147
                                                    else 596
                                                )
                                                if state == 595:
                                                    return -0.00305340393
                                                if state == 596:
                                                    return -0.450108588
                                            if state == 420:
                                                return 0.469986022
                                        if state == 280:
                                            state = (
                                                421
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.980749965)
                                                else 422
                                            )
                                            if state == 421:
                                                state = (
                                                    597
                                                    if x["sgscore1_med"] < 0.36352101
                                                    else 598
                                                )
                                                if state == 597:
                                                    state = (
                                                        787
                                                        if x["maggaia_med"] < 17.8130608
                                                        else 788
                                                    )
                                                    if state == 787:
                                                        return -0.333939075
                                                    if state == 788:
                                                        return 0.0376694873
                                                if state == 598:
                                                    state = (
                                                        789
                                                        if x["maggaia_med"] < 19.192564
                                                        else 790
                                                    )
                                                    if state == 789:
                                                        return 0.41901055
                                                    if state == 790:
                                                        state = (
                                                            1007
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 6.58564949
                                                            )
                                                            else 1008
                                                        )
                                                        if state == 1007:
                                                            return 0.30502224
                                                        if state == 1008:
                                                            return -0.224230438
                                            if state == 422:
                                                state = (
                                                    599
                                                    if x["sgscore1_med"] < 0.0563124977
                                                    else 600
                                                )
                                                if state == 599:
                                                    state = (
                                                        791
                                                        if x["maggaia_med"] < 19.6103153
                                                        else 792
                                                    )
                                                    if state == 791:
                                                        return 0.33968392
                                                    if state == 792:
                                                        return -0.881453276
                                                if state == 600:
                                                    return 0.445343643
                                    if state == 176:
                                        return -0.324006408
    elif num_booster == 5:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_last"]) or (x["col_last"] < 0.583189011) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.245685577)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.591760397)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["col_det"] < 0.149558067 else 16
                        if state == 15:
                            state = 29 if x["mag_peak"] < 18.9473343 else 30
                            if state == 29:
                                state = 57 if x["mag_peak"] < 18.1468697 else 58
                                if state == 57:
                                    state = (
                                        107
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.177785188)
                                        else 108
                                    )
                                    if state == 107:
                                        return 0.424844444
                                    if state == 108:
                                        state = (
                                            173
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.0090008)
                                            else 174
                                        )
                                        if state == 173:
                                            return 0.0816180035
                                        if state == 174:
                                            return -0.46798712
                                if state == 58:
                                    state = (
                                        109
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.275748789)
                                        else 110
                                    )
                                    if state == 109:
                                        state = (
                                            175
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.8875008)
                                            else 176
                                        )
                                        if state == 175:
                                            return -0.308891684
                                        if state == 176:
                                            state = (
                                                271
                                                if x["col_peak"] < -0.250221252
                                                else 272
                                            )
                                            if state == 271:
                                                return -0.255256563
                                            if state == 272:
                                                return 0.287578225
                                    if state == 110:
                                        return 0.414912105
                            if state == 30:
                                state = 59 if x["mag_peak"] < 40.9596024 else 60
                                if state == 59:
                                    return -0.404683232
                                if state == 60:
                                    state = (
                                        111
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.347594112)
                                        else 112
                                    )
                                    if state == 111:
                                        state = (
                                            177
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 16.7625008)
                                            else 178
                                        )
                                        if state == 177:
                                            return 0.0317918845
                                        if state == 178:
                                            return -0.385870576
                                    if state == 112:
                                        state = (
                                            179
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.1549988)
                                            else 180
                                        )
                                        if state == 179:
                                            return -0.255756557
                                        if state == 180:
                                            return 0.0763967559
                        if state == 16:
                            state = 31 if x["mag_peak"] < 18.9848042 else 32
                            if state == 31:
                                state = 61 if x["mag_peak"] < 18.9498997 else 62
                                if state == 61:
                                    state = (
                                        113
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.184573144)
                                        else 114
                                    )
                                    if state == 113:
                                        state = (
                                            181
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.6720009)
                                            else 182
                                        )
                                        if state == 181:
                                            return -0.406936884
                                        if state == 182:
                                            state = (
                                                273 if x["col_peak"] < 0.000001 else 274
                                            )
                                            if state == 273:
                                                return -0.405180633
                                            if state == 274:
                                                state = (
                                                    355
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.52153921)
                                                    else 356
                                                )
                                                if state == 355:
                                                    state = (
                                                        461
                                                        if x["col_det"] < 1.34649754
                                                        else 462
                                                    )
                                                    if state == 461:
                                                        return -0.303049803
                                                    if state == 462:
                                                        state = (
                                                            541
                                                            if x["neargaia_med"]
                                                            < 56.6075668
                                                            else 542
                                                        )
                                                        if state == 541:
                                                            return 0.227205381
                                                        if state == 542:
                                                            return -0.427087367
                                                if state == 356:
                                                    return 0.47276473
                                    if state == 114:
                                        state = (
                                            183
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.5415001)
                                            else 184
                                        )
                                        if state == 183:
                                            state = (
                                                275
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.342952728)
                                                else 276
                                            )
                                            if state == 275:
                                                return -0.453724861
                                            if state == 276:
                                                state = (
                                                    357
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.55052662)
                                                    else 358
                                                )
                                                if state == 357:
                                                    return -0.119981021
                                                if state == 358:
                                                    return 0.244034931
                                        if state == 184:
                                            state = (
                                                277
                                                if x["col_peak"] < -0.298992157
                                                else 278
                                            )
                                            if state == 277:
                                                return -0.422879279
                                            if state == 278:
                                                state = (
                                                    359
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.90921879)
                                                    else 360
                                                )
                                                if state == 359:
                                                    state = (
                                                        463
                                                        if x["col_det"] < 1.63819981
                                                        else 464
                                                    )
                                                    if state == 463:
                                                        return -0.281321228
                                                    if state == 464:
                                                        state = (
                                                            543
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 18.6418877
                                                            )
                                                            else 544
                                                        )
                                                        if state == 543:
                                                            return -0.192946926
                                                        if state == 544:
                                                            return 0.378622472
                                                if state == 360:
                                                    return 0.405136436
                                if state == 62:
                                    state = (
                                        115
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.352877945)
                                        else 116
                                    )
                                    if state == 115:
                                        state = (
                                            185
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.8409996)
                                            else 186
                                        )
                                        if state == 185:
                                            return -0.296402365
                                        if state == 186:
                                            return 0.446895897
                                    if state == 116:
                                        return -0.19098483
                            if state == 32:
                                state = 63 if x["mag_peak"] < 41.4126053 else 64
                                if state == 63:
                                    return -0.408980399
                                if state == 64:
                                    state = (
                                        117
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.0923306942)
                                        else 118
                                    )
                                    if state == 117:
                                        return 0.177500799
                                    if state == 118:
                                        state = (
                                            187
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.0999985)
                                            else 188
                                        )
                                        if state == 187:
                                            return -0.341329664
                                        if state == 188:
                                            return 0.21397613
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.386882305)
                            else 18
                        )
                        if state == 17:
                            state = 33 if x["mag_peak"] < 18.887352 else 34
                            if state == 33:
                                state = 65 if x["mag_peak"] < 16.6276131 else 66
                                if state == 65:
                                    state = (
                                        119
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 6.61023045)
                                        else 120
                                    )
                                    if state == 119:
                                        state = (
                                            189
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.8852501)
                                            else 190
                                        )
                                        if state == 189:
                                            return 0.297388792
                                        if state == 190:
                                            state = (
                                                279 if x["col_peak"] < 0.000001 else 280
                                            )
                                            if state == 279:
                                                return -0.472543955
                                            if state == 280:
                                                state = (
                                                    361
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.98583913)
                                                    else 362
                                                )
                                                if state == 361:
                                                    return 0.368653446
                                                if state == 362:
                                                    state = (
                                                        465
                                                        if x["col_det"] < 0.000001
                                                        else 466
                                                    )
                                                    if state == 465:
                                                        return 0.175925091
                                                    if state == 466:
                                                        state = (
                                                            545
                                                            if x["neargaia_med"]
                                                            < 8.96462917
                                                            else 546
                                                        )
                                                        if state == 545:
                                                            return -0.940473795
                                                        if state == 546:
                                                            return 0.35624513
                                    if state == 120:
                                        state = (
                                            191
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 21.3494987)
                                            else 192
                                        )
                                        if state == 191:
                                            state = (
                                                281 if x["col_peak"] < 0.000001 else 282
                                            )
                                            if state == 281:
                                                return -0.321119219
                                            if state == 282:
                                                return 0.3237786
                                        if state == 192:
                                            return -0.662187457
                                if state == 66:
                                    state = (
                                        121
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 2.48346806)
                                        else 122
                                    )
                                    if state == 121:
                                        state = (
                                            193
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 16.6835003)
                                            else 194
                                        )
                                        if state == 193:
                                            return -0.26874873
                                        if state == 194:
                                            state = (
                                                283
                                                if x["col_peak"] < -0.49502182
                                                else 284
                                            )
                                            if state == 283:
                                                return -0.345872134
                                            if state == 284:
                                                state = (
                                                    363
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.84980321)
                                                    else 364
                                                )
                                                if state == 363:
                                                    state = (
                                                        467
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.141640663)
                                                        else 468
                                                    )
                                                    if state == 467:
                                                        state = (
                                                            547
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 44.271347
                                                            )
                                                            else 548
                                                        )
                                                        if state == 547:
                                                            return 0.163630754
                                                        if state == 548:
                                                            return -0.513034105
                                                    if state == 468:
                                                        return 0.356531471
                                                if state == 364:
                                                    state = (
                                                        469
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.238613129)
                                                        else 470
                                                    )
                                                    if state == 469:
                                                        state = (
                                                            549
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 68.1296539
                                                            )
                                                            else 550
                                                        )
                                                        if state == 549:
                                                            return 0.408090889
                                                        if state == 550:
                                                            return 0.0849522054
                                                    if state == 470:
                                                        state = (
                                                            551
                                                            if x["neargaia_med"]
                                                            < 2.09984398
                                                            else 552
                                                        )
                                                        if state == 551:
                                                            return -0.240085036
                                                        if state == 552:
                                                            return 0.35382989
                                    if state == 122:
                                        state = (
                                            195
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.0817509)
                                            else 196
                                        )
                                        if state == 195:
                                            state = (
                                                285
                                                if x["col_peak"] < -0.343341827
                                                else 286
                                            )
                                            if state == 285:
                                                return -0.401584566
                                            if state == 286:
                                                state = (
                                                    365
                                                    if np.isnan(x["t_predetect"])
                                                    or (
                                                        x["t_predetect"] < 0.00702544954
                                                    )
                                                    else 366
                                                )
                                                if state == 365:
                                                    return -0.640055597
                                                if state == 366:
                                                    state = (
                                                        471
                                                        if x["col_det"] < -0.423399925
                                                        else 472
                                                    )
                                                    if state == 471:
                                                        state = (
                                                            553
                                                            if x["neargaia_med"]
                                                            < 16.9146461
                                                            else 554
                                                        )
                                                        if state == 553:
                                                            return 0.18474184
                                                        if state == 554:
                                                            return -0.596532524
                                                    if state == 472:
                                                        state = (
                                                            555
                                                            if x["neargaia_med"]
                                                            < 3.38891697
                                                            else 556
                                                        )
                                                        if state == 555:
                                                            return -0.223241553
                                                        if state == 556:
                                                            return 0.326877564
                                        if state == 196:
                                            state = (
                                                287
                                                if x["col_peak"] < -0.269519806
                                                else 288
                                            )
                                            if state == 287:
                                                state = (
                                                    367
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.97105885)
                                                    else 368
                                                )
                                                if state == 367:
                                                    state = (
                                                        473
                                                        if x["col_det"] < -0.377272606
                                                        else 474
                                                    )
                                                    if state == 473:
                                                        state = (
                                                            557
                                                            if x["neargaia_med"]
                                                            < 15.153409
                                                            else 558
                                                        )
                                                        if state == 557:
                                                            return 0.187466159
                                                        if state == 558:
                                                            return -0.167650744
                                                    if state == 474:
                                                        return -0.480482757
                                                if state == 368:
                                                    return 0.0350432657
                                            if state == 288:
                                                state = (
                                                    369
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.90497112)
                                                    else 370
                                                )
                                                if state == 369:
                                                    state = (
                                                        475
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.106273651)
                                                        else 476
                                                    )
                                                    if state == 475:
                                                        state = (
                                                            559
                                                            if x["neargaia_med"]
                                                            < 37.4714966
                                                            else 560
                                                        )
                                                        if state == 559:
                                                            return -0.532772303
                                                        if state == 560:
                                                            return 0.262530565
                                                    if state == 476:
                                                        return 0.356288403
                                                if state == 370:
                                                    return 0.398965478
                            if state == 34:
                                state = (
                                    67
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 18.8999405)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        123
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.972635031)
                                        else 124
                                    )
                                    if state == 123:
                                        state = (
                                            197
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.3479996)
                                            else 198
                                        )
                                        if state == 197:
                                            return -0.184151769
                                        if state == 198:
                                            return 0.193749204
                                    if state == 124:
                                        state = (
                                            199
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.4872513)
                                            else 200
                                        )
                                        if state == 199:
                                            return -0.112697452
                                        if state == 200:
                                            return 0.00395638961
                                if state == 68:
                                    state = (
                                        125
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.48270917)
                                        else 126
                                    )
                                    if state == 125:
                                        state = (
                                            201
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.276001)
                                            else 202
                                        )
                                        if state == 201:
                                            return 0.227524921
                                        if state == 202:
                                            state = (
                                                289
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.319517136)
                                                else 290
                                            )
                                            if state == 289:
                                                state = (
                                                    371
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.98442078)
                                                    else 372
                                                )
                                                if state == 371:
                                                    return -0.381466687
                                                if state == 372:
                                                    state = (
                                                        477
                                                        if x["col_det"] < 0.000001
                                                        else 478
                                                    )
                                                    if state == 477:
                                                        return 0.263758212
                                                    if state == 478:
                                                        return -0.226733014
                                            if state == 290:
                                                return -0.557650089
                                    if state == 126:
                                        return -0.430443913
                        if state == 18:
                            state = 35 if x["mag_peak"] < 19.0836296 else 36
                            if state == 35:
                                return 0.405365735
                            if state == 36:
                                state = 69 if x["mag_peak"] < 40.4637985 else 70
                                if state == 69:
                                    return -0.344328225
                                if state == 70:
                                    state = (
                                        127
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 2.13525963)
                                        else 128
                                    )
                                    if state == 127:
                                        state = (
                                            203
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.5735016)
                                            else 204
                                        )
                                        if state == 203:
                                            return 0.28297618
                                        if state == 204:
                                            return -0.219589189
                                    if state == 128:
                                        state = (
                                            205
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.5994987)
                                            else 206
                                        )
                                        if state == 205:
                                            return -0.0551541895
                                        if state == 206:
                                            return -0.267334759
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.452060699)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["col_det"]) or (x["col_det"] < -0.0211000443)
                            else 20
                        )
                        if state == 19:
                            state = 37 if x["mag_peak"] < 18.9288731 else 38
                            if state == 37:
                                state = 71 if x["mag_peak"] < 18.8802719 else 72
                                if state == 71:
                                    state = (
                                        129
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.171174973)
                                        else 130
                                    )
                                    if state == 129:
                                        state = (
                                            207
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.6555004)
                                            else 208
                                        )
                                        if state == 207:
                                            state = (
                                                291
                                                if x["col_peak"] < -0.0564203262
                                                else 292
                                            )
                                            if state == 291:
                                                return 0.306252271
                                            if state == 292:
                                                return -0.427646965
                                        if state == 208:
                                            return 0.382098794
                                    if state == 130:
                                        state = (
                                            209
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.2360001)
                                            else 210
                                        )
                                        if state == 209:
                                            state = (
                                                293
                                                if x["col_peak"] < 0.0694684982
                                                else 294
                                            )
                                            if state == 293:
                                                state = (
                                                    373
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 7.42644119)
                                                    else 374
                                                )
                                                if state == 373:
                                                    state = (
                                                        479
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.345475197)
                                                        else 480
                                                    )
                                                    if state == 479:
                                                        state = (
                                                            561
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 0.344872117
                                                            )
                                                            else 562
                                                        )
                                                        if state == 561:
                                                            return -0.386583418
                                                        if state == 562:
                                                            return 0.270318687
                                                    if state == 480:
                                                        return 0.28036046
                                                if state == 374:
                                                    return -0.594951451
                                            if state == 294:
                                                state = (
                                                    375
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.55468178)
                                                    else 376
                                                )
                                                if state == 375:
                                                    return -0.471876979
                                                if state == 376:
                                                    return -0.055309929
                                        if state == 210:
                                            state = (
                                                295
                                                if x["col_peak"] < 0.178785801
                                                else 296
                                            )
                                            if state == 295:
                                                state = (
                                                    377
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.45104218)
                                                    else 378
                                                )
                                                if state == 377:
                                                    state = (
                                                        481
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.113430023)
                                                        else 482
                                                    )
                                                    if state == 481:
                                                        state = (
                                                            563
                                                            if x["neargaia_med"]
                                                            < 3.41863275
                                                            else 564
                                                        )
                                                        if state == 563:
                                                            return -0.0511488058
                                                        if state == 564:
                                                            return 0.431791186
                                                    if state == 482:
                                                        return -0.171267614
                                                if state == 378:
                                                    state = (
                                                        483
                                                        if x["col_det"] < 0.000001
                                                        else 484
                                                    )
                                                    if state == 483:
                                                        return -0.404234886
                                                    if state == 484:
                                                        return 0.262907326
                                            if state == 296:
                                                state = (
                                                    379
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0337095)
                                                    else 380
                                                )
                                                if state == 379:
                                                    return 0.168809131
                                                if state == 380:
                                                    return -0.566460669
                                if state == 72:
                                    return 0.493861437
                            if state == 38:
                                state = 73 if x["mag_peak"] < 18.9808598 else 74
                                if state == 73:
                                    state = (
                                        131
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.291098624)
                                        else 132
                                    )
                                    if state == 131:
                                        return -0.44225052
                                    if state == 132:
                                        state = (
                                            211
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.9425011)
                                            else 212
                                        )
                                        if state == 211:
                                            state = (
                                                297
                                                if x["col_peak"] < -0.0715007782
                                                else 298
                                            )
                                            if state == 297:
                                                return -0.131245941
                                            if state == 298:
                                                state = (
                                                    381
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.94811916)
                                                    else 382
                                                )
                                                if state == 381:
                                                    return -0.10659977
                                                if state == 382:
                                                    return 0.392841101
                                        if state == 212:
                                            return -0.362254024
                                if state == 74:
                                    return -0.420909882
                        if state == 20:
                            state = 39 if x["mag_peak"] < 18.8743 else 40
                            if state == 39:
                                state = 75 if x["mag_peak"] < 18.8411369 else 76
                                if state == 75:
                                    state = (
                                        133
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.242393345)
                                        else 134
                                    )
                                    if state == 133:
                                        state = (
                                            213
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.5284996)
                                            else 214
                                        )
                                        if state == 213:
                                            return -0.481807679
                                        if state == 214:
                                            state = (
                                                299
                                                if x["col_peak"] < 0.24597168
                                                else 300
                                            )
                                            if state == 299:
                                                state = (
                                                    383
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.96247673)
                                                    else 384
                                                )
                                                if state == 383:
                                                    state = (
                                                        485
                                                        if x["col_det"] < 0.104564667
                                                        else 486
                                                    )
                                                    if state == 485:
                                                        return 0.337353855
                                                    if state == 486:
                                                        return -0.470895529
                                                if state == 384:
                                                    return -0.457522213
                                            if state == 300:
                                                state = (
                                                    385
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.46027184)
                                                    else 386
                                                )
                                                if state == 385:
                                                    state = (
                                                        487
                                                        if x["col_det"] < 0.115802765
                                                        else 488
                                                    )
                                                    if state == 487:
                                                        return -0.11777778
                                                    if state == 488:
                                                        return 0.130749196
                                                if state == 386:
                                                    return 0.316245824
                                    if state == 134:
                                        state = (
                                            215
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 16.6820011)
                                            else 216
                                        )
                                        if state == 215:
                                            return -0.371639073
                                        if state == 216:
                                            state = (
                                                301
                                                if x["col_peak"] < -0.0909452438
                                                else 302
                                            )
                                            if state == 301:
                                                state = (
                                                    387
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 1.46211231)
                                                    else 388
                                                )
                                                if state == 387:
                                                    return 0.283325195
                                                if state == 388:
                                                    return -0.302939534
                                            if state == 302:
                                                state = (
                                                    389
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.46643543)
                                                    else 390
                                                )
                                                if state == 389:
                                                    return 0.416368932
                                                if state == 390:
                                                    state = (
                                                        491
                                                        if x["col_det"] < -0.0109977722
                                                        else 492
                                                    )
                                                    if state == 491:
                                                        return 0.355309755
                                                    if state == 492:
                                                        state = (
                                                            565
                                                            if x["neargaia_med"]
                                                            < 11.7292976
                                                            else 566
                                                        )
                                                        if state == 565:
                                                            return -0.0138485385
                                                        if state == 566:
                                                            return -0.316599548
                                if state == 76:
                                    return 0.566304803
                            if state == 40:
                                return -0.413486928
                    if state == 10:
                        state = 21 if x["col_det"] < -0.0364789963 else 22
                        if state == 21:
                            state = 41 if x["mag_peak"] < 19.0330086 else 42
                            if state == 41:
                                state = 77 if x["mag_peak"] < 19.0299492 else 78
                                if state == 77:
                                    state = (
                                        135
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.778550684)
                                        else 136
                                    )
                                    if state == 135:
                                        state = (
                                            217
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.6000004)
                                            else 218
                                        )
                                        if state == 217:
                                            state = (
                                                303
                                                if x["col_peak"] < 0.0295553207
                                                else 304
                                            )
                                            if state == 303:
                                                state = (
                                                    391
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.48751163)
                                                    else 392
                                                )
                                                if state == 391:
                                                    return 0.138265505
                                                if state == 392:
                                                    return -0.535057306
                                            if state == 304:
                                                return -0.703051805
                                        if state == 218:
                                            state = (
                                                305
                                                if x["col_peak"] < -0.166050911
                                                else 306
                                            )
                                            if state == 305:
                                                state = (
                                                    393
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.91531229)
                                                    else 394
                                                )
                                                if state == 393:
                                                    return 0.233860135
                                                if state == 394:
                                                    return -0.655710101
                                            if state == 306:
                                                state = (
                                                    395
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.42477989)
                                                    else 396
                                                )
                                                if state == 395:
                                                    return 0.390449464
                                                if state == 396:
                                                    state = (
                                                        493
                                                        if x["col_det"] < -0.155539036
                                                        else 494
                                                    )
                                                    if state == 493:
                                                        return -0.497220635
                                                    if state == 494:
                                                        state = (
                                                            567
                                                            if x["neargaia_med"]
                                                            < 22.1613922
                                                            else 568
                                                        )
                                                        if state == 567:
                                                            return -0.314886183
                                                        if state == 568:
                                                            return 0.328602105
                                    if state == 136:
                                        state = (
                                            219
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.3404999)
                                            else 220
                                        )
                                        if state == 219:
                                            state = (
                                                307
                                                if x["col_peak"] < -0.111741066
                                                else 308
                                            )
                                            if state == 307:
                                                state = (
                                                    397
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.91129017)
                                                    else 398
                                                )
                                                if state == 397:
                                                    state = (
                                                        495
                                                        if x["col_det"] < -0.331644535
                                                        else 496
                                                    )
                                                    if state == 495:
                                                        state = (
                                                            569
                                                            if x["neargaia_med"]
                                                            < 37.8447418
                                                            else 570
                                                        )
                                                        if state == 569:
                                                            return -0.336584598
                                                        if state == 570:
                                                            return 0.257485032
                                                    if state == 496:
                                                        return 0.422581434
                                                if state == 398:
                                                    state = (
                                                        497
                                                        if x["col_det"] < -0.108523369
                                                        else 498
                                                    )
                                                    if state == 497:
                                                        state = (
                                                            571
                                                            if x["neargaia_med"]
                                                            < 16.9565907
                                                            else 572
                                                        )
                                                        if state == 571:
                                                            return -0.650808394
                                                        if state == 572:
                                                            return 0.361552566
                                                    if state == 498:
                                                        return -0.655367434
                                            if state == 308:
                                                state = (
                                                    399
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.85430551)
                                                    else 400
                                                )
                                                if state == 399:
                                                    state = (
                                                        499
                                                        if x["col_det"] < -0.195244312
                                                        else 500
                                                    )
                                                    if state == 499:
                                                        return 0.377021343
                                                    if state == 500:
                                                        state = (
                                                            573
                                                            if x["neargaia_med"]
                                                            < 26.1657982
                                                            else 574
                                                        )
                                                        if state == 573:
                                                            return -0.442461878
                                                        if state == 574:
                                                            return 0.288495749
                                                if state == 400:
                                                    state = (
                                                        501
                                                        if x["col_det"] < -0.352341652
                                                        else 502
                                                    )
                                                    if state == 501:
                                                        state = (
                                                            575
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 48.3971481
                                                            )
                                                            else 576
                                                        )
                                                        if state == 575:
                                                            return 0.36238274
                                                        if state == 576:
                                                            return -0.396677464
                                                    if state == 502:
                                                        state = (
                                                            577
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 9.06891823
                                                            )
                                                            else 578
                                                        )
                                                        if state == 577:
                                                            return 0.316504419
                                                        if state == 578:
                                                            return 0.435377508
                                        if state == 220:
                                            state = (
                                                309
                                                if x["col_peak"] < -0.141154289
                                                else 310
                                            )
                                            if state == 309:
                                                state = (
                                                    401
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.42112279)
                                                    else 402
                                                )
                                                if state == 401:
                                                    return -0.317957401
                                                if state == 402:
                                                    state = (
                                                        503
                                                        if x["col_det"] < -0.250700951
                                                        else 504
                                                    )
                                                    if state == 503:
                                                        state = (
                                                            579
                                                            if x["neargaia_med"]
                                                            < 13.5820961
                                                            else 580
                                                        )
                                                        if state == 579:
                                                            return -0.309807062
                                                        if state == 580:
                                                            return 0.304579973
                                                    if state == 504:
                                                        state = (
                                                            581
                                                            if x["neargaia_med"]
                                                            < 15.5728378
                                                            else 582
                                                        )
                                                        if state == 581:
                                                            return -0.226378351
                                                        if state == 582:
                                                            return 0.43399325
                                            if state == 310:
                                                state = (
                                                    403
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.93041611)
                                                    else 404
                                                )
                                                if state == 403:
                                                    state = (
                                                        505
                                                        if x["col_det"] < -0.219222069
                                                        else 506
                                                    )
                                                    if state == 505:
                                                        state = (
                                                            583
                                                            if x["neargaia_med"]
                                                            < 40.7922516
                                                            else 584
                                                        )
                                                        if state == 583:
                                                            return 0.317801178
                                                        if state == 584:
                                                            return -0.643040121
                                                    if state == 506:
                                                        state = (
                                                            585
                                                            if x["neargaia_med"]
                                                            < 20.1564369
                                                            else 586
                                                        )
                                                        if state == 585:
                                                            return -0.179996878
                                                        if state == 586:
                                                            return 0.451788187
                                                if state == 404:
                                                    state = (
                                                        507
                                                        if x["col_det"] < -0.154582977
                                                        else 508
                                                    )
                                                    if state == 507:
                                                        state = (
                                                            587
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 42.5340843
                                                            )
                                                            else 588
                                                        )
                                                        if state == 587:
                                                            return 0.437034547
                                                        if state == 588:
                                                            return 0.00798072573
                                                    if state == 508:
                                                        return -0.872183859
                                if state == 78:
                                    return 0.594578862
                            if state == 42:
                                state = 79 if x["mag_peak"] < 19.1152649 else 80
                                if state == 79:
                                    state = (
                                        137
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 4.29556894)
                                        else 138
                                    )
                                    if state == 137:
                                        return -0.394799709
                                    if state == 138:
                                        state = (
                                            221
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.4075012)
                                            else 222
                                        )
                                        if state == 221:
                                            return 0.451920927
                                        if state == 222:
                                            return -0.160056517
                                if state == 80:
                                    return -0.430942744
                        if state == 22:
                            state = 43 if x["mag_peak"] < 18.9869461 else 44
                            if state == 43:
                                state = 81 if x["mag_peak"] < 18.7482491 else 82
                                if state == 81:
                                    state = (
                                        139
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.883580923)
                                        else 140
                                    )
                                    if state == 139:
                                        state = (
                                            223
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 16.607502)
                                            else 224
                                        )
                                        if state == 223:
                                            state = (
                                                311
                                                if x["col_peak"] < 0.0500235558
                                                else 312
                                            )
                                            if state == 311:
                                                return 0.183354259
                                            if state == 312:
                                                state = (
                                                    405
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.92042828)
                                                    else 406
                                                )
                                                if state == 405:
                                                    state = (
                                                        509
                                                        if x["col_det"] < 0.331924438
                                                        else 510
                                                    )
                                                    if state == 509:
                                                        state = (
                                                            589
                                                            if x["neargaia_med"]
                                                            < 0.672370434
                                                            else 590
                                                        )
                                                        if state == 589:
                                                            return -0.0843365565
                                                        if state == 590:
                                                            return -0.315654814
                                                    if state == 510:
                                                        return -0.371680617
                                                if state == 406:
                                                    return 0.210768953
                                        if state == 224:
                                            state = (
                                                313
                                                if x["col_peak"] < -0.19219175
                                                else 314
                                            )
                                            if state == 313:
                                                state = (
                                                    407
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.94465256)
                                                    else 408
                                                )
                                                if state == 407:
                                                    state = (
                                                        511
                                                        if x["col_det"] < 0.185200736
                                                        else 512
                                                    )
                                                    if state == 511:
                                                        return 0.33657226
                                                    if state == 512:
                                                        return -0.794270456
                                                if state == 408:
                                                    return -0.58752507
                                            if state == 314:
                                                state = (
                                                    409
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.94195604)
                                                    else 410
                                                )
                                                if state == 409:
                                                    return 0.409218371
                                                if state == 410:
                                                    state = (
                                                        513
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.221087933)
                                                        else 514
                                                    )
                                                    if state == 513:
                                                        state = (
                                                            591
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 76.9137421
                                                            )
                                                            else 592
                                                        )
                                                        if state == 591:
                                                            return 0.376583189
                                                        if state == 592:
                                                            return -0.35836938
                                                    if state == 514:
                                                        state = (
                                                            593
                                                            if x["neargaia_med"]
                                                            < 8.54140186
                                                            else 594
                                                        )
                                                        if state == 593:
                                                            return -0.528439462
                                                        if state == 594:
                                                            return 0.398251414
                                    if state == 140:
                                        state = (
                                            225
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 15.6859999)
                                            else 226
                                        )
                                        if state == 225:
                                            return -0.428451359
                                        if state == 226:
                                            state = (
                                                315
                                                if x["col_peak"] < 0.14636597
                                                else 316
                                            )
                                            if state == 315:
                                                state = (
                                                    411
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.9689579)
                                                    else 412
                                                )
                                                if state == 411:
                                                    state = (
                                                        515
                                                        if np.isnan(x["col_det"])
                                                        or (
                                                            x["col_det"] < -0.0183234215
                                                        )
                                                        else 516
                                                    )
                                                    if state == 515:
                                                        state = (
                                                            595
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 13.3856125
                                                            )
                                                            else 596
                                                        )
                                                        if state == 595:
                                                            return 0.446406871
                                                        if state == 596:
                                                            return 0.353881449
                                                    if state == 516:
                                                        state = (
                                                            597
                                                            if x["neargaia_med"]
                                                            < 19.3748322
                                                            else 598
                                                        )
                                                        if state == 597:
                                                            return 0.0609107241
                                                        if state == 598:
                                                            return 0.340290397
                                                if state == 412:
                                                    state = (
                                                        517
                                                        if x["col_det"] < 0.000001
                                                        else 518
                                                    )
                                                    if state == 517:
                                                        return -0.581020594
                                                    if state == 518:
                                                        state = (
                                                            599
                                                            if x["neargaia_med"]
                                                            < 25.642065
                                                            else 600
                                                        )
                                                        if state == 599:
                                                            return 0.349473774
                                                        if state == 600:
                                                            return -0.556848645
                                            if state == 316:
                                                state = (
                                                    413
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.91717625)
                                                    else 414
                                                )
                                                if state == 413:
                                                    state = (
                                                        519
                                                        if x["col_det"] < 0.000868797302
                                                        else 520
                                                    )
                                                    if state == 519:
                                                        return -0.572930992
                                                    if state == 520:
                                                        state = (
                                                            601
                                                            if x["neargaia_med"]
                                                            < 12.4003963
                                                            else 602
                                                        )
                                                        if state == 601:
                                                            return 0.0649424866
                                                        if state == 602:
                                                            return 0.327529848
                                                if state == 414:
                                                    return -0.591453135
                                if state == 82:
                                    state = (
                                        141
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 3.44983244)
                                        else 142
                                    )
                                    if state == 141:
                                        state = (
                                            227
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.1619987)
                                            else 228
                                        )
                                        if state == 227:
                                            state = (
                                                317
                                                if x["col_peak"] < 0.609992027
                                                else 318
                                            )
                                            if state == 317:
                                                state = (
                                                    415
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.04020834)
                                                    else 416
                                                )
                                                if state == 415:
                                                    state = (
                                                        521
                                                        if x["col_det"] < 0.196884155
                                                        else 522
                                                    )
                                                    if state == 521:
                                                        return -0.631249547
                                                    if state == 522:
                                                        state = (
                                                            603
                                                            if x["neargaia_med"]
                                                            < 6.79250717
                                                            else 604
                                                        )
                                                        if state == 603:
                                                            return 0.286427766
                                                        if state == 604:
                                                            return -0.17098555
                                                if state == 416:
                                                    return -0.470429569
                                            if state == 318:
                                                state = (
                                                    417
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.92879057)
                                                    else 418
                                                )
                                                if state == 417:
                                                    return 0.399341255
                                                if state == 418:
                                                    return -0.368109137
                                        if state == 228:
                                            state = (
                                                319
                                                if x["col_peak"] < 0.127588272
                                                else 320
                                            )
                                            if state == 319:
                                                state = (
                                                    419
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.47153378)
                                                    else 420
                                                )
                                                if state == 419:
                                                    state = (
                                                        523
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.0823602676)
                                                        else 524
                                                    )
                                                    if state == 523:
                                                        state = (
                                                            605
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 10.4081879
                                                            )
                                                            else 606
                                                        )
                                                        if state == 605:
                                                            return -0.721920431
                                                        if state == 606:
                                                            return 0.301374435
                                                    if state == 524:
                                                        return -0.462985367
                                                if state == 420:
                                                    return 0.557567358
                                            if state == 320:
                                                state = (
                                                    421
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0951620042)
                                                    else 422
                                                )
                                                if state == 421:
                                                    return 0.0935157016
                                                if state == 422:
                                                    state = (
                                                        525
                                                        if x["col_det"] < 0.168578148
                                                        else 526
                                                    )
                                                    if state == 525:
                                                        return -0.175189912
                                                    if state == 526:
                                                        state = (
                                                            609
                                                            if x["neargaia_med"]
                                                            < 13.7892714
                                                            else 610
                                                        )
                                                        if state == 609:
                                                            return 0.473222643
                                                        if state == 610:
                                                            return 0.261092424
                                    if state == 142:
                                        state = (
                                            229
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.5722504)
                                            else 230
                                        )
                                        if state == 229:
                                            state = (
                                                321
                                                if x["col_peak"] < 0.0178375244
                                                else 322
                                            )
                                            if state == 321:
                                                return -0.710879982
                                            if state == 322:
                                                return 0.14586772
                                        if state == 230:
                                            state = (
                                                323
                                                if x["col_peak"] < -0.116690636
                                                else 324
                                            )
                                            if state == 323:
                                                return -0.550453067
                                            if state == 324:
                                                state = (
                                                    423
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.96053815)
                                                    else 424
                                                )
                                                if state == 423:
                                                    return -0.30771938
                                                if state == 424:
                                                    state = (
                                                        527
                                                        if x["col_det"] < 0.000001
                                                        else 528
                                                    )
                                                    if state == 527:
                                                        return -0.497243643
                                                    if state == 528:
                                                        state = (
                                                            611
                                                            if x["neargaia_med"]
                                                            < 27.7031574
                                                            else 612
                                                        )
                                                        if state == 611:
                                                            return 0.409109384
                                                        if state == 612:
                                                            return -0.191283315
                            if state == 44:
                                state = 83 if x["mag_peak"] < 19.0842991 else 84
                                if state == 83:
                                    state = (
                                        143
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.468459934)
                                        else 144
                                    )
                                    if state == 143:
                                        return 0.324139416
                                    if state == 144:
                                        state = (
                                            231
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.668499)
                                            else 232
                                        )
                                        if state == 231:
                                            state = (
                                                325
                                                if x["col_peak"] < 0.989713669
                                                else 326
                                            )
                                            if state == 325:
                                                state = (
                                                    425
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0175000001)
                                                    else 426
                                                )
                                                if state == 425:
                                                    return 0.39493221
                                                if state == 426:
                                                    state = (
                                                        529
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.168578148)
                                                        else 530
                                                    )
                                                    if state == 529:
                                                        return -0.538214207
                                                    if state == 530:
                                                        state = (
                                                            613
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 48.7183418
                                                            )
                                                            else 614
                                                        )
                                                        if state == 613:
                                                            return -0.374277651
                                                        if state == 614:
                                                            return 0.234199718
                                            if state == 326:
                                                state = (
                                                    427
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.97352433)
                                                    else 428
                                                )
                                                if state == 427:
                                                    return 0.337334156
                                                if state == 428:
                                                    return -0.147384092
                                        if state == 232:
                                            state = (
                                                327
                                                if x["col_peak"] < 0.23606205
                                                else 328
                                            )
                                            if state == 327:
                                                return -0.416719019
                                            if state == 328:
                                                return 0.307642817
                                if state == 84:
                                    return -0.426989228
            if state == 2:
                state = (
                    5
                    if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.189495236)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.888769984)
                        else 12
                    )
                    if state == 11:
                        state = 23 if x["col_det"] < 0.0548734665 else 24
                        if state == 23:
                            state = 45 if x["mag_peak"] < 18.434761 else 46
                            if state == 45:
                                state = 85 if x["mag_peak"] < 17.1609993 else 86
                                if state == 85:
                                    state = (
                                        145
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.33692044)
                                        else 146
                                    )
                                    if state == 145:
                                        return 0.172303513
                                    if state == 146:
                                        return -0.181638643
                                if state == 86:
                                    return 0.197576612
                            if state == 46:
                                state = (
                                    87
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 18.5008717)
                                    else 88
                                )
                                if state == 87:
                                    return -0.531053126
                                if state == 88:
                                    state = (
                                        147
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.520864666)
                                        else 148
                                    )
                                    if state == 147:
                                        return -0.329487979
                                    if state == 148:
                                        state = (
                                            233
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.2649994)
                                            else 234
                                        )
                                        if state == 233:
                                            return 0.170826882
                                        if state == 234:
                                            return -0.157143936
                        if state == 24:
                            state = 47 if x["mag_peak"] < 18.9531994 else 48
                            if state == 47:
                                state = 89 if x["mag_peak"] < 18.6721058 else 90
                                if state == 89:
                                    state = (
                                        149
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.156727597)
                                        else 150
                                    )
                                    if state == 149:
                                        return 0.414189845
                                    if state == 150:
                                        state = (
                                            235
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.1054993)
                                            else 236
                                        )
                                        if state == 235:
                                            return -0.364166647
                                        if state == 236:
                                            state = (
                                                329
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.263933182)
                                                else 330
                                            )
                                            if state == 329:
                                                state = (
                                                    429
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.96958327)
                                                    else 430
                                                )
                                                if state == 429:
                                                    return 0.282713711
                                                if state == 430:
                                                    state = (
                                                        531
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.356912613)
                                                        else 532
                                                    )
                                                    if state == 531:
                                                        state = (
                                                            615
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 17.8678341
                                                            )
                                                            else 616
                                                        )
                                                        if state == 615:
                                                            return -0.32062307
                                                        if state == 616:
                                                            return 0.185094699
                                                    if state == 532:
                                                        return 0.19300662
                                            if state == 330:
                                                state = (
                                                    431
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.96021414)
                                                    else 432
                                                )
                                                if state == 431:
                                                    return 0.117672779
                                                if state == 432:
                                                    return -0.369236678
                                if state == 90:
                                    state = (
                                        151
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.358131409)
                                        else 152
                                    )
                                    if state == 151:
                                        return 0.435711116
                                    if state == 152:
                                        state = (
                                            237
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.3914986)
                                            else 238
                                        )
                                        if state == 237:
                                            return -0.184382632
                                        if state == 238:
                                            return 0.122828081
                            if state == 48:
                                state = 91 if x["mag_peak"] < 40.0070038 else 92
                                if state == 91:
                                    return -0.339119703
                                if state == 92:
                                    state = (
                                        153
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.683150291)
                                        else 154
                                    )
                                    if state == 153:
                                        state = (
                                            239
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.4314995)
                                            else 240
                                        )
                                        if state == 239:
                                            return -0.267206192
                                        if state == 240:
                                            return -0.0919094309
                                    if state == 154:
                                        state = (
                                            241
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.8752499)
                                            else 242
                                        )
                                        if state == 241:
                                            return 0.250875771
                                        if state == 242:
                                            return -0.18756409
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["col_det"]) or (x["col_det"] < -0.183589458)
                            else 26
                        )
                        if state == 25:
                            state = (
                                49
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 18.771801)
                                else 50
                            )
                            if state == 49:
                                state = (
                                    93
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 16.6276131)
                                    else 94
                                )
                                if state == 93:
                                    state = (
                                        155
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 2.62993836)
                                        else 156
                                    )
                                    if state == 155:
                                        state = (
                                            243
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 21.0244999)
                                            else 244
                                        )
                                        if state == 243:
                                            return 0.200511485
                                        if state == 244:
                                            return -0.122882709
                                    if state == 156:
                                        state = (
                                            245
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.2952499)
                                            else 246
                                        )
                                        if state == 245:
                                            return -0.360844225
                                        if state == 246:
                                            state = (
                                                331 if x["col_peak"] < 0.000001 else 332
                                            )
                                            if state == 331:
                                                return -0.25783205
                                            if state == 332:
                                                state = (
                                                    433
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.62786484)
                                                    else 434
                                                )
                                                if state == 433:
                                                    return -0.181393012
                                                if state == 434:
                                                    return 0.194796339
                                if state == 94:
                                    state = (
                                        157
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 4.82286167)
                                        else 158
                                    )
                                    if state == 157:
                                        state = (
                                            247
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.35075)
                                            else 248
                                        )
                                        if state == 247:
                                            state = (
                                                333
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.19990778)
                                                else 334
                                            )
                                            if state == 333:
                                                state = (
                                                    435
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 7.50965881)
                                                    else 436
                                                )
                                                if state == 435:
                                                    state = (
                                                        533
                                                        if x["col_det"] < -0.377099514
                                                        else 534
                                                    )
                                                    if state == 533:
                                                        return -0.0196497459
                                                    if state == 534:
                                                        return 0.34728241
                                                if state == 436:
                                                    return 0.0797601193
                                            if state == 334:
                                                return -0.60813868
                                        if state == 248:
                                            return 0.409375578
                                    if state == 158:
                                        state = (
                                            249
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.9235001)
                                            else 250
                                        )
                                        if state == 249:
                                            state = (
                                                335 if x["col_peak"] < 0.000001 else 336
                                            )
                                            if state == 335:
                                                return 0.102910899
                                            if state == 336:
                                                state = (
                                                    437
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.50035334)
                                                    else 438
                                                )
                                                if state == 437:
                                                    return -0.409492612
                                                if state == 438:
                                                    return 0.14805302
                                        if state == 250:
                                            return 0.216060281
                            if state == 50:
                                state = 95 if x["mag_peak"] < 19.0918484 else 96
                                if state == 95:
                                    state = (
                                        159
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 2.34937239)
                                        else 160
                                    )
                                    if state == 159:
                                        state = (
                                            251
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.223999)
                                            else 252
                                        )
                                        if state == 251:
                                            return -0.251359642
                                        if state == 252:
                                            return 0.358413875
                                    if state == 160:
                                        return -0.390306622
                                if state == 96:
                                    return -0.425064325
                        if state == 26:
                            state = (
                                51
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 18.9110298)
                                else 52
                            )
                            if state == 51:
                                state = 97 if x["mag_peak"] < 37.7419205 else 98
                                if state == 97:
                                    return 0.413181454
                                if state == 98:
                                    state = (
                                        161
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.1770947)
                                        else 162
                                    )
                                    if state == 161:
                                        return -0.150718808
                                    if state == 162:
                                        state = (
                                            253
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.3185005)
                                            else 254
                                        )
                                        if state == 253:
                                            return 0.31165278
                                        if state == 254:
                                            return 0.0715275481
                            if state == 52:
                                return -0.357194245
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.175496489)
                        else 14
                    )
                    if state == 13:
                        return -0.32697469
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["col_det"]) or (x["col_det"] < -0.332249165)
                            else 28
                        )
                        if state == 27:
                            state = 53 if x["mag_peak"] < 18.9597244 else 54
                            if state == 53:
                                state = 99 if x["mag_peak"] < 17.6775379 else 100
                                if state == 99:
                                    return 0.38304615
                                if state == 100:
                                    state = (
                                        163
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.375430048)
                                        else 164
                                    )
                                    if state == 163:
                                        state = (
                                            255
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.5649986)
                                            else 256
                                        )
                                        if state == 255:
                                            state = (
                                                337
                                                if x["col_peak"] < 0.45203495
                                                else 338
                                            )
                                            if state == 337:
                                                return 0.114493102
                                            if state == 338:
                                                return -0.308882535
                                        if state == 256:
                                            state = (
                                                339
                                                if x["col_peak"] < 0.126277924
                                                else 340
                                            )
                                            if state == 339:
                                                return 0.196818307
                                            if state == 340:
                                                return -0.173865438
                                    if state == 164:
                                        state = (
                                            257
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.4505005)
                                            else 258
                                        )
                                        if state == 257:
                                            state = (
                                                341
                                                if x["col_peak"] < 0.00798797607
                                                else 342
                                            )
                                            if state == 341:
                                                state = (
                                                    439
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.05012703)
                                                    else 440
                                                )
                                                if state == 439:
                                                    return 0.373050958
                                                if state == 440:
                                                    return -0.150830165
                                            if state == 342:
                                                state = (
                                                    441
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.55035305)
                                                    else 442
                                                )
                                                if state == 441:
                                                    return 0.173531875
                                                if state == 442:
                                                    return -0.322406083
                                        if state == 258:
                                            state = (
                                                343
                                                if x["col_peak"] < -0.0544233322
                                                else 344
                                            )
                                            if state == 343:
                                                state = (
                                                    443
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.92863989)
                                                    else 444
                                                )
                                                if state == 443:
                                                    return 0.354235142
                                                if state == 444:
                                                    return -0.562893391
                                            if state == 344:
                                                state = (
                                                    445
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0444445014)
                                                    else 446
                                                )
                                                if state == 445:
                                                    return 0.158729181
                                                if state == 446:
                                                    state = (
                                                        535
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.494700432)
                                                        else 536
                                                    )
                                                    if state == 535:
                                                        state = (
                                                            617
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 41.5681572
                                                            )
                                                            else 618
                                                        )
                                                        if state == 617:
                                                            return 0.423020989
                                                        if state == 618:
                                                            return 0.0262773
                                                    if state == 536:
                                                        return -0.0941881612
                            if state == 54:
                                state = 101 if x["mag_peak"] < 18.9895935 else 102
                                if state == 101:
                                    state = (
                                        165
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.91083133)
                                        else 166
                                    )
                                    if state == 165:
                                        state = (
                                            259
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.3450012)
                                            else 260
                                        )
                                        if state == 259:
                                            return -0.356136799
                                        if state == 260:
                                            return 0.119986594
                                    if state == 166:
                                        state = (
                                            261
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.8165016)
                                            else 262
                                        )
                                        if state == 261:
                                            return 0.224493444
                                        if state == 262:
                                            return -0.2059163
                                if state == 102:
                                    return -0.392102093
                        if state == 28:
                            state = 55 if x["mag_peak"] < 18.6790466 else 56
                            if state == 55:
                                state = 103 if x["mag_peak"] < 16.2540302 else 104
                                if state == 103:
                                    state = (
                                        167
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.80622661)
                                        else 168
                                    )
                                    if state == 167:
                                        return 0.311670452
                                    if state == 168:
                                        state = (
                                            263
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.4645004)
                                            else 264
                                        )
                                        if state == 263:
                                            return -0.388560236
                                        if state == 264:
                                            return 0.261193544
                                if state == 104:
                                    state = (
                                        169
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.77961504)
                                        else 170
                                    )
                                    if state == 169:
                                        state = (
                                            265
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 16.3295002)
                                            else 266
                                        )
                                        if state == 265:
                                            return 0.0888161957
                                        if state == 266:
                                            state = (
                                                345
                                                if x["col_peak"] < -0.156857967
                                                else 346
                                            )
                                            if state == 345:
                                                state = (
                                                    447
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.94081593)
                                                    else 448
                                                )
                                                if state == 447:
                                                    return 0.137576878
                                                if state == 448:
                                                    return -0.417322338
                                            if state == 346:
                                                return 0.409558773
                                    if state == 170:
                                        state = (
                                            267
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.4249992)
                                            else 268
                                        )
                                        if state == 267:
                                            state = (
                                                347
                                                if x["col_peak"] < 0.244843483
                                                else 348
                                            )
                                            if state == 347:
                                                state = (
                                                    449
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.94021416)
                                                    else 450
                                                )
                                                if state == 449:
                                                    return -0.039923165
                                                if state == 450:
                                                    return 0.310171574
                                            if state == 348:
                                                state = (
                                                    451
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.47134781)
                                                    else 452
                                                )
                                                if state == 451:
                                                    return 0.255835056
                                                if state == 452:
                                                    return -0.712767899
                                        if state == 268:
                                            state = (
                                                349
                                                if x["col_peak"] < -0.129828453
                                                else 350
                                            )
                                            if state == 349:
                                                state = (
                                                    453
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.92791653)
                                                    else 454
                                                )
                                                if state == 453:
                                                    return 0.287887782
                                                if state == 454:
                                                    return -0.244822353
                                            if state == 350:
                                                return 0.407749414
                            if state == 56:
                                state = 105 if x["mag_peak"] < 18.9927006 else 106
                                if state == 105:
                                    state = (
                                        171
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.475333512)
                                        else 172
                                    )
                                    if state == 171:
                                        return 0.500977099
                                    if state == 172:
                                        state = (
                                            269
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.9604988)
                                            else 270
                                        )
                                        if state == 269:
                                            state = (
                                                351
                                                if x["col_peak"] < 0.0651187897
                                                else 352
                                            )
                                            if state == 351:
                                                state = (
                                                    455
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.9437964)
                                                    else 456
                                                )
                                                if state == 455:
                                                    return 0.321722329
                                                if state == 456:
                                                    return -0.0945102349
                                            if state == 352:
                                                state = (
                                                    457
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.49248886)
                                                    else 458
                                                )
                                                if state == 457:
                                                    state = (
                                                        537
                                                        if x["col_det"] < -0.23982811
                                                        else 538
                                                    )
                                                    if state == 537:
                                                        return 0.152395159
                                                    if state == 538:
                                                        state = (
                                                            619
                                                            if x["neargaia_med"]
                                                            < 27.0373898
                                                            else 620
                                                        )
                                                        if state == 619:
                                                            return 0.0466657616
                                                        if state == 620:
                                                            return -0.468854278
                                                if state == 458:
                                                    return 0.187463537
                                        if state == 270:
                                            state = (
                                                353
                                                if x["col_peak"] < 0.100389481
                                                else 354
                                            )
                                            if state == 353:
                                                state = (
                                                    459
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.56355333)
                                                    else 460
                                                )
                                                if state == 459:
                                                    return 0.124065682
                                                if state == 460:
                                                    return -0.259914607
                                            if state == 354:
                                                return -0.409096092
                                if state == 106:
                                    return -0.378820568
    elif num_booster == 6:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.920000076) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.651818275)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.4167042)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["col_peak"] < 0.340565681 else 16
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.2205009)
                                else 28
                            )
                            if state == 27:
                                state = 47 if x["sgscore1_med"] < 0.056660749 else 48
                                if state == 47:
                                    state = (
                                        79
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.737499952)
                                        else 80
                                    )
                                    if state == 79:
                                        return -0.319812119
                                    if state == 80:
                                        state = (
                                            127
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 0.277895957)
                                            else 128
                                        )
                                        if state == 127:
                                            return -0.185761064
                                        if state == 128:
                                            state = (
                                                201
                                                if x["sgscore1_med"] < 0.0338541493
                                                else 202
                                            )
                                            if state == 201:
                                                return -0.203688562
                                            if state == 202:
                                                return 0.356922358
                                if state == 48:
                                    state = (
                                        81
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.784999967)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            129
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 30.5023136)
                                            else 130
                                        )
                                        if state == 129:
                                            return -0.415815502
                                        if state == 130:
                                            state = (
                                                203
                                                if x["sgscore1_med"] < 0.118568547
                                                else 204
                                            )
                                            if state == 203:
                                                return -0.3444812
                                            if state == 204:
                                                return 0.242664978
                                    if state == 82:
                                        state = (
                                            131
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 0.382495463)
                                            else 132
                                        )
                                        if state == 131:
                                            return -0.25250268
                                        if state == 132:
                                            return 0.215193793
                            if state == 28:
                                state = (
                                    49
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.701501727)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        83
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.593809605)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            133
                                            if x["neargaia_med"] < 26.4898376
                                            else 134
                                        )
                                        if state == 133:
                                            state = (
                                                205
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0365069509)
                                                else 206
                                            )
                                            if state == 205:
                                                return -0.39839536
                                            if state == 206:
                                                state = (
                                                    303
                                                    if x["col_peak"] < -0.0136537552
                                                    else 304
                                                )
                                                if state == 303:
                                                    return -0.288555413
                                                if state == 304:
                                                    return 0.163376033
                                        if state == 134:
                                            state = (
                                                207
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.501991034)
                                                else 208
                                            )
                                            if state == 207:
                                                state = (
                                                    305
                                                    if x["col_peak"] < 0.128087997
                                                    else 306
                                                )
                                                if state == 305:
                                                    state = (
                                                        395
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 56.8786392)
                                                        else 396
                                                    )
                                                    if state == 395:
                                                        state = (
                                                            505
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.339589506
                                                            )
                                                            else 506
                                                        )
                                                        if state == 505:
                                                            return 0.126393929
                                                        if state == 506:
                                                            return -0.483789653
                                                    if state == 396:
                                                        return -0.283489913
                                                if state == 306:
                                                    state = (
                                                        397
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 13.9734383)
                                                        else 398
                                                    )
                                                    if state == 397:
                                                        return -0.033762183
                                                    if state == 398:
                                                        return -0.459471554
                                            if state == 208:
                                                return 0.286080718
                                    if state == 84:
                                        state = (
                                            135
                                            if x["neargaia_med"] < 0.401813775
                                            else 136
                                        )
                                        if state == 135:
                                            state = (
                                                209
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0243749991)
                                                else 210
                                            )
                                            if state == 209:
                                                state = (
                                                    307
                                                    if x["col_peak"] < 0.324730873
                                                    else 308
                                                )
                                                if state == 307:
                                                    state = (
                                                        399
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 48.9672241)
                                                        else 400
                                                    )
                                                    if state == 399:
                                                        state = (
                                                            507
                                                            if x["sgscore1_med"]
                                                            < 0.0112500004
                                                            else 508
                                                        )
                                                        if state == 507:
                                                            return -0.365701318
                                                        if state == 508:
                                                            return 0.173080146
                                                    if state == 400:
                                                        return -0.333634257
                                                if state == 308:
                                                    return 0.347537875
                                            if state == 210:
                                                return -0.396986276
                                        if state == 136:
                                            state = (
                                                211
                                                if x["sgscore1_med"] < 0.00104166649
                                                else 212
                                            )
                                            if state == 211:
                                                return -0.425793201
                                            if state == 212:
                                                state = (
                                                    309
                                                    if x["col_peak"] < -0.340350628
                                                    else 310
                                                )
                                                if state == 309:
                                                    return -0.372195154
                                                if state == 310:
                                                    state = (
                                                        401
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 15.0976219)
                                                        else 402
                                                    )
                                                    if state == 401:
                                                        state = (
                                                            509
                                                            if x["sgscore1_med"]
                                                            < 0.0017708349
                                                            else 510
                                                        )
                                                        if state == 509:
                                                            return 0.00318236905
                                                        if state == 510:
                                                            return -0.340840518
                                                    if state == 402:
                                                        state = (
                                                            511
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.488282502
                                                            )
                                                            else 512
                                                        )
                                                        if state == 511:
                                                            return 0.131304964
                                                        if state == 512:
                                                            return 0.330440313
                                if state == 50:
                                    return -0.419535667
                        if state == 16:
                            state = (
                                29
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.3419991)
                                else 30
                            )
                            if state == 29:
                                state = 51 if x["sgscore1_med"] < 0.0596875027 else 52
                                if state == 51:
                                    state = (
                                        85
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.760833323)
                                        else 86
                                    )
                                    if state == 85:
                                        state = (
                                            137
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 41.0152893)
                                            else 138
                                        )
                                        if state == 137:
                                            state = (
                                                213
                                                if x["sgscore1_med"] < 0.0510357507
                                                else 214
                                            )
                                            if state == 213:
                                                return -0.394874513
                                            if state == 214:
                                                return 0.127165452
                                        if state == 138:
                                            return 0.368401349
                                    if state == 86:
                                        return -0.402180195
                                if state == 52:
                                    state = (
                                        87
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.77309525)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            139
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 32.4561424)
                                            else 140
                                        )
                                        if state == 139:
                                            return -0.422924578
                                        if state == 140:
                                            state = (
                                                215
                                                if x["sgscore1_med"] < 0.319478989
                                                else 216
                                            )
                                            if state == 215:
                                                return -0.0532078929
                                            if state == 216:
                                                return 0.183861569
                                    if state == 88:
                                        state = (
                                            141
                                            if x["neargaia_med"] < 0.144416094
                                            else 142
                                        )
                                        if state == 141:
                                            state = (
                                                217
                                                if x["sgscore1_med"] < 0.174607009
                                                else 218
                                            )
                                            if state == 217:
                                                return -0.394338489
                                            if state == 218:
                                                return 0.192987949
                                        if state == 142:
                                            state = (
                                                219
                                                if x["sgscore1_med"] < 0.100979
                                                else 220
                                            )
                                            if state == 219:
                                                return -0.0620599352
                                            if state == 220:
                                                return -0.42889291
                            if state == 30:
                                state = (
                                    53
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.0673021004)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        89
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.534642756)
                                        else 90
                                    )
                                    if state == 89:
                                        state = (
                                            143
                                            if x["neargaia_med"] < 155.477097
                                            else 144
                                        )
                                        if state == 143:
                                            return -0.375570983
                                        if state == 144:
                                            state = (
                                                221
                                                if x["sgscore1_med"] < 0.117227197
                                                else 222
                                            )
                                            if state == 221:
                                                return -0.361891598
                                            if state == 222:
                                                return -0.110053763
                                    if state == 90:
                                        state = (
                                            145
                                            if x["neargaia_med"] < 11.5001583
                                            else 146
                                        )
                                        if state == 145:
                                            state = (
                                                223
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00997915026)
                                                else 224
                                            )
                                            if state == 223:
                                                state = (
                                                    311
                                                    if x["col_peak"] < 2.80000019
                                                    else 312
                                                )
                                                if state == 311:
                                                    return -0.418745548
                                                if state == 312:
                                                    state = (
                                                        403
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 31.0157928)
                                                        else 404
                                                    )
                                                    if state == 403:
                                                        state = (
                                                            513
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.00458333502
                                                            )
                                                            else 514
                                                        )
                                                        if state == 513:
                                                            return -0.0986298621
                                                        if state == 514:
                                                            return 0.247730464
                                                    if state == 404:
                                                        state = (
                                                            515
                                                            if x["sgscore1_med"]
                                                            < 0.00137499999
                                                            else 516
                                                        )
                                                        if state == 515:
                                                            return -0.233999491
                                                        if state == 516:
                                                            return -0.387664914
                                            if state == 224:
                                                return -0.307334721
                                        if state == 146:
                                            state = (
                                                225
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00112499995)
                                                else 226
                                            )
                                            if state == 225:
                                                state = (
                                                    313
                                                    if x["col_peak"] < 1.49860096
                                                    else 314
                                                )
                                                if state == 313:
                                                    return -0.306055903
                                                if state == 314:
                                                    state = (
                                                        405
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 11.4934435)
                                                        else 406
                                                    )
                                                    if state == 405:
                                                        return 0.0356297269
                                                    if state == 406:
                                                        state = (
                                                            517
                                                            if x["sgscore1_med"]
                                                            < 0.0020010001
                                                            else 518
                                                        )
                                                        if state == 517:
                                                            return -0.38144964
                                                        if state == 518:
                                                            return -0.138579398
                                            if state == 226:
                                                state = (
                                                    315
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.950837135)
                                                    else 316
                                                )
                                                if state == 315:
                                                    state = (
                                                        407
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 7.08771992)
                                                        else 408
                                                    )
                                                    if state == 407:
                                                        state = (
                                                            519
                                                            if x["sgscore1_med"]
                                                            < 0.0504270494
                                                            else 520
                                                        )
                                                        if state == 519:
                                                            return 0.225455403
                                                        if state == 520:
                                                            return 0.499117583
                                                    if state == 408:
                                                        state = (
                                                            521
                                                            if x["sgscore1_med"]
                                                            < 0.00591666531
                                                            else 522
                                                        )
                                                        if state == 521:
                                                            return 0.199470177
                                                        if state == 522:
                                                            return -0.0838043168
                                                if state == 316:
                                                    return 0.316168159
                                if state == 54:
                                    state = (
                                        91
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.522261858)
                                        else 92
                                    )
                                    if state == 91:
                                        state = (
                                            147
                                            if x["neargaia_med"] < 168.277786
                                            else 148
                                        )
                                        if state == 147:
                                            return -0.351093024
                                        if state == 148:
                                            state = (
                                                227
                                                if x["sgscore1_med"] < 0.709249973
                                                else 228
                                            )
                                            if state == 227:
                                                return 0.131657422
                                            if state == 228:
                                                return -0.230889946
                                    if state == 92:
                                        state = (
                                            149
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 20.7366028)
                                            else 150
                                        )
                                        if state == 149:
                                            return -0.398743957
                                        if state == 150:
                                            state = (
                                                229
                                                if x["sgscore1_med"] < 0.509500027
                                                else 230
                                            )
                                            if state == 229:
                                                state = (
                                                    317
                                                    if x["col_peak"] < 0.459459305
                                                    else 318
                                                )
                                                if state == 317:
                                                    state = (
                                                        409
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 30.0196114)
                                                        else 410
                                                    )
                                                    if state == 409:
                                                        return -0.00739688426
                                                    if state == 410:
                                                        return 0.262724131
                                                if state == 318:
                                                    state = (
                                                        411
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 17.5203819)
                                                        else 412
                                                    )
                                                    if state == 411:
                                                        state = (
                                                            523
                                                            if x["sgscore1_med"]
                                                            < 0.492157519
                                                            else 524
                                                        )
                                                        if state == 523:
                                                            return -0.149285212
                                                        if state == 524:
                                                            return 0.253876626
                                                    if state == 412:
                                                        return -0.384679228
                                            if state == 230:
                                                return -0.406826586
                    if state == 8:
                        state = 17 if x["col_peak"] < -0.133242607 else 18
                        if state == 17:
                            return -0.438846856
                        if state == 18:
                            state = (
                                31
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.7319984)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    55
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.0270237997)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        93
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.716547608)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            151
                                            if x["neargaia_med"] < 26.7898598
                                            else 152
                                        )
                                        if state == 151:
                                            return -0.510035872
                                        if state == 152:
                                            state = (
                                                231
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00291666505)
                                                else 232
                                            )
                                            if state == 231:
                                                return -0.209820792
                                            if state == 232:
                                                return 0.399463892
                                    if state == 94:
                                        return -0.459212244
                                if state == 56:
                                    state = (
                                        95
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.704999983)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            153
                                            if x["neargaia_med"] < 26.4667435
                                            else 154
                                        )
                                        if state == 153:
                                            state = (
                                                233
                                                if x["sgscore1_med"] < 0.118205503
                                                else 234
                                            )
                                            if state == 233:
                                                return 0.386788577
                                            if state == 234:
                                                state = (
                                                    319
                                                    if x["col_peak"] < 0.355649948
                                                    else 320
                                                )
                                                if state == 319:
                                                    return 0.27872017
                                                if state == 320:
                                                    return -0.244738206
                                        if state == 154:
                                            return -0.330844671
                                    if state == 96:
                                        return -0.349730313
                            if state == 32:
                                return 0.365564436
                if state == 4:
                    state = 9 if x["maggaia_med"] < 14.9214439 else 10
                    if state == 9:
                        state = 19 if x["col_peak"] < -0.132918358 else 20
                        if state == 19:
                            state = (
                                33
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.9629993)
                                else 34
                            )
                            if state == 33:
                                state = 57 if x["sgscore1_med"] < 0.244532853 else 58
                                if state == 57:
                                    state = (
                                        97
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.593690515)
                                        else 98
                                    )
                                    if state == 97:
                                        return -0.335864305
                                    if state == 98:
                                        state = (
                                            155
                                            if x["neargaia_med"] < 19.2049007
                                            else 156
                                        )
                                        if state == 155:
                                            return -0.218961015
                                        if state == 156:
                                            state = (
                                                235
                                                if x["sgscore1_med"] < 0.0077083353
                                                else 236
                                            )
                                            if state == 235:
                                                return 0.235659719
                                            if state == 236:
                                                return -0.104497738
                                if state == 58:
                                    return 0.411982924
                            if state == 34:
                                return -0.415955096
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.4405003)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    59
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.00395833515)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        99
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.718333364)
                                        else 100
                                    )
                                    if state == 99:
                                        state = (
                                            157
                                            if x["neargaia_med"] < 39.941597
                                            else 158
                                        )
                                        if state == 157:
                                            return -0.466157317
                                        if state == 158:
                                            state = (
                                                237
                                                if x["sgscore1_med"] < 0.00333333481
                                                else 238
                                            )
                                            if state == 237:
                                                return -0.114224032
                                            if state == 238:
                                                return 0.427075326
                                    if state == 100:
                                        return -0.500229716
                                if state == 60:
                                    state = (
                                        101
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.612500072)
                                        else 102
                                    )
                                    if state == 101:
                                        state = (
                                            159
                                            if x["neargaia_med"] < 30.251194
                                            else 160
                                        )
                                        if state == 159:
                                            return -0.41898033
                                        if state == 160:
                                            return 0.228837714
                                    if state == 102:
                                        state = (
                                            161
                                            if x["neargaia_med"] < 31.642849
                                            else 162
                                        )
                                        if state == 161:
                                            state = (
                                                239
                                                if x["sgscore1_med"] < 0.0075000003
                                                else 240
                                            )
                                            if state == 239:
                                                return -1.02542341
                                            if state == 240:
                                                return -0.533952117
                                        if state == 162:
                                            state = (
                                                241
                                                if x["sgscore1_med"] < 0.074988097
                                                else 242
                                            )
                                            if state == 241:
                                                return 0.104510672
                                            if state == 242:
                                                return -0.47643289
                            if state == 36:
                                state = 61 if x["sgscore1_med"] < 0.0082291849 else 62
                                if state == 61:
                                    state = (
                                        103
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.537142873)
                                        else 104
                                    )
                                    if state == 103:
                                        return -0.202266365
                                    if state == 104:
                                        return 0.307972848
                                if state == 62:
                                    state = (
                                        105
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.889642835)
                                        else 106
                                    )
                                    if state == 105:
                                        state = (
                                            163
                                            if x["neargaia_med"] < 13.2142668
                                            else 164
                                        )
                                        if state == 163:
                                            return -0.427848428
                                        if state == 164:
                                            state = (
                                                243
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.121050507)
                                                else 244
                                            )
                                            if state == 243:
                                                return -0.325985759
                                            if state == 244:
                                                state = (
                                                    321
                                                    if x["col_peak"] < -0.0266852379
                                                    else 322
                                                )
                                                if state == 321:
                                                    return 0.185232386
                                                if state == 322:
                                                    state = (
                                                        413
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 46.4684944)
                                                        else 414
                                                    )
                                                    if state == 413:
                                                        return -0.306702584
                                                    if state == 414:
                                                        return 0.154992431
                                    if state == 106:
                                        return 0.128255337
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.209345818)
                            else 22
                        )
                        if state == 21:
                            state = (
                                37
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.5209999)
                                else 38
                            )
                            if state == 37:
                                state = 63 if x["sgscore1_med"] < 0.693312526 else 64
                                if state == 63:
                                    state = (
                                        107
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.240833491)
                                        else 108
                                    )
                                    if state == 107:
                                        return -0.278811216
                                    if state == 108:
                                        state = (
                                            165
                                            if x["neargaia_med"] < 53.5553207
                                            else 166
                                        )
                                        if state == 165:
                                            state = (
                                                245
                                                if x["sgscore1_med"] < 0.0167916492
                                                else 246
                                            )
                                            if state == 245:
                                                state = (
                                                    323
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.273801327)
                                                    else 324
                                                )
                                                if state == 323:
                                                    state = (
                                                        415
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 9.05435181)
                                                        else 416
                                                    )
                                                    if state == 415:
                                                        state = (
                                                            525
                                                            if x["sgscore1_med"]
                                                            < 0.00218750001
                                                            else 526
                                                        )
                                                        if state == 525:
                                                            return 0.446408153
                                                        if state == 526:
                                                            return 0.0954626799
                                                    if state == 416:
                                                        state = (
                                                            527
                                                            if x["sgscore1_med"]
                                                            < 0.00280654989
                                                            else 528
                                                        )
                                                        if state == 527:
                                                            return 0.0797482878
                                                        if state == 528:
                                                            return -0.122185491
                                                if state == 324:
                                                    state = (
                                                        417
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 12.512969)
                                                        else 418
                                                    )
                                                    if state == 417:
                                                        return -0.0381840728
                                                    if state == 418:
                                                        return -0.525880635
                                            if state == 246:
                                                state = (
                                                    325
                                                    if x["col_peak"] < -0.266777039
                                                    else 326
                                                )
                                                if state == 325:
                                                    state = (
                                                        419
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 35.0284767)
                                                        else 420
                                                    )
                                                    if state == 419:
                                                        state = (
                                                            529
                                                            if x["sgscore1_med"]
                                                            < 0.0280416496
                                                            else 530
                                                        )
                                                        if state == 529:
                                                            return -0.143391877
                                                        if state == 530:
                                                            return -0.402425855
                                                    if state == 420:
                                                        state = (
                                                            531
                                                            if x["sgscore1_med"]
                                                            < 0.0225833505
                                                            else 532
                                                        )
                                                        if state == 531:
                                                            return -0.131481409
                                                        if state == 532:
                                                            return 0.274427265
                                                if state == 326:
                                                    state = (
                                                        421
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 50.8718033)
                                                        else 422
                                                    )
                                                    if state == 421:
                                                        state = (
                                                            533
                                                            if x["sgscore1_med"]
                                                            < 0.0169077516
                                                            else 534
                                                        )
                                                        if state == 533:
                                                            return 1.02425051
                                                        if state == 534:
                                                            return 0.0589073524
                                                    if state == 422:
                                                        state = (
                                                            535
                                                            if x["sgscore1_med"]
                                                            < 0.0544926003
                                                            else 536
                                                        )
                                                        if state == 535:
                                                            return 0.307918042
                                                        if state == 536:
                                                            return 0.224290907
                                        if state == 166:
                                            state = (
                                                247
                                                if x["sgscore1_med"] < 0.0380416997
                                                else 248
                                            )
                                            if state == 247:
                                                state = (
                                                    327
                                                    if x["col_peak"] < -0.357300758
                                                    else 328
                                                )
                                                if state == 327:
                                                    return -0.131764978
                                                if state == 328:
                                                    state = (
                                                        423
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 32.475811)
                                                        else 424
                                                    )
                                                    if state == 423:
                                                        state = (
                                                            537
                                                            if x["sgscore1_med"]
                                                            < 0.0115208495
                                                            else 538
                                                        )
                                                        if state == 537:
                                                            return 0.282162726
                                                        if state == 538:
                                                            return -0.0371293426
                                                    if state == 424:
                                                        state = (
                                                            539
                                                            if x["sgscore1_med"]
                                                            < 0.0106458496
                                                            else 540
                                                        )
                                                        if state == 539:
                                                            return 0.12053173
                                                        if state == 540:
                                                            return -0.456306189
                                            if state == 248:
                                                state = (
                                                    329
                                                    if x["col_peak"] < -0.231939316
                                                    else 330
                                                )
                                                if state == 329:
                                                    state = (
                                                        425
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 34.9849167)
                                                        else 426
                                                    )
                                                    if state == 425:
                                                        state = (
                                                            541
                                                            if x["sgscore1_med"]
                                                            < 0.298291653
                                                            else 542
                                                        )
                                                        if state == 541:
                                                            return -0.0648551732
                                                        if state == 542:
                                                            return -0.478289634
                                                    if state == 426:
                                                        state = (
                                                            543
                                                            if x["sgscore1_med"]
                                                            < 0.0912916511
                                                            else 544
                                                        )
                                                        if state == 543:
                                                            return 0.265046507
                                                        if state == 544:
                                                            return -0.169436693
                                                if state == 330:
                                                    state = (
                                                        427
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 19.9956474)
                                                        else 428
                                                    )
                                                    if state == 427:
                                                        state = (
                                                            545
                                                            if x["sgscore1_med"]
                                                            < 0.0386041999
                                                            else 546
                                                        )
                                                        if state == 545:
                                                            return 0.376914293
                                                        if state == 546:
                                                            return 0.0514829271
                                                    if state == 428:
                                                        return 0.3976053
                                if state == 64:
                                    state = (
                                        109
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.613333225)
                                        else 110
                                    )
                                    if state == 109:
                                        state = (
                                            167
                                            if x["neargaia_med"] < 23.6592369
                                            else 168
                                        )
                                        if state == 167:
                                            state = (
                                                249
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.995000005)
                                                else 250
                                            )
                                            if state == 249:
                                                return -0.355195522
                                            if state == 250:
                                                return -0.547692657
                                        if state == 168:
                                            state = (
                                                251
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.962978959)
                                                else 252
                                            )
                                            if state == 251:
                                                return -0.191380933
                                            if state == 252:
                                                state = (
                                                    331
                                                    if x["col_peak"] < 0.000001
                                                    else 332
                                                )
                                                if state == 331:
                                                    return -0.129612997
                                                if state == 332:
                                                    return 0.214971915
                                    if state == 110:
                                        state = (
                                            169
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 8.77365303)
                                            else 170
                                        )
                                        if state == 169:
                                            state = (
                                                253
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.781906486)
                                                else 254
                                            )
                                            if state == 253:
                                                return -0.192990646
                                            if state == 254:
                                                return -0.691164315
                                        if state == 170:
                                            state = (
                                                255
                                                if x["sgscore1_med"] < 2.00000095
                                                else 256
                                            )
                                            if state == 255:
                                                return -0.320576578
                                            if state == 256:
                                                state = (
                                                    333
                                                    if x["col_peak"] < -0.252858162
                                                    else 334
                                                )
                                                if state == 333:
                                                    return -0.233046129
                                                if state == 334:
                                                    state = (
                                                        429
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 21.9718342)
                                                        else 430
                                                    )
                                                    if state == 429:
                                                        return -0.0612300411
                                                    if state == 430:
                                                        return 0.23992148
                            if state == 38:
                                state = (
                                    65
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.00695833471)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        111
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.638571382)
                                        else 112
                                    )
                                    if state == 111:
                                        state = (
                                            171
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 23.539566)
                                            else 172
                                        )
                                        if state == 171:
                                            state = (
                                                257
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00568750035)
                                                else 258
                                            )
                                            if state == 257:
                                                state = (
                                                    335
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.298503876)
                                                    else 336
                                                )
                                                if state == 335:
                                                    state = (
                                                        431
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 15.0173836)
                                                        else 432
                                                    )
                                                    if state == 431:
                                                        state = (
                                                            547
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.00354166492
                                                            )
                                                            else 548
                                                        )
                                                        if state == 547:
                                                            return -0.0699631348
                                                        if state == 548:
                                                            return 0.320817262
                                                    if state == 432:
                                                        state = (
                                                            549
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.00354166492
                                                            )
                                                            else 550
                                                        )
                                                        if state == 549:
                                                            return -0.396820039
                                                        if state == 550:
                                                            return 0.0116630662
                                                if state == 336:
                                                    return 0.398584217
                                            if state == 258:
                                                return -0.469730496
                                        if state == 172:
                                            return -0.512782812
                                    if state == 112:
                                        state = (
                                            173
                                            if x["neargaia_med"] < 31.009449
                                            else 174
                                        )
                                        if state == 173:
                                            state = (
                                                261
                                                if x["sgscore1_med"] < 0.00112499995
                                                else 262
                                            )
                                            if state == 261:
                                                return 0.325768292
                                            if state == 262:
                                                state = (
                                                    337
                                                    if x["col_peak"] < 0.000001
                                                    else 338
                                                )
                                                if state == 337:
                                                    return -0.324344814
                                                if state == 338:
                                                    state = (
                                                        433
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 16.0867481)
                                                        else 434
                                                    )
                                                    if state == 433:
                                                        state = (
                                                            551
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.00178571499
                                                            )
                                                            else 552
                                                        )
                                                        if state == 551:
                                                            return 0.226697177
                                                        if state == 552:
                                                            return -0.0297544934
                                                    if state == 434:
                                                        state = (
                                                            553
                                                            if x["sgscore1_med"]
                                                            < 0.00145833497
                                                            else 554
                                                        )
                                                        if state == 553:
                                                            return 0.0696322098
                                                        if state == 554:
                                                            return -0.261169583
                                        if state == 174:
                                            return -0.349291086
                                if state == 66:
                                    state = (
                                        113
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.407738149)
                                        else 114
                                    )
                                    if state == 113:
                                        state = (
                                            175
                                            if x["neargaia_med"] < 163.874985
                                            else 176
                                        )
                                        if state == 175:
                                            state = (
                                                263
                                                if x["sgscore1_med"] < 0.999374986
                                                else 264
                                            )
                                            if state == 263:
                                                return -0.398213327
                                            if state == 264:
                                                return -0.0178728271
                                        if state == 176:
                                            state = (
                                                265
                                                if x["sgscore1_med"] < 0.249654502
                                                else 266
                                            )
                                            if state == 265:
                                                state = (
                                                    339
                                                    if x["col_peak"] < 0.000001
                                                    else 340
                                                )
                                                if state == 339:
                                                    return -0.129186854
                                                if state == 340:
                                                    return 0.342066944
                                            if state == 266:
                                                return -0.428238451
                                    if state == 114:
                                        state = (
                                            177
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 11.7369652)
                                            else 178
                                        )
                                        if state == 177:
                                            state = (
                                                267
                                                if x["sgscore1_med"] < 0.0319999978
                                                else 268
                                            )
                                            if state == 267:
                                                return -0.142269492
                                            if state == 268:
                                                state = (
                                                    341
                                                    if x["col_peak"] < 0.000001
                                                    else 342
                                                )
                                                if state == 341:
                                                    return -0.324451029
                                                if state == 342:
                                                    state = (
                                                        435
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 9.03738403)
                                                        else 436
                                                    )
                                                    if state == 435:
                                                        return 0.469541818
                                                    if state == 436:
                                                        state = (
                                                            555
                                                            if x["sgscore1_med"]
                                                            < 0.0353333503
                                                            else 556
                                                        )
                                                        if state == 555:
                                                            return 0.374593884
                                                        if state == 556:
                                                            return 0.198682383
                                        if state == 178:
                                            state = (
                                                269
                                                if x["sgscore1_med"] < 0.0157083496
                                                else 270
                                            )
                                            if state == 269:
                                                state = (
                                                    343
                                                    if x["col_peak"] < -0.330381691
                                                    else 344
                                                )
                                                if state == 343:
                                                    return -0.126960471
                                                if state == 344:
                                                    state = (
                                                        437
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 16.0133801)
                                                        else 438
                                                    )
                                                    if state == 437:
                                                        state = (
                                                            557
                                                            if x["sgscore1_med"]
                                                            < 0.0141458008
                                                            else 558
                                                        )
                                                        if state == 557:
                                                            return -0.190021738
                                                        if state == 558:
                                                            return 0.243239537
                                                    if state == 438:
                                                        state = (
                                                            559
                                                            if x["sgscore1_med"]
                                                            < 0.0141041502
                                                            else 560
                                                        )
                                                        if state == 559:
                                                            return -0.13536267
                                                        if state == 560:
                                                            return 0.374287307
                                            if state == 270:
                                                state = (
                                                    345
                                                    if x["col_peak"] < -0.417078018
                                                    else 346
                                                )
                                                if state == 345:
                                                    return 0.37265268
                                                if state == 346:
                                                    state = (
                                                        439
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 6.94363403)
                                                        else 440
                                                    )
                                                    if state == 439:
                                                        state = (
                                                            561
                                                            if x["sgscore1_med"]
                                                            < 0.0256666504
                                                            else 562
                                                        )
                                                        if state == 561:
                                                            return 0.60213244
                                                        if state == 562:
                                                            return -0.0874393955
                                                    if state == 440:
                                                        state = (
                                                            563
                                                            if x["sgscore1_med"]
                                                            < 0.151027501
                                                            else 564
                                                        )
                                                        if state == 563:
                                                            return -0.427438885
                                                        if state == 564:
                                                            return -0.0600440465
                        if state == 22:
                            state = (
                                39
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.9602509)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    67
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.0179166496)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        115
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.53964287)
                                        else 116
                                    )
                                    if state == 115:
                                        state = (
                                            179
                                            if x["neargaia_med"] < 23.3511944
                                            else 180
                                        )
                                        if state == 179:
                                            state = (
                                                271
                                                if x["sgscore1_med"] < 0.00145833497
                                                else 272
                                            )
                                            if state == 271:
                                                state = (
                                                    347
                                                    if x["col_peak"] < -0.0058221817
                                                    else 348
                                                )
                                                if state == 347:
                                                    return 0.253225923
                                                if state == 348:
                                                    return -0.117013946
                                            if state == 272:
                                                return -0.561538339
                                        if state == 180:
                                            state = (
                                                273
                                                if x["sgscore1_med"] < 0.00364583498
                                                else 274
                                            )
                                            if state == 273:
                                                state = (
                                                    349
                                                    if x["col_peak"] < -0.0343308449
                                                    else 350
                                                )
                                                if state == 349:
                                                    state = (
                                                        441
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 23.9795303)
                                                        else 442
                                                    )
                                                    if state == 441:
                                                        state = (
                                                            565
                                                            if x["sgscore1_med"]
                                                            < 0.00145833497
                                                            else 566
                                                        )
                                                        if state == 565:
                                                            return 0.100473545
                                                        if state == 566:
                                                            return -0.0987066329
                                                    if state == 442:
                                                        return 0.202056333
                                                if state == 350:
                                                    return -0.407239556
                                            if state == 274:
                                                state = (
                                                    351
                                                    if x["col_peak"] < -0.115427494
                                                    else 352
                                                )
                                                if state == 351:
                                                    return -0.271582812
                                                if state == 352:
                                                    state = (
                                                        443
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 54.960762)
                                                        else 444
                                                    )
                                                    if state == 443:
                                                        state = (
                                                            567
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.00395833515
                                                            )
                                                            else 568
                                                        )
                                                        if state == 567:
                                                            return 0.280688375
                                                        if state == 568:
                                                            return 0.0312086325
                                                    if state == 444:
                                                        return -0.121559948
                                    if state == 116:
                                        state = (
                                            181
                                            if x["neargaia_med"] < 0.937549353
                                            else 182
                                        )
                                        if state == 181:
                                            state = (
                                                275
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00635416526)
                                                else 276
                                            )
                                            if state == 275:
                                                return -0.596228898
                                            if state == 276:
                                                state = (
                                                    353
                                                    if x["col_peak"] < 0.0922060013
                                                    else 354
                                                )
                                                if state == 353:
                                                    return 0.268574327
                                                if state == 354:
                                                    return -0.16377531
                                        if state == 182:
                                            state = (
                                                277
                                                if x["sgscore1_med"] < 0.00387499994
                                                else 278
                                            )
                                            if state == 277:
                                                state = (
                                                    355
                                                    if x["col_peak"] < 0.208219528
                                                    else 356
                                                )
                                                if state == 355:
                                                    state = (
                                                        445
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 14.9467592)
                                                        else 446
                                                    )
                                                    if state == 445:
                                                        state = (
                                                            569
                                                            if x["sgscore1_med"]
                                                            < 0.00104166649
                                                            else 570
                                                        )
                                                        if state == 569:
                                                            return -0.300443172
                                                        if state == 570:
                                                            return -0.00369284488
                                                    if state == 446:
                                                        state = (
                                                            571
                                                            if x["sgscore1_med"]
                                                            < 0.00372916507
                                                            else 572
                                                        )
                                                        if state == 571:
                                                            return 0.24107103
                                                        if state == 572:
                                                            return 0.448361099
                                                if state == 356:
                                                    state = (
                                                        447
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 45.9611206)
                                                        else 448
                                                    )
                                                    if state == 447:
                                                        state = (
                                                            573
                                                            if x["sgscore1_med"]
                                                            < 0.0017708349
                                                            else 574
                                                        )
                                                        if state == 573:
                                                            return -0.413938969
                                                        if state == 574:
                                                            return 0.0377248041
                                                    if state == 448:
                                                        state = (
                                                            575
                                                            if x["sgscore1_med"]
                                                            < 0.00249999994
                                                            else 576
                                                        )
                                                        if state == 575:
                                                            return -0.284408987
                                                        if state == 576:
                                                            return 0.351143241
                                            if state == 278:
                                                state = (
                                                    357
                                                    if x["col_peak"] < 0.51336956
                                                    else 358
                                                )
                                                if state == 357:
                                                    state = (
                                                        449
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 26.9458332)
                                                        else 450
                                                    )
                                                    if state == 449:
                                                        state = (
                                                            577
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.0103124995
                                                            )
                                                            else 578
                                                        )
                                                        if state == 577:
                                                            return -0.126856446
                                                        if state == 578:
                                                            return -0.540770054
                                                    if state == 450:
                                                        state = (
                                                            579
                                                            if x["sgscore1_med"]
                                                            < 0.007604165
                                                            else 580
                                                        )
                                                        if state == 579:
                                                            return -0.123847298
                                                        if state == 580:
                                                            return 0.174471483
                                                if state == 358:
                                                    return 0.368777066
                                if state == 68:
                                    state = (
                                        117
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.569285631)
                                        else 118
                                    )
                                    if state == 117:
                                        state = (
                                            183
                                            if x["neargaia_med"] < 7.06339884
                                            else 184
                                        )
                                        if state == 183:
                                            state = (
                                                279
                                                if x["sgscore1_med"] < 0.169137001
                                                else 280
                                            )
                                            if state == 279:
                                                state = (
                                                    359
                                                    if x["col_peak"] < 0.171224117
                                                    else 360
                                                )
                                                if state == 359:
                                                    state = (
                                                        451
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 28.8588066)
                                                        else 452
                                                    )
                                                    if state == 451:
                                                        return -0.340546489
                                                    if state == 452:
                                                        return 0.282362074
                                                if state == 360:
                                                    state = (
                                                        453
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 27.9685402)
                                                        else 454
                                                    )
                                                    if state == 453:
                                                        return -0.465375155
                                                    if state == 454:
                                                        return -0.00191375788
                                            if state == 280:
                                                return -0.422184527
                                        if state == 184:
                                            state = (
                                                281
                                                if x["sgscore1_med"] < 0.0652976483
                                                else 282
                                            )
                                            if state == 281:
                                                state = (
                                                    361
                                                    if x["col_peak"] < 0.165591717
                                                    else 362
                                                )
                                                if state == 361:
                                                    state = (
                                                        455
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 26.9648743)
                                                        else 456
                                                    )
                                                    if state == 455:
                                                        state = (
                                                            581
                                                            if x["sgscore1_med"]
                                                            < 0.0533452481
                                                            else 582
                                                        )
                                                        if state == 581:
                                                            return 0.239765912
                                                        if state == 582:
                                                            return -0.266082466
                                                    if state == 456:
                                                        return -0.82787621
                                                if state == 362:
                                                    state = (
                                                        457
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 47.3823242)
                                                        else 458
                                                    )
                                                    if state == 457:
                                                        state = (
                                                            583
                                                            if x["sgscore1_med"]
                                                            < 0.0228541493
                                                            else 584
                                                        )
                                                        if state == 583:
                                                            return 0.288842201
                                                        if state == 584:
                                                            return -0.297730774
                                                    if state == 458:
                                                        return 0.212521017
                                            if state == 282:
                                                state = (
                                                    363
                                                    if x["col_peak"] < 0.118751526
                                                    else 364
                                                )
                                                if state == 363:
                                                    state = (
                                                        459
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 20.9582005)
                                                        else 460
                                                    )
                                                    if state == 459:
                                                        state = (
                                                            585
                                                            if x["sgscore1_med"]
                                                            < 0.0697768033
                                                            else 586
                                                        )
                                                        if state == 585:
                                                            return 0.358974844
                                                        if state == 586:
                                                            return -0.104280196
                                                    if state == 460:
                                                        state = (
                                                            587
                                                            if x["sgscore1_med"]
                                                            < 0.107326999
                                                            else 588
                                                        )
                                                        if state == 587:
                                                            return 0.0291843321
                                                        if state == 588:
                                                            return 0.272284895
                                                if state == 364:
                                                    state = (
                                                        461
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 43.7191277)
                                                        else 462
                                                    )
                                                    if state == 461:
                                                        state = (
                                                            589
                                                            if x["sgscore1_med"]
                                                            < 0.0898749977
                                                            else 590
                                                        )
                                                        if state == 589:
                                                            return -0.0332870111
                                                        if state == 590:
                                                            return -0.359778643
                                                    if state == 462:
                                                        state = (
                                                            591
                                                            if x["sgscore1_med"]
                                                            < 0.321943492
                                                            else 592
                                                        )
                                                        if state == 591:
                                                            return 0.28540501
                                                        if state == 592:
                                                            return 0.145180106
                                    if state == 118:
                                        state = (
                                            185
                                            if x["neargaia_med"] < 0.709330022
                                            else 186
                                        )
                                        if state == 185:
                                            return -0.186955407
                                        if state == 186:
                                            state = (
                                                283
                                                if x["sgscore1_med"] < 0.693312526
                                                else 284
                                            )
                                            if state == 283:
                                                state = (
                                                    365
                                                    if x["col_peak"] < 0.044836998
                                                    else 366
                                                )
                                                if state == 365:
                                                    state = (
                                                        463
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 24.0235405)
                                                        else 464
                                                    )
                                                    if state == 463:
                                                        state = (
                                                            593
                                                            if x["sgscore1_med"]
                                                            < 0.0700089484
                                                            else 594
                                                        )
                                                        if state == 593:
                                                            return -0.00533006014
                                                        if state == 594:
                                                            return 0.20481737
                                                    if state == 464:
                                                        return 0.345657885
                                                if state == 366:
                                                    state = (
                                                        465
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 24.1062164)
                                                        else 466
                                                    )
                                                    if state == 465:
                                                        state = (
                                                            595
                                                            if x["sgscore1_med"]
                                                            < 0.320099503
                                                            else 596
                                                        )
                                                        if state == 595:
                                                            return 0.122962259
                                                        if state == 596:
                                                            return -0.0718757361
                                                    if state == 466:
                                                        state = (
                                                            597
                                                            if x["sgscore1_med"]
                                                            < 0.182981998
                                                            else 598
                                                        )
                                                        if state == 597:
                                                            return 0.128988385
                                                        if state == 598:
                                                            return 0.296902299
                                            if state == 284:
                                                state = (
                                                    367
                                                    if x["col_peak"] < -0.0936164856
                                                    else 368
                                                )
                                                if state == 367:
                                                    state = (
                                                        467
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 45.5173569)
                                                        else 468
                                                    )
                                                    if state == 467:
                                                        state = (
                                                            599
                                                            if x["sgscore1_med"]
                                                            < 0.993052006
                                                            else 600
                                                        )
                                                        if state == 599:
                                                            return 0.124759488
                                                        if state == 600:
                                                            return -0.15324761
                                                    if state == 468:
                                                        return 0.339170575
                                                if state == 368:
                                                    state = (
                                                        469
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 64.9073181)
                                                        else 470
                                                    )
                                                    if state == 469:
                                                        state = (
                                                            601
                                                            if x["sgscore1_med"]
                                                            < 0.993729472
                                                            else 602
                                                        )
                                                        if state == 601:
                                                            return -0.557420194
                                                        if state == 602:
                                                            return -0.0632498786
                                                    if state == 470:
                                                        return 0.216503412
                            if state == 40:
                                state = (
                                    69
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.979687452)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        119
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.565357149)
                                        else 120
                                    )
                                    if state == 119:
                                        state = (
                                            187
                                            if x["neargaia_med"] < 23.3093529
                                            else 188
                                        )
                                        if state == 187:
                                            state = (
                                                285
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.965937495)
                                                else 286
                                            )
                                            if state == 285:
                                                state = (
                                                    369
                                                    if x["col_peak"] < -0.159602642
                                                    else 370
                                                )
                                                if state == 369:
                                                    return -0.023755027
                                                if state == 370:
                                                    return -0.492554039
                                            if state == 286:
                                                return 0.204706877
                                        if state == 188:
                                            state = (
                                                287
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0969376564)
                                                else 288
                                            )
                                            if state == 287:
                                                state = (
                                                    371
                                                    if x["col_peak"] < 0.0978803635
                                                    else 372
                                                )
                                                if state == 371:
                                                    state = (
                                                        471
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 14.5590162)
                                                        else 472
                                                    )
                                                    if state == 471:
                                                        return -0.137107104
                                                    if state == 472:
                                                        return 0.318471998
                                                if state == 372:
                                                    return -0.45677501
                                            if state == 288:
                                                state = (
                                                    373
                                                    if x["col_peak"] < -0.0858020782
                                                    else 374
                                                )
                                                if state == 373:
                                                    return -0.50289464
                                                if state == 374:
                                                    state = (
                                                        473
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 64.9037094)
                                                        else 474
                                                    )
                                                    if state == 473:
                                                        state = (
                                                            603
                                                            if x["sgscore1_med"]
                                                            < 0.974125028
                                                            else 604
                                                        )
                                                        if state == 603:
                                                            return -0.360595018
                                                        if state == 604:
                                                            return 0.284611434
                                                    if state == 474:
                                                        return 0.156093508
                                    if state == 120:
                                        state = (
                                            189
                                            if x["neargaia_med"] < 14.6339273
                                            else 190
                                        )
                                        if state == 189:
                                            state = (
                                                289
                                                if x["sgscore1_med"] < 0.470604002
                                                else 290
                                            )
                                            if state == 289:
                                                state = (
                                                    375
                                                    if x["col_peak"] < -0.063419342
                                                    else 376
                                                )
                                                if state == 375:
                                                    state = (
                                                        475
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 22.0197392)
                                                        else 476
                                                    )
                                                    if state == 475:
                                                        return -0.245020032
                                                    if state == 476:
                                                        return 0.133404031
                                                if state == 376:
                                                    return -0.761294663
                                            if state == 290:
                                                state = (
                                                    377
                                                    if x["col_peak"] < -0.122272491
                                                    else 378
                                                )
                                                if state == 377:
                                                    return -0.255088747
                                                if state == 378:
                                                    state = (
                                                        477
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 10.4766436)
                                                        else 478
                                                    )
                                                    if state == 477:
                                                        return -0.169200614
                                                    if state == 478:
                                                        state = (
                                                            605
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.970800996
                                                            )
                                                            else 606
                                                        )
                                                        if state == 605:
                                                            return 0.361041725
                                                        if state == 606:
                                                            return -0.200982153
                                        if state == 190:
                                            state = (
                                                291
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0109374998)
                                                else 292
                                            )
                                            if state == 291:
                                                state = (
                                                    379
                                                    if x["col_peak"] < -0.108445168
                                                    else 380
                                                )
                                                if state == 379:
                                                    state = (
                                                        479
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 35.5348434)
                                                        else 480
                                                    )
                                                    if state == 479:
                                                        return 0.155515298
                                                    if state == 480:
                                                        return -0.0235939771
                                                if state == 380:
                                                    return -0.268409103
                                            if state == 292:
                                                state = (
                                                    381
                                                    if x["col_peak"] < -0.0657300949
                                                    else 382
                                                )
                                                if state == 381:
                                                    state = (
                                                        481
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 16.4765854)
                                                        else 482
                                                    )
                                                    if state == 481:
                                                        return -0.157817885
                                                    if state == 482:
                                                        return 0.366854906
                                                if state == 382:
                                                    state = (
                                                        483
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 13.4970598)
                                                        else 484
                                                    )
                                                    if state == 483:
                                                        return -0.180039525
                                                    if state == 484:
                                                        state = (
                                                            607
                                                            if x["sgscore1_med"]
                                                            < 0.0289910492
                                                            else 608
                                                        )
                                                        if state == 607:
                                                            return -0.229398221
                                                        if state == 608:
                                                            return 0.296560854
                                if state == 70:
                                    return -0.426248848
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.371279716)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 18.957571)
                        else 12
                    )
                    if state == 11:
                        return -0.378048331
                    if state == 12:
                        state = 23 if x["col_peak"] < 0.0580739975 else 24
                        if state == 23:
                            state = (
                                41
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.8764992)
                                else 42
                            )
                            if state == 41:
                                state = 71 if x["sgscore1_med"] < 0.0490844026 else 72
                                if state == 71:
                                    return -0.200440362
                                if state == 72:
                                    return 0.229966193
                            if state == 42:
                                return -0.365912557
                        if state == 24:
                            state = (
                                43
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 20.2964993)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    73
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.0145982001)
                                    else 74
                                )
                                if state == 73:
                                    state = (
                                        121
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.933214188)
                                        else 122
                                    )
                                    if state == 121:
                                        return -0.232292101
                                    if state == 122:
                                        state = (
                                            191
                                            if x["neargaia_med"] < 21.0902195
                                            else 192
                                        )
                                        if state == 191:
                                            state = (
                                                293
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0127649)
                                                else 294
                                            )
                                            if state == 293:
                                                return -0.26038751
                                            if state == 294:
                                                return 0.454885632
                                        if state == 192:
                                            return 0.41078198
                                if state == 74:
                                    return -0.30509007
                            if state == 44:
                                return -0.273978055
                if state == 6:
                    state = 13 if x["maggaia_med"] < 16.4969025 else 14
                    if state == 13:
                        return 0.358029157
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.361296654)
                            else 26
                        )
                        if state == 25:
                            state = (
                                45
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.1322517)
                                else 46
                            )
                            if state == 45:
                                state = 75 if x["sgscore1_med"] < 0.614187479 else 76
                                if state == 75:
                                    state = (
                                        123
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.946071446)
                                        else 124
                                    )
                                    if state == 123:
                                        state = (
                                            193
                                            if x["neargaia_med"] < 0.741618276
                                            else 194
                                        )
                                        if state == 193:
                                            return -0.30856061
                                        if state == 194:
                                            state = (
                                                295
                                                if x["sgscore1_med"] < 0.0968544036
                                                else 296
                                            )
                                            if state == 295:
                                                state = (
                                                    383
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.0484042168)
                                                    else 384
                                                )
                                                if state == 383:
                                                    state = (
                                                        485
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 18.4980736)
                                                        else 486
                                                    )
                                                    if state == 485:
                                                        state = (
                                                            609
                                                            if x["sgscore1_med"]
                                                            < 0.0167708006
                                                            else 610
                                                        )
                                                        if state == 609:
                                                            return 0.00256759301
                                                        if state == 610:
                                                            return -0.329468489
                                                    if state == 486:
                                                        return 0.372605652
                                                if state == 384:
                                                    return -0.249845654
                                            if state == 296:
                                                return 0.396443695
                                    if state == 124:
                                        state = (
                                            195
                                            if x["neargaia_med"] < 0.340790749
                                            else 196
                                        )
                                        if state == 195:
                                            return -0.137037531
                                        if state == 196:
                                            return 0.399053037
                                if state == 76:
                                    return -0.142424658
                            if state == 46:
                                state = (
                                    77
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.888833523)
                                    else 78
                                )
                                if state == 77:
                                    state = (
                                        125
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.954999983)
                                        else 126
                                    )
                                    if state == 125:
                                        state = (
                                            197
                                            if x["neargaia_med"] < 10.4414778
                                            else 198
                                        )
                                        if state == 197:
                                            state = (
                                                297
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00786904991)
                                                else 298
                                            )
                                            if state == 297:
                                                return -0.364322156
                                            if state == 298:
                                                state = (
                                                    385
                                                    if x["col_peak"] < -0.189831734
                                                    else 386
                                                )
                                                if state == 385:
                                                    return -0.271775901
                                                if state == 386:
                                                    state = (
                                                        487
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 14.495307)
                                                        else 488
                                                    )
                                                    if state == 487:
                                                        state = (
                                                            611
                                                            if x["sgscore1_med"]
                                                            < 0.019312501
                                                            else 612
                                                        )
                                                        if state == 611:
                                                            return 0.140068337
                                                        if state == 612:
                                                            return -0.249850988
                                                    if state == 488:
                                                        state = (
                                                            613
                                                            if x["sgscore1_med"]
                                                            < 0.0393749997
                                                            else 614
                                                        )
                                                        if state == 613:
                                                            return 0.364082247
                                                        if state == 614:
                                                            return 0.0363153368
                                        if state == 198:
                                            state = (
                                                299
                                                if x["sgscore1_med"] < 0.0465000011
                                                else 300
                                            )
                                            if state == 299:
                                                state = (
                                                    387
                                                    if x["col_peak"] < 0.0848855972
                                                    else 388
                                                )
                                                if state == 387:
                                                    state = (
                                                        489
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 27.4539814)
                                                        else 490
                                                    )
                                                    if state == 489:
                                                        state = (
                                                            615
                                                            if x["sgscore1_med"]
                                                            < 0.0103124846
                                                            else 616
                                                        )
                                                        if state == 615:
                                                            return -0.122846521
                                                        if state == 616:
                                                            return 0.264064074
                                                    if state == 490:
                                                        state = (
                                                            617
                                                            if x["sgscore1_med"]
                                                            < 0.0311339498
                                                            else 618
                                                        )
                                                        if state == 617:
                                                            return 0.375526845
                                                        if state == 618:
                                                            return 0.0245556068
                                                if state == 388:
                                                    state = (
                                                        491
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 33.9796677)
                                                        else 492
                                                    )
                                                    if state == 491:
                                                        state = (
                                                            619
                                                            if x["sgscore1_med"]
                                                            < 0.003354165
                                                            else 620
                                                        )
                                                        if state == 619:
                                                            return -0.198442549
                                                        if state == 620:
                                                            return 0.109751463
                                                    if state == 492:
                                                        return -0.326298267
                                            if state == 300:
                                                state = (
                                                    389
                                                    if x["col_peak"] < -0.208384514
                                                    else 390
                                                )
                                                if state == 389:
                                                    state = (
                                                        493
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 27.0091267)
                                                        else 494
                                                    )
                                                    if state == 493:
                                                        state = (
                                                            621
                                                            if x["sgscore1_med"]
                                                            < 0.0943305045
                                                            else 622
                                                        )
                                                        if state == 621:
                                                            return 0.178520724
                                                        if state == 622:
                                                            return -0.316896409
                                                    if state == 494:
                                                        return 0.150444254
                                                if state == 390:
                                                    state = (
                                                        495
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 30.0374889)
                                                        else 496
                                                    )
                                                    if state == 495:
                                                        state = (
                                                            623
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.053187497
                                                            )
                                                            else 624
                                                        )
                                                        if state == 623:
                                                            return 0.0851388872
                                                        if state == 624:
                                                            return 0.336795509
                                                    if state == 496:
                                                        return 0.391609401
                                    if state == 126:
                                        state = (
                                            199
                                            if x["neargaia_med"] < 4.45267868
                                            else 200
                                        )
                                        if state == 199:
                                            return -0.598104239
                                        if state == 200:
                                            state = (
                                                301
                                                if x["sgscore1_med"] < 0.0208749995
                                                else 302
                                            )
                                            if state == 301:
                                                state = (
                                                    391
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.0126581192)
                                                    else 392
                                                )
                                                if state == 391:
                                                    state = (
                                                        497
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 11.4222393)
                                                        else 498
                                                    )
                                                    if state == 497:
                                                        return -0.196537048
                                                    if state == 498:
                                                        state = (
                                                            625
                                                            if x["sgscore1_med"]
                                                            < 0.00572916493
                                                            else 626
                                                        )
                                                        if state == 625:
                                                            return 0.00120748894
                                                        if state == 626:
                                                            return 0.249412686
                                                if state == 392:
                                                    state = (
                                                        499
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 21.019825)
                                                        else 500
                                                    )
                                                    if state == 499:
                                                        return 0.0180932358
                                                    if state == 500:
                                                        return -0.362196386
                                            if state == 302:
                                                state = (
                                                    393
                                                    if x["col_peak"] < 0.27974987
                                                    else 394
                                                )
                                                if state == 393:
                                                    state = (
                                                        501
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 18.4880028)
                                                        else 502
                                                    )
                                                    if state == 501:
                                                        return -0.484975785
                                                    if state == 502:
                                                        state = (
                                                            627
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.0490937494
                                                            )
                                                            else 628
                                                        )
                                                        if state == 627:
                                                            return 0.317805797
                                                        if state == 628:
                                                            return -0.307319701
                                                if state == 394:
                                                    state = (
                                                        503
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 15.5118866)
                                                        else 504
                                                    )
                                                    if state == 503:
                                                        state = (
                                                            629
                                                            if x["sgscore1_med"]
                                                            < 0.0426249988
                                                            else 630
                                                        )
                                                        if state == 629:
                                                            return 0.297034651
                                                        if state == 630:
                                                            return -0.0201125275
                                                    if state == 504:
                                                        return 0.356405437
                                if state == 78:
                                    return -0.353067011
                        if state == 26:
                            return 0.396390021
    elif num_booster == 7:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.910034776)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.97874999)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5545006)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0426620021)
                            else 16
                        )
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.966750026)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    55
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 11.3153343)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        99
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.6065788)
                                        else 100
                                    )
                                    if state == 99:
                                        state = (
                                            165
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.2495995)
                                            else 166
                                        )
                                        if state == 165:
                                            return -0.270540029
                                        if state == 166:
                                            return 0.146363616
                                    if state == 100:
                                        state = (
                                            167
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.3843994)
                                            else 168
                                        )
                                        if state == 167:
                                            return -0.41976124
                                        if state == 168:
                                            state = (
                                                273
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.0043945)
                                                else 274
                                            )
                                            if state == 273:
                                                return 0.0752469972
                                            if state == 274:
                                                state = (
                                                    397
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.388977528)
                                                    else 398
                                                )
                                                if state == 397:
                                                    state = (
                                                        553
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.379451752)
                                                        else 554
                                                    )
                                                    if state == 553:
                                                        return -0.359707028
                                                    if state == 554:
                                                        state = (
                                                            705
                                                            if x["col_last"]
                                                            < 0.467584133
                                                            else 706
                                                        )
                                                        if state == 705:
                                                            return 0.200232938
                                                        if state == 706:
                                                            return -0.157713488
                                                if state == 398:
                                                    state = (
                                                        555
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.588726521)
                                                        else 556
                                                    )
                                                    if state == 555:
                                                        return -0.14783147
                                                    if state == 556:
                                                        return 0.0802717656
                                if state == 56:
                                    state = (
                                        101
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.8625546)
                                        else 102
                                    )
                                    if state == 101:
                                        state = (
                                            169
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4739494)
                                            else 170
                                        )
                                        if state == 169:
                                            return 0.20273976
                                        if state == 170:
                                            return -0.102690034
                                    if state == 102:
                                        return -0.112799317
                            if state == 30:
                                state = (
                                    57
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 2.85551405)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        103
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.6667976)
                                        else 104
                                    )
                                    if state == 103:
                                        state = (
                                            171
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.2722511)
                                            else 172
                                        )
                                        if state == 171:
                                            return -0.460520774
                                        if state == 172:
                                            state = (
                                                275
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.0359936)
                                                else 276
                                            )
                                            if state == 275:
                                                return 0.24545823
                                            if state == 276:
                                                return -0.33941561
                                    if state == 104:
                                        state = (
                                            173
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.2625008)
                                            else 174
                                        )
                                        if state == 173:
                                            return -0.369553298
                                        if state == 174:
                                            state = (
                                                277
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.7407074)
                                                else 278
                                            )
                                            if state == 277:
                                                return 0.271690995
                                            if state == 278:
                                                state = (
                                                    399
                                                    if x["col_peak"] < 1.7868433
                                                    else 400
                                                )
                                                if state == 399:
                                                    return -0.238172635
                                                if state == 400:
                                                    return 0.159793451
                                if state == 58:
                                    state = (
                                        105
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.177494)
                                        else 106
                                    )
                                    if state == 105:
                                        state = (
                                            175
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.7617493)
                                            else 176
                                        )
                                        if state == 175:
                                            return 0.353656173
                                        if state == 176:
                                            state = (
                                                279
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.5486774)
                                                else 280
                                            )
                                            if state == 279:
                                                return 0.282129854
                                            if state == 280:
                                                return -0.165952623
                                    if state == 106:
                                        state = (
                                            177
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.7943459)
                                            else 178
                                        )
                                        if state == 177:
                                            state = (
                                                281
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.2975807)
                                                else 282
                                            )
                                            if state == 281:
                                                return -0.157889366
                                            if state == 282:
                                                return 0.438531876
                                        if state == 178:
                                            state = (
                                                283
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.7197571)
                                                else 284
                                            )
                                            if state == 283:
                                                state = (
                                                    401
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.0770522803)
                                                    else 402
                                                )
                                                if state == 401:
                                                    return -0.495100975
                                                if state == 402:
                                                    return 0.249748409
                                            if state == 284:
                                                state = (
                                                    403
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.0770522803)
                                                    else 404
                                                )
                                                if state == 403:
                                                    return -0.141257495
                                                if state == 404:
                                                    return 0.172385782
                        if state == 16:
                            state = (
                                31
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.973500013)
                                else 32
                            )
                            if state == 31:
                                state = 59 if x["distpsnr1_med"] < 4.59612751 else 60
                                if state == 59:
                                    state = (
                                        107
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.640007)
                                        else 108
                                    )
                                    if state == 107:
                                        state = (
                                            179
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.90415)
                                            else 180
                                        )
                                        if state == 179:
                                            return -0.311154664
                                        if state == 180:
                                            return 0.42313382
                                    if state == 108:
                                        state = (
                                            181
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.3903999)
                                            else 182
                                        )
                                        if state == 181:
                                            state = (
                                                285
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.0203323)
                                                else 286
                                            )
                                            if state == 285:
                                                state = (
                                                    405
                                                    if x["col_peak"] < 1.13196087
                                                    else 406
                                                )
                                                if state == 405:
                                                    return -0.353025258
                                                if state == 406:
                                                    state = (
                                                        557
                                                        if x["col_last"] < 0.310891151
                                                        else 558
                                                    )
                                                    if state == 557:
                                                        return 0.271207064
                                                    if state == 558:
                                                        return -0.367372513
                                            if state == 286:
                                                return -0.400564075
                                        if state == 182:
                                            state = (
                                                287
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.344656)
                                                else 288
                                            )
                                            if state == 287:
                                                state = (
                                                    407
                                                    if x["col_peak"] < 0.744214118
                                                    else 408
                                                )
                                                if state == 407:
                                                    return 0.316248536
                                                if state == 408:
                                                    state = (
                                                        559
                                                        if x["col_last"] < -0.0513095856
                                                        else 560
                                                    )
                                                    if state == 559:
                                                        return 0.152510524
                                                    if state == 560:
                                                        return -0.012603391
                                            if state == 288:
                                                state = (
                                                    409
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.210179329)
                                                    else 410
                                                )
                                                if state == 409:
                                                    return -0.374658525
                                                if state == 410:
                                                    state = (
                                                        561
                                                        if x["col_last"] < 1.5383997
                                                        else 562
                                                    )
                                                    if state == 561:
                                                        return -0.201990142
                                                    if state == 562:
                                                        return 0.300578088
                                if state == 60:
                                    return -0.405824274
                            if state == 32:
                                state = 61 if x["distpsnr1_med"] < 1.28759384 else 62
                                if state == 61:
                                    state = (
                                        109
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.6930771)
                                        else 110
                                    )
                                    if state == 109:
                                        state = (
                                            183
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.1497002)
                                            else 184
                                        )
                                        if state == 183:
                                            return -0.319061965
                                        if state == 184:
                                            state = (
                                                289
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.5992813)
                                                else 290
                                            )
                                            if state == 289:
                                                state = (
                                                    411
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.0746531487)
                                                    else 412
                                                )
                                                if state == 411:
                                                    state = (
                                                        563
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.197388649)
                                                        else 564
                                                    )
                                                    if state == 563:
                                                        return -0.465355724
                                                    if state == 564:
                                                        return 0.173820034
                                                if state == 412:
                                                    return 0.240636781
                                            if state == 290:
                                                return 0.375937194
                                    if state == 110:
                                        return -0.388159245
                                if state == 62:
                                    state = (
                                        111
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.5410233)
                                        else 112
                                    )
                                    if state == 111:
                                        state = (
                                            185
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.6185989)
                                            else 186
                                        )
                                        if state == 185:
                                            return 0.292756677
                                        if state == 186:
                                            state = (
                                                291
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.0421429)
                                                else 292
                                            )
                                            if state == 291:
                                                return 0.245378494
                                            if state == 292:
                                                state = (
                                                    413
                                                    if x["col_peak"] < 1.61213398
                                                    else 414
                                                )
                                                if state == 413:
                                                    return 0.144485131
                                                if state == 414:
                                                    return -0.292062849
                                    if state == 112:
                                        return 0.361331612
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0222743005)
                            else 18
                        )
                        if state == 17:
                            state = (
                                33
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.792250037)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    63
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 4.55292749)
                                    else 64
                                )
                                if state == 63:
                                    return -0.376738757
                                if state == 64:
                                    return 0.756393611
                            if state == 34:
                                return -0.386563033
                        if state == 18:
                            return -0.433905512
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.6553249)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0415972471)
                            else 20
                        )
                        if state == 19:
                            state = (
                                35
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.98574996)
                                else 36
                            )
                            if state == 35:
                                state = 65 if x["distpsnr1_med"] < 0.345880806 else 66
                                if state == 65:
                                    return -0.382696301
                                if state == 66:
                                    state = (
                                        113
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.8334599)
                                        else 114
                                    )
                                    if state == 113:
                                        state = (
                                            187
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.9638367)
                                            else 188
                                        )
                                        if state == 187:
                                            return 0.397906184
                                        if state == 188:
                                            state = (
                                                293
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.4116669)
                                                else 294
                                            )
                                            if state == 293:
                                                return 0.287596375
                                            if state == 294:
                                                state = (
                                                    415
                                                    if x["col_peak"] < 0.813984931
                                                    else 416
                                                )
                                                if state == 415:
                                                    return 0.120318472
                                                if state == 416:
                                                    return -0.345028073
                                    if state == 114:
                                        state = (
                                            189
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.1283798)
                                            else 190
                                        )
                                        if state == 189:
                                            return -0.355766773
                                        if state == 190:
                                            state = (
                                                295
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.2335968)
                                                else 296
                                            )
                                            if state == 295:
                                                return 0.133747861
                                            if state == 296:
                                                return -0.0483627766
                            if state == 36:
                                return -0.337891221
                        if state == 20:
                            state = (
                                37
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.982749999)
                                else 38
                            )
                            if state == 37:
                                state = 67 if x["distpsnr1_med"] < 3.987396 else 68
                                if state == 67:
                                    state = (
                                        115
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.1577721)
                                        else 116
                                    )
                                    if state == 115:
                                        state = (
                                            191
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.2970505)
                                            else 192
                                        )
                                        if state == 191:
                                            state = (
                                                297
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.1056633)
                                                else 298
                                            )
                                            if state == 297:
                                                return -0.192257464
                                            if state == 298:
                                                return 0.214606464
                                        if state == 192:
                                            return -0.449084669
                                    if state == 116:
                                        return 0.200834423
                                if state == 68:
                                    return 0.297253072
                            if state == 38:
                                state = 69 if x["distpsnr1_med"] < 1.00806665 else 70
                                if state == 69:
                                    return -0.379753649
                                if state == 70:
                                    state = (
                                        117
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.3294258)
                                        else 118
                                    )
                                    if state == 117:
                                        return 0.386409849
                                    if state == 118:
                                        state = (
                                            193
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.3451004)
                                            else 194
                                        )
                                        if state == 193:
                                            state = (
                                                299
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.5611153)
                                                else 300
                                            )
                                            if state == 299:
                                                state = (
                                                    417
                                                    if x["col_peak"] < 1.1702013
                                                    else 418
                                                )
                                                if state == 417:
                                                    return 0.108056568
                                                if state == 418:
                                                    return -0.540669441
                                            if state == 300:
                                                state = (
                                                    419
                                                    if x["col_peak"] < 1.19884968
                                                    else 420
                                                )
                                                if state == 419:
                                                    return 0.178479552
                                                if state == 420:
                                                    return -0.278124064
                                        if state == 194:
                                            return 0.20678474
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0616551004)
                            else 22
                        )
                        if state == 21:
                            state = (
                                39
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.982249975)
                                else 40
                            )
                            if state == 39:
                                state = 71 if x["distpsnr1_med"] < 0.618775308 else 72
                                if state == 71:
                                    state = (
                                        119
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.5091591)
                                        else 120
                                    )
                                    if state == 119:
                                        state = (
                                            195
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.2047501)
                                            else 196
                                        )
                                        if state == 195:
                                            return -0.192799166
                                        if state == 196:
                                            return 0.127650142
                                    if state == 120:
                                        state = (
                                            197
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.5305157)
                                            else 198
                                        )
                                        if state == 197:
                                            return 0.337418616
                                        if state == 198:
                                            return -0.232435346
                                if state == 72:
                                    state = (
                                        121
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.4571419)
                                        else 122
                                    )
                                    if state == 121:
                                        state = (
                                            199
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.5024986)
                                            else 200
                                        )
                                        if state == 199:
                                            return 0.312798411
                                        if state == 200:
                                            state = (
                                                301
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.1638031)
                                                else 302
                                            )
                                            if state == 301:
                                                return -0.122613028
                                            if state == 302:
                                                return 0.167606801
                                    if state == 122:
                                        state = (
                                            201
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.1621513)
                                            else 202
                                        )
                                        if state == 201:
                                            return 0.360041618
                                        if state == 202:
                                            state = (
                                                303
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.6463776)
                                                else 304
                                            )
                                            if state == 303:
                                                return -0.387302548
                                            if state == 304:
                                                state = (
                                                    421
                                                    if x["col_peak"] < -0.166417122
                                                    else 422
                                                )
                                                if state == 421:
                                                    return -0.497475386
                                                if state == 422:
                                                    state = (
                                                        565
                                                        if x["col_last"] < 0.290770531
                                                        else 566
                                                    )
                                                    if state == 565:
                                                        return -0.280845463
                                                    if state == 566:
                                                        state = (
                                                            707
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.722392082
                                                            )
                                                            else 708
                                                        )
                                                        if state == 707:
                                                            return -0.0297661554
                                                        if state == 708:
                                                            return 0.256797254
                            if state == 40:
                                state = 73 if x["distpsnr1_med"] < 1.56118095 else 74
                                if state == 73:
                                    state = (
                                        123
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.497921)
                                        else 124
                                    )
                                    if state == 123:
                                        state = (
                                            203
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.1350498)
                                            else 204
                                        )
                                        if state == 203:
                                            return 0.345738232
                                        if state == 204:
                                            state = (
                                                305
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.6239719)
                                                else 306
                                            )
                                            if state == 305:
                                                return 0.144032985
                                            if state == 306:
                                                state = (
                                                    425
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.255545288)
                                                    else 426
                                                )
                                                if state == 425:
                                                    state = (
                                                        567
                                                        if x["col_last"] < -0.0795974731
                                                        else 568
                                                    )
                                                    if state == 567:
                                                        return 0.168508947
                                                    if state == 568:
                                                        return -0.906906009
                                                if state == 426:
                                                    return 0.125539199
                                    if state == 124:
                                        return 0.30824104
                                if state == 74:
                                    return 0.409285843
                        if state == 22:
                            state = (
                                41
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.980749965)
                                else 42
                            )
                            if state == 41:
                                state = 75 if x["distpsnr1_med"] < 0.541787565 else 76
                                if state == 75:
                                    state = (
                                        125
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.9533195)
                                        else 126
                                    )
                                    if state == 125:
                                        return 0.318502992
                                    if state == 126:
                                        state = (
                                            205
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.2949982)
                                            else 206
                                        )
                                        if state == 205:
                                            return -0.214717776
                                        if state == 206:
                                            return 0.128894359
                                if state == 76:
                                    state = (
                                        127
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.0787086)
                                        else 128
                                    )
                                    if state == 127:
                                        state = (
                                            207
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4570007)
                                            else 208
                                        )
                                        if state == 207:
                                            return -0.337599367
                                        if state == 208:
                                            state = (
                                                309
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.9291)
                                                else 310
                                            )
                                            if state == 309:
                                                return 0.206317663
                                            if state == 310:
                                                state = (
                                                    427
                                                    if x["col_peak"] < -0.0819635391
                                                    else 428
                                                )
                                                if state == 427:
                                                    return 0.170594215
                                                if state == 428:
                                                    return -0.280553669
                                    if state == 128:
                                        return 0.258794785
                            if state == 42:
                                state = (
                                    77
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 12.7693901)
                                    else 78
                                )
                                if state == 77:
                                    return 0.461387098
                                if state == 78:
                                    return -0.253801614
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.972249985)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 21.5060997)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.96706593)
                            else 24
                        )
                        if state == 23:
                            state = (
                                43
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.949499965)
                                else 44
                            )
                            if state == 43:
                                return -0.326508135
                            if state == 44:
                                state = 79 if x["distpsnr1_med"] < 2.58070898 else 80
                                if state == 79:
                                    state = (
                                        129
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.2370987)
                                        else 130
                                    )
                                    if state == 129:
                                        return 0.369241565
                                    if state == 130:
                                        return 0.775050819
                                if state == 80:
                                    return -0.343909383
                        if state == 24:
                            state = (
                                45
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.869750023)
                                else 46
                            )
                            if state == 45:
                                return -0.399334043
                            if state == 46:
                                state = (
                                    81
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 1.7797333)
                                    else 82
                                )
                                if state == 81:
                                    state = (
                                        131
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.8361511)
                                        else 132
                                    )
                                    if state == 131:
                                        state = (
                                            209
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.3423004)
                                            else 210
                                        )
                                        if state == 209:
                                            return -0.392712682
                                        if state == 210:
                                            state = (
                                                311
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.7692852)
                                                else 312
                                            )
                                            if state == 311:
                                                return 0.260146141
                                            if state == 312:
                                                state = (
                                                    429
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.273549378)
                                                    else 430
                                                )
                                                if state == 429:
                                                    state = (
                                                        569
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.099234581)
                                                        else 570
                                                    )
                                                    if state == 569:
                                                        state = (
                                                            709
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.0460662842
                                                            )
                                                            else 710
                                                        )
                                                        if state == 709:
                                                            return -0.0198162999
                                                        if state == 710:
                                                            return 0.2690579
                                                    if state == 570:
                                                        return -0.201315776
                                                if state == 430:
                                                    return -0.11610546
                                    if state == 132:
                                        state = (
                                            211
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4853001)
                                            else 212
                                        )
                                        if state == 211:
                                            state = (
                                                313
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.4392128)
                                                else 314
                                            )
                                            if state == 313:
                                                state = (
                                                    431
                                                    if x["col_peak"] < -0.0470409393
                                                    else 432
                                                )
                                                if state == 431:
                                                    return -0.339933962
                                                if state == 432:
                                                    state = (
                                                        571
                                                        if x["col_last"] < 0.0438820496
                                                        else 572
                                                    )
                                                    if state == 571:
                                                        state = (
                                                            711
                                                            if x["col_last"]
                                                            < 0.00678920746
                                                            else 712
                                                        )
                                                        if state == 711:
                                                            return -0.24455671
                                                        if state == 712:
                                                            return 0.375995457
                                                    if state == 572:
                                                        state = (
                                                            713
                                                            if x["col_last"]
                                                            < 0.593410492
                                                            else 714
                                                        )
                                                        if state == 713:
                                                            return -0.37509349
                                                        if state == 714:
                                                            return -0.21414946
                                            if state == 314:
                                                state = (
                                                    433
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.59724617)
                                                    else 434
                                                )
                                                if state == 433:
                                                    state = (
                                                        573
                                                        if x["col_last"] < 0.751927376
                                                        else 574
                                                    )
                                                    if state == 573:
                                                        return -0.400988817
                                                    if state == 574:
                                                        state = (
                                                            715
                                                            if x["col_last"]
                                                            < 0.851179123
                                                            else 716
                                                        )
                                                        if state == 715:
                                                            return -0.0933905244
                                                        if state == 716:
                                                            return -0.322699487
                                                if state == 434:
                                                    state = (
                                                        575
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.981536865)
                                                        else 576
                                                    )
                                                    if state == 575:
                                                        return -0.27615574
                                                    if state == 576:
                                                        return 0.237279758
                                        if state == 212:
                                            return -0.392478585
                                if state == 82:
                                    state = (
                                        133
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.9427643)
                                        else 134
                                    )
                                    if state == 133:
                                        state = (
                                            213
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.7537498)
                                            else 214
                                        )
                                        if state == 213:
                                            state = (
                                                315
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.9351482)
                                                else 316
                                            )
                                            if state == 315:
                                                state = (
                                                    435
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.210741043)
                                                    else 436
                                                )
                                                if state == 435:
                                                    state = (
                                                        577
                                                        if np.isnan(x["col_last"])
                                                        or (
                                                            x["col_last"]
                                                            < -0.0147352219
                                                        )
                                                        else 578
                                                    )
                                                    if state == 577:
                                                        return -0.553842008
                                                    if state == 578:
                                                        state = (
                                                            717
                                                            if x["col_last"]
                                                            < 0.0166897774
                                                            else 718
                                                        )
                                                        if state == 717:
                                                            return 0.133803532
                                                        if state == 718:
                                                            return -0.23812753
                                                if state == 436:
                                                    return 0.085960716
                                            if state == 316:
                                                return 0.135194063
                                        if state == 214:
                                            state = (
                                                317
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.5982399)
                                                else 318
                                            )
                                            if state == 317:
                                                return 0.413072526
                                            if state == 318:
                                                state = (
                                                    437
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.172501564)
                                                    else 438
                                                )
                                                if state == 437:
                                                    state = (
                                                        579
                                                        if x["col_last"] < -0.0600318909
                                                        else 580
                                                    )
                                                    if state == 579:
                                                        return -0.361806631
                                                    if state == 580:
                                                        state = (
                                                            719
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.133423805
                                                            )
                                                            else 720
                                                        )
                                                        if state == 719:
                                                            return 0.270909786
                                                        if state == 720:
                                                            return 0.0305588543
                                                if state == 438:
                                                    return -0.0858647898
                                    if state == 134:
                                        state = (
                                            215
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.2031002)
                                            else 216
                                        )
                                        if state == 215:
                                            state = (
                                                319
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.3229485)
                                                else 320
                                            )
                                            if state == 319:
                                                state = (
                                                    439
                                                    if x["col_peak"] < 1.95373249
                                                    else 440
                                                )
                                                if state == 439:
                                                    return -0.40587303
                                                if state == 440:
                                                    return 0.299678385
                                            if state == 320:
                                                state = (
                                                    441
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.224372715)
                                                    else 442
                                                )
                                                if state == 441:
                                                    return -0.0428263135
                                                if state == 442:
                                                    return 0.344866455
                                        if state == 216:
                                            state = (
                                                321
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6421738)
                                                else 322
                                            )
                                            if state == 321:
                                                state = (
                                                    443
                                                    if x["col_peak"] < 0.435436249
                                                    else 444
                                                )
                                                if state == 443:
                                                    return -0.406620413
                                                if state == 444:
                                                    state = (
                                                        581
                                                        if x["col_last"] < -0.132982254
                                                        else 582
                                                    )
                                                    if state == 581:
                                                        return -0.398685038
                                                    if state == 582:
                                                        state = (
                                                            721
                                                            if x["col_last"]
                                                            < -0.130684614
                                                            else 722
                                                        )
                                                        if state == 721:
                                                            return 0.359163195
                                                        if state == 722:
                                                            return -0.088931568
                                            if state == 322:
                                                state = (
                                                    445
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.599546432)
                                                    else 446
                                                )
                                                if state == 445:
                                                    state = (
                                                        583
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 1.01494122)
                                                        else 584
                                                    )
                                                    if state == 583:
                                                        state = (
                                                            723
                                                            if x["col_last"]
                                                            < -0.2006464
                                                            else 724
                                                        )
                                                        if state == 723:
                                                            return -0.112226218
                                                        if state == 724:
                                                            return -0.356918484
                                                    if state == 584:
                                                        state = (
                                                            725
                                                            if x["col_last"]
                                                            < 1.12201595
                                                            else 726
                                                        )
                                                        if state == 725:
                                                            return 0.172454134
                                                        if state == 726:
                                                            return -0.11118713
                                                if state == 446:
                                                    state = (
                                                        585
                                                        if x["col_last"] < 0.573979378
                                                        else 586
                                                    )
                                                    if state == 585:
                                                        return -0.149192452
                                                    if state == 586:
                                                        state = (
                                                            727
                                                            if x["col_last"]
                                                            < 0.79671669
                                                            else 728
                                                        )
                                                        if state == 727:
                                                            return 0.324192107
                                                        if state == 728:
                                                            return 0.116422884
                    if state == 12:
                        return 0.432945669
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.2420998)
                        else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 4.99370956)
                            else 26
                        )
                        if state == 25:
                            state = (
                                47
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.982749999)
                                else 48
                            )
                            if state == 47:
                                state = (
                                    83
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 1.44711828)
                                    else 84
                                )
                                if state == 83:
                                    state = (
                                        135
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.0580177)
                                        else 136
                                    )
                                    if state == 135:
                                        state = (
                                            217
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.1554489)
                                            else 218
                                        )
                                        if state == 217:
                                            state = (
                                                323
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 17.5194836)
                                                else 324
                                            )
                                            if state == 323:
                                                return -0.0151027534
                                            if state == 324:
                                                state = (
                                                    447
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.095020771)
                                                    else 448
                                                )
                                                if state == 447:
                                                    return -0.563088119
                                                if state == 448:
                                                    state = (
                                                        587
                                                        if x["col_last"] < 0.717968941
                                                        else 588
                                                    )
                                                    if state == 587:
                                                        return 0.0832518041
                                                    if state == 588:
                                                        return -0.220387518
                                        if state == 218:
                                            return 0.297640055
                                    if state == 136:
                                        state = (
                                            219
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.1678009)
                                            else 220
                                        )
                                        if state == 219:
                                            state = (
                                                325
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.1109104)
                                                else 326
                                            )
                                            if state == 325:
                                                return -0.0672591403
                                            if state == 326:
                                                state = (
                                                    449
                                                    if x["col_peak"] < 0.959668219
                                                    else 450
                                                )
                                                if state == 449:
                                                    return -0.452102005
                                                if state == 450:
                                                    return -0.0613794103
                                        if state == 220:
                                            return 0.280333966
                                if state == 84:
                                    state = (
                                        137
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.6149597)
                                        else 138
                                    )
                                    if state == 137:
                                        return 0.36674422
                                    if state == 138:
                                        state = (
                                            221
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.8452034)
                                            else 222
                                        )
                                        if state == 221:
                                            state = (
                                                327
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.3890152)
                                                else 328
                                            )
                                            if state == 327:
                                                state = (
                                                    451
                                                    if x["col_peak"] < -0.0747089386
                                                    else 452
                                                )
                                                if state == 451:
                                                    state = (
                                                        589
                                                        if x["col_last"] < 0.604552746
                                                        else 590
                                                    )
                                                    if state == 589:
                                                        return -0.217564642
                                                    if state == 590:
                                                        return 0.0445478112
                                                if state == 452:
                                                    state = (
                                                        591
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.334926784)
                                                        else 592
                                                    )
                                                    if state == 591:
                                                        return -0.721414566
                                                    if state == 592:
                                                        return 0.0753980204
                                            if state == 328:
                                                state = (
                                                    453
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.0949473381)
                                                    else 454
                                                )
                                                if state == 453:
                                                    state = (
                                                        593
                                                        if x["col_last"] < 0.182336807
                                                        else 594
                                                    )
                                                    if state == 593:
                                                        return -0.253051311
                                                    if state == 594:
                                                        return 0.20587863
                                                if state == 454:
                                                    return -0.444688767
                                        if state == 222:
                                            state = (
                                                329
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6812897)
                                                else 330
                                            )
                                            if state == 329:
                                                state = (
                                                    455
                                                    if x["col_peak"] < 0.136487961
                                                    else 456
                                                )
                                                if state == 455:
                                                    state = (
                                                        595
                                                        if x["col_last"] < 0.195548058
                                                        else 596
                                                    )
                                                    if state == 595:
                                                        return -0.137059674
                                                    if state == 596:
                                                        state = (
                                                            731
                                                            if x["col_last"]
                                                            < 2.61340427
                                                            else 732
                                                        )
                                                        if state == 731:
                                                            return 0.253960401
                                                        if state == 732:
                                                            return 0.102499329
                                                if state == 456:
                                                    return 0.392896473
                                            if state == 330:
                                                state = (
                                                    457
                                                    if x["col_peak"] < 0.136487961
                                                    else 458
                                                )
                                                if state == 457:
                                                    state = (
                                                        597
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.995941162)
                                                        else 598
                                                    )
                                                    if state == 597:
                                                        state = (
                                                            733
                                                            if x["col_last"]
                                                            < 0.931337357
                                                            else 734
                                                        )
                                                        if state == 733:
                                                            return 0.0202024188
                                                        if state == 734:
                                                            return -0.508033037
                                                    if state == 598:
                                                        return 0.135355979
                                                if state == 458:
                                                    return 0.343856215
                            if state == 48:
                                state = 85 if x["distpsnr1_med"] < 1.4366188 else 86
                                if state == 85:
                                    state = (
                                        139
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 17.4609947)
                                        else 140
                                    )
                                    if state == 139:
                                        state = (
                                            223
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 16.8537006)
                                            else 224
                                        )
                                        if state == 223:
                                            return -0.333478898
                                        if state == 224:
                                            state = (
                                                331
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 17.0988007)
                                                else 332
                                            )
                                            if state == 331:
                                                return 0.319501728
                                            if state == 332:
                                                state = (
                                                    459
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.368189335)
                                                    else 460
                                                )
                                                if state == 459:
                                                    state = (
                                                        599
                                                        if np.isnan(x["col_last"])
                                                        or (
                                                            x["col_last"]
                                                            < -0.0633749962
                                                        )
                                                        else 600
                                                    )
                                                    if state == 599:
                                                        return 0.0686608329
                                                    if state == 600:
                                                        return 0.283052653
                                                if state == 460:
                                                    return -0.151243165
                                    if state == 140:
                                        state = (
                                            225
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.6287498)
                                            else 226
                                        )
                                        if state == 225:
                                            state = (
                                                333
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 17.8045635)
                                                else 334
                                            )
                                            if state == 333:
                                                state = (
                                                    461
                                                    if x["col_peak"] < 0.451359898
                                                    else 462
                                                )
                                                if state == 461:
                                                    return -0.0133885108
                                                if state == 462:
                                                    return -0.239372149
                                            if state == 334:
                                                state = (
                                                    463
                                                    if x["col_peak"] < 0.0409607887
                                                    else 464
                                                )
                                                if state == 463:
                                                    return -0.107798465
                                                if state == 464:
                                                    state = (
                                                        605
                                                        if x["col_last"] < -0.064438343
                                                        else 606
                                                    )
                                                    if state == 605:
                                                        return -0.200606406
                                                    if state == 606:
                                                        return -0.925245285
                                        if state == 226:
                                            state = (
                                                335
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.005394)
                                                else 336
                                            )
                                            if state == 335:
                                                state = (
                                                    465
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.163058758)
                                                    else 466
                                                )
                                                if state == 465:
                                                    return 0.365960509
                                                if state == 466:
                                                    return -0.371934503
                                            if state == 336:
                                                state = (
                                                    467
                                                    if x["col_peak"] < 0.362073004
                                                    else 468
                                                )
                                                if state == 467:
                                                    return -0.227192625
                                                if state == 468:
                                                    return 0.203804508
                                if state == 86:
                                    state = (
                                        141
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.1327496)
                                        else 142
                                    )
                                    if state == 141:
                                        state = (
                                            227
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.3190022)
                                            else 228
                                        )
                                        if state == 227:
                                            state = (
                                                337
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 17.2122955)
                                                else 338
                                            )
                                            if state == 337:
                                                return 0.268069774
                                            if state == 338:
                                                state = (
                                                    471
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.196686745)
                                                    else 472
                                                )
                                                if state == 471:
                                                    return -0.457154214
                                                if state == 472:
                                                    state = (
                                                        609
                                                        if x["col_last"] < 0.0491600037
                                                        else 610
                                                    )
                                                    if state == 609:
                                                        return -0.16018416
                                                    if state == 610:
                                                        return 0.0497976579
                                        if state == 228:
                                            state = (
                                                339
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.7346115)
                                                else 340
                                            )
                                            if state == 339:
                                                state = (
                                                    473
                                                    if x["col_peak"] < -0.343474388
                                                    else 474
                                                )
                                                if state == 473:
                                                    return -0.159899861
                                                if state == 474:
                                                    state = (
                                                        611
                                                        if x["col_last"] < -0.139627457
                                                        else 612
                                                    )
                                                    if state == 611:
                                                        state = (
                                                            737
                                                            if x["col_last"]
                                                            < -0.237499237
                                                            else 738
                                                        )
                                                        if state == 737:
                                                            return -0.0753093138
                                                        if state == 738:
                                                            return 0.0812893957
                                                    if state == 612:
                                                        state = (
                                                            739
                                                            if x["col_last"]
                                                            < 0.319250107
                                                            else 740
                                                        )
                                                        if state == 739:
                                                            return 0.275243908
                                                        if state == 740:
                                                            return 0.392839909
                                            if state == 340:
                                                state = (
                                                    475
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.127639294)
                                                    else 476
                                                )
                                                if state == 475:
                                                    return 0.206158698
                                                if state == 476:
                                                    state = (
                                                        613
                                                        if x["col_last"] < 2.76520824
                                                        else 614
                                                    )
                                                    if state == 613:
                                                        return 0.163924485
                                                    if state == 614:
                                                        return -0.0593667403
                                    if state == 142:
                                        state = (
                                            229
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.8686485)
                                            else 230
                                        )
                                        if state == 229:
                                            return -0.189663649
                                        if state == 230:
                                            state = (
                                                341
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.4269428)
                                                else 342
                                            )
                                            if state == 341:
                                                return -0.0500803553
                                            if state == 342:
                                                return 0.120512202
                        if state == 26:
                            state = (
                                49
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.980749965)
                                else 50
                            )
                            if state == 49:
                                state = 87 if x["distpsnr1_med"] < 0.151058808 else 88
                                if state == 87:
                                    return 0.531113386
                                if state == 88:
                                    state = (
                                        143
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.8288288)
                                        else 144
                                    )
                                    if state == 143:
                                        state = (
                                            231
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.208149)
                                            else 232
                                        )
                                        if state == 231:
                                            state = (
                                                343
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6261368)
                                                else 344
                                            )
                                            if state == 343:
                                                state = (
                                                    477
                                                    if x["col_peak"] < 0.358683586
                                                    else 478
                                                )
                                                if state == 477:
                                                    state = (
                                                        615
                                                        if x["col_last"] < 0.163695961
                                                        else 616
                                                    )
                                                    if state == 615:
                                                        return -0.331428736
                                                    if state == 616:
                                                        state = (
                                                            741
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.785039902
                                                            )
                                                            else 742
                                                        )
                                                        if state == 741:
                                                            return 0.147736385
                                                        if state == 742:
                                                            return -0.274439067
                                                if state == 478:
                                                    state = (
                                                        617
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.317923546)
                                                        else 618
                                                    )
                                                    if state == 617:
                                                        state = (
                                                            743
                                                            if x["col_last"]
                                                            < 0.101553917
                                                            else 744
                                                        )
                                                        if state == 743:
                                                            return -0.408773124
                                                        if state == 744:
                                                            return -0.137873486
                                                    if state == 618:
                                                        state = (
                                                            745
                                                            if x["col_last"]
                                                            < 0.745279312
                                                            else 746
                                                        )
                                                        if state == 745:
                                                            return 0.269904673
                                                        if state == 746:
                                                            return -0.214474693
                                            if state == 344:
                                                state = (
                                                    479
                                                    if x["col_peak"] < -0.294668198
                                                    else 480
                                                )
                                                if state == 479:
                                                    return 0.0132004889
                                                if state == 480:
                                                    state = (
                                                        619
                                                        if x["col_last"] < 0.357910156
                                                        else 620
                                                    )
                                                    if state == 619:
                                                        state = (
                                                            747
                                                            if x["col_last"]
                                                            < 0.174368858
                                                            else 748
                                                        )
                                                        if state == 747:
                                                            return -0.102265321
                                                        if state == 748:
                                                            return 0.112374283
                                                    if state == 620:
                                                        return -0.324792802
                                        if state == 232:
                                            return 0.344237626
                                    if state == 144:
                                        state = (
                                            233
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.9215508)
                                            else 234
                                        )
                                        if state == 233:
                                            return 0.400140554
                                        if state == 234:
                                            state = (
                                                345
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.8754959)
                                                else 346
                                            )
                                            if state == 345:
                                                return 0.412242889
                                            if state == 346:
                                                state = (
                                                    481
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.271914482)
                                                    else 482
                                                )
                                                if state == 481:
                                                    state = (
                                                        621
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.552473068)
                                                        else 622
                                                    )
                                                    if state == 621:
                                                        return 0.276526362
                                                    if state == 622:
                                                        return -0.194689184
                                                if state == 482:
                                                    return -0.329197884
                            if state == 50:
                                state = 89 if x["distpsnr1_med"] < 0.23741807 else 90
                                if state == 89:
                                    state = (
                                        145
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.4213696)
                                        else 146
                                    )
                                    if state == 145:
                                        state = (
                                            235
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.90065)
                                            else 236
                                        )
                                        if state == 235:
                                            state = (
                                                347
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.7823658)
                                                else 348
                                            )
                                            if state == 347:
                                                state = (
                                                    483
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.229337692)
                                                    else 484
                                                )
                                                if state == 483:
                                                    return -0.165726379
                                                if state == 484:
                                                    return 0.180132508
                                            if state == 348:
                                                state = (
                                                    485
                                                    if x["col_peak"] < 0.101271629
                                                    else 486
                                                )
                                                if state == 485:
                                                    return -0.240484342
                                                if state == 486:
                                                    state = (
                                                        625
                                                        if x["col_last"] < 0.682361603
                                                        else 626
                                                    )
                                                    if state == 625:
                                                        return -0.0146867801
                                                    if state == 626:
                                                        return 0.390257955
                                        if state == 236:
                                            return -0.438911527
                                    if state == 146:
                                        state = (
                                            237
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.9051514)
                                            else 238
                                        )
                                        if state == 237:
                                            return 0.371499926
                                        if state == 238:
                                            return -0.260981411
                                if state == 90:
                                    state = (
                                        147
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.5578556)
                                        else 148
                                    )
                                    if state == 147:
                                        state = (
                                            239
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.9275513)
                                            else 240
                                        )
                                        if state == 239:
                                            state = (
                                                349
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.9353714)
                                                else 350
                                            )
                                            if state == 349:
                                                state = (
                                                    487
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.110072136)
                                                    else 488
                                                )
                                                if state == 487:
                                                    state = (
                                                        627
                                                        if x["col_last"] < -0.196690083
                                                        else 628
                                                    )
                                                    if state == 627:
                                                        return -0.125958934
                                                    if state == 628:
                                                        return 0.31637603
                                                if state == 488:
                                                    state = (
                                                        629
                                                        if x["col_last"] < 1.10975647
                                                        else 630
                                                    )
                                                    if state == 629:
                                                        state = (
                                                            753
                                                            if x["col_last"]
                                                            < 0.779605865
                                                            else 754
                                                        )
                                                        if state == 753:
                                                            return 0.156893477
                                                        if state == 754:
                                                            return -0.246104538
                                                    if state == 630:
                                                        return 0.263360798
                                            if state == 350:
                                                state = (
                                                    489
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.0989131927)
                                                    else 490
                                                )
                                                if state == 489:
                                                    state = (
                                                        631
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.46421051)
                                                        else 632
                                                    )
                                                    if state == 631:
                                                        return -0.258179903
                                                    if state == 632:
                                                        return 0.173460394
                                                if state == 490:
                                                    state = (
                                                        633
                                                        if x["col_last"] < 0.554615498
                                                        else 634
                                                    )
                                                    if state == 633:
                                                        return -0.041049514
                                                    if state == 634:
                                                        return 0.291628152
                                        if state == 240:
                                            state = (
                                                351
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.5532074)
                                                else 352
                                            )
                                            if state == 351:
                                                state = (
                                                    491
                                                    if x["col_peak"] < -0.287260532
                                                    else 492
                                                )
                                                if state == 491:
                                                    state = (
                                                        635
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.12992382)
                                                        else 636
                                                    )
                                                    if state == 635:
                                                        return -0.204572961
                                                    if state == 636:
                                                        return 0.149741456
                                                if state == 492:
                                                    state = (
                                                        637
                                                        if x["col_last"] < 0.111094952
                                                        else 638
                                                    )
                                                    if state == 637:
                                                        state = (
                                                            755
                                                            if x["col_last"]
                                                            < 0.0911531448
                                                            else 756
                                                        )
                                                        if state == 755:
                                                            return 0.301739752
                                                        if state == 756:
                                                            return -0.0592952333
                                                    if state == 638:
                                                        return 0.346062541
                                            if state == 352:
                                                return -0.13469471
                                    if state == 148:
                                        state = (
                                            241
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.9095001)
                                            else 242
                                        )
                                        if state == 241:
                                            state = (
                                                353
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.0610275)
                                                else 354
                                            )
                                            if state == 353:
                                                state = (
                                                    493
                                                    if x["col_peak"] < 2.31750774
                                                    else 494
                                                )
                                                if state == 493:
                                                    return 0.23769699
                                                if state == 494:
                                                    return -0.108252607
                                            if state == 354:
                                                state = (
                                                    495
                                                    if x["col_peak"] < -0.156159401
                                                    else 496
                                                )
                                                if state == 495:
                                                    return 0.131866872
                                                if state == 496:
                                                    return -0.256758153
                                        if state == 242:
                                            return 0.377332807
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.99327564)
                            else 28
                        )
                        if state == 27:
                            state = (
                                51
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.980749965)
                                else 52
                            )
                            if state == 51:
                                state = 91 if x["distpsnr1_med"] < 0.342260122 else 92
                                if state == 91:
                                    state = (
                                        149
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.4765663)
                                        else 150
                                    )
                                    if state == 149:
                                        state = (
                                            243
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.5178833)
                                            else 244
                                        )
                                        if state == 243:
                                            return 0.0593498535
                                        if state == 244:
                                            return -0.415316403
                                    if state == 150:
                                        state = (
                                            245
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.7552986)
                                            else 246
                                        )
                                        if state == 245:
                                            state = (
                                                355
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.355072)
                                                else 356
                                            )
                                            if state == 355:
                                                state = (
                                                    497
                                                    if x["col_peak"] < -0.237668991
                                                    else 498
                                                )
                                                if state == 497:
                                                    return 0.116571434
                                                if state == 498:
                                                    state = (
                                                        639
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.923864365)
                                                        else 640
                                                    )
                                                    if state == 639:
                                                        return -0.380647957
                                                    if state == 640:
                                                        return 0.147800282
                                            if state == 356:
                                                return 0.153924078
                                        if state == 246:
                                            state = (
                                                357
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.8155804)
                                                else 358
                                            )
                                            if state == 357:
                                                state = (
                                                    499
                                                    if x["col_peak"] < 0.298157752
                                                    else 500
                                                )
                                                if state == 499:
                                                    return -0.121220052
                                                if state == 500:
                                                    return 0.361686617
                                            if state == 358:
                                                return 0.0265002102
                                if state == 92:
                                    state = (
                                        151
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.1747913)
                                        else 152
                                    )
                                    if state == 151:
                                        state = (
                                            247
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.5020008)
                                            else 248
                                        )
                                        if state == 247:
                                            state = (
                                                359
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.9616318)
                                                else 360
                                            )
                                            if state == 359:
                                                return 0.382935971
                                            if state == 360:
                                                state = (
                                                    501
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.110961914)
                                                    else 502
                                                )
                                                if state == 501:
                                                    state = (
                                                        641
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.926440716)
                                                        else 642
                                                    )
                                                    if state == 641:
                                                        state = (
                                                            757
                                                            if x["col_last"]
                                                            < 0.141095161
                                                            else 758
                                                        )
                                                        if state == 757:
                                                            return 0.320126861
                                                        if state == 758:
                                                            return 0.194696441
                                                    if state == 642:
                                                        return -0.0970231295
                                                if state == 502:
                                                    state = (
                                                        643
                                                        if x["col_last"] < 0.824161053
                                                        else 644
                                                    )
                                                    if state == 643:
                                                        return 0.183906302
                                                    if state == 644:
                                                        return -0.223279655
                                        if state == 248:
                                            state = (
                                                361
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.7089462)
                                                else 362
                                            )
                                            if state == 361:
                                                state = (
                                                    503
                                                    if x["col_peak"] < 0.372275412
                                                    else 504
                                                )
                                                if state == 503:
                                                    return -0.45792082
                                                if state == 504:
                                                    state = (
                                                        645
                                                        if x["col_last"] < -0.178904533
                                                        else 646
                                                    )
                                                    if state == 645:
                                                        return 0.300281525
                                                    if state == 646:
                                                        state = (
                                                            759
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.0227546692
                                                            )
                                                            else 760
                                                        )
                                                        if state == 759:
                                                            return -0.444481075
                                                        if state == 760:
                                                            return 0.0140804779
                                            if state == 362:
                                                state = (
                                                    505
                                                    if x["col_peak"] < 0.405023098
                                                    else 506
                                                )
                                                if state == 505:
                                                    return -0.379221231
                                                if state == 506:
                                                    state = (
                                                        647
                                                        if np.isnan(x["col_last"])
                                                        or (
                                                            x["col_last"] < -0.138950825
                                                        )
                                                        else 648
                                                    )
                                                    if state == 647:
                                                        return 0.249925971
                                                    if state == 648:
                                                        state = (
                                                            761
                                                            if x["col_last"]
                                                            < 0.196287155
                                                            else 762
                                                        )
                                                        if state == 761:
                                                            return -0.359529614
                                                        if state == 762:
                                                            return 0.319113195
                                    if state == 152:
                                        state = (
                                            249
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.8889999)
                                            else 250
                                        )
                                        if state == 249:
                                            state = (
                                                363
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.045969)
                                                else 364
                                            )
                                            if state == 363:
                                                state = (
                                                    507
                                                    if x["col_peak"] < -0.0981426239
                                                    else 508
                                                )
                                                if state == 507:
                                                    return -0.510089576
                                                if state == 508:
                                                    state = (
                                                        649
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.284479797)
                                                        else 650
                                                    )
                                                    if state == 649:
                                                        state = (
                                                            763
                                                            if x["col_last"]
                                                            < -0.0813040137
                                                            else 764
                                                        )
                                                        if state == 763:
                                                            return 0.32102567
                                                        if state == 764:
                                                            return -0.0199090894
                                                    if state == 650:
                                                        state = (
                                                            765
                                                            if x["col_last"]
                                                            < 0.539924145
                                                            else 766
                                                        )
                                                        if state == 765:
                                                            return 0.337907463
                                                        if state == 766:
                                                            return 0.0148814963
                                            if state == 364:
                                                state = (
                                                    509
                                                    if x["col_peak"] < 0.102209091
                                                    else 510
                                                )
                                                if state == 509:
                                                    state = (
                                                        651
                                                        if x["col_last"] < 0.617566109
                                                        else 652
                                                    )
                                                    if state == 651:
                                                        return 0.0185658224
                                                    if state == 652:
                                                        return 0.311973989
                                                if state == 510:
                                                    state = (
                                                        653
                                                        if x["col_last"] < 0.803850174
                                                        else 654
                                                    )
                                                    if state == 653:
                                                        return -0.29079324
                                                    if state == 654:
                                                        return 0.106587701
                                        if state == 250:
                                            state = (
                                                365
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.4846916)
                                                else 366
                                            )
                                            if state == 365:
                                                state = (
                                                    511
                                                    if x["col_peak"] < 0.699084342
                                                    else 512
                                                )
                                                if state == 511:
                                                    return 0.207686633
                                                if state == 512:
                                                    state = (
                                                        655
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.17487812)
                                                        else 656
                                                    )
                                                    if state == 655:
                                                        state = (
                                                            767
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.201112598
                                                            )
                                                            else 768
                                                        )
                                                        if state == 767:
                                                            return 0.0210683551
                                                        if state == 768:
                                                            return -0.170858353
                                                    if state == 656:
                                                        return 0.351490796
                                            if state == 366:
                                                return 0.349542379
                            if state == 52:
                                state = 93 if x["distpsnr1_med"] < 0.273624271 else 94
                                if state == 93:
                                    state = (
                                        153
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.1257668)
                                        else 154
                                    )
                                    if state == 153:
                                        state = (
                                            251
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.6352997)
                                            else 252
                                        )
                                        if state == 251:
                                            return 0.261788189
                                        if state == 252:
                                            return -0.386905968
                                    if state == 154:
                                        state = (
                                            253
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.4582996)
                                            else 254
                                        )
                                        if state == 253:
                                            return 0.292536378
                                        if state == 254:
                                            state = (
                                                367
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.3600731)
                                                else 368
                                            )
                                            if state == 367:
                                                return -0.162519738
                                            if state == 368:
                                                return 0.0779102743
                                if state == 94:
                                    state = (
                                        155
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.2736435)
                                        else 156
                                    )
                                    if state == 155:
                                        return 0.417024881
                                    if state == 156:
                                        state = (
                                            255
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.5301991)
                                            else 256
                                        )
                                        if state == 255:
                                            state = (
                                                369
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.8180733)
                                                else 370
                                            )
                                            if state == 369:
                                                state = (
                                                    513
                                                    if x["col_peak"] < 0.692414343
                                                    else 514
                                                )
                                                if state == 513:
                                                    return 0.259097725
                                                if state == 514:
                                                    state = (
                                                        657
                                                        if np.isnan(x["col_last"])
                                                        or (
                                                            x["col_last"] < 0.0942306519
                                                        )
                                                        else 658
                                                    )
                                                    if state == 657:
                                                        state = (
                                                            769
                                                            if x["col_last"]
                                                            < -0.00336647034
                                                            else 770
                                                        )
                                                        if state == 769:
                                                            return 0.000684781175
                                                        if state == 770:
                                                            return -0.359494984
                                                    if state == 658:
                                                        return 0.222454533
                                            if state == 370:
                                                state = (
                                                    515
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.00798797607)
                                                    else 516
                                                )
                                                if state == 515:
                                                    return 0.334394336
                                                if state == 516:
                                                    state = (
                                                        659
                                                        if x["col_last"] < 2.57809353
                                                        else 660
                                                    )
                                                    if state == 659:
                                                        return 0.221602097
                                                    if state == 660:
                                                        return 0.0288552288
                                        if state == 256:
                                            state = (
                                                371
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.9959221)
                                                else 372
                                            )
                                            if state == 371:
                                                return 0.382971227
                                            if state == 372:
                                                state = (
                                                    517
                                                    if x["col_peak"] < -0.246558189
                                                    else 518
                                                )
                                                if state == 517:
                                                    return -0.366568059
                                                if state == 518:
                                                    state = (
                                                        661
                                                        if x["col_last"] < -0.0522937775
                                                        else 662
                                                    )
                                                    if state == 661:
                                                        return -0.268690825
                                                    if state == 662:
                                                        state = (
                                                            771
                                                            if x["col_last"]
                                                            < 0.0646047592
                                                            else 772
                                                        )
                                                        if state == 771:
                                                            return 0.0699788108
                                                        if state == 772:
                                                            return 0.35053587
                        if state == 28:
                            state = (
                                53
                                if np.isnan(x["classtar_med"])
                                or (x["classtar_med"] < 0.981750011)
                                else 54
                            )
                            if state == 53:
                                state = (
                                    95
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 4.58741093)
                                    else 96
                                )
                                if state == 95:
                                    state = (
                                        157
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.7834282)
                                        else 158
                                    )
                                    if state == 157:
                                        state = (
                                            257
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.5332489)
                                            else 258
                                        )
                                        if state == 257:
                                            state = (
                                                373
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.2751369)
                                                else 374
                                            )
                                            if state == 373:
                                                state = (
                                                    519
                                                    if x["col_peak"] < 0.155407429
                                                    else 520
                                                )
                                                if state == 519:
                                                    return -0.0179378204
                                                if state == 520:
                                                    state = (
                                                        663
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.428670406)
                                                        else 664
                                                    )
                                                    if state == 663:
                                                        return 0.284465879
                                                    if state == 664:
                                                        return -0.0546482541
                                            if state == 374:
                                                state = (
                                                    521
                                                    if x["col_peak"] < 0.457659245
                                                    else 522
                                                )
                                                if state == 521:
                                                    return -0.325279385
                                                if state == 522:
                                                    state = (
                                                        665
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.206634521)
                                                        else 666
                                                    )
                                                    if state == 665:
                                                        state = (
                                                            773
                                                            if x["col_last"]
                                                            < 0.412495673
                                                            else 774
                                                        )
                                                        if state == 773:
                                                            return -0.321078062
                                                        if state == 774:
                                                            return -0.129512146
                                                    if state == 666:
                                                        return 0.103444129
                                        if state == 258:
                                            state = (
                                                375
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 17.9500408)
                                                else 376
                                            )
                                            if state == 375:
                                                return 0.0142706018
                                            if state == 376:
                                                state = (
                                                    523
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.193566799)
                                                    else 524
                                                )
                                                if state == 523:
                                                    state = (
                                                        667
                                                        if x["col_last"] < 0.01014328
                                                        else 668
                                                    )
                                                    if state == 667:
                                                        return 0.396154493
                                                    if state == 668:
                                                        state = (
                                                            775
                                                            if x["col_last"]
                                                            < 0.199751377
                                                            else 776
                                                        )
                                                        if state == 775:
                                                            return 0.0107513703
                                                        if state == 776:
                                                            return 0.292266399
                                                if state == 524:
                                                    state = (
                                                        669
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.554603577)
                                                        else 670
                                                    )
                                                    if state == 669:
                                                        return -0.0963189155
                                                    if state == 670:
                                                        return 0.169784129
                                    if state == 158:
                                        state = (
                                            259
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.2751007)
                                            else 260
                                        )
                                        if state == 259:
                                            state = (
                                                377
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.0937729)
                                                else 378
                                            )
                                            if state == 377:
                                                state = (
                                                    525
                                                    if x["col_peak"] < 0.180821463
                                                    else 526
                                                )
                                                if state == 525:
                                                    return 0.101902522
                                                if state == 526:
                                                    state = (
                                                        671
                                                        if x["col_last"] < 0.45924902
                                                        else 672
                                                    )
                                                    if state == 671:
                                                        return -0.402781248
                                                    if state == 672:
                                                        return 0.282603621
                                            if state == 378:
                                                state = (
                                                    527
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.0999193192)
                                                    else 528
                                                )
                                                if state == 527:
                                                    return 0.390921533
                                                if state == 528:
                                                    return -0.46787104
                                        if state == 260:
                                            state = (
                                                379
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.8372574)
                                                else 380
                                            )
                                            if state == 379:
                                                state = (
                                                    529
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.492320061)
                                                    else 530
                                                )
                                                if state == 529:
                                                    state = (
                                                        673
                                                        if x["col_last"] < 0.0471162796
                                                        else 674
                                                    )
                                                    if state == 673:
                                                        state = (
                                                            779
                                                            if x["col_last"]
                                                            < -0.102609634
                                                            else 780
                                                        )
                                                        if state == 779:
                                                            return -0.0758159384
                                                        if state == 780:
                                                            return -0.354088396
                                                    if state == 674:
                                                        state = (
                                                            781
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 1.01768589
                                                            )
                                                            else 782
                                                        )
                                                        if state == 781:
                                                            return -0.0904131979
                                                        if state == 782:
                                                            return -0.34233433
                                                if state == 530:
                                                    return 0.324648708
                                            if state == 380:
                                                state = (
                                                    531
                                                    if x["col_peak"] < 0.140612602
                                                    else 532
                                                )
                                                if state == 531:
                                                    state = (
                                                        675
                                                        if x["col_last"] < 0.455459595
                                                        else 676
                                                    )
                                                    if state == 675:
                                                        return -0.293016821
                                                    if state == 676:
                                                        state = (
                                                            783
                                                            if x["col_last"]
                                                            < 0.496584892
                                                            else 784
                                                        )
                                                        if state == 783:
                                                            return 0.122026064
                                                        if state == 784:
                                                            return -0.0756819248
                                                if state == 532:
                                                    state = (
                                                        677
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.96325016)
                                                        else 678
                                                    )
                                                    if state == 677:
                                                        state = (
                                                            785
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.863948822
                                                            )
                                                            else 786
                                                        )
                                                        if state == 785:
                                                            return 0.068611756
                                                        if state == 786:
                                                            return -0.303449273
                                                    if state == 678:
                                                        return 0.34410584
                                if state == 96:
                                    state = (
                                        159
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.3517723)
                                        else 160
                                    )
                                    if state == 159:
                                        state = (
                                            261
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.5767517)
                                            else 262
                                        )
                                        if state == 261:
                                            state = (
                                                381
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.8292198)
                                                else 382
                                            )
                                            if state == 381:
                                                return -0.717507362
                                            if state == 382:
                                                state = (
                                                    533
                                                    if x["col_peak"] < 0.10654211
                                                    else 534
                                                )
                                                if state == 533:
                                                    return -0.420778364
                                                if state == 534:
                                                    state = (
                                                        679
                                                        if x["col_last"] < 0.0932950974
                                                        else 680
                                                    )
                                                    if state == 679:
                                                        state = (
                                                            787
                                                            if x["col_last"]
                                                            < -0.113300323
                                                            else 788
                                                        )
                                                        if state == 787:
                                                            return 0.184537351
                                                        if state == 788:
                                                            return -0.325145572
                                                    if state == 680:
                                                        state = (
                                                            789
                                                            if x["col_last"] < 0.428195
                                                            else 790
                                                        )
                                                        if state == 789:
                                                            return 0.308325022
                                                        if state == 790:
                                                            return -0.0126574263
                                        if state == 262:
                                            state = (
                                                383
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.2959976)
                                                else 384
                                            )
                                            if state == 383:
                                                state = (
                                                    535
                                                    if x["col_peak"] < -0.136003494
                                                    else 536
                                                )
                                                if state == 535:
                                                    return 0.14630568
                                                if state == 536:
                                                    state = (
                                                        681
                                                        if np.isnan(x["col_last"])
                                                        or (
                                                            x["col_last"] < 0.0730905533
                                                        )
                                                        else 682
                                                    )
                                                    if state == 681:
                                                        state = (
                                                            791
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.148326874
                                                            )
                                                            else 792
                                                        )
                                                        if state == 791:
                                                            return -0.1213625
                                                        if state == 792:
                                                            return -0.608007491
                                                    if state == 682:
                                                        return 0.121523201
                                            if state == 384:
                                                state = (
                                                    537
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.152352333)
                                                    else 538
                                                )
                                                if state == 537:
                                                    state = (
                                                        683
                                                        if x["col_last"] < -0.0885562897
                                                        else 684
                                                    )
                                                    if state == 683:
                                                        return 0.503414869
                                                    if state == 684:
                                                        state = (
                                                            793
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.0965709686
                                                            )
                                                            else 794
                                                        )
                                                        if state == 793:
                                                            return 0.047239434
                                                        if state == 794:
                                                            return -0.255824208
                                                if state == 538:
                                                    state = (
                                                        685
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.673724174)
                                                        else 686
                                                    )
                                                    if state == 685:
                                                        state = (
                                                            795
                                                            if x["col_last"]
                                                            < 1.28189564
                                                            else 796
                                                        )
                                                        if state == 795:
                                                            return -0.343607098
                                                        if state == 796:
                                                            return -0.0918324739
                                                    if state == 686:
                                                        return 0.144700244
                                    if state == 160:
                                        state = (
                                            263
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.7175503)
                                            else 264
                                        )
                                        if state == 263:
                                            state = (
                                                385
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.6723614)
                                                else 386
                                            )
                                            if state == 385:
                                                state = (
                                                    539
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.119727135)
                                                    else 540
                                                )
                                                if state == 539:
                                                    return -0.471908152
                                                if state == 540:
                                                    state = (
                                                        687
                                                        if x["col_last"] < 0.410441399
                                                        else 688
                                                    )
                                                    if state == 687:
                                                        return 0.131884649
                                                    if state == 688:
                                                        return -0.341233343
                                            if state == 386:
                                                state = (
                                                    541
                                                    if x["col_peak"] < -0.0852165222
                                                    else 542
                                                )
                                                if state == 541:
                                                    state = (
                                                        689
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.877818108)
                                                        else 690
                                                    )
                                                    if state == 689:
                                                        state = (
                                                            797
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.604129791
                                                            )
                                                            else 798
                                                        )
                                                        if state == 797:
                                                            return 0.0281598363
                                                        if state == 798:
                                                            return 0.185409397
                                                    if state == 690:
                                                        return -0.166876808
                                                if state == 542:
                                                    state = (
                                                        691
                                                        if x["col_last"] < 0.472703934
                                                        else 692
                                                    )
                                                    if state == 691:
                                                        state = (
                                                            799
                                                            if x["col_last"]
                                                            < 0.43393898
                                                            else 800
                                                        )
                                                        if state == 799:
                                                            return -0.108841002
                                                        if state == 800:
                                                            return 0.234682009
                                                    if state == 692:
                                                        return -0.416948646
                                        if state == 264:
                                            state = (
                                                387
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 20.0265045)
                                                else 388
                                            )
                                            if state == 387:
                                                state = (
                                                    543
                                                    if x["col_peak"] < 0.0882501602
                                                    else 544
                                                )
                                                if state == 543:
                                                    return 0.279737175
                                                if state == 544:
                                                    state = (
                                                        693
                                                        if x["col_last"] < 2.28189564
                                                        else 694
                                                    )
                                                    if state == 693:
                                                        return 0.130358681
                                                    if state == 694:
                                                        return -0.0667047575
                                            if state == 388:
                                                return -0.0117788613
                            if state == 54:
                                state = (
                                    97
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 0.178033948)
                                    else 98
                                )
                                if state == 97:
                                    state = (
                                        161
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.3131676)
                                        else 162
                                    )
                                    if state == 161:
                                        state = (
                                            265
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.0632)
                                            else 266
                                        )
                                        if state == 265:
                                            state = (
                                                389
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 17.8520393)
                                                else 390
                                            )
                                            if state == 389:
                                                return -0.238653824
                                            if state == 390:
                                                state = (
                                                    545
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.139006615)
                                                    else 546
                                                )
                                                if state == 545:
                                                    return 0.070974119
                                                if state == 546:
                                                    return -0.128285602
                                        if state == 266:
                                            state = (
                                                391
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.1705933)
                                                else 392
                                            )
                                            if state == 391:
                                                return 0.046580527
                                            if state == 392:
                                                return 0.342756867
                                    if state == 162:
                                        state = (
                                            267
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.9584007)
                                            else 268
                                        )
                                        if state == 267:
                                            return -0.33065027
                                        if state == 268:
                                            return 0.322593808
                                if state == 98:
                                    state = (
                                        163
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.6242065)
                                        else 164
                                    )
                                    if state == 163:
                                        state = (
                                            269
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.5799503)
                                            else 270
                                        )
                                        if state == 269:
                                            state = (
                                                393
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 16.796669)
                                                else 394
                                            )
                                            if state == 393:
                                                return -0.472603053
                                            if state == 394:
                                                state = (
                                                    547
                                                    if x["col_peak"] < 0.0410480499
                                                    else 548
                                                )
                                                if state == 547:
                                                    return 0.358005643
                                                if state == 548:
                                                    state = (
                                                        697
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.408016205)
                                                        else 698
                                                    )
                                                    if state == 697:
                                                        state = (
                                                            801
                                                            if x["col_last"]
                                                            < 0.0773181915
                                                            else 802
                                                        )
                                                        if state == 801:
                                                            return 0.372038394
                                                        if state == 802:
                                                            return 0.118054643
                                                    if state == 698:
                                                        state = (
                                                            803
                                                            if x["col_last"]
                                                            < 1.42272758
                                                            else 804
                                                        )
                                                        if state == 803:
                                                            return -0.0987056196
                                                        if state == 804:
                                                            return -0.444798589
                                        if state == 270:
                                            return 0.36542502
                                    if state == 164:
                                        state = (
                                            271
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.2693501)
                                            else 272
                                        )
                                        if state == 271:
                                            return -1.08093381
                                        if state == 272:
                                            state = (
                                                395
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.4705811)
                                                else 396
                                            )
                                            if state == 395:
                                                state = (
                                                    549
                                                    if x["col_peak"] < -0.0942993164
                                                    else 550
                                                )
                                                if state == 549:
                                                    return 0.308624893
                                                if state == 550:
                                                    state = (
                                                        699
                                                        if x["col_last"] < 0.284755707
                                                        else 700
                                                    )
                                                    if state == 699:
                                                        state = (
                                                            805
                                                            if x["col_last"]
                                                            < 0.185506821
                                                            else 806
                                                        )
                                                        if state == 805:
                                                            return 0.182442129
                                                        if state == 806:
                                                            return -0.131711736
                                                    if state == 700:
                                                        state = (
                                                            807
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 1.53334284
                                                            )
                                                            else 808
                                                        )
                                                        if state == 807:
                                                            return 0.249918804
                                                        if state == 808:
                                                            return -0.215864375
                                            if state == 396:
                                                state = (
                                                    551
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.0771331787)
                                                    else 552
                                                )
                                                if state == 551:
                                                    state = (
                                                        701
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.196011066)
                                                        else 702
                                                    )
                                                    if state == 701:
                                                        return 0.358035356
                                                    if state == 702:
                                                        state = (
                                                            809
                                                            if x["col_last"]
                                                            < 0.261770248
                                                            else 810
                                                        )
                                                        if state == 809:
                                                            return -0.166247204
                                                        if state == 810:
                                                            return 0.222240523
                                                if state == 552:
                                                    state = (
                                                        703
                                                        if x["col_last"] < 3.260602
                                                        else 704
                                                    )
                                                    if state == 703:
                                                        return 0.269764274
                                                    if state == 704:
                                                        return 0.124704942
    elif num_booster == 8:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.9395142) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.981750011)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.879500031)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 16.1069679)
                            else 16
                        )
                        if state == 15:
                            state = (
                                31
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.99461222)
                                else 32
                            )
                            if state == 31:
                                state = 59 if x["maggaia_med"] < 16.0056133 else 60
                                if state == 59:
                                    return 0.153936565
                                if state == 60:
                                    return -0.222188294
                            if state == 32:
                                state = 61 if x["maggaia_med"] < 19.6532631 else 62
                                if state == 61:
                                    state = (
                                        113 if x["neargaia_med"] < 18.8352737 else 114
                                    )
                                    if state == 113:
                                        return -0.126965627
                                    if state == 114:
                                        return 0.159854412
                                if state == 62:
                                    return 0.247082725
                        if state == 16:
                            return -0.394099563
                    if state == 8:
                        state = (
                            17 if np.isnan(x["t_lc"]) or (x["t_lc"] < 44.007019) else 18
                        )
                        if state == 17:
                            state = (
                                33
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 10.9381943)
                                else 34
                            )
                            if state == 33:
                                state = 63 if x["maggaia_med"] < 18.3097115 else 64
                                if state == 63:
                                    state = (
                                        115 if x["neargaia_med"] < 12.9878788 else 116
                                    )
                                    if state == 115:
                                        state = (
                                            193
                                            if x["neargaia_med"] < 1.85575676
                                            else 194
                                        )
                                        if state == 193:
                                            return 0.00312197953
                                        if state == 194:
                                            state = (
                                                303
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 8.96277237)
                                                else 304
                                            )
                                            if state == 303:
                                                return -0.470388114
                                            if state == 304:
                                                state = (
                                                    431
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.972499967)
                                                    else 432
                                                )
                                                if state == 431:
                                                    return 0.268024474
                                                if state == 432:
                                                    return -0.217083976
                                    if state == 116:
                                        state = (
                                            195
                                            if x["neargaia_med"] < 39.3004608
                                            else 196
                                        )
                                        if state == 195:
                                            return 0.327796787
                                        if state == 196:
                                            state = (
                                                305
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 8.99652767)
                                                else 306
                                            )
                                            if state == 305:
                                                return -0.398205042
                                            if state == 306:
                                                return 0.273332328
                                if state == 64:
                                    state = (
                                        117
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 42.6372757)
                                        else 118
                                    )
                                    if state == 117:
                                        state = (
                                            197
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 34.6568947)
                                            else 198
                                        )
                                        if state == 197:
                                            state = (
                                                307
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 5.02081013)
                                                else 308
                                            )
                                            if state == 307:
                                                state = (
                                                    433
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.973249972)
                                                    else 434
                                                )
                                                if state == 433:
                                                    return -0.198517039
                                                if state == 434:
                                                    return 0.142747059
                                            if state == 308:
                                                return 0.366708249
                                        if state == 198:
                                            state = (
                                                309
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 3.98506927)
                                                else 310
                                            )
                                            if state == 309:
                                                return -0.403693527
                                            if state == 310:
                                                return 0.327044517
                                    if state == 118:
                                        state = (
                                            199
                                            if x["neargaia_med"] < 52.8233032
                                            else 200
                                        )
                                        if state == 199:
                                            return -0.428424686
                                        if state == 200:
                                            state = (
                                                311
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 7.53366375)
                                                else 312
                                            )
                                            if state == 311:
                                                state = (
                                                    435
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.980499983)
                                                    else 436
                                                )
                                                if state == 435:
                                                    return 0.213399008
                                                if state == 436:
                                                    return -0.0606081113
                                            if state == 312:
                                                state = (
                                                    437
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.980499983)
                                                    else 438
                                                )
                                                if state == 437:
                                                    return 0.172407955
                                                if state == 438:
                                                    return -0.262266308
                            if state == 34:
                                state = 65 if x["maggaia_med"] < 15.611393 else 66
                                if state == 65:
                                    state = (
                                        119 if x["neargaia_med"] < 54.6139679 else 120
                                    )
                                    if state == 119:
                                        state = (
                                            201
                                            if x["neargaia_med"] < 18.946991
                                            else 202
                                        )
                                        if state == 201:
                                            return -0.447877705
                                        if state == 202:
                                            state = (
                                                313
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 11.961956)
                                                else 314
                                            )
                                            if state == 313:
                                                return 0.0256608427
                                            if state == 314:
                                                state = (
                                                    439
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.960500002)
                                                    else 440
                                                )
                                                if state == 439:
                                                    state = (
                                                        587
                                                        if x["distpsnr1_med"]
                                                        < 14.1146202
                                                        else 588
                                                    )
                                                    if state == 587:
                                                        return -0.0580440573
                                                    if state == 588:
                                                        return 0.137523174
                                                if state == 440:
                                                    state = (
                                                        589
                                                        if x["distpsnr1_med"]
                                                        < 2.0739646
                                                        else 590
                                                    )
                                                    if state == 589:
                                                        return 0.305686384
                                                    if state == 590:
                                                        return -0.0165195949
                                    if state == 120:
                                        return -0.785008907
                                if state == 66:
                                    state = (
                                        121
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 13.6233349)
                                        else 122
                                    )
                                    if state == 121:
                                        state = (
                                            203
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 11.6185875)
                                            else 204
                                        )
                                        if state == 203:
                                            state = (
                                                315
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 30.0795135)
                                                else 316
                                            )
                                            if state == 315:
                                                state = (
                                                    441
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.926500022)
                                                    else 442
                                                )
                                                if state == 441:
                                                    return -0.326917917
                                                if state == 442:
                                                    state = (
                                                        591
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 5.97024632
                                                        )
                                                        else 592
                                                    )
                                                    if state == 591:
                                                        state = (
                                                            787
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.87447524
                                                            )
                                                            else 788
                                                        )
                                                        if state == 787:
                                                            return 0.144231752
                                                        if state == 788:
                                                            return -0.0349282101
                                                    if state == 592:
                                                        return 0.365950376
                                            if state == 316:
                                                state = (
                                                    443
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.976250052)
                                                    else 444
                                                )
                                                if state == 443:
                                                    return -0.379155099
                                                if state == 444:
                                                    state = (
                                                        593
                                                        if x["distpsnr1_med"]
                                                        < 0.575119972
                                                        else 594
                                                    )
                                                    if state == 593:
                                                        return -0.322860926
                                                    if state == 594:
                                                        state = (
                                                            789
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.749007344
                                                            )
                                                            else 790
                                                        )
                                                        if state == 789:
                                                            return 0.293518603
                                                        if state == 790:
                                                            return -0.0401776023
                                        if state == 204:
                                            state = (
                                                317
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 18.4915504)
                                                else 318
                                            )
                                            if state == 317:
                                                state = (
                                                    445
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.979750037)
                                                    else 446
                                                )
                                                if state == 445:
                                                    state = (
                                                        595
                                                        if x["distpsnr1_med"]
                                                        < 2.63958645
                                                        else 596
                                                    )
                                                    if state == 595:
                                                        state = (
                                                            791
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.915765524
                                                            )
                                                            else 792
                                                        )
                                                        if state == 791:
                                                            return 0.132893071
                                                        if state == 792:
                                                            return -0.0606914982
                                                    if state == 596:
                                                        return -0.633951902
                                                if state == 446:
                                                    state = (
                                                        597
                                                        if x["distpsnr1_med"]
                                                        < 2.60127831
                                                        else 598
                                                    )
                                                    if state == 597:
                                                        return 0.272935241
                                                    if state == 598:
                                                        return -0.0383084714
                                            if state == 318:
                                                state = (
                                                    447
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.975750029)
                                                    else 448
                                                )
                                                if state == 447:
                                                    return 0.170591176
                                                if state == 448:
                                                    return -0.625047565
                                    if state == 122:
                                        state = (
                                            205
                                            if x["neargaia_med"] < 28.1199226
                                            else 206
                                        )
                                        if state == 205:
                                            state = (
                                                319
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 20.8211632)
                                                else 320
                                            )
                                            if state == 319:
                                                state = (
                                                    449
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.979000032)
                                                    else 450
                                                )
                                                if state == 449:
                                                    state = (
                                                        599
                                                        if x["distpsnr1_med"]
                                                        < 2.13441372
                                                        else 600
                                                    )
                                                    if state == 599:
                                                        state = (
                                                            793
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.74519563
                                                            )
                                                            else 794
                                                        )
                                                        if state == 793:
                                                            return 0.0060104127
                                                        if state == 794:
                                                            return -0.558462262
                                                    if state == 600:
                                                        state = (
                                                            795
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.48356175
                                                            )
                                                            else 796
                                                        )
                                                        if state == 795:
                                                            return -0.00136390771
                                                        if state == 796:
                                                            return 0.302007973
                                                if state == 450:
                                                    state = (
                                                        601
                                                        if x["distpsnr1_med"]
                                                        < 0.10438478
                                                        else 602
                                                    )
                                                    if state == 601:
                                                        return -0.255253494
                                                    if state == 602:
                                                        state = (
                                                            797
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 5.93771076
                                                            )
                                                            else 798
                                                        )
                                                        if state == 797:
                                                            return 0.264592409
                                                        if state == 798:
                                                            return 0.0261110943
                                            if state == 320:
                                                return 0.447812051
                                        if state == 206:
                                            state = (
                                                321
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 14.080266)
                                                else 322
                                            )
                                            if state == 321:
                                                state = (
                                                    451
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.979249954)
                                                    else 452
                                                )
                                                if state == 451:
                                                    state = (
                                                        603
                                                        if x["distpsnr1_med"]
                                                        < 1.03198886
                                                        else 604
                                                    )
                                                    if state == 603:
                                                        state = (
                                                            799
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.389553249
                                                            )
                                                            else 800
                                                        )
                                                        if state == 799:
                                                            return -0.105736956
                                                        if state == 800:
                                                            return 0.294331223
                                                    if state == 604:
                                                        state = (
                                                            801
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.99611473
                                                            )
                                                            else 802
                                                        )
                                                        if state == 801:
                                                            return -0.152356371
                                                        if state == 802:
                                                            return 0.109211564
                                                if state == 452:
                                                    state = (
                                                        605
                                                        if x["distpsnr1_med"]
                                                        < 7.88235092
                                                        else 606
                                                    )
                                                    if state == 605:
                                                        state = (
                                                            803
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.07446003
                                                            )
                                                            else 804
                                                        )
                                                        if state == 803:
                                                            return -0.169609472
                                                        if state == 804:
                                                            return 0.297836483
                                                    if state == 606:
                                                        return -0.868889213
                                            if state == 322:
                                                state = (
                                                    453
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.965499997)
                                                    else 454
                                                )
                                                if state == 453:
                                                    state = (
                                                        607
                                                        if x["distpsnr1_med"]
                                                        < 0.374086678
                                                        else 608
                                                    )
                                                    if state == 607:
                                                        state = (
                                                            805
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.259005725
                                                            )
                                                            else 806
                                                        )
                                                        if state == 805:
                                                            return -0.206216246
                                                        if state == 806:
                                                            return 0.24335517
                                                    if state == 608:
                                                        state = (
                                                            807
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.71062851
                                                            )
                                                            else 808
                                                        )
                                                        if state == 807:
                                                            return 0.330714583
                                                        if state == 808:
                                                            return -0.0379068144
                                                if state == 454:
                                                    state = (
                                                        609
                                                        if x["distpsnr1_med"]
                                                        < 0.318598211
                                                        else 610
                                                    )
                                                    if state == 609:
                                                        return -0.345548064
                                                    if state == 610:
                                                        state = (
                                                            809
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.89990497
                                                            )
                                                            else 810
                                                        )
                                                        if state == 809:
                                                            return 0.232814461
                                                        if state == 810:
                                                            return -0.0593941361
                        if state == 18:
                            state = (
                                35
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 45.3957138)
                                else 36
                            )
                            if state == 35:
                                state = 67 if x["maggaia_med"] < 18.7008476 else 68
                                if state == 67:
                                    state = (
                                        123 if x["neargaia_med"] < 27.2708664 else 124
                                    )
                                    if state == 123:
                                        return -0.161093131
                                    if state == 124:
                                        return 0.057978373
                                if state == 68:
                                    return -0.378245562
                            if state == 36:
                                state = (
                                    69
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.4027748)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        125
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 10.8796291)
                                        else 126
                                    )
                                    if state == 125:
                                        state = (
                                            207
                                            if x["neargaia_med"] < 0.663789153
                                            else 208
                                        )
                                        if state == 207:
                                            return -0.385245174
                                        if state == 208:
                                            state = (
                                                323
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 52.4523468)
                                                else 324
                                            )
                                            if state == 323:
                                                state = (
                                                    455
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.980499983)
                                                    else 456
                                                )
                                                if state == 455:
                                                    return -0.220657885
                                                if state == 456:
                                                    state = (
                                                        611
                                                        if x["distpsnr1_med"]
                                                        < 1.07935727
                                                        else 612
                                                    )
                                                    if state == 611:
                                                        return -0.0140797049
                                                    if state == 612:
                                                        return 0.242494196
                                            if state == 324:
                                                return -0.29897505
                                    if state == 126:
                                        return 0.351496339
                                if state == 70:
                                    state = (
                                        127 if x["neargaia_med"] < 1.6769737 else 128
                                    )
                                    if state == 127:
                                        return -0.267301291
                                    if state == 128:
                                        return 0.321613491
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.989000022)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 8.12839699)
                            else 20
                        )
                        if state == 19:
                            state = (
                                37
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 8.00013351)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    71
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 17.829052)
                                    else 72
                                )
                                if state == 71:
                                    state = (
                                        129 if x["neargaia_med"] < 15.4156513 else 130
                                    )
                                    if state == 129:
                                        state = (
                                            211
                                            if x["neargaia_med"] < 13.2174454
                                            else 212
                                        )
                                        if state == 211:
                                            return 0.242741987
                                        if state == 212:
                                            return -0.188759118
                                    if state == 130:
                                        return 0.30733785
                                if state == 72:
                                    state = (
                                        131 if x["neargaia_med"] < 9.21995735 else 132
                                    )
                                    if state == 131:
                                        state = (
                                            213
                                            if x["neargaia_med"] < 1.91155326
                                            else 214
                                        )
                                        if state == 213:
                                            return -0.688347995
                                        if state == 214:
                                            return -0.146384358
                                    if state == 132:
                                        state = (
                                            215
                                            if x["neargaia_med"] < 25.7016487
                                            else 216
                                        )
                                        if state == 215:
                                            state = (
                                                325
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 6.19316006)
                                                else 326
                                            )
                                            if state == 325:
                                                state = (
                                                    457
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.984250069)
                                                    else 458
                                                )
                                                if state == 457:
                                                    state = (
                                                        613
                                                        if x["distpsnr1_med"]
                                                        < 2.76661491
                                                        else 614
                                                    )
                                                    if state == 613:
                                                        return -0.190627441
                                                    if state == 614:
                                                        state = (
                                                            811
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.31027222
                                                            )
                                                            else 812
                                                        )
                                                        if state == 811:
                                                            return -0.12551941
                                                        if state == 812:
                                                            return 0.115459576
                                                if state == 458:
                                                    return 0.102711067
                                            if state == 326:
                                                return 0.132512271
                                        if state == 216:
                                            return 0.266980886
                            if state == 38:
                                state = 73 if x["maggaia_med"] < 18.0833092 else 74
                                if state == 73:
                                    return 0.121934056
                                if state == 74:
                                    state = (
                                        133 if x["neargaia_med"] < 19.7620296 else 134
                                    )
                                    if state == 133:
                                        return -0.422111928
                                    if state == 134:
                                        return 0.0560416766
                        if state == 20:
                            state = (
                                39
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 50.0018997)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    75
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 20.6092453)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        135 if x["neargaia_med"] < 18.6943188 else 136
                                    )
                                    if state == 135:
                                        state = (
                                            217
                                            if x["neargaia_med"] < 18.5674286
                                            else 218
                                        )
                                        if state == 217:
                                            state = (
                                                327
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 18.981163)
                                                else 328
                                            )
                                            if state == 327:
                                                state = (
                                                    459
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982249975)
                                                    else 460
                                                )
                                                if state == 459:
                                                    state = (
                                                        615
                                                        if x["distpsnr1_med"]
                                                        < 1.27921486
                                                        else 616
                                                    )
                                                    if state == 615:
                                                        state = (
                                                            813
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.198220715
                                                            )
                                                            else 814
                                                        )
                                                        if state == 813:
                                                            return 0.0345667005
                                                        if state == 814:
                                                            return 0.265948713
                                                    if state == 616:
                                                        state = (
                                                            815
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 4.49798393
                                                            )
                                                            else 816
                                                        )
                                                        if state == 815:
                                                            return -0.247214243
                                                        if state == 816:
                                                            return 0.2556943
                                                if state == 460:
                                                    state = (
                                                        617
                                                        if x["distpsnr1_med"]
                                                        < 0.0977274701
                                                        else 618
                                                    )
                                                    if state == 617:
                                                        state = (
                                                            817
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.169514999
                                                            )
                                                            else 818
                                                        )
                                                        if state == 817:
                                                            return 0.13394554
                                                        if state == 818:
                                                            return -0.33442229
                                                    if state == 618:
                                                        state = (
                                                            819
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.17411041
                                                            )
                                                            else 820
                                                        )
                                                        if state == 819:
                                                            return 0.332644612
                                                        if state == 820:
                                                            return 0.0357966311
                                            if state == 328:
                                                state = (
                                                    461
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982749999)
                                                    else 462
                                                )
                                                if state == 461:
                                                    state = (
                                                        619
                                                        if x["distpsnr1_med"]
                                                        < 0.343499184
                                                        else 620
                                                    )
                                                    if state == 619:
                                                        return -0.214799464
                                                    if state == 620:
                                                        state = (
                                                            821
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.17975569
                                                            )
                                                            else 822
                                                        )
                                                        if state == 821:
                                                            return 0.250193805
                                                        if state == 822:
                                                            return 0.0923087373
                                                if state == 462:
                                                    state = (
                                                        621
                                                        if x["distpsnr1_med"]
                                                        < 0.272719651
                                                        else 622
                                                    )
                                                    if state == 621:
                                                        state = (
                                                            823
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.264683843
                                                            )
                                                            else 824
                                                        )
                                                        if state == 823:
                                                            return -0.152931914
                                                        if state == 824:
                                                            return 0.0842830017
                                                    if state == 622:
                                                        state = (
                                                            825
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.769016445
                                                            )
                                                            else 826
                                                        )
                                                        if state == 825:
                                                            return 0.146245211
                                                        if state == 826:
                                                            return 0.322353691
                                        if state == 218:
                                            return -0.67238915
                                    if state == 136:
                                        state = (
                                            219
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 35.5520439)
                                            else 220
                                        )
                                        if state == 219:
                                            state = (
                                                329
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 9.0076561)
                                                else 330
                                            )
                                            if state == 329:
                                                state = (
                                                    463
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.983500004)
                                                    else 464
                                                )
                                                if state == 463:
                                                    return 0.221812978
                                                if state == 464:
                                                    state = (
                                                        623
                                                        if x["distpsnr1_med"]
                                                        < 4.79089451
                                                        else 624
                                                    )
                                                    if state == 623:
                                                        return -0.191055685
                                                    if state == 624:
                                                        return 0.120762952
                                            if state == 330:
                                                state = (
                                                    465
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.986500025)
                                                    else 466
                                                )
                                                if state == 465:
                                                    state = (
                                                        625
                                                        if x["distpsnr1_med"]
                                                        < 0.242914349
                                                        else 626
                                                    )
                                                    if state == 625:
                                                        state = (
                                                            827
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.755559921
                                                            )
                                                            else 828
                                                        )
                                                        if state == 827:
                                                            return 0.140798584
                                                        if state == 828:
                                                            return -0.16584383
                                                    if state == 626:
                                                        state = (
                                                            829
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 6.63562822
                                                            )
                                                            else 830
                                                        )
                                                        if state == 829:
                                                            return 0.373538524
                                                        if state == 830:
                                                            return 0.227826715
                                                if state == 466:
                                                    return 0.019344775
                                        if state == 220:
                                            state = (
                                                331
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 19.9515495)
                                                else 332
                                            )
                                            if state == 331:
                                                state = (
                                                    467
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.983250022)
                                                    else 468
                                                )
                                                if state == 467:
                                                    state = (
                                                        627
                                                        if x["distpsnr1_med"]
                                                        < 4.67886639
                                                        else 628
                                                    )
                                                    if state == 627:
                                                        state = (
                                                            831
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.89304876
                                                            )
                                                            else 832
                                                        )
                                                        if state == 831:
                                                            return 0.193279713
                                                        if state == 832:
                                                            return -0.0720886588
                                                    if state == 628:
                                                        return 0.366090804
                                                if state == 468:
                                                    return 0.364317566
                                            if state == 332:
                                                state = (
                                                    469
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982249975)
                                                    else 470
                                                )
                                                if state == 469:
                                                    state = (
                                                        629
                                                        if x["distpsnr1_med"]
                                                        < 0.803364038
                                                        else 630
                                                    )
                                                    if state == 629:
                                                        return -0.173378095
                                                    if state == 630:
                                                        return 0.279354721
                                                if state == 470:
                                                    state = (
                                                        631
                                                        if x["distpsnr1_med"]
                                                        < 0.188972786
                                                        else 632
                                                    )
                                                    if state == 631:
                                                        state = (
                                                            833
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.246108711
                                                            )
                                                            else 834
                                                        )
                                                        if state == 833:
                                                            return -0.226861402
                                                        if state == 834:
                                                            return 0.31753698
                                                    if state == 632:
                                                        state = (
                                                            835
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.157588989
                                                            )
                                                            else 836
                                                        )
                                                        if state == 835:
                                                            return 0.0222488437
                                                        if state == 836:
                                                            return 0.351601809
                                if state == 76:
                                    state = (
                                        137 if x["neargaia_med"] < 27.1012402 else 138
                                    )
                                    if state == 137:
                                        state = (
                                            221
                                            if x["neargaia_med"] < 17.1721687
                                            else 222
                                        )
                                        if state == 221:
                                            state = (
                                                333
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 16.3810883)
                                                else 334
                                            )
                                            if state == 333:
                                                return 0.187058374
                                            if state == 334:
                                                return -0.439179868
                                        if state == 222:
                                            return 0.320794404
                                    if state == 138:
                                        state = (
                                            223
                                            if x["neargaia_med"] < 36.0691605
                                            else 224
                                        )
                                        if state == 223:
                                            state = (
                                                335
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 23.061058)
                                                else 336
                                            )
                                            if state == 335:
                                                return -0.00147804932
                                            if state == 336:
                                                return -0.420792997
                                        if state == 224:
                                            state = (
                                                337
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 17.9950218)
                                                else 338
                                            )
                                            if state == 337:
                                                return -0.22988762
                                            if state == 338:
                                                return 0.222195834
                            if state == 40:
                                state = (
                                    77
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 20.0721321)
                                    else 78
                                )
                                if state == 77:
                                    state = (
                                        139 if x["neargaia_med"] < 1.20490611 else 140
                                    )
                                    if state == 139:
                                        return -0.310352504
                                    if state == 140:
                                        return 0.350762606
                                if state == 78:
                                    state = (
                                        141 if x["neargaia_med"] < 7.99070644 else 142
                                    )
                                    if state == 141:
                                        state = (
                                            225
                                            if x["neargaia_med"] < 5.55766106
                                            else 226
                                        )
                                        if state == 225:
                                            return 0.0872819722
                                        if state == 226:
                                            return -0.674409091
                                    if state == 142:
                                        state = (
                                            227
                                            if x["neargaia_med"] < 32.2552032
                                            else 228
                                        )
                                        if state == 227:
                                            return 0.354073405
                                        if state == 228:
                                            state = (
                                                341
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 61.014267)
                                                else 342
                                            )
                                            if state == 341:
                                                return -0.0299207829
                                            if state == 342:
                                                return 0.216809735
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 21.0334091)
                            else 22
                        )
                        if state == 21:
                            state = (
                                41
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 15.9774885)
                                else 42
                            )
                            if state == 41:
                                state = 79 if x["maggaia_med"] < 17.4687157 else 80
                                if state == 79:
                                    return -0.01412261
                                if state == 80:
                                    return 0.295010626
                            if state == 42:
                                return 0.0620889924
                        if state == 22:
                            state = (
                                43
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 45.4113693)
                                else 44
                            )
                            if state == 43:
                                state = 83 if x["maggaia_med"] < 12.9279423 else 84
                                if state == 83:
                                    return 0.116987608
                                if state == 84:
                                    state = (
                                        145
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 38.6739464)
                                        else 146
                                    )
                                    if state == 145:
                                        return -0.275551826
                                    if state == 146:
                                        return 0.1680509
                            if state == 44:
                                return -0.362260193
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.972249985)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.897000015)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 9.04534721)
                            else 24
                        )
                        if state == 23:
                            state = (
                                45
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 8.99913788)
                                else 46
                            )
                            if state == 45:
                                state = (
                                    85
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 20.4090309)
                                    else 86
                                )
                                if state == 85:
                                    return -0.388779193
                                if state == 86:
                                    return 0.0583234467
                            if state == 46:
                                state = (
                                    87
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.1754074)
                                    else 88
                                )
                                if state == 87:
                                    return -0.290764809
                                if state == 88:
                                    state = (
                                        147 if x["neargaia_med"] < 22.2333755 else 148
                                    )
                                    if state == 147:
                                        return -0.172105476
                                    if state == 148:
                                        state = (
                                            229
                                            if x["neargaia_med"] < 24.1502781
                                            else 230
                                        )
                                        if state == 229:
                                            return 0.759557545
                                        if state == 230:
                                            state = (
                                                343
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 9.03794575)
                                                else 344
                                            )
                                            if state == 343:
                                                return -0.124318019
                                            if state == 344:
                                                return 0.274295449
                        if state == 24:
                            return -0.371001452
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 9.04927063)
                            else 26
                        )
                        if state == 25:
                            state = (
                                47
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.05865169)
                                else 48
                            )
                            if state == 47:
                                state = (
                                    89
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.1286411)
                                    else 90
                                )
                                if state == 89:
                                    state = (
                                        149 if x["neargaia_med"] < 20.8868637 else 150
                                    )
                                    if state == 149:
                                        return 0.111196108
                                    if state == 150:
                                        state = (
                                            231
                                            if x["neargaia_med"] < 90.7084351
                                            else 232
                                        )
                                        if state == 231:
                                            return -0.126058504
                                        if state == 232:
                                            state = (
                                                345
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 2.54965281)
                                                else 346
                                            )
                                            if state == 345:
                                                return 0.115231626
                                            if state == 346:
                                                return -0.121731184
                                if state == 90:
                                    return 0.518966973
                            if state == 48:
                                state = 91 if x["maggaia_med"] < 19.6771393 else 92
                                if state == 91:
                                    state = (
                                        151 if x["neargaia_med"] < 23.9813499 else 152
                                    )
                                    if state == 151:
                                        state = (
                                            233
                                            if x["neargaia_med"] < 18.0081596
                                            else 234
                                        )
                                        if state == 233:
                                            state = (
                                                347
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 9.00676537)
                                                else 348
                                            )
                                            if state == 347:
                                                return -0.365607709
                                            if state == 348:
                                                state = (
                                                    471
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.965749979)
                                                    else 472
                                                )
                                                if state == 471:
                                                    state = (
                                                        633
                                                        if x["distpsnr1_med"]
                                                        < 0.162439555
                                                        else 634
                                                    )
                                                    if state == 633:
                                                        return 0.175330147
                                                    if state == 634:
                                                        return -0.174823344
                                                if state == 472:
                                                    return 0.546869814
                                        if state == 234:
                                            state = (
                                                349
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 4.06265068)
                                                else 350
                                            )
                                            if state == 349:
                                                return -0.205112368
                                            if state == 350:
                                                state = (
                                                    473
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.961749971)
                                                    else 474
                                                )
                                                if state == 473:
                                                    state = (
                                                        635
                                                        if x["distpsnr1_med"]
                                                        < 3.92135763
                                                        else 636
                                                    )
                                                    if state == 635:
                                                        return 0.297166169
                                                    if state == 636:
                                                        return 1.0010221
                                                if state == 474:
                                                    state = (
                                                        637
                                                        if x["distpsnr1_med"]
                                                        < 2.10532045
                                                        else 638
                                                    )
                                                    if state == 637:
                                                        state = (
                                                            837
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.690455794
                                                            )
                                                            else 838
                                                        )
                                                        if state == 837:
                                                            return 0.160480902
                                                        if state == 838:
                                                            return -0.135888979
                                                    if state == 638:
                                                        return 0.25771445
                                    if state == 152:
                                        state = (
                                            235
                                            if x["neargaia_med"] < 37.6492577
                                            else 236
                                        )
                                        if state == 235:
                                            return -0.36699155
                                        if state == 236:
                                            state = (
                                                351
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 8.98563671)
                                                else 352
                                            )
                                            if state == 351:
                                                state = (
                                                    475
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.932500005)
                                                    else 476
                                                )
                                                if state == 475:
                                                    return -0.190550163
                                                if state == 476:
                                                    state = (
                                                        639
                                                        if x["distpsnr1_med"]
                                                        < 1.80621529
                                                        else 640
                                                    )
                                                    if state == 639:
                                                        return -0.182326302
                                                    if state == 640:
                                                        state = (
                                                            839
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.87889397
                                                            )
                                                            else 840
                                                        )
                                                        if state == 839:
                                                            return 0.546435356
                                                        if state == 840:
                                                            return 0.0808866844
                                            if state == 352:
                                                return -0.189769745
                                if state == 92:
                                    state = (
                                        153
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 9.75328827)
                                        else 154
                                    )
                                    if state == 153:
                                        state = (
                                            237
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 9.55918121)
                                            else 238
                                        )
                                        if state == 237:
                                            state = (
                                                353
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 6.02807903)
                                                else 354
                                            )
                                            if state == 353:
                                                state = (
                                                    477
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.940999985)
                                                    else 478
                                                )
                                                if state == 477:
                                                    return 0.29579407
                                                if state == 478:
                                                    state = (
                                                        641
                                                        if x["distpsnr1_med"]
                                                        < 0.671902001
                                                        else 642
                                                    )
                                                    if state == 641:
                                                        return -0.226192668
                                                    if state == 642:
                                                        state = (
                                                            841
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.68940735
                                                            )
                                                            else 842
                                                        )
                                                        if state == 841:
                                                            return 0.225412235
                                                        if state == 842:
                                                            return -0.145533428
                                            if state == 354:
                                                return -0.34070304
                                        if state == 238:
                                            return 0.355305135
                                    if state == 154:
                                        return -0.375469536
                        if state == 26:
                            state = (
                                49
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 24.980278)
                                else 50
                            )
                            if state == 49:
                                state = 93 if x["maggaia_med"] < 17.8190193 else 94
                                if state == 93:
                                    return -0.400016755
                                if state == 94:
                                    state = (
                                        155 if x["neargaia_med"] < 0.268108964 else 156
                                    )
                                    if state == 155:
                                        state = (
                                            239
                                            if x["neargaia_med"] < 0.202880889
                                            else 240
                                        )
                                        if state == 239:
                                            return -0.263371527
                                        if state == 240:
                                            state = (
                                                355
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 16.0648556)
                                                else 356
                                            )
                                            if state == 355:
                                                return -0.225705177
                                            if state == 356:
                                                state = (
                                                    479
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.938500047)
                                                    else 480
                                                )
                                                if state == 479:
                                                    return -0.162384093
                                                if state == 480:
                                                    return 0.435388833
                                    if state == 156:
                                        state = (
                                            241
                                            if x["neargaia_med"] < 55.0692215
                                            else 242
                                        )
                                        if state == 241:
                                            state = (
                                                357
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 9.09585571)
                                                else 358
                                            )
                                            if state == 357:
                                                state = (
                                                    481
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.969250023)
                                                    else 482
                                                )
                                                if state == 481:
                                                    return -0.20028992
                                                if state == 482:
                                                    return 0.241845891
                                            if state == 358:
                                                state = (
                                                    483
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.97025001)
                                                    else 484
                                                )
                                                if state == 483:
                                                    state = (
                                                        643
                                                        if x["distpsnr1_med"]
                                                        < 0.116048545
                                                        else 644
                                                    )
                                                    if state == 643:
                                                        state = (
                                                            843
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.249737561
                                                            )
                                                            else 844
                                                        )
                                                        if state == 843:
                                                            return 0.391034812
                                                        if state == 844:
                                                            return -0.145395428
                                                    if state == 644:
                                                        return -0.377021521
                                                if state == 484:
                                                    state = (
                                                        645
                                                        if x["distpsnr1_med"]
                                                        < 0.178338587
                                                        else 646
                                                    )
                                                    if state == 645:
                                                        return 0.158273786
                                                    if state == 646:
                                                        state = (
                                                            845
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.92244864
                                                            )
                                                            else 846
                                                        )
                                                        if state == 845:
                                                            return -0.245294705
                                                        if state == 846:
                                                            return -0.0656429008
                                        if state == 242:
                                            state = (
                                                359
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 16.9641609)
                                                else 360
                                            )
                                            if state == 359:
                                                state = (
                                                    485
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.96450001)
                                                    else 486
                                                )
                                                if state == 485:
                                                    return -0.375734627
                                                if state == 486:
                                                    state = (
                                                        647
                                                        if x["distpsnr1_med"]
                                                        < 1.34441495
                                                        else 648
                                                    )
                                                    if state == 647:
                                                        state = (
                                                            847
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.20931029
                                                            )
                                                            else 848
                                                        )
                                                        if state == 847:
                                                            return 0.0961306244
                                                        if state == 848:
                                                            return 0.527010143
                                                    if state == 648:
                                                        return -0.290899456
                                            if state == 360:
                                                state = (
                                                    487
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.971750021)
                                                    else 488
                                                )
                                                if state == 487:
                                                    return -0.422095805
                                                if state == 488:
                                                    return 0.0922467113
                            if state == 50:
                                state = (
                                    95
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 16.5549965)
                                    else 96
                                )
                                if state == 95:
                                    state = (
                                        157
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 54.3848343)
                                        else 158
                                    )
                                    if state == 157:
                                        state = (
                                            243
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 22.5428238)
                                            else 244
                                        )
                                        if state == 243:
                                            state = (
                                                361
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 28.950161)
                                                else 362
                                            )
                                            if state == 361:
                                                state = (
                                                    489
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.953250051)
                                                    else 490
                                                )
                                                if state == 489:
                                                    state = (
                                                        649
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 3.28814626
                                                        )
                                                        else 650
                                                    )
                                                    if state == 649:
                                                        return -0.252630889
                                                    if state == 650:
                                                        return 0.325644732
                                                if state == 490:
                                                    state = (
                                                        651
                                                        if x["distpsnr1_med"]
                                                        < 4.32287884
                                                        else 652
                                                    )
                                                    if state == 651:
                                                        return -0.359602541
                                                    if state == 652:
                                                        return -0.0445697717
                                            if state == 362:
                                                state = (
                                                    491
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.964000046)
                                                    else 492
                                                )
                                                if state == 491:
                                                    state = (
                                                        653
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 1.98001027
                                                        )
                                                        else 654
                                                    )
                                                    if state == 653:
                                                        return -0.352670401
                                                    if state == 654:
                                                        state = (
                                                            849
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.35018563
                                                            )
                                                            else 850
                                                        )
                                                        if state == 849:
                                                            return 0.21112299
                                                        if state == 850:
                                                            return -0.321731627
                                                if state == 492:
                                                    state = (
                                                        655
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 0.236416772
                                                        )
                                                        else 656
                                                    )
                                                    if state == 655:
                                                        return -0.177429155
                                                    if state == 656:
                                                        state = (
                                                            851
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.38593173
                                                            )
                                                            else 852
                                                        )
                                                        if state == 851:
                                                            return 0.176369429
                                                        if state == 852:
                                                            return 0.441259354
                                        if state == 244:
                                            state = (
                                                363
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 26.4473667)
                                                else 364
                                            )
                                            if state == 363:
                                                state = (
                                                    493
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.902999997)
                                                    else 494
                                                )
                                                if state == 493:
                                                    return 0.396072298
                                                if state == 494:
                                                    return -0.185775384
                                            if state == 364:
                                                state = (
                                                    495
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.925999999)
                                                    else 496
                                                )
                                                if state == 495:
                                                    state = (
                                                        657
                                                        if x["distpsnr1_med"]
                                                        < 2.06274199
                                                        else 658
                                                    )
                                                    if state == 657:
                                                        return -0.124114737
                                                    if state == 658:
                                                        return 0.383370638
                                                if state == 496:
                                                    state = (
                                                        659
                                                        if x["distpsnr1_med"]
                                                        < 13.6794014
                                                        else 660
                                                    )
                                                    if state == 659:
                                                        return -0.466898888
                                                    if state == 660:
                                                        state = (
                                                            853
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 6.15001869
                                                            )
                                                            else 854
                                                        )
                                                        if state == 853:
                                                            return -0.264206529
                                                        if state == 854:
                                                            return 0.041302368
                                    if state == 158:
                                        state = (
                                            245
                                            if x["neargaia_med"] < 55.0632401
                                            else 246
                                        )
                                        if state == 245:
                                            return 0.456237555
                                        if state == 246:
                                            return -0.282691002
                                if state == 96:
                                    state = (
                                        159 if x["neargaia_med"] < 5.53913164 else 160
                                    )
                                    if state == 159:
                                        state = (
                                            247
                                            if x["neargaia_med"] < 1.88343167
                                            else 248
                                        )
                                        if state == 247:
                                            state = (
                                                365
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 29.8767242)
                                                else 366
                                            )
                                            if state == 365:
                                                state = (
                                                    497
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.941500008)
                                                    else 498
                                                )
                                                if state == 497:
                                                    state = (
                                                        661
                                                        if x["distpsnr1_med"]
                                                        < 0.221692055
                                                        else 662
                                                    )
                                                    if state == 661:
                                                        state = (
                                                            855
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.263738394
                                                            )
                                                            else 856
                                                        )
                                                        if state == 855:
                                                            return -0.119842894
                                                        if state == 856:
                                                            return 0.0790615678
                                                    if state == 662:
                                                        return -0.196079969
                                                if state == 498:
                                                    state = (
                                                        663
                                                        if x["distpsnr1_med"]
                                                        < 0.169732213
                                                        else 664
                                                    )
                                                    if state == 663:
                                                        return -0.182579249
                                                    if state == 664:
                                                        state = (
                                                            857
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.275105
                                                            )
                                                            else 858
                                                        )
                                                        if state == 857:
                                                            return -0.13798216
                                                        if state == 858:
                                                            return 0.223653927
                                            if state == 366:
                                                return -0.360161215
                                        if state == 248:
                                            state = (
                                                367
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 51.8807182)
                                                else 368
                                            )
                                            if state == 367:
                                                return -0.440485597
                                            if state == 368:
                                                return -0.109614968
                                    if state == 160:
                                        state = (
                                            249
                                            if x["neargaia_med"] < 10.9730244
                                            else 250
                                        )
                                        if state == 249:
                                            state = (
                                                369
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 60.4187431)
                                                else 370
                                            )
                                            if state == 369:
                                                state = (
                                                    499
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.947000027)
                                                    else 500
                                                )
                                                if state == 499:
                                                    state = (
                                                        665
                                                        if x["distpsnr1_med"]
                                                        < 0.94405663
                                                        else 666
                                                    )
                                                    if state == 665:
                                                        return -0.253265619
                                                    if state == 666:
                                                        state = (
                                                            859
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 5.21696854
                                                            )
                                                            else 860
                                                        )
                                                        if state == 859:
                                                            return 0.304780304
                                                        if state == 860:
                                                            return -0.139247656
                                                if state == 500:
                                                    state = (
                                                        667
                                                        if x["distpsnr1_med"]
                                                        < 1.78970075
                                                        else 668
                                                    )
                                                    if state == 667:
                                                        state = (
                                                            861
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.16281438
                                                            )
                                                            else 862
                                                        )
                                                        if state == 861:
                                                            return -0.374521852
                                                        if state == 862:
                                                            return 0.212116882
                                                    if state == 668:
                                                        state = (
                                                            863
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.22053003
                                                            )
                                                            else 864
                                                        )
                                                        if state == 863:
                                                            return 0.281966954
                                                        if state == 864:
                                                            return -0.309612781
                                            if state == 370:
                                                state = (
                                                    501
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.951499999)
                                                    else 502
                                                )
                                                if state == 501:
                                                    state = (
                                                        669
                                                        if x["distpsnr1_med"]
                                                        < 4.35656595
                                                        else 670
                                                    )
                                                    if state == 669:
                                                        state = (
                                                            865
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.36799097
                                                            )
                                                            else 866
                                                        )
                                                        if state == 865:
                                                            return -0.0705713555
                                                        if state == 866:
                                                            return 0.329552144
                                                    if state == 670:
                                                        return -0.108756758
                                                if state == 502:
                                                    return 0.06973885
                                        if state == 250:
                                            state = (
                                                371
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 52.9190521)
                                                else 372
                                            )
                                            if state == 371:
                                                state = (
                                                    503
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.965749979)
                                                    else 504
                                                )
                                                if state == 503:
                                                    return -0.348710418
                                                if state == 504:
                                                    state = (
                                                        673
                                                        if x["distpsnr1_med"]
                                                        < 6.06732464
                                                        else 674
                                                    )
                                                    if state == 673:
                                                        state = (
                                                            867
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 5.51787376
                                                            )
                                                            else 868
                                                        )
                                                        if state == 867:
                                                            return -0.21628812
                                                        if state == 868:
                                                            return 0.136268765
                                                    if state == 674:
                                                        return -0.464470088
                                            if state == 372:
                                                state = (
                                                    505
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.952250004)
                                                    else 506
                                                )
                                                if state == 505:
                                                    state = (
                                                        675
                                                        if x["distpsnr1_med"]
                                                        < 3.81781721
                                                        else 676
                                                    )
                                                    if state == 675:
                                                        return -0.346623212
                                                    if state == 676:
                                                        state = (
                                                            869
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.766879022
                                                            )
                                                            else 870
                                                        )
                                                        if state == 869:
                                                            return 0.153345302
                                                        if state == 870:
                                                            return -0.230126306
                                                if state == 506:
                                                    state = (
                                                        677
                                                        if x["distpsnr1_med"]
                                                        < 7.43751574
                                                        else 678
                                                    )
                                                    if state == 677:
                                                        state = (
                                                            871
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.23107135
                                                            )
                                                            else 872
                                                        )
                                                        if state == 871:
                                                            return 0.212409824
                                                        if state == 872:
                                                            return -0.0701888725
                                                    if state == 678:
                                                        return -0.333166569
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.980749965)
                        else 14
                    )
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 42.9421997)
                            else 28
                        )
                        if state == 27:
                            state = (
                                51
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.97113419)
                                else 52
                            )
                            if state == 51:
                                state = (
                                    97
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.4106598)
                                    else 98
                                )
                                if state == 97:
                                    state = (
                                        161
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 32.9973221)
                                        else 162
                                    )
                                    if state == 161:
                                        state = (
                                            251
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 13.2032681)
                                            else 252
                                        )
                                        if state == 251:
                                            state = (
                                                373
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 5.97567129)
                                                else 374
                                            )
                                            if state == 373:
                                                return 0.158652931
                                            if state == 374:
                                                return -0.356025368
                                        if state == 252:
                                            return 0.378383726
                                    if state == 162:
                                        return -0.191935658
                                if state == 98:
                                    state = 163 if x["neargaia_med"] < 36.86409 else 164
                                    if state == 163:
                                        return 0.390645713
                                    if state == 164:
                                        return -0.0726177618
                            if state == 52:
                                state = (
                                    99
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 16.9282837)
                                    else 100
                                )
                                if state == 99:
                                    state = (
                                        165 if x["neargaia_med"] < 8.48993778 else 166
                                    )
                                    if state == 165:
                                        state = (
                                            255
                                            if x["neargaia_med"] < 6.58851242
                                            else 256
                                        )
                                        if state == 255:
                                            return -0.115852252
                                        if state == 256:
                                            return 0.29668656
                                    if state == 166:
                                        state = (
                                            257
                                            if x["neargaia_med"] < 150.840149
                                            else 258
                                        )
                                        if state == 257:
                                            state = (
                                                375
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 12.8937035)
                                                else 376
                                            )
                                            if state == 375:
                                                state = (
                                                    509
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.975250006)
                                                    else 510
                                                )
                                                if state == 509:
                                                    state = (
                                                        679
                                                        if x["distpsnr1_med"]
                                                        < 13.8294773
                                                        else 680
                                                    )
                                                    if state == 679:
                                                        return -0.183432326
                                                    if state == 680:
                                                        return 0.300665855
                                                if state == 510:
                                                    state = (
                                                        681
                                                        if x["distpsnr1_med"]
                                                        < 10.7207232
                                                        else 682
                                                    )
                                                    if state == 681:
                                                        state = (
                                                            873
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.14692497
                                                            )
                                                            else 874
                                                        )
                                                        if state == 873:
                                                            return 0.18711701
                                                        if state == 874:
                                                            return -0.416201174
                                                    if state == 682:
                                                        return 0.334931374
                                            if state == 376:
                                                state = (
                                                    511
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.980250001)
                                                    else 512
                                                )
                                                if state == 511:
                                                    state = (
                                                        683
                                                        if x["distpsnr1_med"]
                                                        < 1.04122567
                                                        else 684
                                                    )
                                                    if state == 683:
                                                        state = (
                                                            875
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.3743093
                                                            )
                                                            else 876
                                                        )
                                                        if state == 875:
                                                            return -0.238953665
                                                        if state == 876:
                                                            return 0.186090529
                                                    if state == 684:
                                                        state = (
                                                            877
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.39427137
                                                            )
                                                            else 878
                                                        )
                                                        if state == 877:
                                                            return -0.523295522
                                                        if state == 878:
                                                            return -0.291189998
                                                if state == 512:
                                                    state = (
                                                        685
                                                        if x["distpsnr1_med"]
                                                        < 2.66959691
                                                        else 686
                                                    )
                                                    if state == 685:
                                                        state = (
                                                            879
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.78593874
                                                            )
                                                            else 880
                                                        )
                                                        if state == 879:
                                                            return 0.149536699
                                                        if state == 880:
                                                            return -0.211096808
                                                    if state == 686:
                                                        return 0.153298005
                                        if state == 258:
                                            state = (
                                                377
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 28.0562096)
                                                else 378
                                            )
                                            if state == 377:
                                                state = (
                                                    513
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.97874999)
                                                    else 514
                                                )
                                                if state == 513:
                                                    state = (
                                                        687
                                                        if x["distpsnr1_med"]
                                                        < 1.28141093
                                                        else 688
                                                    )
                                                    if state == 687:
                                                        state = (
                                                            881
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.12065744
                                                            )
                                                            else 882
                                                        )
                                                        if state == 881:
                                                            return -0.351425231
                                                        if state == 882:
                                                            return 0.318739414
                                                    if state == 688:
                                                        return -0.399565578
                                                if state == 514:
                                                    state = (
                                                        689
                                                        if x["distpsnr1_med"]
                                                        < 0.241595298
                                                        else 690
                                                    )
                                                    if state == 689:
                                                        state = (
                                                            883
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.200406909
                                                            )
                                                            else 884
                                                        )
                                                        if state == 883:
                                                            return 0.198048428
                                                        if state == 884:
                                                            return -0.118698999
                                                    if state == 690:
                                                        state = (
                                                            885
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 8.23108673
                                                            )
                                                            else 886
                                                        )
                                                        if state == 885:
                                                            return -0.422165692
                                                        if state == 886:
                                                            return 0.0792125911
                                            if state == 378:
                                                state = (
                                                    515
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.978249967)
                                                    else 516
                                                )
                                                if state == 515:
                                                    state = (
                                                        691
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 3.68107057
                                                        )
                                                        else 692
                                                    )
                                                    if state == 691:
                                                        state = (
                                                            887
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.304956198
                                                            )
                                                            else 888
                                                        )
                                                        if state == 887:
                                                            return -0.163468659
                                                        if state == 888:
                                                            return 0.298048556
                                                    if state == 692:
                                                        state = (
                                                            889
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 10.1389122
                                                            )
                                                            else 890
                                                        )
                                                        if state == 889:
                                                            return -0.347840667
                                                        if state == 890:
                                                            return 0.136676833
                                                if state == 516:
                                                    state = (
                                                        693
                                                        if x["distpsnr1_med"]
                                                        < 2.20235586
                                                        else 694
                                                    )
                                                    if state == 693:
                                                        state = (
                                                            891
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.201262131
                                                            )
                                                            else 892
                                                        )
                                                        if state == 891:
                                                            return 0.31674087
                                                        if state == 892:
                                                            return -0.0592854843
                                                    if state == 694:
                                                        state = (
                                                            893
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 7.65929031
                                                            )
                                                            else 894
                                                        )
                                                        if state == 893:
                                                            return -0.498257369
                                                        if state == 894:
                                                            return 0.155226216
                                if state == 100:
                                    state = (
                                        167 if x["neargaia_med"] < 2.29735804 else 168
                                    )
                                    if state == 167:
                                        state = (
                                            259
                                            if x["neargaia_med"] < 0.114709362
                                            else 260
                                        )
                                        if state == 259:
                                            return -0.329756945
                                        if state == 260:
                                            state = (
                                                379
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 17.958107)
                                                else 380
                                            )
                                            if state == 379:
                                                state = (
                                                    517
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.979750037)
                                                    else 518
                                                )
                                                if state == 517:
                                                    state = (
                                                        695
                                                        if x["distpsnr1_med"]
                                                        < 0.637836814
                                                        else 696
                                                    )
                                                    if state == 695:
                                                        state = (
                                                            895
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.74599123
                                                            )
                                                            else 896
                                                        )
                                                        if state == 895:
                                                            return -0.184946924
                                                        if state == 896:
                                                            return 0.404899031
                                                    if state == 696:
                                                        return -0.474917144
                                                if state == 518:
                                                    state = (
                                                        697
                                                        if x["distpsnr1_med"]
                                                        < 1.52844119
                                                        else 698
                                                    )
                                                    if state == 697:
                                                        state = (
                                                            897
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.756963909
                                                            )
                                                            else 898
                                                        )
                                                        if state == 897:
                                                            return 0.0739073977
                                                        if state == 898:
                                                            return -0.188366294
                                                    if state == 698:
                                                        return 0.345188856
                                            if state == 380:
                                                state = (
                                                    519
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.974250019)
                                                    else 520
                                                )
                                                if state == 519:
                                                    state = (
                                                        699
                                                        if x["distpsnr1_med"]
                                                        < 0.13145864
                                                        else 700
                                                    )
                                                    if state == 699:
                                                        return 0.278810918
                                                    if state == 700:
                                                        state = (
                                                            899
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.291288704
                                                            )
                                                            else 900
                                                        )
                                                        if state == 899:
                                                            return -0.186189756
                                                        if state == 900:
                                                            return 0.137148976
                                                if state == 520:
                                                    state = (
                                                        701
                                                        if x["distpsnr1_med"]
                                                        < 0.118475154
                                                        else 702
                                                    )
                                                    if state == 701:
                                                        return -0.0167930033
                                                    if state == 702:
                                                        state = (
                                                            901
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.04812539
                                                            )
                                                            else 902
                                                        )
                                                        if state == 901:
                                                            return 0.356405318
                                                        if state == 902:
                                                            return 0.147858873
                                    if state == 168:
                                        state = (
                                            261
                                            if x["neargaia_med"] < 10.4668427
                                            else 262
                                        )
                                        if state == 261:
                                            state = (
                                                381
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 16.0556374)
                                                else 382
                                            )
                                            if state == 381:
                                                state = (
                                                    521
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.976250052)
                                                    else 522
                                                )
                                                if state == 521:
                                                    state = (
                                                        703
                                                        if x["distpsnr1_med"]
                                                        < 3.41037512
                                                        else 704
                                                    )
                                                    if state == 703:
                                                        state = (
                                                            903
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.003685
                                                            )
                                                            else 904
                                                        )
                                                        if state == 903:
                                                            return -0.299074978
                                                        if state == 904:
                                                            return 0.243025899
                                                    if state == 704:
                                                        return -0.327070564
                                                if state == 522:
                                                    state = (
                                                        705
                                                        if x["distpsnr1_med"]
                                                        < 1.28988397
                                                        else 706
                                                    )
                                                    if state == 705:
                                                        return -0.42765066
                                                    if state == 706:
                                                        state = (
                                                            905
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.57380438
                                                            )
                                                            else 906
                                                        )
                                                        if state == 905:
                                                            return 0.22332108
                                                        if state == 906:
                                                            return -0.311284602
                                            if state == 382:
                                                state = (
                                                    523
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.973249972)
                                                    else 524
                                                )
                                                if state == 523:
                                                    state = (
                                                        707
                                                        if x["distpsnr1_med"]
                                                        < 3.49990463
                                                        else 708
                                                    )
                                                    if state == 707:
                                                        return -0.358299673
                                                    if state == 708:
                                                        state = (
                                                            907
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.37027311
                                                            )
                                                            else 908
                                                        )
                                                        if state == 907:
                                                            return 0.318105966
                                                        if state == 908:
                                                            return -0.155657634
                                                if state == 524:
                                                    state = (
                                                        709
                                                        if x["distpsnr1_med"]
                                                        < 1.38302517
                                                        else 710
                                                    )
                                                    if state == 709:
                                                        state = (
                                                            909
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.402457595
                                                            )
                                                            else 910
                                                        )
                                                        if state == 909:
                                                            return 0.224803299
                                                        if state == 910:
                                                            return -0.152567253
                                                    if state == 710:
                                                        state = (
                                                            911
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.48039293
                                                            )
                                                            else 912
                                                        )
                                                        if state == 911:
                                                            return -0.600264668
                                                        if state == 912:
                                                            return -0.323066086
                                        if state == 262:
                                            state = (
                                                383
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 22.5485706)
                                                else 384
                                            )
                                            if state == 383:
                                                state = (
                                                    525
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.97874999)
                                                    else 526
                                                )
                                                if state == 525:
                                                    state = (
                                                        711
                                                        if x["distpsnr1_med"]
                                                        < 2.93936539
                                                        else 712
                                                    )
                                                    if state == 711:
                                                        state = (
                                                            913
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.91052294
                                                            )
                                                            else 914
                                                        )
                                                        if state == 913:
                                                            return -0.126159668
                                                        if state == 914:
                                                            return 0.415702224
                                                    if state == 712:
                                                        state = (
                                                            915
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.57748628
                                                            )
                                                            else 916
                                                        )
                                                        if state == 915:
                                                            return -0.0542890243
                                                        if state == 916:
                                                            return -0.395114958
                                                if state == 526:
                                                    state = (
                                                        713
                                                        if x["distpsnr1_med"]
                                                        < 1.98959064
                                                        else 714
                                                    )
                                                    if state == 713:
                                                        state = (
                                                            917
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.124375597
                                                            )
                                                            else 918
                                                        )
                                                        if state == 917:
                                                            return 0.299905837
                                                        if state == 918:
                                                            return -0.223282531
                                                    if state == 714:
                                                        state = (
                                                            919
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 4.34186172
                                                            )
                                                            else 920
                                                        )
                                                        if state == 919:
                                                            return 0.150214016
                                                        if state == 920:
                                                            return -0.296605945
                                            if state == 384:
                                                state = (
                                                    527
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.976500034)
                                                    else 528
                                                )
                                                if state == 527:
                                                    state = (
                                                        715
                                                        if x["distpsnr1_med"]
                                                        < 2.8124361
                                                        else 716
                                                    )
                                                    if state == 715:
                                                        state = (
                                                            921
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.283818871
                                                            )
                                                            else 922
                                                        )
                                                        if state == 921:
                                                            return -0.263764769
                                                        if state == 922:
                                                            return 0.203855276
                                                    if state == 716:
                                                        state = (
                                                            923
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.32562923
                                                            )
                                                            else 924
                                                        )
                                                        if state == 923:
                                                            return 0.304973602
                                                        if state == 924:
                                                            return -0.17775242
                                                if state == 528:
                                                    state = (
                                                        717
                                                        if x["distpsnr1_med"]
                                                        < 1.97562265
                                                        else 718
                                                    )
                                                    if state == 717:
                                                        state = (
                                                            925
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.21788001
                                                            )
                                                            else 926
                                                        )
                                                        if state == 925:
                                                            return 0.0148005765
                                                        if state == 926:
                                                            return -0.435054034
                                                    if state == 718:
                                                        state = (
                                                            927
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.13393164
                                                            )
                                                            else 928
                                                        )
                                                        if state == 927:
                                                            return 0.17522262
                                                        if state == 928:
                                                            return -0.100141995
                        if state == 28:
                            state = (
                                53
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 53.9480133)
                                else 54
                            )
                            if state == 53:
                                state = (
                                    101
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.1122704)
                                    else 102
                                )
                                if state == 101:
                                    state = (
                                        169
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 12.3384552)
                                        else 170
                                    )
                                    if state == 169:
                                        state = (
                                            263
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 7.4882803)
                                            else 264
                                        )
                                        if state == 263:
                                            state = (
                                                385
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 52.9227295)
                                                else 386
                                            )
                                            if state == 385:
                                                state = (
                                                    529
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.97874999)
                                                    else 530
                                                )
                                                if state == 529:
                                                    state = (
                                                        719
                                                        if x["distpsnr1_med"]
                                                        < 2.41350079
                                                        else 720
                                                    )
                                                    if state == 719:
                                                        return -0.270291805
                                                    if state == 720:
                                                        state = (
                                                            929
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.72682238
                                                            )
                                                            else 930
                                                        )
                                                        if state == 929:
                                                            return -0.0502778254
                                                        if state == 930:
                                                            return 0.307158023
                                                if state == 530:
                                                    state = (
                                                        721
                                                        if x["distpsnr1_med"]
                                                        < 5.02378893
                                                        else 722
                                                    )
                                                    if state == 721:
                                                        state = (
                                                            931
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.47779775
                                                            )
                                                            else 932
                                                        )
                                                        if state == 931:
                                                            return 0.371223092
                                                        if state == 932:
                                                            return 0.0467492007
                                                    if state == 722:
                                                        return -0.195028558
                                            if state == 386:
                                                return -0.317625612
                                        if state == 264:
                                            return -0.325488925
                                    if state == 170:
                                        state = (
                                            265
                                            if x["neargaia_med"] < 15.0988445
                                            else 266
                                        )
                                        if state == 265:
                                            return 0.348202795
                                        if state == 266:
                                            state = (
                                                387
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 44.9586411)
                                                else 388
                                            )
                                            if state == 387:
                                                state = (
                                                    531
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.973249972)
                                                    else 532
                                                )
                                                if state == 531:
                                                    return 0.0443052761
                                                if state == 532:
                                                    state = (
                                                        723
                                                        if x["distpsnr1_med"]
                                                        < 3.22471333
                                                        else 724
                                                    )
                                                    if state == 723:
                                                        return 0.289742142
                                                    if state == 724:
                                                        return -0.122873113
                                            if state == 388:
                                                state = (
                                                    533
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.973749995)
                                                    else 534
                                                )
                                                if state == 533:
                                                    return -0.280534327
                                                if state == 534:
                                                    state = (
                                                        725
                                                        if x["distpsnr1_med"]
                                                        < 1.05491734
                                                        else 726
                                                    )
                                                    if state == 725:
                                                        state = (
                                                            933
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.518905282
                                                            )
                                                            else 934
                                                        )
                                                        if state == 933:
                                                            return 0.0589497909
                                                        if state == 934:
                                                            return -0.189483121
                                                    if state == 726:
                                                        state = (
                                                            935
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 5.02938223
                                                            )
                                                            else 936
                                                        )
                                                        if state == 935:
                                                            return 0.195871606
                                                        if state == 936:
                                                            return -0.102909245
                                if state == 102:
                                    state = (
                                        171 if x["neargaia_med"] < 2.51879883 else 172
                                    )
                                    if state == 171:
                                        state = (
                                            267
                                            if x["neargaia_med"] < 0.714266181
                                            else 268
                                        )
                                        if state == 267:
                                            return -0.129570052
                                        if state == 268:
                                            return 0.253076613
                                    if state == 172:
                                        state = (
                                            269
                                            if x["neargaia_med"] < 16.401577
                                            else 270
                                        )
                                        if state == 269:
                                            return -0.387444884
                                        if state == 270:
                                            state = (
                                                389
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 43.4366226)
                                                else 390
                                            )
                                            if state == 389:
                                                return 0.183553249
                                            if state == 390:
                                                state = (
                                                    535
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.976250052)
                                                    else 536
                                                )
                                                if state == 535:
                                                    state = (
                                                        727
                                                        if x["distpsnr1_med"]
                                                        < 1.23208129
                                                        else 728
                                                    )
                                                    if state == 727:
                                                        return 0.156670377
                                                    if state == 728:
                                                        return -0.290944278
                                                if state == 536:
                                                    state = (
                                                        729
                                                        if x["distpsnr1_med"]
                                                        < 9.67857361
                                                        else 730
                                                    )
                                                    if state == 729:
                                                        state = (
                                                            937
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.6403532
                                                            )
                                                            else 938
                                                        )
                                                        if state == 937:
                                                            return -0.144463778
                                                        if state == 938:
                                                            return 0.0488192514
                                                    if state == 730:
                                                        return 0.234866455
                            if state == 54:
                                state = 103 if x["maggaia_med"] < 20.3643723 else 104
                                if state == 103:
                                    state = (
                                        173 if x["neargaia_med"] < 0.603323638 else 174
                                    )
                                    if state == 173:
                                        return -0.371527702
                                    if state == 174:
                                        state = (
                                            271
                                            if x["neargaia_med"] < 51.3312492
                                            else 272
                                        )
                                        if state == 271:
                                            state = (
                                                391
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 55.9597473)
                                                else 392
                                            )
                                            if state == 391:
                                                return 0.219439611
                                            if state == 392:
                                                state = (
                                                    537
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.97450006)
                                                    else 538
                                                )
                                                if state == 537:
                                                    state = (
                                                        731
                                                        if x["distpsnr1_med"]
                                                        < 0.56210959
                                                        else 732
                                                    )
                                                    if state == 731:
                                                        return 0.170694545
                                                    if state == 732:
                                                        state = (
                                                            941
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.75215626
                                                            )
                                                            else 942
                                                        )
                                                        if state == 941:
                                                            return -0.288389385
                                                        if state == 942:
                                                            return 0.0296806209
                                                if state == 538:
                                                    state = (
                                                        733
                                                        if x["distpsnr1_med"]
                                                        < 2.03887558
                                                        else 734
                                                    )
                                                    if state == 733:
                                                        state = (
                                                            943
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.897676229
                                                            )
                                                            else 944
                                                        )
                                                        if state == 943:
                                                            return 0.051488705
                                                        if state == 944:
                                                            return 0.288669825
                                                    if state == 734:
                                                        state = (
                                                            945
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.57531905
                                                            )
                                                            else 946
                                                        )
                                                        if state == 945:
                                                            return -0.161956564
                                                        if state == 946:
                                                            return 0.243767217
                                        if state == 272:
                                            return 0.392776877
                                if state == 104:
                                    state = (
                                        175
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 4.27853251)
                                        else 176
                                    )
                                    if state == 175:
                                        return 0.328799218
                                    if state == 176:
                                        state = (
                                            273
                                            if x["neargaia_med"] < 17.0853462
                                            else 274
                                        )
                                        if state == 273:
                                            return -0.209776878
                                        if state == 274:
                                            return 0.212911561
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 26.0197563)
                            else 30
                        )
                        if state == 29:
                            state = (
                                55
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 13.9257698)
                                else 56
                            )
                            if state == 55:
                                state = 105 if x["maggaia_med"] < 19.2939339 else 106
                                if state == 105:
                                    state = (
                                        177 if x["neargaia_med"] < 14.4731741 else 178
                                    )
                                    if state == 177:
                                        state = (
                                            275
                                            if x["neargaia_med"] < 1.58747196
                                            else 276
                                        )
                                        if state == 275:
                                            state = (
                                                393
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 7.48913765)
                                                else 394
                                            )
                                            if state == 393:
                                                return -0.128912047
                                            if state == 394:
                                                return 0.1833231
                                        if state == 276:
                                            state = (
                                                395
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 12.0445662)
                                                else 396
                                            )
                                            if state == 395:
                                                return -0.677369773
                                            if state == 396:
                                                return -0.0343744755
                                    if state == 178:
                                        state = (
                                            277
                                            if x["neargaia_med"] < 28.0330524
                                            else 278
                                        )
                                        if state == 277:
                                            state = (
                                                397
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 11.9049358)
                                                else 398
                                            )
                                            if state == 397:
                                                return 0.256152898
                                            if state == 398:
                                                return 0.000777322915
                                        if state == 278:
                                            state = (
                                                399
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 7.03666067)
                                                else 400
                                            )
                                            if state == 399:
                                                return -0.0794068351
                                            if state == 400:
                                                return -0.432890922
                                if state == 106:
                                    state = (
                                        179
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 19.3224964)
                                        else 180
                                    )
                                    if state == 179:
                                        state = (
                                            279
                                            if x["neargaia_med"] < 0.805457532
                                            else 280
                                        )
                                        if state == 279:
                                            return 0.141959876
                                        if state == 280:
                                            state = (
                                                401
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 8.90884781)
                                                else 402
                                            )
                                            if state == 401:
                                                state = (
                                                    541
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.981250048)
                                                    else 542
                                                )
                                                if state == 541:
                                                    return 0.0751077384
                                                if state == 542:
                                                    return -0.159224048
                                            if state == 402:
                                                return -0.349822909
                                    if state == 180:
                                        state = (
                                            281
                                            if x["neargaia_med"] < 33.4263268
                                            else 282
                                        )
                                        if state == 281:
                                            return 0.199071079
                                        if state == 282:
                                            state = (
                                                403
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 11.95364)
                                                else 404
                                            )
                                            if state == 403:
                                                state = (
                                                    543
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.983250022)
                                                    else 544
                                                )
                                                if state == 543:
                                                    return 0.229776725
                                                if state == 544:
                                                    return -0.128143713
                                            if state == 404:
                                                return -0.214626431
                            if state == 56:
                                state = 107 if x["maggaia_med"] < 16.9825668 else 108
                                if state == 107:
                                    state = (
                                        181 if x["neargaia_med"] < 13.7522259 else 182
                                    )
                                    if state == 181:
                                        state = (
                                            283
                                            if x["neargaia_med"] < 11.8308868
                                            else 284
                                        )
                                        if state == 283:
                                            return 0.126043797
                                        if state == 284:
                                            return -0.111763842
                                    if state == 182:
                                        state = (
                                            285
                                            if x["neargaia_med"] < 65.7634888
                                            else 286
                                        )
                                        if state == 285:
                                            state = (
                                                407
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 22.0139694)
                                                else 408
                                            )
                                            if state == 407:
                                                state = (
                                                    549
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982749999)
                                                    else 550
                                                )
                                                if state == 549:
                                                    state = (
                                                        739
                                                        if x["distpsnr1_med"]
                                                        < 0.602623701
                                                        else 740
                                                    )
                                                    if state == 739:
                                                        state = (
                                                            947
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.625802517
                                                            )
                                                            else 948
                                                        )
                                                        if state == 947:
                                                            return 0.0367049947
                                                        if state == 948:
                                                            return -0.14248684
                                                    if state == 740:
                                                        return 0.433829635
                                                if state == 550:
                                                    state = (
                                                        741
                                                        if x["distpsnr1_med"]
                                                        < 3.81259298
                                                        else 742
                                                    )
                                                    if state == 741:
                                                        return 0.137081146
                                                    if state == 742:
                                                        return -0.0836408436
                                            if state == 408:
                                                state = (
                                                    551
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.981250048)
                                                    else 552
                                                )
                                                if state == 551:
                                                    return 0.0584689155
                                                if state == 552:
                                                    state = (
                                                        745
                                                        if x["distpsnr1_med"]
                                                        < 6.11747551
                                                        else 746
                                                    )
                                                    if state == 745:
                                                        state = (
                                                            951
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 4.15117645
                                                            )
                                                            else 952
                                                        )
                                                        if state == 951:
                                                            return 0.186779067
                                                        if state == 952:
                                                            return -0.20980534
                                                    if state == 746:
                                                        return 0.30809024
                                        if state == 286:
                                            return -0.0846512169
                                if state == 108:
                                    state = (
                                        183 if x["neargaia_med"] < 18.0681229 else 184
                                    )
                                    if state == 183:
                                        state = (
                                            287
                                            if x["neargaia_med"] < 15.6488857
                                            else 288
                                        )
                                        if state == 287:
                                            state = (
                                                409
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 14.9414577)
                                                else 410
                                            )
                                            if state == 409:
                                                state = (
                                                    553
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982499957)
                                                    else 554
                                                )
                                                if state == 553:
                                                    return 0.445364326
                                                if state == 554:
                                                    return 0.0134726465
                                            if state == 410:
                                                state = (
                                                    555
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982249975)
                                                    else 556
                                                )
                                                if state == 555:
                                                    state = (
                                                        747
                                                        if x["distpsnr1_med"]
                                                        < 1.57212067
                                                        else 748
                                                    )
                                                    if state == 747:
                                                        state = (
                                                            953
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.20321333
                                                            )
                                                            else 954
                                                        )
                                                        if state == 953:
                                                            return -0.0381780714
                                                        if state == 954:
                                                            return 0.355934083
                                                    if state == 748:
                                                        state = (
                                                            955
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.16092253
                                                            )
                                                            else 956
                                                        )
                                                        if state == 955:
                                                            return -0.495816559
                                                        if state == 956:
                                                            return -0.140384972
                                                if state == 556:
                                                    state = (
                                                        749
                                                        if x["distpsnr1_med"]
                                                        < 5.13714504
                                                        else 750
                                                    )
                                                    if state == 749:
                                                        state = (
                                                            957
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.56092477
                                                            )
                                                            else 958
                                                        )
                                                        if state == 957:
                                                            return 0.194662571
                                                        if state == 958:
                                                            return -0.22031717
                                                    if state == 750:
                                                        state = (
                                                            959
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.00934684
                                                            )
                                                            else 960
                                                        )
                                                        if state == 959:
                                                            return -0.0890158936
                                                        if state == 960:
                                                            return 0.284813941
                                        if state == 288:
                                            return -0.500767529
                                    if state == 184:
                                        state = (
                                            289
                                            if x["neargaia_med"] < 33.9011307
                                            else 290
                                        )
                                        if state == 289:
                                            state = (
                                                411
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 25.0057831)
                                                else 412
                                            )
                                            if state == 411:
                                                return 0.258900642
                                            if state == 412:
                                                state = (
                                                    557
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982249975)
                                                    else 558
                                                )
                                                if state == 557:
                                                    state = (
                                                        751
                                                        if x["distpsnr1_med"]
                                                        < 4.03291512
                                                        else 752
                                                    )
                                                    if state == 751:
                                                        state = (
                                                            961
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.84624052
                                                            )
                                                            else 962
                                                        )
                                                        if state == 961:
                                                            return -0.00186520081
                                                        if state == 962:
                                                            return -0.295075089
                                                    if state == 752:
                                                        return 0.249192476
                                                if state == 558:
                                                    state = (
                                                        753
                                                        if x["distpsnr1_med"]
                                                        < 3.61441231
                                                        else 754
                                                    )
                                                    if state == 753:
                                                        return 0.160426959
                                                    if state == 754:
                                                        return -0.301556289
                                        if state == 290:
                                            state = (
                                                413
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 25.9501457)
                                                else 414
                                            )
                                            if state == 413:
                                                state = (
                                                    559
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982249975)
                                                    else 560
                                                )
                                                if state == 559:
                                                    state = (
                                                        755
                                                        if x["distpsnr1_med"]
                                                        < 3.69974661
                                                        else 756
                                                    )
                                                    if state == 755:
                                                        state = (
                                                            963
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.59915489
                                                            )
                                                            else 964
                                                        )
                                                        if state == 963:
                                                            return 0.0295708813
                                                        if state == 964:
                                                            return -0.338689297
                                                    if state == 756:
                                                        state = (
                                                            965
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 9.37474823
                                                            )
                                                            else 966
                                                        )
                                                        if state == 965:
                                                            return -0.0145718576
                                                        if state == 966:
                                                            return 0.325698972
                                                if state == 560:
                                                    state = (
                                                        757
                                                        if x["distpsnr1_med"]
                                                        < 4.65741682
                                                        else 758
                                                    )
                                                    if state == 757:
                                                        state = (
                                                            967
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.23136163
                                                            )
                                                            else 968
                                                        )
                                                        if state == 967:
                                                            return 0.102336302
                                                        if state == 968:
                                                            return -0.315089077
                                                    if state == 758:
                                                        return 0.337008387
                                            if state == 414:
                                                state = (
                                                    561
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.983250022)
                                                    else 562
                                                )
                                                if state == 561:
                                                    return -0.452953756
                                                if state == 562:
                                                    return -0.0372818969
                        if state == 30:
                            state = (
                                57
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 36.9405899)
                                else 58
                            )
                            if state == 57:
                                state = 109 if x["maggaia_med"] < 18.7685165 else 110
                                if state == 109:
                                    state = (
                                        185 if x["neargaia_med"] < 18.2999821 else 186
                                    )
                                    if state == 185:
                                        state = (
                                            291
                                            if x["neargaia_med"] < 12.076129
                                            else 292
                                        )
                                        if state == 291:
                                            state = (
                                                415
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 26.9276447)
                                                else 416
                                            )
                                            if state == 415:
                                                return -0.0588922761
                                            if state == 416:
                                                state = (
                                                    563
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.981750011)
                                                    else 564
                                                )
                                                if state == 563:
                                                    state = (
                                                        759
                                                        if x["distpsnr1_med"]
                                                        < 1.65669477
                                                        else 760
                                                    )
                                                    if state == 759:
                                                        return 0.282391876
                                                    if state == 760:
                                                        state = (
                                                            971
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.24838066
                                                            )
                                                            else 972
                                                        )
                                                        if state == 971:
                                                            return -0.309752762
                                                        if state == 972:
                                                            return 0.131966367
                                                if state == 564:
                                                    state = (
                                                        761
                                                        if x["distpsnr1_med"]
                                                        < 0.321109295
                                                        else 762
                                                    )
                                                    if state == 761:
                                                        return -0.0177022386
                                                    if state == 762:
                                                        return 0.347153306
                                        if state == 292:
                                            state = (
                                                417
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 30.9523087)
                                                else 418
                                            )
                                            if state == 417:
                                                state = (
                                                    565
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.981250048)
                                                    else 566
                                                )
                                                if state == 565:
                                                    state = (
                                                        763
                                                        if x["distpsnr1_med"]
                                                        < 2.82191038
                                                        else 764
                                                    )
                                                    if state == 763:
                                                        return 0.132107049
                                                    if state == 764:
                                                        return -0.218580365
                                                if state == 566:
                                                    return 0.279357493
                                            if state == 418:
                                                state = (
                                                    567
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.983250022)
                                                    else 568
                                                )
                                                if state == 567:
                                                    state = (
                                                        765
                                                        if x["distpsnr1_med"]
                                                        < 1.31434619
                                                        else 766
                                                    )
                                                    if state == 765:
                                                        return 0.229659811
                                                    if state == 766:
                                                        state = (
                                                            973
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.4539392
                                                            )
                                                            else 974
                                                        )
                                                        if state == 973:
                                                            return 0.114032976
                                                        if state == 974:
                                                            return -0.312581867
                                                if state == 568:
                                                    return 0.164175645
                                    if state == 186:
                                        return 0.31473127
                                if state == 110:
                                    state = (
                                        187
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 41.9776649)
                                        else 188
                                    )
                                    if state == 187:
                                        state = (
                                            293
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 17.8558807)
                                            else 294
                                        )
                                        if state == 293:
                                            state = (
                                                419
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 33.0918274)
                                                else 420
                                            )
                                            if state == 419:
                                                state = (
                                                    569
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982749999)
                                                    else 570
                                                )
                                                if state == 569:
                                                    state = (
                                                        767
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 1.83499622
                                                        )
                                                        else 768
                                                    )
                                                    if state == 767:
                                                        state = (
                                                            975
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.1963121
                                                            )
                                                            else 976
                                                        )
                                                        if state == 975:
                                                            return 0.233457506
                                                        if state == 976:
                                                            return 0.00487184618
                                                    if state == 768:
                                                        state = (
                                                            977
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.52727485
                                                            )
                                                            else 978
                                                        )
                                                        if state == 977:
                                                            return -0.51133883
                                                        if state == 978:
                                                            return 0.101331867
                                                if state == 570:
                                                    state = (
                                                        769
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 7.97203779
                                                        )
                                                        else 770
                                                    )
                                                    if state == 769:
                                                        state = (
                                                            979
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.64972353
                                                            )
                                                            else 980
                                                        )
                                                        if state == 979:
                                                            return 0.380116522
                                                        if state == 980:
                                                            return 0.156781599
                                                    if state == 770:
                                                        return -0.214044482
                                            if state == 420:
                                                state = (
                                                    571
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982749999)
                                                    else 572
                                                )
                                                if state == 571:
                                                    state = (
                                                        771
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 0.635789037
                                                        )
                                                        else 772
                                                    )
                                                    if state == 771:
                                                        return 0.304096252
                                                    if state == 772:
                                                        state = (
                                                            981
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.732284248
                                                            )
                                                            else 982
                                                        )
                                                        if state == 981:
                                                            return 0.117722005
                                                        if state == 982:
                                                            return -0.184265688
                                                if state == 572:
                                                    return 0.345443338
                                        if state == 294:
                                            state = (
                                                421
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 34.9084435)
                                                else 422
                                            )
                                            if state == 421:
                                                state = (
                                                    573
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.981250048)
                                                    else 574
                                                )
                                                if state == 573:
                                                    state = (
                                                        773
                                                        if x["distpsnr1_med"]
                                                        < 3.46361637
                                                        else 774
                                                    )
                                                    if state == 773:
                                                        state = (
                                                            983
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.35295081
                                                            )
                                                            else 984
                                                        )
                                                        if state == 983:
                                                            return 0.262999117
                                                        if state == 984:
                                                            return -0.129103333
                                                    if state == 774:
                                                        state = (
                                                            985
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.58968639
                                                            )
                                                            else 986
                                                        )
                                                        if state == 985:
                                                            return -0.170466721
                                                        if state == 986:
                                                            return 0.178888008
                                                if state == 574:
                                                    return 0.39450407
                                            if state == 422:
                                                state = (
                                                    575
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.981750011)
                                                    else 576
                                                )
                                                if state == 575:
                                                    return -0.00491687562
                                                if state == 576:
                                                    return 0.225873366
                                    if state == 188:
                                        state = (
                                            295
                                            if x["neargaia_med"] < 63.9508057
                                            else 296
                                        )
                                        if state == 295:
                                            state = (
                                                423
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 33.5252762)
                                                else 424
                                            )
                                            if state == 423:
                                                state = (
                                                    577
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982749999)
                                                    else 578
                                                )
                                                if state == 577:
                                                    state = (
                                                        775
                                                        if x["distpsnr1_med"]
                                                        < 0.182189614
                                                        else 776
                                                    )
                                                    if state == 775:
                                                        return 0.131549835
                                                    if state == 776:
                                                        return -0.471462309
                                                if state == 578:
                                                    state = (
                                                        777
                                                        if x["distpsnr1_med"]
                                                        < 1.34859753
                                                        else 778
                                                    )
                                                    if state == 777:
                                                        state = (
                                                            987
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.506159723
                                                            )
                                                            else 988
                                                        )
                                                        if state == 987:
                                                            return 0.176861808
                                                        if state == 988:
                                                            return -0.275503039
                                                    if state == 778:
                                                        return 0.211533248
                                            if state == 424:
                                                return -0.410582244
                                        if state == 296:
                                            return 0.25213033
                            if state == 58:
                                state = (
                                    111
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 15.5528975)
                                    else 112
                                )
                                if state == 111:
                                    state = (
                                        189 if x["neargaia_med"] < 25.3041573 else 190
                                    )
                                    if state == 189:
                                        return -0.488101631
                                    if state == 190:
                                        state = (
                                            297
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 45.6906662)
                                            else 298
                                        )
                                        if state == 297:
                                            state = (
                                                425
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 58.5280533)
                                                else 426
                                            )
                                            if state == 425:
                                                return 0.291429877
                                            if state == 426:
                                                state = (
                                                    579
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982249975)
                                                    else 580
                                                )
                                                if state == 579:
                                                    state = (
                                                        779
                                                        if x["distpsnr1_med"]
                                                        < 2.13498521
                                                        else 780
                                                    )
                                                    if state == 779:
                                                        return -0.351582319
                                                    if state == 780:
                                                        return 0.118420117
                                                if state == 580:
                                                    return 0.147603557
                                        if state == 298:
                                            state = (
                                                427
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 51.3871613)
                                                else 428
                                            )
                                            if state == 427:
                                                return -0.168712601
                                            if state == 428:
                                                return 0.17255564
                                if state == 112:
                                    state = (
                                        191 if x["neargaia_med"] < 0.132091612 else 192
                                    )
                                    if state == 191:
                                        return -0.224985883
                                    if state == 192:
                                        state = (
                                            299
                                            if x["neargaia_med"] < 15.9710712
                                            else 300
                                        )
                                        if state == 299:
                                            state = (
                                                429
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 37.9927979)
                                                else 430
                                            )
                                            if state == 429:
                                                state = (
                                                    581
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.98150003)
                                                    else 582
                                                )
                                                if state == 581:
                                                    return -0.380657107
                                                if state == 582:
                                                    state = (
                                                        781
                                                        if x["distpsnr1_med"]
                                                        < 1.74264479
                                                        else 782
                                                    )
                                                    if state == 781:
                                                        return 0.255129844
                                                    if state == 782:
                                                        state = (
                                                            989
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.69492722
                                                            )
                                                            else 990
                                                        )
                                                        if state == 989:
                                                            return -0.112034827
                                                        if state == 990:
                                                            return 0.232345894
                                            if state == 430:
                                                state = (
                                                    583
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982249975)
                                                    else 584
                                                )
                                                if state == 583:
                                                    state = (
                                                        783
                                                        if x["distpsnr1_med"]
                                                        < 0.20253852
                                                        else 784
                                                    )
                                                    if state == 783:
                                                        state = (
                                                            991
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.277472109
                                                            )
                                                            else 992
                                                        )
                                                        if state == 991:
                                                            return -0.291853786
                                                        if state == 992:
                                                            return 0.347355664
                                                    if state == 784:
                                                        state = (
                                                            993
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 5.80105257
                                                            )
                                                            else 994
                                                        )
                                                        if state == 993:
                                                            return 0.254757494
                                                        if state == 994:
                                                            return -0.130766153
                                                if state == 584:
                                                    state = (
                                                        785
                                                        if x["distpsnr1_med"]
                                                        < 2.69570255
                                                        else 786
                                                    )
                                                    if state == 785:
                                                        state = (
                                                            995
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.48495054
                                                            )
                                                            else 996
                                                        )
                                                        if state == 995:
                                                            return 0.274006665
                                                        if state == 996:
                                                            return -0.160510644
                                                    if state == 786:
                                                        state = (
                                                            997
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.479688108
                                                            )
                                                            else 998
                                                        )
                                                        if state == 997:
                                                            return -0.190069839
                                                        if state == 998:
                                                            return 0.378329962
                                        if state == 300:
                                            return 0.34776637
    elif num_booster == 9:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.341547757) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.976250052)
                    else 4
                )
                if state == 3:
                    return -0.391638696
                if state == 4:
                    state = 7 if x["maggaia_med"] < 41.7316742 else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 16.0669003)
                            else 14
                        )
                        if state == 13:
                            return 0.0576364398
                        if state == 14:
                            return -0.384669393
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.7907639)
                            else 16
                        )
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 9.50869179)
                                else 26
                            )
                            if state == 25:
                                return 0.322404683
                            if state == 26:
                                return -0.230433285
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 8.36882591)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    45
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 22.9712849)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        81
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 19.9456406)
                                        else 82
                                    )
                                    if state == 81:
                                        return -0.225736633
                                    if state == 82:
                                        return 0.166373342
                                if state == 46:
                                    state = (
                                        83
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 35.5052338)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            147
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982249975)
                                            else 148
                                        )
                                        if state == 147:
                                            return -0.284730345
                                        if state == 148:
                                            return 0.156374022
                                    if state == 84:
                                        state = (
                                            149
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.981750011)
                                            else 150
                                        )
                                        if state == 149:
                                            return -0.337656587
                                        if state == 150:
                                            return -0.0147075439
                            if state == 28:
                                state = (
                                    47
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 26.9826622)
                                    else 48
                                )
                                if state == 47:
                                    return -0.211898535
                                if state == 48:
                                    state = (
                                        87
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 53.3714066)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            151
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.97874999)
                                            else 152
                                        )
                                        if state == 151:
                                            return 0.0123081477
                                        if state == 152:
                                            return 0.195681006
                                    if state == 88:
                                        return -0.213662818
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.972249985)
                    else 6
                )
                if state == 5:
                    state = 9 if x["maggaia_med"] < 16.5544395 else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6711159)
                            else 18
                        )
                        if state == 17:
                            state = (
                                29
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.94959497)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    49
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 26.4194489)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        89
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 6.51607656)
                                        else 90
                                    )
                                    if state == 89:
                                        return 0.368122935
                                    if state == 90:
                                        state = (
                                            153
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.901000023)
                                            else 154
                                        )
                                        if state == 153:
                                            state = (
                                                237
                                                if x["maggaia_med"] < 16.4968719
                                                else 238
                                            )
                                            if state == 237:
                                                return -0.133471102
                                            if state == 238:
                                                return 0.455139935
                                        if state == 154:
                                            state = (
                                                239
                                                if x["maggaia_med"] < 16.1716766
                                                else 240
                                            )
                                            if state == 239:
                                                state = (
                                                    353
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.962249994)
                                                    else 354
                                                )
                                                if state == 353:
                                                    state = (
                                                        475
                                                        if x["distpsnr1_med"]
                                                        < 9.8248682
                                                        else 476
                                                    )
                                                    if state == 475:
                                                        state = (
                                                            647
                                                            if x["distpsnr1_med"]
                                                            < 2.09811258
                                                            else 648
                                                        )
                                                        if state == 647:
                                                            return -0.0335091352
                                                        if state == 648:
                                                            return -0.277919501
                                                    if state == 476:
                                                        return 0.174058542
                                                if state == 354:
                                                    state = (
                                                        477
                                                        if x["distpsnr1_med"]
                                                        < 0.381498486
                                                        else 478
                                                    )
                                                    if state == 477:
                                                        return 0.0988526791
                                                    if state == 478:
                                                        return -0.430156976
                                            if state == 240:
                                                state = (
                                                    355
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.965499997)
                                                    else 356
                                                )
                                                if state == 355:
                                                    return -0.131008908
                                                if state == 356:
                                                    return 0.374305695
                                if state == 50:
                                    state = (
                                        91
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 32.9660988)
                                        else 92
                                    )
                                    if state == 91:
                                        state = (
                                            155
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.955500007)
                                            else 156
                                        )
                                        if state == 155:
                                            state = (
                                                241
                                                if x["maggaia_med"] < 16.4968719
                                                else 242
                                            )
                                            if state == 241:
                                                state = (
                                                    357
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.952250004)
                                                    else 358
                                                )
                                                if state == 357:
                                                    return -0.178254515
                                                if state == 358:
                                                    return 0.15539746
                                            if state == 242:
                                                return 0.272219688
                                        if state == 156:
                                            return -0.316526979
                                    if state == 92:
                                        return -0.37860921
                            if state == 30:
                                state = (
                                    51
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 20.4621296)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        93
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 15.4158621)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            157
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.96025002)
                                            else 158
                                        )
                                        if state == 157:
                                            state = (
                                                243
                                                if x["maggaia_med"] < 15.9949379
                                                else 244
                                            )
                                            if state == 243:
                                                state = (
                                                    359
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.76700002)
                                                    else 360
                                                )
                                                if state == 359:
                                                    return 0.110745959
                                                if state == 360:
                                                    return -0.135280088
                                            if state == 244:
                                                return 0.1991207
                                        if state == 158:
                                            state = (
                                                245
                                                if x["maggaia_med"] < 15.5326023
                                                else 246
                                            )
                                            if state == 245:
                                                return -0.312685907
                                            if state == 246:
                                                return 0.0909532011
                                    if state == 94:
                                        return -0.29436639
                                if state == 52:
                                    state = (
                                        95
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 31.021719)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            159
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.908749998)
                                            else 160
                                        )
                                        if state == 159:
                                            state = (
                                                247
                                                if x["maggaia_med"] < 15.7814999
                                                else 248
                                            )
                                            if state == 247:
                                                return 0.388301581
                                            if state == 248:
                                                return -0.120433487
                                        if state == 160:
                                            state = (
                                                249
                                                if x["maggaia_med"] < 15.9789343
                                                else 250
                                            )
                                            if state == 249:
                                                return 0.270823836
                                            if state == 250:
                                                state = (
                                                    361
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.945500016)
                                                    else 362
                                                )
                                                if state == 361:
                                                    return -0.222308487
                                                if state == 362:
                                                    state = (
                                                        479
                                                        if x["distpsnr1_med"]
                                                        < 0.288782656
                                                        else 480
                                                    )
                                                    if state == 479:
                                                        return 0.285130411
                                                    if state == 480:
                                                        return -0.193728998
                                    if state == 96:
                                        state = (
                                            161
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.912999988)
                                            else 162
                                        )
                                        if state == 161:
                                            return -0.111382574
                                        if state == 162:
                                            state = (
                                                251
                                                if x["maggaia_med"] < 14.9639149
                                                else 252
                                            )
                                            if state == 251:
                                                return -0.152069047
                                            if state == 252:
                                                return 0.424410284
                        if state == 18:
                            state = (
                                31
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.923495412)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    53
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 11.9957695)
                                    else 54
                                )
                                if state == 53:
                                    return -0.242837995
                                if state == 54:
                                    state = (
                                        97
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 13.0192366)
                                        else 98
                                    )
                                    if state == 97:
                                        return 0.24819009
                                    if state == 98:
                                        state = (
                                            163
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.969500005)
                                            else 164
                                        )
                                        if state == 163:
                                            state = (
                                                253
                                                if x["maggaia_med"] < 15.3236065
                                                else 254
                                            )
                                            if state == 253:
                                                return -0.280195683
                                            if state == 254:
                                                state = (
                                                    363
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.844750047)
                                                    else 364
                                                )
                                                if state == 363:
                                                    state = (
                                                        481
                                                        if x["distpsnr1_med"]
                                                        < 0.46089685
                                                        else 482
                                                    )
                                                    if state == 481:
                                                        return -0.137403384
                                                    if state == 482:
                                                        return 0.229490384
                                                if state == 364:
                                                    return -0.212793663
                                        if state == 164:
                                            return 0.146295667
                            if state == 32:
                                state = (
                                    55
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 45.8821182)
                                    else 56
                                )
                                if state == 55:
                                    return -0.402490646
                                if state == 56:
                                    state = (
                                        99
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 49.9361496)
                                        else 100
                                    )
                                    if state == 99:
                                        return 0.21912916
                                    if state == 100:
                                        state = (
                                            165
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.935000002)
                                            else 166
                                        )
                                        if state == 165:
                                            state = (
                                                255
                                                if x["maggaia_med"] < 15.0650921
                                                else 256
                                            )
                                            if state == 255:
                                                return 0.185391545
                                            if state == 256:
                                                return -0.247645497
                                        if state == 166:
                                            return -0.268850416
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5362511)
                            else 20
                        )
                        if state == 19:
                            state = (
                                33
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.02832174)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    57
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 16.0095673)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        101
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 9.94891167)
                                        else 102
                                    )
                                    if state == 101:
                                        state = (
                                            167
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.804999948)
                                            else 168
                                        )
                                        if state == 167:
                                            return -0.243959635
                                        if state == 168:
                                            state = (
                                                257
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 20.6324234)
                                                else 258
                                            )
                                            if state == 257:
                                                state = (
                                                    365
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.934499979)
                                                    else 366
                                                )
                                                if state == 365:
                                                    state = (
                                                        483
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 0.831292808
                                                        )
                                                        else 484
                                                    )
                                                    if state == 483:
                                                        return -0.110931017
                                                    if state == 484:
                                                        return 0.530728579
                                                if state == 366:
                                                    state = (
                                                        485
                                                        if x["distpsnr1_med"]
                                                        < 1.31953454
                                                        else 486
                                                    )
                                                    if state == 485:
                                                        state = (
                                                            653
                                                            if x["distpsnr1_med"]
                                                            < 1.08038282
                                                            else 654
                                                        )
                                                        if state == 653:
                                                            return 0.144568518
                                                        if state == 654:
                                                            return 0.631732047
                                                    if state == 486:
                                                        state = (
                                                            655
                                                            if x["distpsnr1_med"]
                                                            < 2.535748
                                                            else 656
                                                        )
                                                        if state == 655:
                                                            return -0.208170727
                                                        if state == 656:
                                                            return 0.268324882
                                            if state == 258:
                                                return -0.225395456
                                    if state == 102:
                                        state = (
                                            169
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.910750031)
                                            else 170
                                        )
                                        if state == 169:
                                            state = (
                                                259
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 18.2188873)
                                                else 260
                                            )
                                            if state == 259:
                                                return -0.173456863
                                            if state == 260:
                                                state = (
                                                    367
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.877000034)
                                                    else 368
                                                )
                                                if state == 367:
                                                    state = (
                                                        487
                                                        if x["distpsnr1_med"]
                                                        < 1.66871667
                                                        else 488
                                                    )
                                                    if state == 487:
                                                        return -0.195330635
                                                    if state == 488:
                                                        return 0.250534624
                                                if state == 368:
                                                    state = (
                                                        489
                                                        if x["distpsnr1_med"]
                                                        < 1.85409284
                                                        else 490
                                                    )
                                                    if state == 489:
                                                        return 0.017370915
                                                    if state == 490:
                                                        state = (
                                                            657
                                                            if x["distpsnr1_med"]
                                                            < 7.2549777
                                                            else 658
                                                        )
                                                        if state == 657:
                                                            return 0.930745602
                                                        if state == 658:
                                                            return 0.149763227
                                        if state == 170:
                                            state = (
                                                261
                                                if x["maggaia_med"] < 17.828495
                                                else 262
                                            )
                                            if state == 261:
                                                state = (
                                                    369
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.966750026)
                                                    else 370
                                                )
                                                if state == 369:
                                                    return -0.457716614
                                                if state == 370:
                                                    return -0.0258596614
                                            if state == 262:
                                                state = (
                                                    371
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.962749958)
                                                    else 372
                                                )
                                                if state == 371:
                                                    state = (
                                                        491
                                                        if x["distpsnr1_med"]
                                                        < 9.8453064
                                                        else 492
                                                    )
                                                    if state == 491:
                                                        state = (
                                                            659
                                                            if x["distpsnr1_med"]
                                                            < 0.193422496
                                                            else 660
                                                        )
                                                        if state == 659:
                                                            return 0.0982037187
                                                        if state == 660:
                                                            return -0.21647355
                                                    if state == 492:
                                                        state = (
                                                            661
                                                            if x["distpsnr1_med"]
                                                            < 11.6500959
                                                            else 662
                                                        )
                                                        if state == 661:
                                                            return 0.23108457
                                                        if state == 662:
                                                            return 0.0106198462
                                                if state == 372:
                                                    state = (
                                                        493
                                                        if x["distpsnr1_med"]
                                                        < 1.57382369
                                                        else 494
                                                    )
                                                    if state == 493:
                                                        state = (
                                                            663
                                                            if x["distpsnr1_med"]
                                                            < 1.186409
                                                            else 664
                                                        )
                                                        if state == 663:
                                                            return 0.0197763573
                                                        if state == 664:
                                                            return 0.432267368
                                                    if state == 494:
                                                        state = (
                                                            665
                                                            if x["distpsnr1_med"]
                                                            < 3.04273009
                                                            else 666
                                                        )
                                                        if state == 665:
                                                            return -0.233467996
                                                        if state == 666:
                                                            return 0.0542073101
                                if state == 58:
                                    state = (
                                        103
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 44.8750229)
                                        else 104
                                    )
                                    if state == 103:
                                        state = (
                                            171
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.900750041)
                                            else 172
                                        )
                                        if state == 171:
                                            state = (
                                                263
                                                if x["maggaia_med"] < 17.272253
                                                else 264
                                            )
                                            if state == 263:
                                                state = (
                                                    373
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.817499995)
                                                    else 374
                                                )
                                                if state == 373:
                                                    return -0.221481964
                                                if state == 374:
                                                    state = (
                                                        495
                                                        if x["distpsnr1_med"]
                                                        < 0.968977571
                                                        else 496
                                                    )
                                                    if state == 495:
                                                        return -0.190922394
                                                    if state == 496:
                                                        return 0.185978264
                                            if state == 264:
                                                return -0.328736037
                                        if state == 172:
                                            state = (
                                                265
                                                if x["maggaia_med"] < 17.1021347
                                                else 266
                                            )
                                            if state == 265:
                                                return -0.383756012
                                            if state == 266:
                                                state = (
                                                    375
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.968000054)
                                                    else 376
                                                )
                                                if state == 375:
                                                    state = (
                                                        497
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 1.72903883
                                                        )
                                                        else 498
                                                    )
                                                    if state == 497:
                                                        state = (
                                                            667
                                                            if x["distpsnr1_med"]
                                                            < 0.173917174
                                                            else 668
                                                        )
                                                        if state == 667:
                                                            return 0.0141723147
                                                        if state == 668:
                                                            return -0.295710504
                                                    if state == 498:
                                                        state = (
                                                            669
                                                            if x["distpsnr1_med"]
                                                            < 4.6055541
                                                            else 670
                                                        )
                                                        if state == 669:
                                                            return 0.414845467
                                                        if state == 670:
                                                            return 0.129953846
                                                if state == 376:
                                                    state = (
                                                        499
                                                        if x["distpsnr1_med"]
                                                        < 1.21809518
                                                        else 500
                                                    )
                                                    if state == 499:
                                                        state = (
                                                            671
                                                            if x["distpsnr1_med"]
                                                            < 0.11576131
                                                            else 672
                                                        )
                                                        if state == 671:
                                                            return 0.0874000564
                                                        if state == 672:
                                                            return -0.309957594
                                                    if state == 500:
                                                        state = (
                                                            673
                                                            if x["distpsnr1_med"]
                                                            < 1.40541339
                                                            else 674
                                                        )
                                                        if state == 673:
                                                            return 0.294895828
                                                        if state == 674:
                                                            return -0.0137808137
                                    if state == 104:
                                        state = (
                                            173
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.971750021)
                                            else 174
                                        )
                                        if state == 173:
                                            state = (
                                                267
                                                if x["maggaia_med"] < 40.9020538
                                                else 268
                                            )
                                            if state == 267:
                                                state = (
                                                    377
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.950749993)
                                                    else 378
                                                )
                                                if state == 377:
                                                    return -0.364280403
                                                if state == 378:
                                                    state = (
                                                        501
                                                        if x["distpsnr1_med"]
                                                        < 2.83647346
                                                        else 502
                                                    )
                                                    if state == 501:
                                                        return -0.307253271
                                                    if state == 502:
                                                        state = (
                                                            675
                                                            if x["distpsnr1_med"]
                                                            < 8.18214703
                                                            else 676
                                                        )
                                                        if state == 675:
                                                            return 0.177537411
                                                        if state == 676:
                                                            return -0.197390527
                                            if state == 268:
                                                return 0.00573225645
                                        if state == 174:
                                            return 0.0541210696
                            if state == 34:
                                state = (
                                    59
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.0222683)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        105
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 5.97746563)
                                        else 106
                                    )
                                    if state == 105:
                                        state = (
                                            175
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.968500018)
                                            else 176
                                        )
                                        if state == 175:
                                            return -0.193857491
                                        if state == 176:
                                            return 0.0636115894
                                    if state == 106:
                                        return 0.184212402
                                if state == 60:
                                    state = (
                                        107
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 18.0681953)
                                        else 108
                                    )
                                    if state == 107:
                                        state = (
                                            177
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.964749992)
                                            else 178
                                        )
                                        if state == 177:
                                            return -0.403314859
                                        if state == 178:
                                            state = (
                                                271
                                                if x["maggaia_med"] < 18.6360912
                                                else 272
                                            )
                                            if state == 271:
                                                return -0.455919027
                                            if state == 272:
                                                state = (
                                                    381
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.97025001)
                                                    else 382
                                                )
                                                if state == 381:
                                                    state = (
                                                        503
                                                        if x["distpsnr1_med"]
                                                        < 2.08380532
                                                        else 504
                                                    )
                                                    if state == 503:
                                                        state = (
                                                            677
                                                            if x["distpsnr1_med"]
                                                            < 1.50798631
                                                            else 678
                                                        )
                                                        if state == 677:
                                                            return 0.0133004654
                                                        if state == 678:
                                                            return -0.214696139
                                                    if state == 504:
                                                        state = (
                                                            679
                                                            if x["distpsnr1_med"]
                                                            < 2.67470789
                                                            else 680
                                                        )
                                                        if state == 679:
                                                            return 0.296172887
                                                        if state == 680:
                                                            return -0.00355532067
                                                if state == 382:
                                                    state = (
                                                        505
                                                        if x["distpsnr1_med"]
                                                        < 3.27980828
                                                        else 506
                                                    )
                                                    if state == 505:
                                                        return -0.295346022
                                                    if state == 506:
                                                        state = (
                                                            681
                                                            if x["distpsnr1_med"]
                                                            < 3.83461666
                                                            else 682
                                                        )
                                                        if state == 681:
                                                            return 0.158949479
                                                        if state == 682:
                                                            return -0.134022295
                                    if state == 108:
                                        state = (
                                            179
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.92474997)
                                            else 180
                                        )
                                        if state == 179:
                                            state = (
                                                273
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 19.0562172)
                                                else 274
                                            )
                                            if state == 273:
                                                return -0.368496835
                                            if state == 274:
                                                state = (
                                                    383
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.871250033)
                                                    else 384
                                                )
                                                if state == 383:
                                                    state = (
                                                        507
                                                        if x["distpsnr1_med"]
                                                        < 2.74311495
                                                        else 508
                                                    )
                                                    if state == 507:
                                                        return -0.196790591
                                                    if state == 508:
                                                        return 0.386548162
                                                if state == 384:
                                                    return -0.181661293
                                        if state == 180:
                                            state = (
                                                275
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 18.7533569)
                                                else 276
                                            )
                                            if state == 275:
                                                return -0.43677941
                                            if state == 276:
                                                state = (
                                                    385
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.956750035)
                                                    else 386
                                                )
                                                if state == 385:
                                                    state = (
                                                        509
                                                        if x["distpsnr1_med"]
                                                        < 4.95941067
                                                        else 510
                                                    )
                                                    if state == 509:
                                                        return 0.370721191
                                                    if state == 510:
                                                        state = (
                                                            683
                                                            if x["distpsnr1_med"]
                                                            < 5.40886211
                                                            else 684
                                                        )
                                                        if state == 683:
                                                            return -0.20766674
                                                        if state == 684:
                                                            return 0.0190556087
                                                if state == 386:
                                                    state = (
                                                        511
                                                        if x["distpsnr1_med"]
                                                        < 0.462272763
                                                        else 512
                                                    )
                                                    if state == 511:
                                                        state = (
                                                            685
                                                            if x["distpsnr1_med"]
                                                            < 0.211049333
                                                            else 686
                                                        )
                                                        if state == 685:
                                                            return -0.0041304417
                                                        if state == 686:
                                                            return 0.299301088
                                                    if state == 512:
                                                        state = (
                                                            687
                                                            if x["distpsnr1_med"]
                                                            < 5.41826248
                                                            else 688
                                                        )
                                                        if state == 687:
                                                            return -0.289735734
                                                        if state == 688:
                                                            return 0.142298713
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.00303245)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    61
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 7.52580452)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        109
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 6.01318836)
                                        else 110
                                    )
                                    if state == 109:
                                        state = (
                                            181
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.971500039)
                                            else 182
                                        )
                                        if state == 181:
                                            state = (
                                                277
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 19.1578541)
                                                else 278
                                            )
                                            if state == 277:
                                                return -0.321517617
                                            if state == 278:
                                                state = (
                                                    387
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.902750015)
                                                    else 388
                                                )
                                                if state == 387:
                                                    state = (
                                                        513
                                                        if x["distpsnr1_med"]
                                                        < 4.56428957
                                                        else 514
                                                    )
                                                    if state == 513:
                                                        return -0.187753558
                                                    if state == 514:
                                                        return 0.270548224
                                                if state == 388:
                                                    return -0.20388481
                                        if state == 182:
                                            return 0.231584564
                                    if state == 110:
                                        state = (
                                            183
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.966750026)
                                            else 184
                                        )
                                        if state == 183:
                                            state = (
                                                279
                                                if x["maggaia_med"] < 19.6724548
                                                else 280
                                            )
                                            if state == 279:
                                                return -0.268454731
                                            if state == 280:
                                                state = (
                                                    389
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.924000025)
                                                    else 390
                                                )
                                                if state == 389:
                                                    state = (
                                                        515
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 1.50195408
                                                        )
                                                        else 516
                                                    )
                                                    if state == 515:
                                                        return -0.106865622
                                                    if state == 516:
                                                        return 0.326147109
                                                if state == 390:
                                                    state = (
                                                        517
                                                        if x["distpsnr1_med"]
                                                        < 1.09632647
                                                        else 518
                                                    )
                                                    if state == 517:
                                                        return -0.0977423936
                                                    if state == 518:
                                                        return 0.0989227593
                                        if state == 184:
                                            return 0.460619122
                                if state == 62:
                                    state = (
                                        111
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 24.0046768)
                                        else 112
                                    )
                                    if state == 111:
                                        state = (
                                            185
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.707499981)
                                            else 186
                                        )
                                        if state == 185:
                                            state = (
                                                281
                                                if x["maggaia_med"] < 17.3650322
                                                else 282
                                            )
                                            if state == 281:
                                                return 0.518634081
                                            if state == 282:
                                                return -0.335123003
                                        if state == 186:
                                            return -0.390271515
                                    if state == 112:
                                        state = (
                                            187
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.951249957)
                                            else 188
                                        )
                                        if state == 187:
                                            state = (
                                                283
                                                if x["maggaia_med"] < 18.2486229
                                                else 284
                                            )
                                            if state == 283:
                                                state = (
                                                    391
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.916499972)
                                                    else 392
                                                )
                                                if state == 391:
                                                    state = (
                                                        519
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 4.51618099
                                                        )
                                                        else 520
                                                    )
                                                    if state == 519:
                                                        return -0.370068818
                                                    if state == 520:
                                                        state = (
                                                            689
                                                            if x["distpsnr1_med"]
                                                            < 4.7027421
                                                            else 690
                                                        )
                                                        if state == 689:
                                                            return 0.575918019
                                                        if state == 690:
                                                            return -0.151026964
                                                if state == 392:
                                                    state = (
                                                        521
                                                        if x["distpsnr1_med"]
                                                        < 1.78942442
                                                        else 522
                                                    )
                                                    if state == 521:
                                                        return -0.323299438
                                                    if state == 522:
                                                        state = (
                                                            691
                                                            if x["distpsnr1_med"]
                                                            < 4.03032684
                                                            else 692
                                                        )
                                                        if state == 691:
                                                            return 0.225982934
                                                        if state == 692:
                                                            return -0.128916293
                                            if state == 284:
                                                return -0.374862105
                                        if state == 188:
                                            state = (
                                                285
                                                if x["maggaia_med"] < 41.8589859
                                                else 286
                                            )
                                            if state == 285:
                                                state = (
                                                    393
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.953249991)
                                                    else 394
                                                )
                                                if state == 393:
                                                    state = (
                                                        523
                                                        if x["distpsnr1_med"]
                                                        < 1.4927125
                                                        else 524
                                                    )
                                                    if state == 523:
                                                        return 0.33683458
                                                    if state == 524:
                                                        return -0.133402616
                                                if state == 394:
                                                    state = (
                                                        525
                                                        if x["distpsnr1_med"]
                                                        < 3.62338448
                                                        else 526
                                                    )
                                                    if state == 525:
                                                        state = (
                                                            693
                                                            if x["distpsnr1_med"]
                                                            < 0.0950683802
                                                            else 694
                                                        )
                                                        if state == 693:
                                                            return 0.105721779
                                                        if state == 694:
                                                            return -0.277461171
                                                    if state == 526:
                                                        state = (
                                                            695
                                                            if x["distpsnr1_med"]
                                                            < 6.62785721
                                                            else 696
                                                        )
                                                        if state == 695:
                                                            return 0.0636147335
                                                        if state == 696:
                                                            return -0.253182888
                                            if state == 286:
                                                state = (
                                                    395
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.96450001)
                                                    else 396
                                                )
                                                if state == 395:
                                                    state = (
                                                        527
                                                        if x["distpsnr1_med"]
                                                        < 3.82311273
                                                        else 528
                                                    )
                                                    if state == 527:
                                                        state = (
                                                            697
                                                            if x["distpsnr1_med"]
                                                            < 0.597448707
                                                            else 698
                                                        )
                                                        if state == 697:
                                                            return -0.0951567441
                                                        if state == 698:
                                                            return 0.720878839
                                                    if state == 528:
                                                        return -0.124085456
                                                if state == 396:
                                                    state = (
                                                        529
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 1.111902
                                                        )
                                                        else 530
                                                    )
                                                    if state == 529:
                                                        return -0.183686033
                                                    if state == 530:
                                                        state = (
                                                            699
                                                            if x["distpsnr1_med"]
                                                            < 1.71845472
                                                            else 700
                                                        )
                                                        if state == 699:
                                                            return 0.35062471
                                                        if state == 700:
                                                            return -0.128698245
                            if state == 36:
                                state = (
                                    63
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 49.8105469)
                                    else 64
                                )
                                if state == 63:
                                    return -0.349350959
                                if state == 64:
                                    state = (
                                        113
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 49.8215942)
                                        else 114
                                    )
                                    if state == 113:
                                        return 0.161930218
                                    if state == 114:
                                        state = (
                                            189
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.93325001)
                                            else 190
                                        )
                                        if state == 189:
                                            return -0.367499053
                                        if state == 190:
                                            state = (
                                                287
                                                if x["maggaia_med"] < 18.4293079
                                                else 288
                                            )
                                            if state == 287:
                                                return -0.366033286
                                            if state == 288:
                                                state = (
                                                    397
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.947000027)
                                                    else 398
                                                )
                                                if state == 397:
                                                    state = (
                                                        531
                                                        if x["distpsnr1_med"]
                                                        < 1.85681832
                                                        else 532
                                                    )
                                                    if state == 531:
                                                        return -0.175598964
                                                    if state == 532:
                                                        return 0.227559716
                                                if state == 398:
                                                    state = (
                                                        533
                                                        if x["distpsnr1_med"]
                                                        < 1.71119273
                                                        else 534
                                                    )
                                                    if state == 533:
                                                        return -0.261755943
                                                    if state == 534:
                                                        state = (
                                                            703
                                                            if x["distpsnr1_med"]
                                                            < 3.06339145
                                                            else 704
                                                        )
                                                        if state == 703:
                                                            return 0.242506236
                                                        if state == 704:
                                                            return -0.273034543
                if state == 6:
                    state = 11 if x["maggaia_med"] < 15.6147394 else 12
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.4146729)
                            else 22
                        )
                        if state == 21:
                            state = (
                                37
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 4.93690968)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    65
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 18.0398254)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        115
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 10.1241264)
                                        else 116
                                    )
                                    if state == 115:
                                        return -0.105138227
                                    if state == 116:
                                        state = (
                                            191
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982249975)
                                            else 192
                                        )
                                        if state == 191:
                                            return -0.492826968
                                        if state == 192:
                                            return 0.05483298
                                if state == 66:
                                    state = (
                                        117
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 42.8224564)
                                        else 118
                                    )
                                    if state == 117:
                                        state = (
                                            193
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.984250069)
                                            else 194
                                        )
                                        if state == 193:
                                            state = (
                                                291
                                                if x["maggaia_med"] < 15.472537
                                                else 292
                                            )
                                            if state == 291:
                                                state = (
                                                    399
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.983250022)
                                                    else 400
                                                )
                                                if state == 399:
                                                    state = (
                                                        535
                                                        if x["distpsnr1_med"]
                                                        < 0.669509768
                                                        else 536
                                                    )
                                                    if state == 535:
                                                        return -0.171206698
                                                    if state == 536:
                                                        return 0.0324612744
                                                if state == 400:
                                                    return 0.226951495
                                            if state == 292:
                                                return -0.112776585
                                        if state == 194:
                                            return -0.259278387
                                    if state == 118:
                                        return -0.297419608
                            if state == 38:
                                state = (
                                    67
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 20.5256481)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        119
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 15.9754343)
                                        else 120
                                    )
                                    if state == 119:
                                        return 0.18754071
                                    if state == 120:
                                        return -0.302234232
                                if state == 68:
                                    state = (
                                        121
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 55.5154037)
                                        else 122
                                    )
                                    if state == 121:
                                        state = (
                                            195
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.987500012)
                                            else 196
                                        )
                                        if state == 195:
                                            return 0.254677266
                                        if state == 196:
                                            return 0.0205062982
                                    if state == 122:
                                        return -0.120405182
                        if state == 22:
                            state = (
                                39
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.08951395)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    69
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 12.9517069)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        123
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 10.5255089)
                                        else 124
                                    )
                                    if state == 123:
                                        return 0.17972897
                                    if state == 124:
                                        state = (
                                            199
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.980000019)
                                            else 200
                                        )
                                        if state == 199:
                                            state = (
                                                293
                                                if x["maggaia_med"] < 15.0202084
                                                else 294
                                            )
                                            if state == 293:
                                                return -0.197347701
                                            if state == 294:
                                                return 0.112774618
                                        if state == 200:
                                            return 0.131785601
                                if state == 70:
                                    return -0.437313169
                            if state == 40:
                                state = (
                                    71
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 42.9390488)
                                    else 72
                                )
                                if state == 71:
                                    state = (
                                        125
                                        if np.isnan(x["t_lc"]) or (x["t_lc"] < 28.51651)
                                        else 126
                                    )
                                    if state == 125:
                                        state = (
                                            201
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.975749969)
                                            else 202
                                        )
                                        if state == 201:
                                            return -0.317598581
                                        if state == 202:
                                            state = (
                                                295
                                                if x["maggaia_med"] < 15.4197578
                                                else 296
                                            )
                                            if state == 295:
                                                state = (
                                                    401
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.981250048)
                                                    else 402
                                                )
                                                if state == 401:
                                                    state = (
                                                        537
                                                        if x["distpsnr1_med"]
                                                        < 1.70002103
                                                        else 538
                                                    )
                                                    if state == 537:
                                                        state = (
                                                            705
                                                            if x["distpsnr1_med"]
                                                            < 0.167061552
                                                            else 706
                                                        )
                                                        if state == 705:
                                                            return -0.0907645524
                                                        if state == 706:
                                                            return 0.19945848
                                                    if state == 538:
                                                        state = (
                                                            707
                                                            if x["distpsnr1_med"]
                                                            < 7.45970297
                                                            else 708
                                                        )
                                                        if state == 707:
                                                            return -0.334108025
                                                        if state == 708:
                                                            return 0.220283449
                                                if state == 402:
                                                    state = (
                                                        539
                                                        if x["distpsnr1_med"]
                                                        < 0.850733936
                                                        else 540
                                                    )
                                                    if state == 539:
                                                        return -0.211907685
                                                    if state == 540:
                                                        return 0.287841707
                                            if state == 296:
                                                return -0.528795719
                                    if state == 126:
                                        state = (
                                            203
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.981750011)
                                            else 204
                                        )
                                        if state == 203:
                                            state = (
                                                297
                                                if x["maggaia_med"] < 12.9892216
                                                else 298
                                            )
                                            if state == 297:
                                                return 0.154816955
                                            if state == 298:
                                                state = (
                                                    403
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.97724998)
                                                    else 404
                                                )
                                                if state == 403:
                                                    state = (
                                                        541
                                                        if x["distpsnr1_med"]
                                                        < 0.363640726
                                                        else 542
                                                    )
                                                    if state == 541:
                                                        return 0.0610863157
                                                    if state == 542:
                                                        return -0.26628229
                                                if state == 404:
                                                    state = (
                                                        543
                                                        if x["distpsnr1_med"]
                                                        < 9.81622505
                                                        else 544
                                                    )
                                                    if state == 543:
                                                        return -0.472177446
                                                    if state == 544:
                                                        return 0.000070
                                        if state == 204:
                                            state = (
                                                299
                                                if x["maggaia_med"] < 14.1423044
                                                else 300
                                            )
                                            if state == 299:
                                                return 0.231392816
                                            if state == 300:
                                                state = (
                                                    405
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982749999)
                                                    else 406
                                                )
                                                if state == 405:
                                                    return 0.147013709
                                                if state == 406:
                                                    state = (
                                                        545
                                                        if x["distpsnr1_med"]
                                                        < 1.8464036
                                                        else 546
                                                    )
                                                    if state == 545:
                                                        return 0.0562330559
                                                    if state == 546:
                                                        return -0.304852843
                                if state == 72:
                                    state = (
                                        127
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 45.4377251)
                                        else 128
                                    )
                                    if state == 127:
                                        return 0.222282454
                                    if state == 128:
                                        state = (
                                            205
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.974249959)
                                            else 206
                                        )
                                        if state == 205:
                                            return -0.108756363
                                        if state == 206:
                                            state = (
                                                303
                                                if x["maggaia_med"] < 14.6045532
                                                else 304
                                            )
                                            if state == 303:
                                                state = (
                                                    407
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.979499996)
                                                    else 408
                                                )
                                                if state == 407:
                                                    return -0.273609251
                                                if state == 408:
                                                    state = (
                                                        547
                                                        if x["distpsnr1_med"]
                                                        < 2.5351243
                                                        else 548
                                                    )
                                                    if state == 547:
                                                        state = (
                                                            711
                                                            if x["distpsnr1_med"]
                                                            < 1.54412973
                                                            else 712
                                                        )
                                                        if state == 711:
                                                            return 0.0960470811
                                                        if state == 712:
                                                            return -0.171500474
                                                    if state == 548:
                                                        return 0.181337714
                                            if state == 304:
                                                state = (
                                                    409
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982249975)
                                                    else 410
                                                )
                                                if state == 409:
                                                    return 0.303547978
                                                if state == 410:
                                                    state = (
                                                        549
                                                        if x["distpsnr1_med"]
                                                        < 0.818549275
                                                        else 550
                                                    )
                                                    if state == 549:
                                                        return -0.110703051
                                                    if state == 550:
                                                        state = (
                                                            713
                                                            if x["distpsnr1_med"]
                                                            < 3.14324379
                                                            else 714
                                                        )
                                                        if state == 713:
                                                            return 0.19293198
                                                        if state == 714:
                                                            return -0.0645852014
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.5544682)
                            else 24
                        )
                        if state == 23:
                            state = (
                                41
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 8.98141766)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    73
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.00032997)
                                    else 74
                                )
                                if state == 73:
                                    state = (
                                        129
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 5.94802094)
                                        else 130
                                    )
                                    if state == 129:
                                        state = (
                                            207
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.983500004)
                                            else 208
                                        )
                                        if state == 207:
                                            return 0.18475461
                                        if state == 208:
                                            return -0.0922093093
                                    if state == 130:
                                        state = (
                                            209
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.983500004)
                                            else 210
                                        )
                                        if state == 209:
                                            return -0.0476777144
                                        if state == 210:
                                            state = (
                                                307
                                                if x["maggaia_med"] < 19.140173
                                                else 308
                                            )
                                            if state == 307:
                                                return -0.406865358
                                            if state == 308:
                                                return 0.125108734
                                if state == 74:
                                    state = (
                                        131
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 47.0088577)
                                        else 132
                                    )
                                    if state == 131:
                                        state = (
                                            211
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982749999)
                                            else 212
                                        )
                                        if state == 211:
                                            state = (
                                                309
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 20.7113247)
                                                else 310
                                            )
                                            if state == 309:
                                                state = (
                                                    411
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.977750003)
                                                    else 412
                                                )
                                                if state == 411:
                                                    state = (
                                                        551
                                                        if x["distpsnr1_med"]
                                                        < 0.133290276
                                                        else 552
                                                    )
                                                    if state == 551:
                                                        return -0.121395327
                                                    if state == 552:
                                                        return 0.346269071
                                                if state == 412:
                                                    state = (
                                                        553
                                                        if x["distpsnr1_med"]
                                                        < 1.43985581
                                                        else 554
                                                    )
                                                    if state == 553:
                                                        state = (
                                                            715
                                                            if x["distpsnr1_med"]
                                                            < 1.390481
                                                            else 716
                                                        )
                                                        if state == 715:
                                                            return 0.0452157818
                                                        if state == 716:
                                                            return -0.849702299
                                                    if state == 554:
                                                        state = (
                                                            717
                                                            if x["distpsnr1_med"]
                                                            < 5.87257004
                                                            else 718
                                                        )
                                                        if state == 717:
                                                            return 0.30962804
                                                        if state == 718:
                                                            return -0.0177693162
                                            if state == 310:
                                                return -0.561182261
                                        if state == 212:
                                            state = (
                                                311
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 19.3674774)
                                                else 312
                                            )
                                            if state == 311:
                                                state = (
                                                    413
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.994250059)
                                                    else 414
                                                )
                                                if state == 413:
                                                    state = (
                                                        555
                                                        if x["distpsnr1_med"]
                                                        < 0.178460598
                                                        else 556
                                                    )
                                                    if state == 555:
                                                        state = (
                                                            719
                                                            if x["distpsnr1_med"]
                                                            < 0.0774423182
                                                            else 720
                                                        )
                                                        if state == 719:
                                                            return -0.209801123
                                                        if state == 720:
                                                            return 0.0505781844
                                                    if state == 556:
                                                        return 0.348204851
                                                if state == 414:
                                                    return -0.170810863
                                            if state == 312:
                                                state = (
                                                    415
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.995499969)
                                                    else 416
                                                )
                                                if state == 415:
                                                    state = (
                                                        557
                                                        if x["distpsnr1_med"]
                                                        < 0.0555657744
                                                        else 558
                                                    )
                                                    if state == 557:
                                                        return -0.187911317
                                                    if state == 558:
                                                        state = (
                                                            721
                                                            if x["distpsnr1_med"]
                                                            < 10.7795086
                                                            else 722
                                                        )
                                                        if state == 721:
                                                            return 0.243172869
                                                        if state == 722:
                                                            return 0.0345700495
                                                if state == 416:
                                                    return 0.00577745866
                                    if state == 132:
                                        state = (
                                            213
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982749999)
                                            else 214
                                        )
                                        if state == 213:
                                            state = (
                                                313
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 17.8894653)
                                                else 314
                                            )
                                            if state == 313:
                                                state = (
                                                    417
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.981750011)
                                                    else 418
                                                )
                                                if state == 417:
                                                    return -0.321115166
                                                if state == 418:
                                                    state = (
                                                        559
                                                        if x["distpsnr1_med"]
                                                        < 1.0407753
                                                        else 560
                                                    )
                                                    if state == 559:
                                                        return -0.204597622
                                                    if state == 560:
                                                        return 0.17356661
                                            if state == 314:
                                                state = (
                                                    419
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.97874999)
                                                    else 420
                                                )
                                                if state == 419:
                                                    return 0.231399685
                                                if state == 420:
                                                    state = (
                                                        561
                                                        if x["distpsnr1_med"]
                                                        < 1.34549153
                                                        else 562
                                                    )
                                                    if state == 561:
                                                        return -0.106241263
                                                    if state == 562:
                                                        return 0.132934839
                                        if state == 214:
                                            state = (
                                                315
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 20.0721321)
                                                else 316
                                            )
                                            if state == 315:
                                                state = (
                                                    421
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.986999989)
                                                    else 422
                                                )
                                                if state == 421:
                                                    state = (
                                                        563
                                                        if x["distpsnr1_med"]
                                                        < 0.138912976
                                                        else 564
                                                    )
                                                    if state == 563:
                                                        state = (
                                                            723
                                                            if x["distpsnr1_med"]
                                                            < 0.0489532314
                                                            else 724
                                                        )
                                                        if state == 723:
                                                            return 0.251510948
                                                        if state == 724:
                                                            return -0.277623445
                                                    if state == 564:
                                                        return 0.369990706
                                                if state == 422:
                                                    return -0.271477491
                                            if state == 316:
                                                state = (
                                                    423
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.983250022)
                                                    else 424
                                                )
                                                if state == 423:
                                                    state = (
                                                        565
                                                        if x["distpsnr1_med"]
                                                        < 2.99648571
                                                        else 566
                                                    )
                                                    if state == 565:
                                                        state = (
                                                            725
                                                            if x["distpsnr1_med"]
                                                            < 2.4708972
                                                            else 726
                                                        )
                                                        if state == 725:
                                                            return 0.0965892598
                                                        if state == 726:
                                                            return -0.565049231
                                                    if state == 566:
                                                        return 0.294794232
                                                if state == 424:
                                                    return 0.228976116
                            if state == 42:
                                state = (
                                    75
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 26.9668236)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        133
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 20.9819794)
                                        else 134
                                    )
                                    if state == 133:
                                        state = (
                                            215
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.983250022)
                                            else 216
                                        )
                                        if state == 215:
                                            state = (
                                                317
                                                if x["maggaia_med"] < 19.6059513
                                                else 318
                                            )
                                            if state == 317:
                                                state = (
                                                    425
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982499957)
                                                    else 426
                                                )
                                                if state == 425:
                                                    return 0.116850838
                                                if state == 426:
                                                    return -0.417762011
                                            if state == 318:
                                                return 0.131333873
                                        if state == 216:
                                            return 0.179918945
                                    if state == 134:
                                        return 0.226340696
                                if state == 76:
                                    state = (
                                        135
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 30.0202713)
                                        else 136
                                    )
                                    if state == 135:
                                        state = (
                                            217
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.983250022)
                                            else 218
                                        )
                                        if state == 217:
                                            return -0.276130259
                                        if state == 218:
                                            return 0.0341646932
                                    if state == 136:
                                        state = (
                                            219
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.980250001)
                                            else 220
                                        )
                                        if state == 219:
                                            return -0.212955654
                                        if state == 220:
                                            state = (
                                                321
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 17.2581406)
                                                else 322
                                            )
                                            if state == 321:
                                                state = (
                                                    427
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.984500051)
                                                    else 428
                                                )
                                                if state == 427:
                                                    state = (
                                                        567
                                                        if x["distpsnr1_med"]
                                                        < 0.166278377
                                                        else 568
                                                    )
                                                    if state == 567:
                                                        return -0.282104522
                                                    if state == 568:
                                                        return 0.0263919346
                                                if state == 428:
                                                    return 0.0641864911
                                            if state == 322:
                                                return 0.204857722
                        if state == 24:
                            state = (
                                43
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.13888311)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    77
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 24.90452)
                                    else 78
                                )
                                if state == 77:
                                    state = (
                                        137
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 8.97475052)
                                        else 138
                                    )
                                    if state == 137:
                                        state = (
                                            221
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.973249972)
                                            else 222
                                        )
                                        if state == 221:
                                            return -0.109958097
                                        if state == 222:
                                            state = (
                                                323
                                                if x["maggaia_med"] < 20.5769882
                                                else 324
                                            )
                                            if state == 323:
                                                state = (
                                                    429
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.980749965)
                                                    else 430
                                                )
                                                if state == 429:
                                                    state = (
                                                        569
                                                        if x["distpsnr1_med"]
                                                        < 0.376565635
                                                        else 570
                                                    )
                                                    if state == 569:
                                                        state = (
                                                            727
                                                            if x["distpsnr1_med"]
                                                            < 0.158407211
                                                            else 728
                                                        )
                                                        if state == 727:
                                                            return 0.126117453
                                                        if state == 728:
                                                            return -0.0633625388
                                                    if state == 570:
                                                        return 0.396760643
                                                if state == 430:
                                                    state = (
                                                        571
                                                        if x["distpsnr1_med"]
                                                        < 5.30848694
                                                        else 572
                                                    )
                                                    if state == 571:
                                                        state = (
                                                            729
                                                            if x["distpsnr1_med"]
                                                            < 0.697638333
                                                            else 730
                                                        )
                                                        if state == 729:
                                                            return -0.0492790267
                                                        if state == 730:
                                                            return 0.263098061
                                                    if state == 572:
                                                        state = (
                                                            731
                                                            if x["distpsnr1_med"]
                                                            < 6.70523357
                                                            else 732
                                                        )
                                                        if state == 731:
                                                            return -0.272422403
                                                        if state == 732:
                                                            return 0.171042576
                                            if state == 324:
                                                state = (
                                                    431
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.978500009)
                                                    else 432
                                                )
                                                if state == 431:
                                                    return -0.155377045
                                                if state == 432:
                                                    state = (
                                                        573
                                                        if x["distpsnr1_med"]
                                                        < 1.28952777
                                                        else 574
                                                    )
                                                    if state == 573:
                                                        return 0.203770146
                                                    if state == 574:
                                                        return -0.0583191216
                                    if state == 138:
                                        state = (
                                            223
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.980250001)
                                            else 224
                                        )
                                        if state == 223:
                                            state = (
                                                325
                                                if x["maggaia_med"] < 17.958931
                                                else 326
                                            )
                                            if state == 325:
                                                state = (
                                                    433
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.976750016)
                                                    else 434
                                                )
                                                if state == 433:
                                                    state = (
                                                        575
                                                        if x["distpsnr1_med"]
                                                        < 1.89972818
                                                        else 576
                                                    )
                                                    if state == 575:
                                                        return -0.35151571
                                                    if state == 576:
                                                        state = (
                                                            733
                                                            if x["distpsnr1_med"]
                                                            < 2.32008886
                                                            else 734
                                                        )
                                                        if state == 733:
                                                            return 0.480448186
                                                        if state == 734:
                                                            return -0.105822355
                                                if state == 434:
                                                    state = (
                                                        577
                                                        if x["distpsnr1_med"]
                                                        < 0.291653454
                                                        else 578
                                                    )
                                                    if state == 577:
                                                        return -0.135962263
                                                    if state == 578:
                                                        state = (
                                                            735
                                                            if x["distpsnr1_med"]
                                                            < 5.32938147
                                                            else 736
                                                        )
                                                        if state == 735:
                                                            return 0.378290415
                                                        if state == 736:
                                                            return -0.0309491642
                                            if state == 326:
                                                state = (
                                                    435
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.97724998)
                                                    else 436
                                                )
                                                if state == 435:
                                                    state = (
                                                        579
                                                        if x["distpsnr1_med"]
                                                        < 2.94298887
                                                        else 580
                                                    )
                                                    if state == 579:
                                                        state = (
                                                            737
                                                            if x["distpsnr1_med"]
                                                            < 1.27329993
                                                            else 738
                                                        )
                                                        if state == 737:
                                                            return -0.0133536514
                                                        if state == 738:
                                                            return 0.158515215
                                                    if state == 580:
                                                        state = (
                                                            739
                                                            if x["distpsnr1_med"]
                                                            < 9.64372444
                                                            else 740
                                                        )
                                                        if state == 739:
                                                            return -0.298128784
                                                        if state == 740:
                                                            return 0.0048969062
                                                if state == 436:
                                                    state = (
                                                        581
                                                        if x["distpsnr1_med"]
                                                        < 7.76116562
                                                        else 582
                                                    )
                                                    if state == 581:
                                                        state = (
                                                            741
                                                            if x["distpsnr1_med"]
                                                            < 4.92917633
                                                            else 742
                                                        )
                                                        if state == 741:
                                                            return -0.176145047
                                                        if state == 742:
                                                            return -0.486433953
                                                    if state == 582:
                                                        state = (
                                                            743
                                                            if np.isnan(
                                                                x["distpsnr1_med"]
                                                            )
                                                            or (
                                                                x["distpsnr1_med"]
                                                                < 11.625761
                                                            )
                                                            else 744
                                                        )
                                                        if state == 743:
                                                            return 0.408951014
                                                        if state == 744:
                                                            return -0.293552101
                                        if state == 224:
                                            state = (
                                                327
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 18.5186653)
                                                else 328
                                            )
                                            if state == 327:
                                                state = (
                                                    437
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.981250048)
                                                    else 438
                                                )
                                                if state == 437:
                                                    state = (
                                                        583
                                                        if x["distpsnr1_med"]
                                                        < 1.8405714
                                                        else 584
                                                    )
                                                    if state == 583:
                                                        state = (
                                                            745
                                                            if x["distpsnr1_med"]
                                                            < 0.816538393
                                                            else 746
                                                        )
                                                        if state == 745:
                                                            return -0.0075847432
                                                        if state == 746:
                                                            return 0.349470973
                                                    if state == 584:
                                                        state = (
                                                            747
                                                            if x["distpsnr1_med"]
                                                            < 8.89352989
                                                            else 748
                                                        )
                                                        if state == 747:
                                                            return -0.144574642
                                                        if state == 748:
                                                            return 0.129785568
                                                if state == 438:
                                                    state = (
                                                        585
                                                        if x["distpsnr1_med"]
                                                        < 5.49765015
                                                        else 586
                                                    )
                                                    if state == 585:
                                                        state = (
                                                            749
                                                            if x["distpsnr1_med"]
                                                            < 4.26675129
                                                            else 750
                                                        )
                                                        if state == 749:
                                                            return 0.226259112
                                                        if state == 750:
                                                            return -0.253342718
                                                    if state == 586:
                                                        state = (
                                                            751
                                                            if np.isnan(
                                                                x["distpsnr1_med"]
                                                            )
                                                            or (
                                                                x["distpsnr1_med"]
                                                                < 22.9344101
                                                            )
                                                            else 752
                                                        )
                                                        if state == 751:
                                                            return 0.392171115
                                                        if state == 752:
                                                            return -0.106613643
                                            if state == 328:
                                                state = (
                                                    439
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.983749986)
                                                    else 440
                                                )
                                                if state == 439:
                                                    state = (
                                                        587
                                                        if x["distpsnr1_med"]
                                                        < 4.84732437
                                                        else 588
                                                    )
                                                    if state == 587:
                                                        state = (
                                                            753
                                                            if x["distpsnr1_med"]
                                                            < 3.23957682
                                                            else 754
                                                        )
                                                        if state == 753:
                                                            return 0.03480177
                                                        if state == 754:
                                                            return -0.239142269
                                                    if state == 588:
                                                        state = (
                                                            755
                                                            if np.isnan(
                                                                x["distpsnr1_med"]
                                                            )
                                                            or (
                                                                x["distpsnr1_med"]
                                                                < 5.90825176
                                                            )
                                                            else 756
                                                        )
                                                        if state == 755:
                                                            return 0.371364057
                                                        if state == 756:
                                                            return 0.114967734
                                                if state == 440:
                                                    state = (
                                                        589
                                                        if x["distpsnr1_med"]
                                                        < 0.162428156
                                                        else 590
                                                    )
                                                    if state == 589:
                                                        return 0.121614181
                                                    if state == 590:
                                                        return -0.267792493
                                if state == 78:
                                    state = (
                                        139
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 48.980484)
                                        else 140
                                    )
                                    if state == 139:
                                        state = (
                                            225
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.980250001)
                                            else 226
                                        )
                                        if state == 225:
                                            state = (
                                                329
                                                if x["maggaia_med"] < 18.9810867
                                                else 330
                                            )
                                            if state == 329:
                                                state = (
                                                    441
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.979750037)
                                                    else 442
                                                )
                                                if state == 441:
                                                    state = (
                                                        591
                                                        if x["distpsnr1_med"]
                                                        < 0.409351349
                                                        else 592
                                                    )
                                                    if state == 591:
                                                        state = (
                                                            757
                                                            if x["distpsnr1_med"]
                                                            < 0.136053458
                                                            else 758
                                                        )
                                                        if state == 757:
                                                            return 0.207270384
                                                        if state == 758:
                                                            return -0.322678953
                                                    if state == 592:
                                                        state = (
                                                            759
                                                            if x["distpsnr1_med"]
                                                            < 6.97876263
                                                            else 760
                                                        )
                                                        if state == 759:
                                                            return 0.205734164
                                                        if state == 760:
                                                            return -0.130468473
                                                if state == 442:
                                                    state = (
                                                        593
                                                        if x["distpsnr1_med"]
                                                        < 2.95240235
                                                        else 594
                                                    )
                                                    if state == 593:
                                                        state = (
                                                            761
                                                            if x["distpsnr1_med"]
                                                            < 0.803058982
                                                            else 762
                                                        )
                                                        if state == 761:
                                                            return -0.0956670567
                                                        if state == 762:
                                                            return 0.277518213
                                                    if state == 594:
                                                        state = (
                                                            763
                                                            if x["distpsnr1_med"]
                                                            < 8.94079494
                                                            else 764
                                                        )
                                                        if state == 763:
                                                            return -0.34926641
                                                        if state == 764:
                                                            return 0.24581629
                                            if state == 330:
                                                state = (
                                                    443
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.979000032)
                                                    else 444
                                                )
                                                if state == 443:
                                                    state = (
                                                        595
                                                        if x["distpsnr1_med"]
                                                        < 7.06223917
                                                        else 596
                                                    )
                                                    if state == 595:
                                                        state = (
                                                            765
                                                            if x["distpsnr1_med"]
                                                            < 1.22689915
                                                            else 766
                                                        )
                                                        if state == 765:
                                                            return 0.0174095966
                                                        if state == 766:
                                                            return -0.268845797
                                                    if state == 596:
                                                        state = (
                                                            767
                                                            if x["distpsnr1_med"]
                                                            < 11.0661545
                                                            else 768
                                                        )
                                                        if state == 767:
                                                            return 0.356852293
                                                        if state == 768:
                                                            return -0.299045026
                                                if state == 444:
                                                    state = (
                                                        597
                                                        if x["distpsnr1_med"]
                                                        < 5.09831619
                                                        else 598
                                                    )
                                                    if state == 597:
                                                        state = (
                                                            769
                                                            if x["distpsnr1_med"]
                                                            < 3.59121418
                                                            else 770
                                                        )
                                                        if state == 769:
                                                            return 0.0388058499
                                                        if state == 770:
                                                            return 0.332881778
                                                    if state == 598:
                                                        state = (
                                                            771
                                                            if x["distpsnr1_med"]
                                                            < 5.89036083
                                                            else 772
                                                        )
                                                        if state == 771:
                                                            return -0.279070705
                                                        if state == 772:
                                                            return -0.0364099331
                                        if state == 226:
                                            state = (
                                                331
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 16.1202927)
                                                else 332
                                            )
                                            if state == 331:
                                                state = (
                                                    445
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982749999)
                                                    else 446
                                                )
                                                if state == 445:
                                                    state = (
                                                        599
                                                        if x["distpsnr1_med"]
                                                        < 5.03902054
                                                        else 600
                                                    )
                                                    if state == 599:
                                                        return -0.399834454
                                                    if state == 600:
                                                        return 0.223710611
                                                if state == 446:
                                                    state = (
                                                        601
                                                        if x["distpsnr1_med"]
                                                        < 1.8377862
                                                        else 602
                                                    )
                                                    if state == 601:
                                                        state = (
                                                            773
                                                            if x["distpsnr1_med"]
                                                            < 1.24911749
                                                            else 774
                                                        )
                                                        if state == 773:
                                                            return 0.112329282
                                                        if state == 774:
                                                            return -0.328632265
                                                    if state == 602:
                                                        return 0.32924217
                                            if state == 332:
                                                state = (
                                                    447
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982249975)
                                                    else 448
                                                )
                                                if state == 447:
                                                    state = (
                                                        603
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 3.9815743
                                                        )
                                                        else 604
                                                    )
                                                    if state == 603:
                                                        state = (
                                                            775
                                                            if x["distpsnr1_med"]
                                                            < 0.25942862
                                                            else 776
                                                        )
                                                        if state == 775:
                                                            return 0.100239106
                                                        if state == 776:
                                                            return 0.312572837
                                                    if state == 604:
                                                        state = (
                                                            777
                                                            if x["distpsnr1_med"]
                                                            < 4.5271697
                                                            else 778
                                                        )
                                                        if state == 777:
                                                            return -0.317243338
                                                        if state == 778:
                                                            return 0.247765705
                                                if state == 448:
                                                    return 0.300858617
                                    if state == 140:
                                        state = (
                                            227
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982249975)
                                            else 228
                                        )
                                        if state == 227:
                                            state = (
                                                333
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 17.7179184)
                                                else 334
                                            )
                                            if state == 333:
                                                state = (
                                                    449
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.977749944)
                                                    else 450
                                                )
                                                if state == 449:
                                                    state = (
                                                        605
                                                        if x["distpsnr1_med"]
                                                        < 0.520902693
                                                        else 606
                                                    )
                                                    if state == 605:
                                                        state = (
                                                            779
                                                            if x["distpsnr1_med"]
                                                            < 0.410398155
                                                            else 780
                                                        )
                                                        if state == 779:
                                                            return -0.19629316
                                                        if state == 780:
                                                            return 0.207928926
                                                    if state == 606:
                                                        return -0.231724694
                                                if state == 450:
                                                    state = (
                                                        607
                                                        if x["distpsnr1_med"]
                                                        < 2.21575212
                                                        else 608
                                                    )
                                                    if state == 607:
                                                        state = (
                                                            783
                                                            if x["distpsnr1_med"]
                                                            < 0.0953914672
                                                            else 784
                                                        )
                                                        if state == 783:
                                                            return 0.250316709
                                                        if state == 784:
                                                            return -0.246883199
                                                    if state == 608:
                                                        state = (
                                                            785
                                                            if x["distpsnr1_med"]
                                                            < 6.02408123
                                                            else 786
                                                        )
                                                        if state == 785:
                                                            return 0.322447091
                                                        if state == 786:
                                                            return 0.0581099279
                                            if state == 334:
                                                state = (
                                                    451
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.980749965)
                                                    else 452
                                                )
                                                if state == 451:
                                                    state = (
                                                        609
                                                        if x["distpsnr1_med"]
                                                        < 0.357859015
                                                        else 610
                                                    )
                                                    if state == 609:
                                                        return -0.243600368
                                                    if state == 610:
                                                        state = (
                                                            787
                                                            if x["distpsnr1_med"]
                                                            < 3.051229
                                                            else 788
                                                        )
                                                        if state == 787:
                                                            return 0.33456704
                                                        if state == 788:
                                                            return 0.129463211
                                                if state == 452:
                                                    state = (
                                                        611
                                                        if x["distpsnr1_med"]
                                                        < 0.296998024
                                                        else 612
                                                    )
                                                    if state == 611:
                                                        return -0.272709578
                                                    if state == 612:
                                                        return 0.362570137
                                        if state == 228:
                                            state = (
                                                335
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 20.0643425)
                                                else 336
                                            )
                                            if state == 335:
                                                return 0.355068088
                                            if state == 336:
                                                return 0.155170336
                            if state == 44:
                                state = (
                                    79
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 26.0199947)
                                    else 80
                                )
                                if state == 79:
                                    state = (
                                        141
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 11.9654865)
                                        else 142
                                    )
                                    if state == 141:
                                        state = (
                                            229
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982249975)
                                            else 230
                                        )
                                        if state == 229:
                                            state = (
                                                337
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 15.8906631)
                                                else 338
                                            )
                                            if state == 337:
                                                state = (
                                                    453
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.979499996)
                                                    else 454
                                                )
                                                if state == 453:
                                                    state = (
                                                        613
                                                        if x["distpsnr1_med"]
                                                        < 13.5567789
                                                        else 614
                                                    )
                                                    if state == 613:
                                                        return -0.35669744
                                                    if state == 614:
                                                        return 0.3200306
                                                if state == 454:
                                                    state = (
                                                        615
                                                        if x["distpsnr1_med"]
                                                        < 1.51940298
                                                        else 616
                                                    )
                                                    if state == 615:
                                                        return -0.0231572893
                                                    if state == 616:
                                                        return 0.221959695
                                            if state == 338:
                                                state = (
                                                    455
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.978250027)
                                                    else 456
                                                )
                                                if state == 455:
                                                    state = (
                                                        617
                                                        if x["distpsnr1_med"]
                                                        < 0.402006239
                                                        else 618
                                                    )
                                                    if state == 617:
                                                        state = (
                                                            789
                                                            if x["distpsnr1_med"]
                                                            < 0.12471655
                                                            else 790
                                                        )
                                                        if state == 789:
                                                            return 0.156398073
                                                        if state == 790:
                                                            return -0.0296432059
                                                    if state == 618:
                                                        state = (
                                                            791
                                                            if x["distpsnr1_med"]
                                                            < 2.7404542
                                                            else 792
                                                        )
                                                        if state == 791:
                                                            return -0.397407591
                                                        if state == 792:
                                                            return -0.204770029
                                                if state == 456:
                                                    state = (
                                                        619
                                                        if x["distpsnr1_med"]
                                                        < 0.474156469
                                                        else 620
                                                    )
                                                    if state == 619:
                                                        state = (
                                                            793
                                                            if x["distpsnr1_med"]
                                                            < 0.407747298
                                                            else 794
                                                        )
                                                        if state == 793:
                                                            return -0.407658398
                                                        if state == 794:
                                                            return 0.242527142
                                                    if state == 620:
                                                        state = (
                                                            795
                                                            if x["distpsnr1_med"]
                                                            < 3.02260971
                                                            else 796
                                                        )
                                                        if state == 795:
                                                            return -0.560864031
                                                        if state == 796:
                                                            return -0.213983908
                                        if state == 230:
                                            state = (
                                                339
                                                if x["maggaia_med"] < 41.4849396
                                                else 340
                                            )
                                            if state == 339:
                                                state = (
                                                    457
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.983500004)
                                                    else 458
                                                )
                                                if state == 457:
                                                    state = (
                                                        621
                                                        if x["distpsnr1_med"]
                                                        < 4.57823944
                                                        else 622
                                                    )
                                                    if state == 621:
                                                        return -0.178360224
                                                    if state == 622:
                                                        return 0.15970777
                                                if state == 458:
                                                    return -0.345387697
                                            if state == 340:
                                                return 0.192088008
                                    if state == 142:
                                        state = (
                                            231
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982249975)
                                            else 232
                                        )
                                        if state == 231:
                                            state = (
                                                341
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 18.8420715)
                                                else 342
                                            )
                                            if state == 341:
                                                state = (
                                                    459
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.976750016)
                                                    else 460
                                                )
                                                if state == 459:
                                                    state = (
                                                        623
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 0.794368386
                                                        )
                                                        else 624
                                                    )
                                                    if state == 623:
                                                        state = (
                                                            797
                                                            if x["distpsnr1_med"]
                                                            < 0.524260759
                                                            else 798
                                                        )
                                                        if state == 797:
                                                            return -0.121115997
                                                        if state == 798:
                                                            return 0.432619721
                                                    if state == 624:
                                                        state = (
                                                            799
                                                            if x["distpsnr1_med"]
                                                            < 2.69455385
                                                            else 800
                                                        )
                                                        if state == 799:
                                                            return -0.311310172
                                                        if state == 800:
                                                            return 0.0946802273
                                                if state == 460:
                                                    state = (
                                                        625
                                                        if x["distpsnr1_med"]
                                                        < 0.216338456
                                                        else 626
                                                    )
                                                    if state == 625:
                                                        return -0.392920166
                                                    if state == 626:
                                                        state = (
                                                            801
                                                            if x["distpsnr1_med"]
                                                            < 1.6064651
                                                            else 802
                                                        )
                                                        if state == 801:
                                                            return 0.0754506886
                                                        if state == 802:
                                                            return -0.145829424
                                            if state == 342:
                                                state = (
                                                    461
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.977750003)
                                                    else 462
                                                )
                                                if state == 461:
                                                    state = (
                                                        627
                                                        if x["distpsnr1_med"]
                                                        < 0.161337689
                                                        else 628
                                                    )
                                                    if state == 627:
                                                        state = (
                                                            803
                                                            if x["distpsnr1_med"]
                                                            < 0.116796046
                                                            else 804
                                                        )
                                                        if state == 803:
                                                            return -0.109603651
                                                        if state == 804:
                                                            return 0.371099979
                                                    if state == 628:
                                                        state = (
                                                            805
                                                            if x["distpsnr1_med"]
                                                            < 0.50513196
                                                            else 806
                                                        )
                                                        if state == 805:
                                                            return -0.123267055
                                                        if state == 806:
                                                            return -0.430014968
                                                if state == 462:
                                                    state = (
                                                        629
                                                        if x["distpsnr1_med"]
                                                        < 0.430893242
                                                        else 630
                                                    )
                                                    if state == 629:
                                                        state = (
                                                            807
                                                            if x["distpsnr1_med"]
                                                            < 0.0606765822
                                                            else 808
                                                        )
                                                        if state == 807:
                                                            return 0.336737633
                                                        if state == 808:
                                                            return 0.1358217
                                                    if state == 630:
                                                        state = (
                                                            809
                                                            if x["distpsnr1_med"]
                                                            < 5.82414055
                                                            else 810
                                                        )
                                                        if state == 809:
                                                            return -0.215316996
                                                        if state == 810:
                                                            return -0.529690862
                                        if state == 232:
                                            state = (
                                                343
                                                if x["maggaia_med"] < 18.89011
                                                else 344
                                            )
                                            if state == 343:
                                                state = (
                                                    463
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.98724997)
                                                    else 464
                                                )
                                                if state == 463:
                                                    state = (
                                                        631
                                                        if x["distpsnr1_med"]
                                                        < 1.48903227
                                                        else 632
                                                    )
                                                    if state == 631:
                                                        state = (
                                                            811
                                                            if x["distpsnr1_med"]
                                                            < 0.389682144
                                                            else 812
                                                        )
                                                        if state == 811:
                                                            return -0.305558681
                                                        if state == 812:
                                                            return 0.0882334262
                                                    if state == 632:
                                                        return -0.667955995
                                                if state == 464:
                                                    return 0.229459956
                                            if state == 344:
                                                return 0.221912399
                                if state == 80:
                                    state = (
                                        143
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 44.8759727)
                                        else 144
                                    )
                                    if state == 143:
                                        state = (
                                            233
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982749999)
                                            else 234
                                        )
                                        if state == 233:
                                            state = (
                                                345
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 19.9470882)
                                                else 346
                                            )
                                            if state == 345:
                                                state = (
                                                    465
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.975500047)
                                                    else 466
                                                )
                                                if state == 465:
                                                    state = (
                                                        633
                                                        if x["distpsnr1_med"]
                                                        < 1.29901779
                                                        else 634
                                                    )
                                                    if state == 633:
                                                        return 0.292976886
                                                    if state == 634:
                                                        state = (
                                                            815
                                                            if np.isnan(
                                                                x["distpsnr1_med"]
                                                            )
                                                            or (
                                                                x["distpsnr1_med"]
                                                                < 1.78846335
                                                            )
                                                            else 816
                                                        )
                                                        if state == 815:
                                                            return -0.397271991
                                                        if state == 816:
                                                            return 0.0239491966
                                                if state == 466:
                                                    state = (
                                                        635
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 14.1208878
                                                        )
                                                        else 636
                                                    )
                                                    if state == 635:
                                                        state = (
                                                            817
                                                            if np.isnan(
                                                                x["distpsnr1_med"]
                                                            )
                                                            or (
                                                                x["distpsnr1_med"]
                                                                < 1.35056031
                                                            )
                                                            else 818
                                                        )
                                                        if state == 817:
                                                            return 0.102409847
                                                        if state == 818:
                                                            return -0.0829930604
                                                    if state == 636:
                                                        return 0.333755106
                                            if state == 346:
                                                state = (
                                                    467
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.977749944)
                                                    else 468
                                                )
                                                if state == 467:
                                                    state = (
                                                        637
                                                        if x["distpsnr1_med"]
                                                        < 0.22805196
                                                        else 638
                                                    )
                                                    if state == 637:
                                                        return -0.028488474
                                                    if state == 638:
                                                        return -0.402329206
                                                if state == 468:
                                                    state = (
                                                        639
                                                        if x["distpsnr1_med"]
                                                        < 0.26198712
                                                        else 640
                                                    )
                                                    if state == 639:
                                                        return 0.329878718
                                                    if state == 640:
                                                        state = (
                                                            819
                                                            if x["distpsnr1_med"]
                                                            < 1.66434383
                                                            else 820
                                                        )
                                                        if state == 819:
                                                            return -0.629121959
                                                        if state == 820:
                                                            return 0.106600836
                                        if state == 234:
                                            state = (
                                                347
                                                if x["maggaia_med"] < 17.0958481
                                                else 348
                                            )
                                            if state == 347:
                                                return -0.125087395
                                            if state == 348:
                                                return 0.297671795
                                    if state == 144:
                                        state = (
                                            235
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.979750037)
                                            else 236
                                        )
                                        if state == 235:
                                            state = (
                                                349
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 20.2074032)
                                                else 350
                                            )
                                            if state == 349:
                                                state = (
                                                    469
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.972750008)
                                                    else 470
                                                )
                                                if state == 469:
                                                    return 0.286486536
                                                if state == 470:
                                                    state = (
                                                        641
                                                        if x["distpsnr1_med"]
                                                        < 0.452649236
                                                        else 642
                                                    )
                                                    if state == 641:
                                                        state = (
                                                            821
                                                            if x["distpsnr1_med"]
                                                            < 0.159434199
                                                            else 822
                                                        )
                                                        if state == 821:
                                                            return -0.00899531413
                                                        if state == 822:
                                                            return -0.217755497
                                                    if state == 642:
                                                        state = (
                                                            823
                                                            if x["distpsnr1_med"]
                                                            < 2.15129614
                                                            else 824
                                                        )
                                                        if state == 823:
                                                            return 0.186933503
                                                        if state == 824:
                                                            return -0.0382910445
                                            if state == 350:
                                                return -0.341379434
                                        if state == 236:
                                            state = (
                                                351
                                                if np.isnan(x["maggaia_med"])
                                                or (x["maggaia_med"] < 20.6699829)
                                                else 352
                                            )
                                            if state == 351:
                                                state = (
                                                    471
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.984250009)
                                                    else 472
                                                )
                                                if state == 471:
                                                    state = (
                                                        643
                                                        if x["distpsnr1_med"]
                                                        < 0.203195572
                                                        else 644
                                                    )
                                                    if state == 643:
                                                        state = (
                                                            825
                                                            if x["distpsnr1_med"]
                                                            < 0.152669072
                                                            else 826
                                                        )
                                                        if state == 825:
                                                            return 0.0350926109
                                                        if state == 826:
                                                            return -0.198846385
                                                    if state == 644:
                                                        state = (
                                                            827
                                                            if x["distpsnr1_med"]
                                                            < 1.55241704
                                                            else 828
                                                        )
                                                        if state == 827:
                                                            return 0.219637558
                                                        if state == 828:
                                                            return 0.34598121
                                                if state == 472:
                                                    return -0.0998804048
                                            if state == 352:
                                                state = (
                                                    473
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982499957)
                                                    else 474
                                                )
                                                if state == 473:
                                                    state = (
                                                        645
                                                        if x["distpsnr1_med"]
                                                        < 5.89493275
                                                        else 646
                                                    )
                                                    if state == 645:
                                                        return 0.206637606
                                                    if state == 646:
                                                        return -0.200833455
                                                if state == 474:
                                                    return -0.303921044
    elif num_booster == 10:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.572118759) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 0.3728773)
                    else 4
                )
                if state == 3:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.833333075) else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.0206165314)
                            else 16
                        )
                        if state == 15:
                            state = (
                                31
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.0139999)
                                else 32
                            )
                            if state == 31:
                                return -0.367017299
                            if state == 32:
                                state = (
                                    53
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.3994999)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        81
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.829285741)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            127
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.14261055)
                                            else 128
                                        )
                                        if state == 127:
                                            state = (
                                                179
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.184068531)
                                                else 180
                                            )
                                            if state == 179:
                                                state = (
                                                    255
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.230898857)
                                                    else 256
                                                )
                                                if state == 255:
                                                    state = (
                                                        339
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.97874999
                                                        )
                                                        else 340
                                                    )
                                                    if state == 339:
                                                        state = (
                                                            453
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 9.45088005
                                                            )
                                                            else 454
                                                        )
                                                        if state == 453:
                                                            return -0.34484449
                                                        if state == 454:
                                                            return 0.175229654
                                                    if state == 340:
                                                        state = (
                                                            455
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 3.01130772
                                                            )
                                                            else 456
                                                        )
                                                        if state == 455:
                                                            return -0.167030543
                                                        if state == 456:
                                                            return 0.356645107
                                                if state == 256:
                                                    return 0.41319257
                                            if state == 180:
                                                state = (
                                                    257
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < -0.059053421)
                                                    else 258
                                                )
                                                if state == 257:
                                                    state = (
                                                        341
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.935750008
                                                        )
                                                        else 342
                                                    )
                                                    if state == 341:
                                                        return -0.373763174
                                                    if state == 342:
                                                        state = (
                                                            457
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 8.89889431
                                                            )
                                                            else 458
                                                        )
                                                        if state == 457:
                                                            return -0.0996234119
                                                        if state == 458:
                                                            return -0.389537573
                                                if state == 258:
                                                    state = (
                                                        343
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.907249987
                                                        )
                                                        else 344
                                                    )
                                                    if state == 343:
                                                        return -0.32704708
                                                    if state == 344:
                                                        state = (
                                                            459
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 3.01905107
                                                            )
                                                            else 460
                                                        )
                                                        if state == 459:
                                                            return -0.107526064
                                                        if state == 460:
                                                            return 0.340133458
                                        if state == 128:
                                            state = (
                                                181
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.300668567)
                                                else 182
                                            )
                                            if state == 181:
                                                state = (
                                                    259
                                                    if x["col_last"] < 0.0895023346
                                                    else 260
                                                )
                                                if state == 259:
                                                    return -0.196232438
                                                if state == 260:
                                                    state = (
                                                        347
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.97874999
                                                        )
                                                        else 348
                                                    )
                                                    if state == 347:
                                                        state = (
                                                            461
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 0.522089064
                                                            )
                                                            else 462
                                                        )
                                                        if state == 461:
                                                            return 0.22922276
                                                        if state == 462:
                                                            return -0.210881263
                                                    if state == 348:
                                                        state = (
                                                            463
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 3.00370955
                                                            )
                                                            else 464
                                                        )
                                                        if state == 463:
                                                            return -0.0836001486
                                                        if state == 464:
                                                            return 0.384493798
                                            if state == 182:
                                                return -0.196433768
                                    if state == 82:
                                        return 0.2719405
                                if state == 54:
                                    state = (
                                        83
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.639642715)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            129 if x["col_peak"] < -0.168987274 else 130
                                        )
                                        if state == 129:
                                            state = (
                                                183
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.237733126)
                                                else 184
                                            )
                                            if state == 183:
                                                return 0.254917443
                                            if state == 184:
                                                state = (
                                                    261
                                                    if x["col_last"] < 0.723500311
                                                    else 262
                                                )
                                                if state == 261:
                                                    return -0.115612343
                                                if state == 262:
                                                    state = (
                                                        349
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.981750011
                                                        )
                                                        else 350
                                                    )
                                                    if state == 349:
                                                        state = (
                                                            465
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 7.43631363
                                                            )
                                                            else 466
                                                        )
                                                        if state == 465:
                                                            return -0.124086402
                                                        if state == 466:
                                                            return 0.296251327
                                                    if state == 350:
                                                        state = (
                                                            467
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 9.41383743
                                                            )
                                                            else 468
                                                        )
                                                        if state == 467:
                                                            return 0.0975968763
                                                        if state == 468:
                                                            return -0.17302765
                                        if state == 130:
                                            return -0.35102579
                                    if state == 84:
                                        state = (
                                            131
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.0129585266)
                                            else 132
                                        )
                                        if state == 131:
                                            state = (
                                                185
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.112215161)
                                                else 186
                                            )
                                            if state == 185:
                                                return 0.332333267
                                            if state == 186:
                                                state = (
                                                    263
                                                    if x["col_last"] < 0.00172472
                                                    else 264
                                                )
                                                if state == 263:
                                                    state = (
                                                        351
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.965250015
                                                        )
                                                        else 352
                                                    )
                                                    if state == 351:
                                                        return -0.321516871
                                                    if state == 352:
                                                        state = (
                                                            469
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 0.0687268972
                                                            )
                                                            else 470
                                                        )
                                                        if state == 469:
                                                            return -0.106356762
                                                        if state == 470:
                                                            return 0.174255863
                                                if state == 264:
                                                    state = (
                                                        353
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.946249962
                                                        )
                                                        else 354
                                                    )
                                                    if state == 353:
                                                        return -0.366420895
                                                    if state == 354:
                                                        state = (
                                                            471
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 3.55131364
                                                            )
                                                            else 472
                                                        )
                                                        if state == 471:
                                                            return -0.225222975
                                                        if state == 472:
                                                            return 0.199964285
                                        if state == 132:
                                            return -0.372963399
                        if state == 16:
                            state = (
                                33
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.7824993)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    55
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 16.8404999)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        85
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.714523792)
                                        else 86
                                    )
                                    if state == 85:
                                        return -0.301993906
                                    if state == 86:
                                        return 0.367646247
                                if state == 56:
                                    state = (
                                        87
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.777500033)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            133 if x["col_peak"] < 0.130631447 else 134
                                        )
                                        if state == 133:
                                            state = (
                                                187
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.245917588)
                                                else 188
                                            )
                                            if state == 187:
                                                return -0.113679513
                                            if state == 188:
                                                return 0.236825913
                                        if state == 134:
                                            state = (
                                                189
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 2.11123633)
                                                else 190
                                            )
                                            if state == 189:
                                                state = (
                                                    265
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.928097248)
                                                    else 266
                                                )
                                                if state == 265:
                                                    state = (
                                                        355
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.982499957
                                                        )
                                                        else 356
                                                    )
                                                    if state == 355:
                                                        state = (
                                                            473
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 5.92510414
                                                            )
                                                            else 474
                                                        )
                                                        if state == 473:
                                                            return -0.400211781
                                                        if state == 474:
                                                            return -0.191368267
                                                    if state == 356:
                                                        return 0.224532083
                                                if state == 266:
                                                    return 0.162229314
                                            if state == 190:
                                                return 0.282494962
                                    if state == 88:
                                        state = (
                                            135
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < 0.236005783)
                                            else 136
                                        )
                                        if state == 135:
                                            state = (
                                                191
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.275499761)
                                                else 192
                                            )
                                            if state == 191:
                                                state = (
                                                    267
                                                    if x["col_last"] < 0.357108116
                                                    else 268
                                                )
                                                if state == 267:
                                                    return 0.186004326
                                                if state == 268:
                                                    return -0.264711797
                                            if state == 192:
                                                state = (
                                                    269
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.207058907)
                                                    else 270
                                                )
                                                if state == 269:
                                                    return -0.0829413608
                                                if state == 270:
                                                    return 0.196206301
                                        if state == 136:
                                            return 0.263151556
                            if state == 34:
                                state = (
                                    57
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 20.9372482)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        89
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.616190493)
                                        else 90
                                    )
                                    if state == 89:
                                        return -0.120034069
                                    if state == 90:
                                        state = (
                                            137 if x["col_peak"] < 0.149980545 else 138
                                        )
                                        if state == 137:
                                            return 0.00925682113
                                        if state == 138:
                                            return 0.361339808
                                if state == 58:
                                    state = (
                                        91
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.287023753)
                                        else 92
                                    )
                                    if state == 91:
                                        return -0.00872310065
                                    if state == 92:
                                        return -0.291668266
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.0352077484)
                            else 18
                        )
                        if state == 17:
                            state = (
                                35
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.2835007)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    59
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 18.0904999)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        93
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.937857091)
                                        else 94
                                    )
                                    if state == 93:
                                        return -0.364914596
                                    if state == 94:
                                        state = (
                                            139
                                            if x["col_peak"] < -0.0922775269
                                            else 140
                                        )
                                        if state == 139:
                                            state = (
                                                195
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.348822594)
                                                else 196
                                            )
                                            if state == 195:
                                                return -0.145291939
                                            if state == 196:
                                                return 0.227351084
                                        if state == 140:
                                            return -0.314230114
                                if state == 60:
                                    state = (
                                        95
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.963928521)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            141
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.244453907)
                                            else 142
                                        )
                                        if state == 141:
                                            state = (
                                                197
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.187814504)
                                                else 198
                                            )
                                            if state == 197:
                                                return 0.254455835
                                            if state == 198:
                                                state = (
                                                    271
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.00043964386)
                                                    else 272
                                                )
                                                if state == 271:
                                                    return -0.213195473
                                                if state == 272:
                                                    return 0.125326574
                                        if state == 142:
                                            return -0.179938972
                                    if state == 96:
                                        return 0.254434407
                            if state == 36:
                                state = (
                                    61
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 22.0697498)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        97
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.940000176)
                                        else 98
                                    )
                                    if state == 97:
                                        return -0.391574562
                                    if state == 98:
                                        state = (
                                            143 if x["col_peak"] < 0.0862417221 else 144
                                        )
                                        if state == 143:
                                            return -0.348218769
                                        if state == 144:
                                            state = (
                                                199
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.166187644)
                                                else 200
                                            )
                                            if state == 199:
                                                return 0.261738598
                                            if state == 200:
                                                state = (
                                                    273
                                                    if x["col_last"] < -0.120129585
                                                    else 274
                                                )
                                                if state == 273:
                                                    state = (
                                                        359
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.978500009
                                                        )
                                                        else 360
                                                    )
                                                    if state == 359:
                                                        return -0.13310127
                                                    if state == 360:
                                                        return 0.100215517
                                                if state == 274:
                                                    state = (
                                                        361
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.982749999
                                                        )
                                                        else 362
                                                    )
                                                    if state == 361:
                                                        return -0.27409485
                                                    if state == 362:
                                                        state = (
                                                            475
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 5.4155035
                                                            )
                                                            else 476
                                                        )
                                                        if state == 475:
                                                            return 0.0667303652
                                                        if state == 476:
                                                            return -0.193098009
                                if state == 62:
                                    state = (
                                        99
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.903928757)
                                        else 100
                                    )
                                    if state == 99:
                                        return -0.255721927
                                    if state == 100:
                                        state = 145 if x["col_peak"] < 0.000001 else 146
                                        if state == 145:
                                            return -0.141818404
                                        if state == 146:
                                            state = (
                                                201
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.36503756)
                                                else 202
                                            )
                                            if state == 201:
                                                return -0.0449281223
                                            if state == 202:
                                                return 0.156679392
                        if state == 18:
                            state = (
                                37
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.8190002)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    63
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 17.3400002)
                                    else 64
                                )
                                if state == 63:
                                    return -0.290147126
                                if state == 64:
                                    state = (
                                        101
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.944999993)
                                        else 102
                                    )
                                    if state == 101:
                                        state = (
                                            147
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < 0.424108505)
                                            else 148
                                        )
                                        if state == 147:
                                            return -0.206539735
                                        if state == 148:
                                            return 0.118698917
                                    if state == 102:
                                        return 0.307051301
                            if state == 38:
                                return -0.337430894
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.264643013)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.393100262)
                            else 20
                        )
                        if state == 19:
                            state = (
                                39
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.6305008)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    65
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.7730007)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        103
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.257500231)
                                        else 104
                                    )
                                    if state == 103:
                                        state = (
                                            149 if x["col_peak"] < 0.128449917 else 150
                                        )
                                        if state == 149:
                                            return 0.108960636
                                        if state == 150:
                                            state = (
                                                203
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.85900223)
                                                else 204
                                            )
                                            if state == 203:
                                                return -0.103656605
                                            if state == 204:
                                                return -0.38968581
                                    if state == 104:
                                        return 0.0527140573
                                if state == 66:
                                    state = (
                                        105
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.236666754)
                                        else 106
                                    )
                                    if state == 105:
                                        return -0.457569212
                                    if state == 106:
                                        return -0.136766806
                            if state == 40:
                                state = (
                                    67
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 21.7110004)
                                    else 68
                                )
                                if state == 67:
                                    return 0.249746501
                                if state == 68:
                                    state = (
                                        107
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.0816664994)
                                        else 108
                                    )
                                    if state == 107:
                                        return 0.129714146
                                    if state == 108:
                                        return -0.353596061
                        if state == 20:
                            state = (
                                41
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.6254997)
                                else 42
                            )
                            if state == 41:
                                return 0.264059991
                            if state == 42:
                                return -0.19738844
                    if state == 10:
                        state = 21 if x["col_det"] < -0.0301346779 else 22
                        if state == 21:
                            state = (
                                43
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 20.2877502)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    69
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.4064999)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        109
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.596547604)
                                        else 110
                                    )
                                    if state == 109:
                                        state = (
                                            151
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.0891294479)
                                            else 152
                                        )
                                        if state == 151:
                                            state = (
                                                205
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 7.78845406)
                                                else 206
                                            )
                                            if state == 205:
                                                state = (
                                                    277
                                                    if x["col_last"] < 0.0766243935
                                                    else 278
                                                )
                                                if state == 277:
                                                    state = (
                                                        363
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.97724998
                                                        )
                                                        else 364
                                                    )
                                                    if state == 363:
                                                        return -0.291698128
                                                    if state == 364:
                                                        state = (
                                                            477
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 6.0658741
                                                            )
                                                            else 478
                                                        )
                                                        if state == 477:
                                                            return 0.173395991
                                                        if state == 478:
                                                            return -0.145099506
                                                if state == 278:
                                                    return -0.410680592
                                            if state == 206:
                                                return 0.335555971
                                        if state == 152:
                                            state = (
                                                207
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.48681855)
                                                else 208
                                            )
                                            if state == 207:
                                                return 0.304673225
                                            if state == 208:
                                                state = (
                                                    279
                                                    if x["col_last"] < 0.49103117
                                                    else 280
                                                )
                                                if state == 279:
                                                    state = (
                                                        367
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980999947
                                                        )
                                                        else 368
                                                    )
                                                    if state == 367:
                                                        return -0.157718465
                                                    if state == 368:
                                                        return 0.106862232
                                                if state == 280:
                                                    state = (
                                                        369
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.975250006
                                                        )
                                                        else 370
                                                    )
                                                    if state == 369:
                                                        return -0.0992082059
                                                    if state == 370:
                                                        return 0.239745468
                                    if state == 110:
                                        state = (
                                            153
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.084022522)
                                            else 154
                                        )
                                        if state == 153:
                                            state = (
                                                209
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.999123693)
                                                else 210
                                            )
                                            if state == 209:
                                                state = (
                                                    281
                                                    if x["col_last"] < -0.186812401
                                                    else 282
                                                )
                                                if state == 281:
                                                    return 0.0416080058
                                                if state == 282:
                                                    state = (
                                                        371
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.982249975
                                                        )
                                                        else 372
                                                    )
                                                    if state == 371:
                                                        state = (
                                                            479
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 9.97289944
                                                            )
                                                            else 480
                                                        )
                                                        if state == 479:
                                                            return -0.424338728
                                                        if state == 480:
                                                            return 0.329635561
                                                    if state == 372:
                                                        state = (
                                                            481
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 4.48751163
                                                            )
                                                            else 482
                                                        )
                                                        if state == 481:
                                                            return 0.256144404
                                                        if state == 482:
                                                            return -0.0725221708
                                            if state == 210:
                                                state = (
                                                    283
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.22013092)
                                                    else 284
                                                )
                                                if state == 283:
                                                    state = (
                                                        373
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.972750008
                                                        )
                                                        else 374
                                                    )
                                                    if state == 373:
                                                        state = (
                                                            483
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.94195604
                                                            )
                                                            else 484
                                                        )
                                                        if state == 483:
                                                            return -0.408103973
                                                        if state == 484:
                                                            return -0.185365483
                                                    if state == 374:
                                                        state = (
                                                            485
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 6.51966476
                                                            )
                                                            else 486
                                                        )
                                                        if state == 485:
                                                            return 0.0549318194
                                                        if state == 486:
                                                            return 0.306581169
                                                if state == 284:
                                                    state = (
                                                        375
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.974750042
                                                        )
                                                        else 376
                                                    )
                                                    if state == 375:
                                                        return -0.246030912
                                                    if state == 376:
                                                        state = (
                                                            487
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 9.43942738
                                                            )
                                                            else 488
                                                        )
                                                        if state == 487:
                                                            return 0.349547803
                                                        if state == 488:
                                                            return 0.0282121524
                                        if state == 154:
                                            state = (
                                                211
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.5991832)
                                                else 212
                                            )
                                            if state == 211:
                                                state = (
                                                    285
                                                    if x["col_last"] < 0.160317421
                                                    else 286
                                                )
                                                if state == 285:
                                                    state = (
                                                        377
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.978250027
                                                        )
                                                        else 378
                                                    )
                                                    if state == 377:
                                                        return -0.200815767
                                                    if state == 378:
                                                        return 0.214369446
                                                if state == 286:
                                                    state = (
                                                        379
                                                        if np.isnan(x["classtar_med"])
                                                        or (x["classtar_med"] < 0.96875)
                                                        else 380
                                                    )
                                                    if state == 379:
                                                        return -0.157669052
                                                    if state == 380:
                                                        state = (
                                                            489
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 8.4298954
                                                            )
                                                            else 490
                                                        )
                                                        if state == 489:
                                                            return 0.398427784
                                                        if state == 490:
                                                            return 0.0168200806
                                            if state == 212:
                                                state = (
                                                    287
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.138838768)
                                                    else 288
                                                )
                                                if state == 287:
                                                    state = (
                                                        381
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.981750011
                                                        )
                                                        else 382
                                                    )
                                                    if state == 381:
                                                        state = (
                                                            491
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 3.04589128
                                                            )
                                                            else 492
                                                        )
                                                        if state == 491:
                                                            return 0.190275908
                                                        if state == 492:
                                                            return -0.197329715
                                                    if state == 382:
                                                        state = (
                                                            493
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 7.9606595
                                                            )
                                                            else 494
                                                        )
                                                        if state == 493:
                                                            return 0.2387373
                                                        if state == 494:
                                                            return -0.154893056
                                                if state == 288:
                                                    return 0.284369051
                                if state == 70:
                                    state = (
                                        111
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.954999924)
                                        else 112
                                    )
                                    if state == 111:
                                        state = (
                                            155 if x["col_peak"] < -0.165803909 else 156
                                        )
                                        if state == 155:
                                            state = (
                                                213
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.1680758)
                                                else 214
                                            )
                                            if state == 213:
                                                return -0.310648739
                                            if state == 214:
                                                state = (
                                                    289
                                                    if x["col_last"] < -0.0384140015
                                                    else 290
                                                )
                                                if state == 289:
                                                    return 0.0865677223
                                                if state == 290:
                                                    state = (
                                                        383
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980999947
                                                        )
                                                        else 384
                                                    )
                                                    if state == 383:
                                                        return -0.244676664
                                                    if state == 384:
                                                        state = (
                                                            495
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.98557854
                                                            )
                                                            else 496
                                                        )
                                                        if state == 495:
                                                            return -0.137261093
                                                        if state == 496:
                                                            return 0.168374211
                                        if state == 156:
                                            state = (
                                                215
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.32110286)
                                                else 216
                                            )
                                            if state == 215:
                                                state = (
                                                    291
                                                    if x["col_last"] < 0.0612392426
                                                    else 292
                                                )
                                                if state == 291:
                                                    state = (
                                                        385
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.966250002
                                                        )
                                                        else 386
                                                    )
                                                    if state == 385:
                                                        state = (
                                                            497
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.95714712
                                                            )
                                                            else 498
                                                        )
                                                        if state == 497:
                                                            return 0.0591998845
                                                        if state == 498:
                                                            return -0.185234591
                                                    if state == 386:
                                                        state = (
                                                            499
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.86319447
                                                            )
                                                            else 500
                                                        )
                                                        if state == 499:
                                                            return 0.335218012
                                                        if state == 500:
                                                            return 0.0804431811
                                                if state == 292:
                                                    state = (
                                                        387
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.976000011
                                                        )
                                                        else 388
                                                    )
                                                    if state == 387:
                                                        state = (
                                                            501
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.94315386
                                                            )
                                                            else 502
                                                        )
                                                        if state == 501:
                                                            return -0.159676626
                                                        if state == 502:
                                                            return 0.275031954
                                                    if state == 388:
                                                        state = (
                                                            503
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 8.45806122
                                                            )
                                                            else 504
                                                        )
                                                        if state == 503:
                                                            return 0.347798765
                                                        if state == 504:
                                                            return 0.10178823
                                            if state == 216:
                                                state = (
                                                    293
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < -0.0741987228)
                                                    else 294
                                                )
                                                if state == 293:
                                                    state = (
                                                        389
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980250001
                                                        )
                                                        else 390
                                                    )
                                                    if state == 389:
                                                        state = (
                                                            505
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 4.9417944
                                                            )
                                                            else 506
                                                        )
                                                        if state == 505:
                                                            return -0.332358569
                                                        if state == 506:
                                                            return 0.0507667027
                                                    if state == 390:
                                                        state = (
                                                            507
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 6.9379282
                                                            )
                                                            else 508
                                                        )
                                                        if state == 507:
                                                            return -0.0184928924
                                                        if state == 508:
                                                            return 0.240084246
                                                if state == 294:
                                                    state = (
                                                        391
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.960749984
                                                        )
                                                        else 392
                                                    )
                                                    if state == 391:
                                                        return 0.294669658
                                                    if state == 392:
                                                        state = (
                                                            509
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 6.95814228
                                                            )
                                                            else 510
                                                        )
                                                        if state == 509:
                                                            return -0.143938288
                                                        if state == 510:
                                                            return 0.0774922594
                                    if state == 112:
                                        return -0.310112119
                            if state == 44:
                                state = (
                                    71
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 20.5084991)
                                    else 72
                                )
                                if state == 71:
                                    state = (
                                        113
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.934999943)
                                        else 114
                                    )
                                    if state == 113:
                                        state = (
                                            157 if x["col_peak"] < -0.122176647 else 158
                                        )
                                        if state == 157:
                                            state = (
                                                217
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.24240255)
                                                else 218
                                            )
                                            if state == 217:
                                                state = (
                                                    295
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.364449501)
                                                    else 296
                                                )
                                                if state == 295:
                                                    return 0.246596053
                                                if state == 296:
                                                    return -0.0479441807
                                            if state == 218:
                                                return -0.230497003
                                        if state == 158:
                                            return -0.465831488
                                    if state == 114:
                                        return 0.174362734
                                if state == 72:
                                    state = (
                                        115
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.593809485)
                                        else 116
                                    )
                                    if state == 115:
                                        state = (
                                            159
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.000201225281)
                                            else 160
                                        )
                                        if state == 159:
                                            state = (
                                                219
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.52601743)
                                                else 220
                                            )
                                            if state == 219:
                                                state = (
                                                    299
                                                    if x["col_last"] < 0.308515549
                                                    else 300
                                                )
                                                if state == 299:
                                                    state = (
                                                        393
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.973250031
                                                        )
                                                        else 394
                                                    )
                                                    if state == 393:
                                                        state = (
                                                            511
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.96126747
                                                            )
                                                            else 512
                                                        )
                                                        if state == 511:
                                                            return 0.18066892
                                                        if state == 512:
                                                            return -0.172002062
                                                    if state == 394:
                                                        return -0.21897462
                                                if state == 300:
                                                    state = (
                                                        395
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.968500018
                                                        )
                                                        else 396
                                                    )
                                                    if state == 395:
                                                        return -0.213365033
                                                    if state == 396:
                                                        state = (
                                                            515
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 8.43991852
                                                            )
                                                            else 516
                                                        )
                                                        if state == 515:
                                                            return 0.228405997
                                                        if state == 516:
                                                            return -0.128731981
                                            if state == 220:
                                                state = (
                                                    301
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.180686474)
                                                    else 302
                                                )
                                                if state == 301:
                                                    state = (
                                                        397
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.976750016
                                                        )
                                                        else 398
                                                    )
                                                    if state == 397:
                                                        state = (
                                                            517
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.97747684
                                                            )
                                                            else 518
                                                        )
                                                        if state == 517:
                                                            return 0.371044099
                                                        if state == 518:
                                                            return -0.100461908
                                                    if state == 398:
                                                        state = (
                                                            519
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 8.94788742
                                                            )
                                                            else 520
                                                        )
                                                        if state == 519:
                                                            return 0.370412976
                                                        if state == 520:
                                                            return 0.0235870313
                                                if state == 302:
                                                    state = (
                                                        399
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.973999977
                                                        )
                                                        else 400
                                                    )
                                                    if state == 399:
                                                        return -0.349159092
                                                    if state == 400:
                                                        return 0.222640127
                                        if state == 160:
                                            state = (
                                                221
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 2.28850937)
                                                else 222
                                            )
                                            if state == 221:
                                                return -0.345478654
                                            if state == 222:
                                                state = (
                                                    303
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.185166359)
                                                    else 304
                                                )
                                                if state == 303:
                                                    state = (
                                                        401
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.981250048
                                                        )
                                                        else 402
                                                    )
                                                    if state == 401:
                                                        state = (
                                                            521
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.94767356
                                                            )
                                                            else 522
                                                        )
                                                        if state == 521:
                                                            return 0.2214645
                                                        if state == 522:
                                                            return -0.286177933
                                                    if state == 402:
                                                        return 0.138692483
                                                if state == 304:
                                                    return 0.183010027
                                    if state == 116:
                                        state = (
                                            161 if x["col_peak"] < -0.188547611 else 162
                                        )
                                        if state == 161:
                                            state = (
                                                223
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.37207615)
                                                else 224
                                            )
                                            if state == 223:
                                                return -0.448714793
                                            if state == 224:
                                                state = (
                                                    305
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.0673570633)
                                                    else 306
                                                )
                                                if state == 305:
                                                    state = (
                                                        403
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.977749944
                                                        )
                                                        else 404
                                                    )
                                                    if state == 403:
                                                        return 0.02235041
                                                    if state == 404:
                                                        state = (
                                                            523
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 5.44263887
                                                            )
                                                            else 524
                                                        )
                                                        if state == 523:
                                                            return -0.377006978
                                                        if state == 524:
                                                            return 0.00837945286
                                                if state == 306:
                                                    return 0.0228481665
                                        if state == 162:
                                            state = (
                                                225
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.568668783)
                                                else 226
                                            )
                                            if state == 225:
                                                return -0.453569353
                                            if state == 226:
                                                state = (
                                                    307
                                                    if x["col_last"] < 0.177726746
                                                    else 308
                                                )
                                                if state == 307:
                                                    state = (
                                                        405
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.974249959
                                                        )
                                                        else 406
                                                    )
                                                    if state == 405:
                                                        return -0.322629452
                                                    if state == 406:
                                                        state = (
                                                            525
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 7.42330456
                                                            )
                                                            else 526
                                                        )
                                                        if state == 525:
                                                            return -0.0245623495
                                                        if state == 526:
                                                            return 0.197532654
                                                if state == 308:
                                                    state = (
                                                        407
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980250001
                                                        )
                                                        else 408
                                                    )
                                                    if state == 407:
                                                        state = (
                                                            527
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.88221073
                                                            )
                                                            else 528
                                                        )
                                                        if state == 527:
                                                            return -0.271605879
                                                        if state == 528:
                                                            return 0.0325415134
                                                    if state == 408:
                                                        state = (
                                                            529
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.88966441
                                                            )
                                                            else 530
                                                        )
                                                        if state == 529:
                                                            return -0.366193652
                                                        if state == 530:
                                                            return 0.280011624
                        if state == 22:
                            state = (
                                45
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.9344997)
                                else 46
                            )
                            if state == 45:
                                state = (
                                    73
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 15.8115005)
                                    else 74
                                )
                                if state == 73:
                                    state = (
                                        117
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.609285712)
                                        else 118
                                    )
                                    if state == 117:
                                        return -0.406176448
                                    if state == 118:
                                        state = (
                                            163 if x["col_peak"] < 0.430439949 else 164
                                        )
                                        if state == 163:
                                            return 0.0905265808
                                        if state == 164:
                                            return -0.179399833
                                if state == 74:
                                    state = (
                                        119
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.887142897)
                                        else 120
                                    )
                                    if state == 119:
                                        state = (
                                            165
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < 0.144868851)
                                            else 166
                                        )
                                        if state == 165:
                                            state = (
                                                229
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 5.88913441)
                                                else 230
                                            )
                                            if state == 229:
                                                state = (
                                                    309
                                                    if x["col_last"] < 0.29240799
                                                    else 310
                                                )
                                                if state == 309:
                                                    state = (
                                                        409
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.96724999
                                                        )
                                                        else 410
                                                    )
                                                    if state == 409:
                                                        state = (
                                                            531
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 3.02845478
                                                            )
                                                            else 532
                                                        )
                                                        if state == 531:
                                                            return -0.216476172
                                                        if state == 532:
                                                            return -0.351167679
                                                    if state == 410:
                                                        state = (
                                                            533
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.93690968
                                                            )
                                                            else 534
                                                        )
                                                        if state == 533:
                                                            return 0.150658876
                                                        if state == 534:
                                                            return -0.00793145318
                                                if state == 310:
                                                    state = (
                                                        411
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.961250007
                                                        )
                                                        else 412
                                                    )
                                                    if state == 411:
                                                        state = (
                                                            535
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.99376154
                                                            )
                                                            else 536
                                                        )
                                                        if state == 535:
                                                            return -0.0950834975
                                                        if state == 536:
                                                            return -0.30992198
                                                    if state == 412:
                                                        state = (
                                                            537
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 3.50066566
                                                            )
                                                            else 538
                                                        )
                                                        if state == 537:
                                                            return 0.126460209
                                                        if state == 538:
                                                            return 0.024102306
                                            if state == 230:
                                                state = (
                                                    311
                                                    if x["col_last"] < 0.391993523
                                                    else 312
                                                )
                                                if state == 311:
                                                    state = (
                                                        413
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.98150003
                                                        )
                                                        else 414
                                                    )
                                                    if state == 413:
                                                        return -0.312565506
                                                    if state == 414:
                                                        state = (
                                                            539
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 6.48002911
                                                            )
                                                            else 540
                                                        )
                                                        if state == 539:
                                                            return 0.34000659
                                                        if state == 540:
                                                            return -0.090176262
                                                if state == 312:
                                                    state = (
                                                        415
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.979249954
                                                        )
                                                        else 416
                                                    )
                                                    if state == 415:
                                                        state = (
                                                            541
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 0.00114585017
                                                            )
                                                            else 542
                                                        )
                                                        if state == 541:
                                                            return 0.226826042
                                                        if state == 542:
                                                            return -0.149430364
                                                    if state == 416:
                                                        state = (
                                                            543
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 0.0993402451
                                                            )
                                                            else 544
                                                        )
                                                        if state == 543:
                                                            return 0.01628327
                                                        if state == 544:
                                                            return 0.368783951
                                        if state == 166:
                                            state = (
                                                231
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.66786766)
                                                else 232
                                            )
                                            if state == 231:
                                                state = (
                                                    313
                                                    if x["col_last"] < 0.190625191
                                                    else 314
                                                )
                                                if state == 313:
                                                    state = (
                                                        417
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980000019
                                                        )
                                                        else 418
                                                    )
                                                    if state == 417:
                                                        return -0.337788343
                                                    if state == 418:
                                                        state = (
                                                            545
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 6.39925337
                                                            )
                                                            else 546
                                                        )
                                                        if state == 545:
                                                            return -0.23118569
                                                        if state == 546:
                                                            return 0.137239411
                                                if state == 314:
                                                    state = (
                                                        419
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980250001
                                                        )
                                                        else 420
                                                    )
                                                    if state == 419:
                                                        state = (
                                                            547
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 5.9395256
                                                            )
                                                            else 548
                                                        )
                                                        if state == 547:
                                                            return -0.344479829
                                                        if state == 548:
                                                            return -0.141788945
                                                    if state == 420:
                                                        state = (
                                                            549
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.94235516
                                                            )
                                                            else 550
                                                        )
                                                        if state == 549:
                                                            return -0.0641576126
                                                        if state == 550:
                                                            return 0.193877071
                                            if state == 232:
                                                state = (
                                                    315
                                                    if x["col_last"] < 0.334190369
                                                    else 316
                                                )
                                                if state == 315:
                                                    state = (
                                                        421
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980749965
                                                        )
                                                        else 422
                                                    )
                                                    if state == 421:
                                                        return -0.172474876
                                                    if state == 422:
                                                        return 0.0597579777
                                                if state == 316:
                                                    state = (
                                                        423
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980499983
                                                        )
                                                        else 424
                                                    )
                                                    if state == 423:
                                                        state = (
                                                            551
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.44089127
                                                            )
                                                            else 552
                                                        )
                                                        if state == 551:
                                                            return 0.217488885
                                                        if state == 552:
                                                            return -0.354203343
                                                    if state == 424:
                                                        return 0.316465437
                                    if state == 120:
                                        state = (
                                            167 if x["col_peak"] < 0.0361728668 else 168
                                        )
                                        if state == 167:
                                            state = (
                                                233
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.409987628)
                                                else 234
                                            )
                                            if state == 233:
                                                return -0.190726474
                                            if state == 234:
                                                return 0.308024257
                                        if state == 168:
                                            state = (
                                                235
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.5867424)
                                                else 236
                                            )
                                            if state == 235:
                                                state = (
                                                    317
                                                    if x["col_last"] < 0.393532276
                                                    else 318
                                                )
                                                if state == 317:
                                                    state = (
                                                        425
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980749965
                                                        )
                                                        else 426
                                                    )
                                                    if state == 425:
                                                        state = (
                                                            553
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 0.00114584994
                                                            )
                                                            else 554
                                                        )
                                                        if state == 553:
                                                            return 0.195372477
                                                        if state == 554:
                                                            return -0.32497409
                                                    if state == 426:
                                                        state = (
                                                            555
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.99026036
                                                            )
                                                            else 556
                                                        )
                                                        if state == 555:
                                                            return 0.354990214
                                                        if state == 556:
                                                            return 0.0398597233
                                                if state == 318:
                                                    state = (
                                                        427
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.979750037
                                                        )
                                                        else 428
                                                    )
                                                    if state == 427:
                                                        state = (
                                                            557
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 0.0583217964
                                                            )
                                                            else 558
                                                        )
                                                        if state == 557:
                                                            return 0.256231755
                                                        if state == 558:
                                                            return -0.274109364
                                                    if state == 428:
                                                        state = (
                                                            559
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.99217606
                                                            )
                                                            else 560
                                                        )
                                                        if state == 559:
                                                            return 0.398121566
                                                        if state == 560:
                                                            return 0.161827013
                                            if state == 236:
                                                state = (
                                                    319
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.178083748)
                                                    else 320
                                                )
                                                if state == 319:
                                                    state = (
                                                        429
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.982749999
                                                        )
                                                        else 430
                                                    )
                                                    if state == 429:
                                                        state = (
                                                            561
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.41448498
                                                            )
                                                            else 562
                                                        )
                                                        if state == 561:
                                                            return -0.324178934
                                                        if state == 562:
                                                            return 0.112968251
                                                    if state == 430:
                                                        state = (
                                                            563
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 0.0293692499
                                                            )
                                                            else 564
                                                        )
                                                        if state == 563:
                                                            return -0.523319781
                                                        if state == 564:
                                                            return 0.224462032
                                                if state == 320:
                                                    state = (
                                                        431
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.982749999
                                                        )
                                                        else 432
                                                    )
                                                    if state == 431:
                                                        state = (
                                                            565
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 0.0480787009
                                                            )
                                                            else 566
                                                        )
                                                        if state == 565:
                                                            return -0.215819106
                                                        if state == 566:
                                                            return 0.208172753
                                                    if state == 432:
                                                        return 0.263988197
                            if state == 46:
                                state = (
                                    75
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 22.7449989)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        121
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.61190474)
                                        else 122
                                    )
                                    if state == 121:
                                        state = (
                                            169 if x["col_peak"] < 0.0978803635 else 170
                                        )
                                        if state == 169:
                                            state = (
                                                237
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 16.3089809)
                                                else 238
                                            )
                                            if state == 237:
                                                state = (
                                                    321
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.620381355)
                                                    else 322
                                                )
                                                if state == 321:
                                                    state = (
                                                        433
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.977750003
                                                        )
                                                        else 434
                                                    )
                                                    if state == 433:
                                                        return -0.350609928
                                                    if state == 434:
                                                        state = (
                                                            567
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 1.93387151
                                                            )
                                                            else 568
                                                        )
                                                        if state == 567:
                                                            return 0.239835396
                                                        if state == 568:
                                                            return 0.0211829562
                                                if state == 322:
                                                    state = (
                                                        435
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.98150003
                                                        )
                                                        else 436
                                                    )
                                                    if state == 435:
                                                        return -0.163584724
                                                    if state == 436:
                                                        return 0.193948269
                                            if state == 238:
                                                return 0.347752213
                                        if state == 170:
                                            state = (
                                                239
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 11.8551331)
                                                else 240
                                            )
                                            if state == 239:
                                                state = (
                                                    323
                                                    if x["col_last"] < 0.966247559
                                                    else 324
                                                )
                                                if state == 323:
                                                    state = (
                                                        437
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.981750011
                                                        )
                                                        else 438
                                                    )
                                                    if state == 437:
                                                        return -0.448821008
                                                    if state == 438:
                                                        state = (
                                                            569
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.93219328
                                                            )
                                                            else 570
                                                        )
                                                        if state == 569:
                                                            return 0.203099757
                                                        if state == 570:
                                                            return -0.135774806
                                                if state == 324:
                                                    state = (
                                                        439
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980749965
                                                        )
                                                        else 440
                                                    )
                                                    if state == 439:
                                                        return -0.361578792
                                                    if state == 440:
                                                        state = (
                                                            571
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 0.986290574
                                                            )
                                                            else 572
                                                        )
                                                        if state == 571:
                                                            return -0.0188900549
                                                        if state == 572:
                                                            return 0.198226705
                                            if state == 240:
                                                state = (
                                                    325
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.0270681381)
                                                    else 326
                                                )
                                                if state == 325:
                                                    return -0.12319614
                                                if state == 326:
                                                    return 0.287934065
                                    if state == 122:
                                        state = (
                                            171
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < 0.0845899582)
                                            else 172
                                        )
                                        if state == 171:
                                            state = (
                                                241
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.04201496)
                                                else 242
                                            )
                                            if state == 241:
                                                state = (
                                                    327
                                                    if x["col_last"] < 0.0969126225
                                                    else 328
                                                )
                                                if state == 327:
                                                    return 0.236857638
                                                if state == 328:
                                                    return -0.28883031
                                            if state == 242:
                                                return -0.488932163
                                        if state == 172:
                                            state = (
                                                243
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.26834393)
                                                else 244
                                            )
                                            if state == 243:
                                                return 0.238886118
                                            if state == 244:
                                                state = (
                                                    329
                                                    if x["col_last"] < 0.873888016
                                                    else 330
                                                )
                                                if state == 329:
                                                    return -0.182629898
                                                if state == 330:
                                                    state = (
                                                        441
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.981999993
                                                        )
                                                        else 442
                                                    )
                                                    if state == 441:
                                                        return -0.160560817
                                                    if state == 442:
                                                        return 0.131640345
                                if state == 76:
                                    state = (
                                        123
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.503095388)
                                        else 124
                                    )
                                    if state == 123:
                                        state = (
                                            173
                                            if x["col_peak"] < -0.00938510895
                                            else 174
                                        )
                                        if state == 173:
                                            state = (
                                                245
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 9.30114746)
                                                else 246
                                            )
                                            if state == 245:
                                                return 0.164288014
                                            if state == 246:
                                                return -0.158745185
                                        if state == 174:
                                            state = (
                                                247
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 5.31533432)
                                                else 248
                                            )
                                            if state == 247:
                                                state = (
                                                    331
                                                    if x["col_last"] < 0.385356426
                                                    else 332
                                                )
                                                if state == 331:
                                                    return 0.118246831
                                                if state == 332:
                                                    state = (
                                                        443
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.981000006
                                                        )
                                                        else 444
                                                    )
                                                    if state == 443:
                                                        return -0.245603845
                                                    if state == 444:
                                                        return 0.0871162415
                                            if state == 248:
                                                return -0.359371662
                                    if state == 124:
                                        state = (
                                            175 if x["col_peak"] < 0.404845715 else 176
                                        )
                                        if state == 175:
                                            state = (
                                                249
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 13.2284088)
                                                else 250
                                            )
                                            if state == 249:
                                                state = (
                                                    333
                                                    if x["col_last"] < 0.0296225548
                                                    else 334
                                                )
                                                if state == 333:
                                                    return 0.0891224816
                                                if state == 334:
                                                    state = (
                                                        445
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.982499957
                                                        )
                                                        else 446
                                                    )
                                                    if state == 445:
                                                        return -0.298616499
                                                    if state == 446:
                                                        return 0.176256686
                                            if state == 250:
                                                return 0.105494134
                                        if state == 176:
                                            state = (
                                                251
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.75390482)
                                                else 252
                                            )
                                            if state == 251:
                                                return 0.347099513
                                            if state == 252:
                                                state = (
                                                    335
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.00532420445)
                                                    else 336
                                                )
                                                if state == 335:
                                                    state = (
                                                        447
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.976500034
                                                        )
                                                        else 448
                                                    )
                                                    if state == 447:
                                                        return -0.315538704
                                                    if state == 448:
                                                        state = (
                                                            575
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 9.48697281
                                                            )
                                                            else 576
                                                        )
                                                        if state == 575:
                                                            return 0.323881686
                                                        if state == 576:
                                                            return -0.154410928
                                                if state == 336:
                                                    state = (
                                                        449
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.978249967
                                                        )
                                                        else 450
                                                    )
                                                    if state == 449:
                                                        return -0.310514301
                                                    if state == 450:
                                                        return 0.00292086648
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.471078098 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.918928683)
                        else 12
                    )
                    if state == 11:
                        state = 23 if x["col_det"] < 2.09129429 else 24
                        if state == 23:
                            return -0.351154596
                        if state == 24:
                            state = (
                                47
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.7340012)
                                else 48
                            )
                            if state == 47:
                                return -0.330242008
                            if state == 48:
                                state = (
                                    77
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 18.8214989)
                                    else 78
                                )
                                if state == 77:
                                    return 0.284485549
                                if state == 78:
                                    return -0.292198986
                    if state == 12:
                        state = 25 if x["col_det"] < 0.716199875 else 26
                        if state == 25:
                            return 0.419098794
                        if state == 26:
                            return -0.0611823127
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.379047543)
                        else 14
                    )
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.740200043)
                            else 28
                        )
                        if state == 27:
                            return -0.289943367
                        if state == 28:
                            return 0.208729625
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.369436264)
                            else 30
                        )
                        if state == 29:
                            state = (
                                49
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 22.0284996)
                                else 50
                            )
                            if state == 49:
                                state = (
                                    79
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 17.2205009)
                                    else 80
                                )
                                if state == 79:
                                    return 0.028872814
                                if state == 80:
                                    state = (
                                        125
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.873214126)
                                        else 126
                                    )
                                    if state == 125:
                                        state = (
                                            177 if x["col_peak"] < 1.26796103 else 178
                                        )
                                        if state == 177:
                                            state = (
                                                253
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.899052322)
                                                else 254
                                            )
                                            if state == 253:
                                                return -0.124869205
                                            if state == 254:
                                                state = (
                                                    337
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 1.36605453)
                                                    else 338
                                                )
                                                if state == 337:
                                                    state = (
                                                        451
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.978249967
                                                        )
                                                        else 452
                                                    )
                                                    if state == 451:
                                                        state = (
                                                            577
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.92197347
                                                            )
                                                            else 578
                                                        )
                                                        if state == 577:
                                                            return 0.291751862
                                                        if state == 578:
                                                            return -0.259074956
                                                    if state == 452:
                                                        return 0.347507656
                                                if state == 338:
                                                    return -0.0323479474
                                        if state == 178:
                                            return -0.0481544361
                                    if state == 126:
                                        return 0.392383546
                            if state == 50:
                                return -0.175743669
                        if state == 30:
                            state = (
                                51
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.3687496)
                                else 52
                            )
                            if state == 51:
                                return -0.142893061
                            if state == 52:
                                return 0.393588573
    elif num_booster == 11:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.701184511)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.6515484)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.3289986)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 15.8009996)
                            else 16
                        )
                        if state == 15:
                            state = 27 if x["maggaia_med"] < 14.4359798 else 28
                            if state == 27:
                                state = (
                                    43
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.537575185)
                                    else 44
                                )
                                if state == 43:
                                    return -0.180212289
                                if state == 44:
                                    return 0.18462953
                            if state == 28:
                                return -0.424973488
                        if state == 16:
                            state = (
                                29
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 17.3313408)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    45
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 6.91836834)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        65
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 1.64808631)
                                        else 66
                                    )
                                    if state == 65:
                                        state = (
                                            101 if x["col_last"] < 0.0191111565 else 102
                                        )
                                        if state == 101:
                                            state = (
                                                151
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 15.4950113)
                                                else 152
                                            )
                                            if state == 151:
                                                return 0.155569196
                                            if state == 152:
                                                return -0.217339516
                                        if state == 102:
                                            state = (
                                                153
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 24.993618)
                                                else 154
                                            )
                                            if state == 153:
                                                state = (
                                                    217
                                                    if x["maggaia_med"] < 16.844532
                                                    else 218
                                                )
                                                if state == 217:
                                                    state = (
                                                        297
                                                        if x["distpsnr1_med"]
                                                        < 0.394707978
                                                        else 298
                                                    )
                                                    if state == 297:
                                                        return 0.190731779
                                                    if state == 298:
                                                        return -0.162978813
                                                if state == 218:
                                                    return -0.288925737
                                            if state == 154:
                                                state = (
                                                    219
                                                    if x["maggaia_med"] < 15.2923536
                                                    else 220
                                                )
                                                if state == 219:
                                                    state = (
                                                        299
                                                        if x["distpsnr1_med"]
                                                        < 1.11478794
                                                        else 300
                                                    )
                                                    if state == 299:
                                                        return -0.0706454813
                                                    if state == 300:
                                                        return 0.140723199
                                                if state == 220:
                                                    return -0.359929144
                                    if state == 66:
                                        state = (
                                            103
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.0554552078)
                                            else 104
                                        )
                                        if state == 103:
                                            state = (
                                                155
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 38.4263382)
                                                else 156
                                            )
                                            if state == 155:
                                                return 0.274791539
                                            if state == 156:
                                                state = (
                                                    221
                                                    if x["maggaia_med"] < 15.2166634
                                                    else 222
                                                )
                                                if state == 221:
                                                    return -0.157510772
                                                if state == 222:
                                                    return 0.144289389
                                        if state == 104:
                                            return -0.0257667731
                                if state == 46:
                                    state = (
                                        67
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 3.22357464)
                                        else 68
                                    )
                                    if state == 67:
                                        return -0.466948956
                                    if state == 68:
                                        return 0.200537965
                            if state == 30:
                                state = (
                                    47
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 4.01598358)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        69 if x["distpsnr1_med"] < 0.558293581 else 70
                                    )
                                    if state == 69:
                                        state = (
                                            105 if x["col_last"] < 0.601027489 else 106
                                        )
                                        if state == 105:
                                            state = (
                                                159
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 10.0643578)
                                                else 160
                                            )
                                            if state == 159:
                                                return 0.0679735839
                                            if state == 160:
                                                state = (
                                                    223
                                                    if x["maggaia_med"] < 17.460392
                                                    else 224
                                                )
                                                if state == 223:
                                                    state = (
                                                        301
                                                        if x["distpsnr1_med"]
                                                        < 0.279571444
                                                        else 302
                                                    )
                                                    if state == 301:
                                                        return -0.0445095636
                                                    if state == 302:
                                                        return 0.153270826
                                                if state == 224:
                                                    return -0.344761521
                                        if state == 106:
                                            state = (
                                                161
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 18.4453812)
                                                else 162
                                            )
                                            if state == 161:
                                                return 0.37607345
                                            if state == 162:
                                                state = (
                                                    225
                                                    if x["maggaia_med"] < 17.4096699
                                                    else 226
                                                )
                                                if state == 225:
                                                    return 0.250608563
                                                if state == 226:
                                                    state = (
                                                        303
                                                        if x["distpsnr1_med"]
                                                        < 0.11449264
                                                        else 304
                                                    )
                                                    if state == 303:
                                                        return 0.13996686
                                                    if state == 304:
                                                        state = (
                                                            393
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.755108833
                                                            )
                                                            else 394
                                                        )
                                                        if state == 393:
                                                            return -0.335855484
                                                        if state == 394:
                                                            return -0.0235641804
                                    if state == 70:
                                        state = (
                                            107
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.38752079)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                163
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 15.4893694)
                                                else 164
                                            )
                                            if state == 163:
                                                state = (
                                                    227
                                                    if x["maggaia_med"] < 17.9329147
                                                    else 228
                                                )
                                                if state == 227:
                                                    return 0.204819918
                                                if state == 228:
                                                    state = (
                                                        305
                                                        if x["distpsnr1_med"]
                                                        < 1.5126555
                                                        else 306
                                                    )
                                                    if state == 305:
                                                        return 0.129178777
                                                    if state == 306:
                                                        return -0.146577343
                                            if state == 164:
                                                return 0.285335839
                                        if state == 108:
                                            state = (
                                                165
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 33.5426674)
                                                else 166
                                            )
                                            if state == 165:
                                                state = (
                                                    231
                                                    if x["maggaia_med"] < 19.9213066
                                                    else 232
                                                )
                                                if state == 231:
                                                    return -0.0160450563
                                                if state == 232:
                                                    return 0.142575875
                                            if state == 166:
                                                state = (
                                                    233
                                                    if x["maggaia_med"] < 18.2454796
                                                    else 234
                                                )
                                                if state == 233:
                                                    return 0.111982346
                                                if state == 234:
                                                    return -0.374970973
                                if state == 48:
                                    state = (
                                        71 if x["distpsnr1_med"] < 0.265056401 else 72
                                    )
                                    if state == 71:
                                        state = (
                                            109
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.502987862)
                                            else 110
                                        )
                                        if state == 109:
                                            return -0.364645272
                                        if state == 110:
                                            return -0.0348933227
                                    if state == 72:
                                        state = (
                                            111
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.350072861)
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                167
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 29.9392776)
                                                else 168
                                            )
                                            if state == 167:
                                                state = (
                                                    235
                                                    if x["maggaia_med"] < 18.2318172
                                                    else 236
                                                )
                                                if state == 235:
                                                    state = (
                                                        311
                                                        if x["distpsnr1_med"]
                                                        < 1.56102562
                                                        else 312
                                                    )
                                                    if state == 311:
                                                        state = (
                                                            397
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.144404411
                                                            )
                                                            else 398
                                                        )
                                                        if state == 397:
                                                            return -0.0914284438
                                                        if state == 398:
                                                            return -0.420727581
                                                    if state == 312:
                                                        return 0.118688151
                                                if state == 236:
                                                    return -0.408555359
                                            if state == 168:
                                                state = (
                                                    237
                                                    if x["maggaia_med"] < 18.2719231
                                                    else 238
                                                )
                                                if state == 237:
                                                    state = (
                                                        315
                                                        if x["distpsnr1_med"]
                                                        < 1.1382575
                                                        else 316
                                                    )
                                                    if state == 315:
                                                        return 0.0398368426
                                                    if state == 316:
                                                        return 0.300108761
                                                if state == 238:
                                                    return -0.232000053
                                        if state == 112:
                                            state = (
                                                169
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 21.3721066)
                                                else 170
                                            )
                                            if state == 169:
                                                return 0.00385181
                                            if state == 170:
                                                state = (
                                                    239
                                                    if x["maggaia_med"] < 18.9089584
                                                    else 240
                                                )
                                                if state == 239:
                                                    return 0.316783696
                                                if state == 240:
                                                    return 0.00269075413
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.1152496)
                            else 18
                        )
                        if state == 17:
                            state = 31 if x["maggaia_med"] < 14.4461384 else 32
                            if state == 31:
                                state = (
                                    49
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.00511003)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        73 if x["distpsnr1_med"] < 10.2881203 else 74
                                    )
                                    if state == 73:
                                        return -0.464291245
                                    if state == 74:
                                        return 0.0849157572
                                if state == 50:
                                    state = (
                                        75 if x["distpsnr1_med"] < 11.2575359 else 76
                                    )
                                    if state == 75:
                                        state = (
                                            113
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.892742157)
                                            else 114
                                        )
                                        if state == 113:
                                            state = (
                                                171
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 23.0235882)
                                                else 172
                                            )
                                            if state == 171:
                                                state = (
                                                    241
                                                    if x["maggaia_med"] < 12.6051331
                                                    else 242
                                                )
                                                if state == 241:
                                                    return -0.0270219427
                                                if state == 242:
                                                    state = (
                                                        317
                                                        if x["distpsnr1_med"]
                                                        < 1.61493611
                                                        else 318
                                                    )
                                                    if state == 317:
                                                        return -0.00868001301
                                                    if state == 318:
                                                        return -0.365185738
                                            if state == 172:
                                                state = (
                                                    243
                                                    if x["maggaia_med"] < 14.1423044
                                                    else 244
                                                )
                                                if state == 243:
                                                    state = (
                                                        319
                                                        if x["distpsnr1_med"]
                                                        < 5.65193462
                                                        else 320
                                                    )
                                                    if state == 319:
                                                        return 0.153823733
                                                    if state == 320:
                                                        return -0.210436717
                                                if state == 244:
                                                    return -0.245291829
                                        if state == 114:
                                            return 0.0702900812
                                    if state == 76:
                                        return 0.255746812
                            if state == 32:
                                state = (
                                    51
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.905920208)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        77
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 1.2916863)
                                        else 78
                                    )
                                    if state == 77:
                                        state = (
                                            115
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.210150719)
                                            else 116
                                        )
                                        if state == 115:
                                            state = (
                                                173
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 43.9463501)
                                                else 174
                                            )
                                            if state == 173:
                                                state = (
                                                    245
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 18.9715176)
                                                    else 246
                                                )
                                                if state == 245:
                                                    state = (
                                                        321
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 0.879444599
                                                        )
                                                        else 322
                                                    )
                                                    if state == 321:
                                                        state = (
                                                            403
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.168683052
                                                            )
                                                            else 404
                                                        )
                                                        if state == 403:
                                                            return -0.249940366
                                                        if state == 404:
                                                            return -0.133210823
                                                    if state == 322:
                                                        state = (
                                                            405
                                                            if x["col_last"]
                                                            < -0.115840435
                                                            else 406
                                                        )
                                                        if state == 405:
                                                            return 0.214328215
                                                        if state == 406:
                                                            return -0.140150294
                                                if state == 246:
                                                    state = (
                                                        323
                                                        if x["distpsnr1_med"]
                                                        < 0.544495702
                                                        else 324
                                                    )
                                                    if state == 323:
                                                        state = (
                                                            407
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.109754086
                                                            )
                                                            else 408
                                                        )
                                                        if state == 407:
                                                            return 0.207456782
                                                        if state == 408:
                                                            return 0.0835281312
                                                    if state == 324:
                                                        return -0.369109303
                                            if state == 174:
                                                state = (
                                                    247
                                                    if x["maggaia_med"] < 16.2177734
                                                    else 248
                                                )
                                                if state == 247:
                                                    return 0.234716356
                                                if state == 248:
                                                    state = (
                                                        325
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 0.862622142
                                                        )
                                                        else 326
                                                    )
                                                    if state == 325:
                                                        return -0.358401835
                                                    if state == 326:
                                                        return 0.140605167
                                        if state == 116:
                                            state = (
                                                175
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 35.0110092)
                                                else 176
                                            )
                                            if state == 175:
                                                state = (
                                                    249
                                                    if x["maggaia_med"] < 19.1084805
                                                    else 250
                                                )
                                                if state == 249:
                                                    state = (
                                                        327
                                                        if x["distpsnr1_med"]
                                                        < 0.262116611
                                                        else 328
                                                    )
                                                    if state == 327:
                                                        return 0.338650912
                                                    if state == 328:
                                                        return -0.020199433
                                                if state == 250:
                                                    state = (
                                                        329
                                                        if x["distpsnr1_med"]
                                                        < 0.691823125
                                                        else 330
                                                    )
                                                    if state == 329:
                                                        state = (
                                                            411
                                                            if x["col_last"]
                                                            < 0.512100101
                                                            else 412
                                                        )
                                                        if state == 411:
                                                            return 0.0450703874
                                                        if state == 412:
                                                            return -0.139790982
                                                    if state == 330:
                                                        return -0.259248704
                                            if state == 176:
                                                state = (
                                                    251
                                                    if x["maggaia_med"] < 20.4526653
                                                    else 252
                                                )
                                                if state == 251:
                                                    state = (
                                                        331
                                                        if x["distpsnr1_med"]
                                                        < 0.495262384
                                                        else 332
                                                    )
                                                    if state == 331:
                                                        state = (
                                                            413
                                                            if x["col_last"]
                                                            < 1.11460209
                                                            else 414
                                                        )
                                                        if state == 413:
                                                            return -0.274380177
                                                        if state == 414:
                                                            return 0.00567036262
                                                    if state == 332:
                                                        state = (
                                                            415
                                                            if x["col_last"]
                                                            < 0.739395142
                                                            else 416
                                                        )
                                                        if state == 415:
                                                            return -0.127422437
                                                        if state == 416:
                                                            return 0.11076723
                                                if state == 252:
                                                    return 0.00568047119
                                    if state == 78:
                                        state = (
                                            117 if x["col_last"] < 0.251574516 else 118
                                        )
                                        if state == 117:
                                            state = (
                                                177
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 28.0688438)
                                                else 178
                                            )
                                            if state == 177:
                                                state = (
                                                    253
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 19.3617172)
                                                    else 254
                                                )
                                                if state == 253:
                                                    state = (
                                                        333
                                                        if x["distpsnr1_med"]
                                                        < 4.03324509
                                                        else 334
                                                    )
                                                    if state == 333:
                                                        state = (
                                                            417
                                                            if x["col_last"]
                                                            < -0.0601882935
                                                            else 418
                                                        )
                                                        if state == 417:
                                                            return 0.023289917
                                                        if state == 418:
                                                            return -0.219307557
                                                    if state == 334:
                                                        state = (
                                                            419
                                                            if x["col_last"]
                                                            < -0.15116024
                                                            else 420
                                                        )
                                                        if state == 419:
                                                            return -0.113546878
                                                        if state == 420:
                                                            return 0.258488894
                                                if state == 254:
                                                    return -0.470979899
                                            if state == 178:
                                                state = (
                                                    255
                                                    if x["maggaia_med"] < 19.7913475
                                                    else 256
                                                )
                                                if state == 255:
                                                    return 0.151065737
                                                if state == 256:
                                                    return -0.03789239
                                        if state == 118:
                                            state = (
                                                179
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 14.9393578)
                                                else 180
                                            )
                                            if state == 179:
                                                state = (
                                                    257
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 17.5362358)
                                                    else 258
                                                )
                                                if state == 257:
                                                    state = (
                                                        335
                                                        if x["distpsnr1_med"]
                                                        < 1.98158765
                                                        else 336
                                                    )
                                                    if state == 335:
                                                        state = (
                                                            421
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.566889286
                                                            )
                                                            else 422
                                                        )
                                                        if state == 421:
                                                            return -0.127643183
                                                        if state == 422:
                                                            return 0.258060098
                                                    if state == 336:
                                                        state = (
                                                            423
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.563492775
                                                            )
                                                            else 424
                                                        )
                                                        if state == 423:
                                                            return 0.408470035
                                                        if state == 424:
                                                            return 0.0417857803
                                                if state == 258:
                                                    state = (
                                                        337
                                                        if x["distpsnr1_med"]
                                                        < 1.81747687
                                                        else 338
                                                    )
                                                    if state == 337:
                                                        state = (
                                                            425
                                                            if x["col_last"] < 1.5397234
                                                            else 426
                                                        )
                                                        if state == 425:
                                                            return 0.503127277
                                                        if state == 426:
                                                            return 0.061584264
                                                    if state == 338:
                                                        state = (
                                                            427
                                                            if x["col_last"]
                                                            < 0.251885235
                                                            else 428
                                                        )
                                                        if state == 427:
                                                            return 0.113525651
                                                        if state == 428:
                                                            return -0.0437046848
                                            if state == 180:
                                                state = (
                                                    259
                                                    if x["maggaia_med"] < 19.3617172
                                                    else 260
                                                )
                                                if state == 259:
                                                    state = (
                                                        339
                                                        if x["distpsnr1_med"]
                                                        < 4.41630745
                                                        else 340
                                                    )
                                                    if state == 339:
                                                        state = (
                                                            429
                                                            if x["col_last"]
                                                            < 0.703780651
                                                            else 430
                                                        )
                                                        if state == 429:
                                                            return -0.051962316
                                                        if state == 430:
                                                            return 0.143114224
                                                    if state == 340:
                                                        return 0.366695702
                                                if state == 260:
                                                    state = (
                                                        341
                                                        if x["distpsnr1_med"]
                                                        < 7.47659111
                                                        else 342
                                                    )
                                                    if state == 341:
                                                        state = (
                                                            431
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.309897423
                                                            )
                                                            else 432
                                                        )
                                                        if state == 431:
                                                            return -0.307486564
                                                        if state == 432:
                                                            return -0.0143540716
                                                    if state == 342:
                                                        state = (
                                                            433
                                                            if x["col_last"]
                                                            < 0.71244669
                                                            else 434
                                                        )
                                                        if state == 433:
                                                            return -0.260756195
                                                        if state == 434:
                                                            return 0.185299009
                                if state == 52:
                                    state = (
                                        79
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 4.54852962)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            119 if x["col_last"] < -0.351015091 else 120
                                        )
                                        if state == 119:
                                            return -0.295013756
                                        if state == 120:
                                            state = (
                                                181
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 22.1321468)
                                                else 182
                                            )
                                            if state == 181:
                                                state = (
                                                    261
                                                    if x["maggaia_med"] < 15.1108179
                                                    else 262
                                                )
                                                if state == 261:
                                                    state = (
                                                        343
                                                        if x["distpsnr1_med"]
                                                        < 2.78099132
                                                        else 344
                                                    )
                                                    if state == 343:
                                                        state = (
                                                            435
                                                            if x["col_last"]
                                                            < -0.0621225052
                                                            else 436
                                                        )
                                                        if state == 435:
                                                            return 0.09459012
                                                        if state == 436:
                                                            return 0.323572189
                                                    if state == 344:
                                                        return -0.311242342
                                                if state == 262:
                                                    state = (
                                                        345
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 4.41586637
                                                        )
                                                        else 346
                                                    )
                                                    if state == 345:
                                                        state = (
                                                            437
                                                            if x["col_last"]
                                                            < 0.0917081833
                                                            else 438
                                                        )
                                                        if state == 437:
                                                            return 0.0730067119
                                                        if state == 438:
                                                            return -0.041318547
                                                    if state == 346:
                                                        state = (
                                                            439
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.19931221
                                                            )
                                                            else 440
                                                        )
                                                        if state == 439:
                                                            return -0.503137887
                                                        if state == 440:
                                                            return -0.0777972862
                                            if state == 182:
                                                state = (
                                                    263
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 19.399601)
                                                    else 264
                                                )
                                                if state == 263:
                                                    state = (
                                                        347
                                                        if x["distpsnr1_med"]
                                                        < 4.0086937
                                                        else 348
                                                    )
                                                    if state == 347:
                                                        state = (
                                                            441
                                                            if x["col_last"]
                                                            < 0.0827097893
                                                            else 442
                                                        )
                                                        if state == 441:
                                                            return -0.030815525
                                                        if state == 442:
                                                            return 0.123927727
                                                    if state == 348:
                                                        state = (
                                                            443
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.931800842
                                                            )
                                                            else 444
                                                        )
                                                        if state == 443:
                                                            return -0.201148644
                                                        if state == 444:
                                                            return 0.0427430645
                                                if state == 264:
                                                    state = (
                                                        349
                                                        if x["distpsnr1_med"]
                                                        < 1.63526082
                                                        else 350
                                                    )
                                                    if state == 349:
                                                        state = (
                                                            445
                                                            if x["col_last"]
                                                            < 0.616480827
                                                            else 446
                                                        )
                                                        if state == 445:
                                                            return -0.193536237
                                                        if state == 446:
                                                            return -0.0635571778
                                                    if state == 350:
                                                        state = (
                                                            447
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 1.23291779
                                                            )
                                                            else 448
                                                        )
                                                        if state == 447:
                                                            return 0.183926061
                                                        if state == 448:
                                                            return -0.246348858
                                    if state == 80:
                                        state = (
                                            121
                                            if x["col_last"] < -0.0540189743
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                183
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 8.02745342)
                                                else 184
                                            )
                                            if state == 183:
                                                state = (
                                                    265
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 17.8624802)
                                                    else 266
                                                )
                                                if state == 265:
                                                    state = (
                                                        351
                                                        if x["distpsnr1_med"]
                                                        < 5.59223318
                                                        else 352
                                                    )
                                                    if state == 351:
                                                        return -0.109151833
                                                    if state == 352:
                                                        return 0.110363364
                                                if state == 266:
                                                    return -0.268475503
                                            if state == 184:
                                                state = (
                                                    267
                                                    if x["maggaia_med"] < 19.8255348
                                                    else 268
                                                )
                                                if state == 267:
                                                    state = (
                                                        355
                                                        if x["distpsnr1_med"]
                                                        < 4.86359882
                                                        else 356
                                                    )
                                                    if state == 355:
                                                        return -0.15807423
                                                    if state == 356:
                                                        state = (
                                                            451
                                                            if x["col_last"]
                                                            < -0.11916256
                                                            else 452
                                                        )
                                                        if state == 451:
                                                            return 0.186739251
                                                        if state == 452:
                                                            return -0.134013996
                                                if state == 268:
                                                    return 0.267614365
                                        if state == 122:
                                            state = (
                                                185
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 30.9939537)
                                                else 186
                                            )
                                            if state == 185:
                                                state = (
                                                    269
                                                    if x["maggaia_med"] < 18.8637486
                                                    else 270
                                                )
                                                if state == 269:
                                                    state = (
                                                        357
                                                        if x["distpsnr1_med"]
                                                        < 4.60209131
                                                        else 358
                                                    )
                                                    if state == 357:
                                                        return 0.326419115
                                                    if state == 358:
                                                        state = (
                                                            453
                                                            if x["col_last"]
                                                            < 0.167034149
                                                            else 454
                                                        )
                                                        if state == 453:
                                                            return 0.0958263278
                                                        if state == 454:
                                                            return -0.0455809906
                                                if state == 270:
                                                    state = (
                                                        359
                                                        if x["distpsnr1_med"]
                                                        < 5.95291805
                                                        else 360
                                                    )
                                                    if state == 359:
                                                        state = (
                                                            455
                                                            if x["col_last"]
                                                            < 0.181986809
                                                            else 456
                                                        )
                                                        if state == 455:
                                                            return 0.476902783
                                                        if state == 456:
                                                            return 0.206821978
                                                    if state == 360:
                                                        state = (
                                                            457
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.896100044
                                                            )
                                                            else 458
                                                        )
                                                        if state == 457:
                                                            return 0.0918924958
                                                        if state == 458:
                                                            return -0.336732477
                                            if state == 186:
                                                state = (
                                                    271
                                                    if x["maggaia_med"] < 18.8585491
                                                    else 272
                                                )
                                                if state == 271:
                                                    state = (
                                                        361
                                                        if x["distpsnr1_med"]
                                                        < 5.03217936
                                                        else 362
                                                    )
                                                    if state == 361:
                                                        return 0.365201831
                                                    if state == 362:
                                                        state = (
                                                            459
                                                            if x["col_last"]
                                                            < 1.01412392
                                                            else 460
                                                        )
                                                        if state == 459:
                                                            return 0.00160645391
                                                        if state == 460:
                                                            return 0.128591597
                                                if state == 272:
                                                    state = (
                                                        363
                                                        if x["distpsnr1_med"]
                                                        < 5.95499134
                                                        else 364
                                                    )
                                                    if state == 363:
                                                        return 0.336603671
                                                    if state == 364:
                                                        state = (
                                                            463
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.370285034
                                                            )
                                                            else 464
                                                        )
                                                        if state == 463:
                                                            return 0.179486632
                                                        if state == 464:
                                                            return 0.3192074
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 19.1057701)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    53
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.94058466)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        81
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.39708361)
                                        else 82
                                    )
                                    if state == 81:
                                        return -0.390019447
                                    if state == 82:
                                        state = (
                                            123
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < -0.111690044)
                                            else 124
                                        )
                                        if state == 123:
                                            state = (
                                                187
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 29.9354458)
                                                else 188
                                            )
                                            if state == 187:
                                                state = (
                                                    273
                                                    if x["maggaia_med"] < 18.5921555
                                                    else 274
                                                )
                                                if state == 273:
                                                    state = (
                                                        365
                                                        if x["distpsnr1_med"]
                                                        < 0.542569637
                                                        else 366
                                                    )
                                                    if state == 365:
                                                        return 0.193240702
                                                    if state == 366:
                                                        return -0.220693588
                                                if state == 274:
                                                    state = (
                                                        367
                                                        if x["distpsnr1_med"]
                                                        < 11.625761
                                                        else 368
                                                    )
                                                    if state == 367:
                                                        return 0.19561623
                                                    if state == 368:
                                                        return -0.0935732201
                                            if state == 188:
                                                state = (
                                                    275
                                                    if x["maggaia_med"] < 17.1614761
                                                    else 276
                                                )
                                                if state == 275:
                                                    state = (
                                                        369
                                                        if x["distpsnr1_med"]
                                                        < 11.5742836
                                                        else 370
                                                    )
                                                    if state == 369:
                                                        return 0.0406146422
                                                    if state == 370:
                                                        return 0.300527781
                                                if state == 276:
                                                    state = (
                                                        371
                                                        if x["distpsnr1_med"]
                                                        < 11.5370235
                                                        else 372
                                                    )
                                                    if state == 371:
                                                        return 0.0531198345
                                                    if state == 372:
                                                        return -0.204616144
                                        if state == 124:
                                            state = (
                                                189
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 21.9827156)
                                                else 190
                                            )
                                            if state == 189:
                                                state = (
                                                    277
                                                    if x["maggaia_med"] < 38.2103577
                                                    else 278
                                                )
                                                if state == 277:
                                                    state = (
                                                        373
                                                        if x["distpsnr1_med"]
                                                        < 17.501936
                                                        else 374
                                                    )
                                                    if state == 373:
                                                        state = (
                                                            465
                                                            if x["col_last"]
                                                            < 0.130851269
                                                            else 466
                                                        )
                                                        if state == 465:
                                                            return -0.412874103
                                                        if state == 466:
                                                            return -0.0841955841
                                                    if state == 374:
                                                        state = (
                                                            467
                                                            if x["col_last"]
                                                            < 0.0270776749
                                                            else 468
                                                        )
                                                        if state == 467:
                                                            return 0.0659077317
                                                        if state == 468:
                                                            return -0.18242459
                                                if state == 278:
                                                    return -0.00378408446
                                            if state == 190:
                                                state = (
                                                    279
                                                    if x["maggaia_med"] < 17.3324356
                                                    else 280
                                                )
                                                if state == 279:
                                                    state = (
                                                        375
                                                        if x["distpsnr1_med"]
                                                        < 1.10160446
                                                        else 376
                                                    )
                                                    if state == 375:
                                                        return 0.22087808
                                                    if state == 376:
                                                        state = (
                                                            469
                                                            if x["col_last"]
                                                            < 0.904633522
                                                            else 470
                                                        )
                                                        if state == 469:
                                                            return -0.112549022
                                                        if state == 470:
                                                            return 0.118958078
                                                if state == 280:
                                                    state = (
                                                        377
                                                        if x["distpsnr1_med"]
                                                        < 14.8663101
                                                        else 378
                                                    )
                                                    if state == 377:
                                                        state = (
                                                            471
                                                            if x["col_last"]
                                                            < 0.629765272
                                                            else 472
                                                        )
                                                        if state == 471:
                                                            return -0.192550585
                                                        if state == 472:
                                                            return 0.00167458702
                                                    if state == 378:
                                                        return -0.00496780314
                                if state == 54:
                                    state = (
                                        83
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 7.16604424)
                                        else 84
                                    )
                                    if state == 83:
                                        return -0.409864008
                                    if state == 84:
                                        state = (
                                            125
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.253103256)
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                191
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 14.9612617)
                                                else 192
                                            )
                                            if state == 191:
                                                return -0.386404693
                                            if state == 192:
                                                state = (
                                                    281
                                                    if x["maggaia_med"] < 18.6318989
                                                    else 282
                                                )
                                                if state == 281:
                                                    state = (
                                                        379
                                                        if x["distpsnr1_med"]
                                                        < 9.98327637
                                                        else 380
                                                    )
                                                    if state == 379:
                                                        return 0.322878331
                                                    if state == 380:
                                                        return -0.182567179
                                                if state == 282:
                                                    state = (
                                                        381
                                                        if x["distpsnr1_med"]
                                                        < 11.3634338
                                                        else 382
                                                    )
                                                    if state == 381:
                                                        return -0.443352938
                                                    if state == 382:
                                                        return -0.0270246156
                                        if state == 126:
                                            state = (
                                                193
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 39.9825211)
                                                else 194
                                            )
                                            if state == 193:
                                                state = (
                                                    283
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 17.3594818)
                                                    else 284
                                                )
                                                if state == 283:
                                                    return -0.164738327
                                                if state == 284:
                                                    state = (
                                                        383
                                                        if x["distpsnr1_med"]
                                                        < 8.52156734
                                                        else 384
                                                    )
                                                    if state == 383:
                                                        return 0.190614492
                                                    if state == 384:
                                                        state = (
                                                            473
                                                            if x["col_last"]
                                                            < 0.636198044
                                                            else 474
                                                        )
                                                        if state == 473:
                                                            return 0.102138489
                                                        if state == 474:
                                                            return -0.108073078
                                            if state == 194:
                                                return 0.140224129
                            if state == 34:
                                state = (
                                    55
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.50490165)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        85
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 6.60444355)
                                        else 86
                                    )
                                    if state == 85:
                                        state = (
                                            127 if x["col_last"] < 0.074593544 else 128
                                        )
                                        if state == 127:
                                            state = (
                                                195
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 11.9466381)
                                                else 196
                                            )
                                            if state == 195:
                                                state = (
                                                    285
                                                    if x["maggaia_med"] < 19.9287949
                                                    else 286
                                                )
                                                if state == 285:
                                                    return -0.175818786
                                                if state == 286:
                                                    return 0.119301036
                                            if state == 196:
                                                return 0.0499003753
                                        if state == 128:
                                            state = (
                                                197
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 34.0098953)
                                                else 198
                                            )
                                            if state == 197:
                                                state = (
                                                    287
                                                    if x["maggaia_med"] < 19.4103012
                                                    else 288
                                                )
                                                if state == 287:
                                                    return 0.0604806468
                                                if state == 288:
                                                    state = (
                                                        385
                                                        if x["distpsnr1_med"]
                                                        < 4.19901514
                                                        else 386
                                                    )
                                                    if state == 385:
                                                        return -0.0408273712
                                                    if state == 386:
                                                        return -0.422518671
                                            if state == 198:
                                                return 0.0697516054
                                    if state == 86:
                                        state = (
                                            129
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.241622925)
                                            else 130
                                        )
                                        if state == 129:
                                            return 0.206659734
                                        if state == 130:
                                            return -0.0132502774
                                if state == 56:
                                    state = (
                                        87 if x["distpsnr1_med"] < 11.6389179 else 88
                                    )
                                    if state == 87:
                                        state = (
                                            131 if x["col_last"] < -0.157002926 else 132
                                        )
                                        if state == 131:
                                            state = (
                                                201
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 10.034236)
                                                else 202
                                            )
                                            if state == 201:
                                                return -0.0984330922
                                            if state == 202:
                                                return 0.23830384
                                        if state == 132:
                                            state = (
                                                203
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 48.9438095)
                                                else 204
                                            )
                                            if state == 203:
                                                state = (
                                                    289
                                                    if x["maggaia_med"] < 19.9034996
                                                    else 290
                                                )
                                                if state == 289:
                                                    state = (
                                                        387
                                                        if x["distpsnr1_med"]
                                                        < 0.978631616
                                                        else 388
                                                    )
                                                    if state == 387:
                                                        return -0.237063006
                                                    if state == 388:
                                                        state = (
                                                            475
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.445201874
                                                            )
                                                            else 476
                                                        )
                                                        if state == 475:
                                                            return 0.0469492525
                                                        if state == 476:
                                                            return -0.127378702
                                                if state == 290:
                                                    state = (
                                                        389
                                                        if x["distpsnr1_med"]
                                                        < 2.5268836
                                                        else 390
                                                    )
                                                    if state == 389:
                                                        return -0.0278652385
                                                    if state == 390:
                                                        return -0.503121614
                                            if state == 204:
                                                return 0.0372367576
                                    if state == 88:
                                        state = (
                                            133
                                            if x["col_last"] < -0.0945863724
                                            else 134
                                        )
                                        if state == 133:
                                            return -0.172814339
                                        if state == 134:
                                            state = (
                                                205
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 21.4996948)
                                                else 206
                                            )
                                            if state == 205:
                                                state = (
                                                    291
                                                    if x["maggaia_med"] < 19.1780357
                                                    else 292
                                                )
                                                if state == 291:
                                                    return 0.177505836
                                                if state == 292:
                                                    return -0.114533894
                                            if state == 206:
                                                return 0.295660824
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.918251)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.776001)
                            else 20
                        )
                        if state == 19:
                            state = 35 if x["maggaia_med"] < 20.7164154 else 36
                            if state == 35:
                                return -0.314238846
                            if state == 36:
                                return 0.135066122
                        if state == 20:
                            return -0.537369311
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.4659996)
                            else 22
                        )
                        if state == 21:
                            state = 37 if x["maggaia_med"] < 21.0371361 else 38
                            if state == 37:
                                state = (
                                    57
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 7.89912033)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        89 if x["distpsnr1_med"] < 4.36435413 else 90
                                    )
                                    if state == 89:
                                        state = (
                                            135 if x["col_last"] < 0.042714119 else 136
                                        )
                                        if state == 135:
                                            state = (
                                                207
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 14.0968227)
                                                else 208
                                            )
                                            if state == 207:
                                                return 0.197006091
                                            if state == 208:
                                                return -0.12954016
                                        if state == 136:
                                            state = (
                                                209
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 17.0082703)
                                                else 210
                                            )
                                            if state == 209:
                                                state = (
                                                    293
                                                    if x["maggaia_med"] < 20.7181015
                                                    else 294
                                                )
                                                if state == 293:
                                                    return -0.147148684
                                                if state == 294:
                                                    return 0.0754257366
                                            if state == 210:
                                                return -0.310744822
                                    if state == 90:
                                        return 0.287002087
                                if state == 58:
                                    return -0.390931547
                            if state == 38:
                                return 0.275524348
                        if state == 22:
                            state = 39 if x["maggaia_med"] < 20.7415314 else 40
                            if state == 39:
                                state = (
                                    59
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 6.50526047)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        91 if x["distpsnr1_med"] < 2.33354378 else 92
                                    )
                                    if state == 91:
                                        state = (
                                            137 if x["col_last"] < 0.0924015045 else 138
                                        )
                                        if state == 137:
                                            state = (
                                                211
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 15.0437565)
                                                else 212
                                            )
                                            if state == 211:
                                                return 0.0309715346
                                            if state == 212:
                                                return -0.144715086
                                        if state == 138:
                                            return -0.244724274
                                    if state == 92:
                                        state = (
                                            139 if x["col_last"] < 0.181725502 else 140
                                        )
                                        if state == 139:
                                            return -0.176287457
                                        if state == 140:
                                            return 0.223666072
                                if state == 60:
                                    return -0.310906291
                            if state == 40:
                                return -0.426214695
            if state == 2:
                state = (
                    5
                    if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.468689)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.4370003)
                        else 12
                    )
                    if state == 11:
                        return -0.395520151
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.5149994)
                            else 24
                        )
                        if state == 23:
                            return 0.335702151
                        if state == 24:
                            state = (
                                41
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 17.0224113)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    61
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.99199057)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        93 if x["distpsnr1_med"] < 15.0657063 else 94
                                    )
                                    if state == 93:
                                        state = (
                                            141 if x["col_last"] < 0.711247444 else 142
                                        )
                                        if state == 141:
                                            return -0.140759096
                                        if state == 142:
                                            return 0.161312908
                                    if state == 94:
                                        state = (
                                            143
                                            if x["col_last"] < -0.00836706161
                                            else 144
                                        )
                                        if state == 143:
                                            return -0.015532258
                                        if state == 144:
                                            return -0.286830246
                                if state == 62:
                                    state = (
                                        95 if x["distpsnr1_med"] < 13.9938641 else 96
                                    )
                                    if state == 95:
                                        state = (
                                            145
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < -0.10852623)
                                            else 146
                                        )
                                        if state == 145:
                                            state = (
                                                213
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 51.4635773)
                                                else 214
                                            )
                                            if state == 213:
                                                return -0.0987130329
                                            if state == 214:
                                                return 0.154258043
                                        if state == 146:
                                            return -0.102299243
                                    if state == 96:
                                        return 0.355733305
                            if state == 42:
                                state = (
                                    63
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 7.47312498)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        97 if x["distpsnr1_med"] < 18.4527225 else 98
                                    )
                                    if state == 97:
                                        state = (
                                            147
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.307704449)
                                            else 148
                                        )
                                        if state == 147:
                                            return -0.427837431
                                        if state == 148:
                                            state = (
                                                215
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 23.4443817)
                                                else 216
                                            )
                                            if state == 215:
                                                return 0.0387180224
                                            if state == 216:
                                                return -0.24451068
                                    if state == 98:
                                        state = (
                                            149 if x["col_last"] < 0.791605949 else 150
                                        )
                                        if state == 149:
                                            return -0.0245896038
                                        if state == 150:
                                            return 0.230594277
                                if state == 64:
                                    state = (
                                        99 if x["distpsnr1_med"] < 7.9185853 else 100
                                    )
                                    if state == 99:
                                        return -0.301074594
                                    if state == 100:
                                        return 0.303219557
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.8624992)
                        else 14
                    )
                    if state == 13:
                        return -0.162431628
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.5050011)
                            else 26
                        )
                        if state == 25:
                            return 0.423127711
                        if state == 26:
                            return -0.139960781
    elif num_booster == 12:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.663600981)
                else 2
            )
            if state == 1:
                state = 3 if x["sgscore1_med"] < 0.00095833349 else 4
                if state == 3:
                    state = 7 if x["col_last"] < -0.0439252853 else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7161522)
                            else 16
                        )
                        if state == 15:
                            return -0.568924844
                        if state == 16:
                            return -0.0406670235
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.9908276)
                            else 18
                        )
                        if state == 17:
                            return 0.292140394
                        if state == 18:
                            state = 29 if x["sgscore1_med"] < 0.000773809501 else 30
                            if state == 29:
                                return -0.362090498
                            if state == 30:
                                state = 43 if x["neargaia_med"] < 14.2235718 else 44
                                if state == 43:
                                    state = 61 if x["neargaia_med"] < 10.9387398 else 62
                                    if state == 61:
                                        return -0.228403956
                                    if state == 62:
                                        return 0.282157034
                                if state == 44:
                                    state = (
                                        63
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 33.1810722)
                                        else 64
                                    )
                                    if state == 63:
                                        return -0.429048955
                                    if state == 64:
                                        state = (
                                            91
                                            if x["sgscore1_med"] < 0.000875000027
                                            else 92
                                        )
                                        if state == 91:
                                            state = (
                                                129
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 16.0195847)
                                                else 130
                                            )
                                            if state == 129:
                                                return -0.127780303
                                            if state == 130:
                                                state = (
                                                    181
                                                    if x["neargaia_med"] < 35.4769363
                                                    else 182
                                                )
                                                if state == 181:
                                                    return 0.287726015
                                                if state == 182:
                                                    return -0.269142985
                                        if state == 92:
                                            return -0.26409471
                if state == 4:
                    state = 9 if x["col_last"] < -0.294481754 else 10
                    if state == 9:
                        return -0.279735386
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.2420998)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0518333018)
                                else 32
                            )
                            if state == 31:
                                state = 45 if x["neargaia_med"] < 3.29215479 else 46
                                if state == 45:
                                    state = 65 if x["neargaia_med"] < 0.13023752 else 66
                                    if state == 65:
                                        return -0.135351688
                                    if state == 66:
                                        state = (
                                            95
                                            if x["sgscore1_med"] < 0.00395833515
                                            else 96
                                        )
                                        if state == 95:
                                            state = (
                                                131
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 15.9152145)
                                                else 132
                                            )
                                            if state == 131:
                                                return 0.175145343
                                            if state == 132:
                                                state = (
                                                    183
                                                    if x["neargaia_med"] < 0.187695429
                                                    else 184
                                                )
                                                if state == 183:
                                                    return 0.00928799249
                                                if state == 184:
                                                    return -0.308007389
                                        if state == 96:
                                            return 0.389817417
                                if state == 46:
                                    state = 67 if x["neargaia_med"] < 10.8976879 else 68
                                    if state == 67:
                                        state = (
                                            97
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0277291983)
                                            else 98
                                        )
                                        if state == 97:
                                            state = (
                                                133
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 43.8663101)
                                                else 134
                                            )
                                            if state == 133:
                                                return -0.696981847
                                            if state == 134:
                                                state = (
                                                    185
                                                    if x["neargaia_med"] < 8.22100258
                                                    else 186
                                                )
                                                if state == 185:
                                                    return -0.185264692
                                                if state == 186:
                                                    return 0.103912972
                                        if state == 98:
                                            state = (
                                                135
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 24.9739647)
                                                else 136
                                            )
                                            if state == 135:
                                                state = (
                                                    187
                                                    if x["neargaia_med"] < 6.78094244
                                                    else 188
                                                )
                                                if state == 187:
                                                    return -0.330134422
                                                if state == 188:
                                                    return 0.112958401
                                            if state == 136:
                                                state = (
                                                    189
                                                    if x["neargaia_med"] < 6.9351368
                                                    else 190
                                                )
                                                if state == 189:
                                                    return -0.108222447
                                                if state == 190:
                                                    return 0.233730406
                                    if state == 68:
                                        state = (
                                            99
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0304166507)
                                            else 100
                                        )
                                        if state == 99:
                                            state = (
                                                137
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 28.9905624)
                                                else 138
                                            )
                                            if state == 137:
                                                state = (
                                                    191
                                                    if x["neargaia_med"] < 61.1999969
                                                    else 192
                                                )
                                                if state == 191:
                                                    state = (
                                                        249
                                                        if np.isnan(x["col_last"])
                                                        or (
                                                            x["col_last"] < 0.0968160629
                                                        )
                                                        else 250
                                                    )
                                                    if state == 249:
                                                        state = (
                                                            319
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.0074997
                                                            )
                                                            else 320
                                                        )
                                                        if state == 319:
                                                            return 0.130817518
                                                        if state == 320:
                                                            return -0.270882457
                                                    if state == 250:
                                                        state = (
                                                            321
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.6660004
                                                            )
                                                            else 322
                                                        )
                                                        if state == 321:
                                                            return -0.0248650871
                                                        if state == 322:
                                                            return 0.262072265
                                                if state == 192:
                                                    state = (
                                                        251
                                                        if x["col_last"] < -0.0320491791
                                                        else 252
                                                    )
                                                    if state == 251:
                                                        return 0.0276329033
                                                    if state == 252:
                                                        state = (
                                                            323
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.2805004
                                                            )
                                                            else 324
                                                        )
                                                        if state == 323:
                                                            return -0.174559787
                                                        if state == 324:
                                                            return 0.0389742516
                                            if state == 138:
                                                state = (
                                                    193
                                                    if x["neargaia_med"] < 170.595169
                                                    else 194
                                                )
                                                if state == 193:
                                                    state = (
                                                        253
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 1.14310741)
                                                        else 254
                                                    )
                                                    if state == 253:
                                                        return 0.34369871
                                                    if state == 254:
                                                        return 0.00325261126
                                                if state == 194:
                                                    state = (
                                                        255
                                                        if x["col_last"] < 0.401607513
                                                        else 256
                                                    )
                                                    if state == 255:
                                                        return -0.131469309
                                                    if state == 256:
                                                        state = (
                                                            327
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.8525009
                                                            )
                                                            else 328
                                                        )
                                                        if state == 327:
                                                            return 0.259872913
                                                        if state == 328:
                                                            return -0.0314219408
                                        if state == 100:
                                            return 0.349305153
                            if state == 32:
                                state = 47 if x["neargaia_med"] < 15.5559998 else 48
                                if state == 47:
                                    state = 69 if x["neargaia_med"] < 13.4263506 else 70
                                    if state == 69:
                                        state = (
                                            101
                                            if x["sgscore1_med"] < 0.148517996
                                            else 102
                                        )
                                        if state == 101:
                                            state = (
                                                139
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 5.99787045)
                                                else 140
                                            )
                                            if state == 139:
                                                return -0.487355232
                                            if state == 140:
                                                state = (
                                                    195
                                                    if x["neargaia_med"] < 0.664475739
                                                    else 196
                                                )
                                                if state == 195:
                                                    state = (
                                                        257
                                                        if x["col_last"] < 2.80319691
                                                        else 258
                                                    )
                                                    if state == 257:
                                                        return -0.29829064
                                                    if state == 258:
                                                        state = (
                                                            329
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 16.3455009
                                                            )
                                                            else 330
                                                        )
                                                        if state == 329:
                                                            return -0.0931597501
                                                        if state == 330:
                                                            return -0.260592639
                                                if state == 196:
                                                    state = (
                                                        259
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.365465641)
                                                        else 260
                                                    )
                                                    if state == 259:
                                                        state = (
                                                            331
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.1619987
                                                            )
                                                            else 332
                                                        )
                                                        if state == 331:
                                                            return 0.0464966334
                                                        if state == 332:
                                                            return -0.12453761
                                                    if state == 260:
                                                        state = (
                                                            333
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.1609993
                                                            )
                                                            else 334
                                                        )
                                                        if state == 333:
                                                            return 0.254320055
                                                        if state == 334:
                                                            return 0.0154999066
                                        if state == 102:
                                            state = (
                                                141
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 35.9579391)
                                                else 142
                                            )
                                            if state == 141:
                                                state = (
                                                    197
                                                    if x["neargaia_med"] < 3.89564443
                                                    else 198
                                                )
                                                if state == 197:
                                                    state = (
                                                        261
                                                        if x["col_last"] < 0.00614643097
                                                        else 262
                                                    )
                                                    if state == 261:
                                                        return 0.0988632739
                                                    if state == 262:
                                                        state = (
                                                            337
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 16.2270012
                                                            )
                                                            else 338
                                                        )
                                                        if state == 337:
                                                            return -0.417544037
                                                        if state == 338:
                                                            return 0.0330328681
                                                if state == 198:
                                                    state = (
                                                        263
                                                        if x["col_last"] < -0.0423340797
                                                        else 264
                                                    )
                                                    if state == 263:
                                                        return -0.11948365
                                                    if state == 264:
                                                        state = (
                                                            339
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.2294998
                                                            )
                                                            else 340
                                                        )
                                                        if state == 339:
                                                            return 0.383325577
                                                        if state == 340:
                                                            return -0.176383004
                                            if state == 142:
                                                state = (
                                                    199
                                                    if x["neargaia_med"] < 1.60982704
                                                    else 200
                                                )
                                                if state == 199:
                                                    state = (
                                                        265
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.958460808)
                                                        else 266
                                                    )
                                                    if state == 265:
                                                        state = (
                                                            341
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 16.2589989
                                                            )
                                                            else 342
                                                        )
                                                        if state == 341:
                                                            return -0.256796271
                                                        if state == 342:
                                                            return 0.000956511474
                                                    if state == 266:
                                                        return 0.111858025
                                                if state == 200:
                                                    return 0.300428659
                                    if state == 70:
                                        state = (
                                            103
                                            if x["sgscore1_med"] < 0.416297495
                                            else 104
                                        )
                                        if state == 103:
                                            state = (
                                                143
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 73.9357147)
                                                else 144
                                            )
                                            if state == 143:
                                                return -0.829292715
                                            if state == 144:
                                                return -0.0989607647
                                        if state == 104:
                                            return 0.220606044
                                if state == 48:
                                    state = 71 if x["neargaia_med"] < 35.9955215 else 72
                                    if state == 71:
                                        state = (
                                            105
                                            if x["sgscore1_med"] < 0.0671041533
                                            else 106
                                        )
                                        if state == 105:
                                            state = (
                                                145
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 19.8865967)
                                                else 146
                                            )
                                            if state == 145:
                                                return -0.60321182
                                            if state == 146:
                                                return 0.234619394
                                        if state == 106:
                                            state = (
                                                147
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 40.8718529)
                                                else 148
                                            )
                                            if state == 147:
                                                return 0.314632714
                                            if state == 148:
                                                state = (
                                                    201
                                                    if x["neargaia_med"] < 20.2364655
                                                    else 202
                                                )
                                                if state == 201:
                                                    return 0.329574108
                                                if state == 202:
                                                    state = (
                                                        267
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 1.22839928)
                                                        else 268
                                                    )
                                                    if state == 267:
                                                        state = (
                                                            343
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.0999985
                                                            )
                                                            else 344
                                                        )
                                                        if state == 343:
                                                            return -0.0149904313
                                                        if state == 344:
                                                            return 0.306010872
                                                    if state == 268:
                                                        return -0.0736615807
                                    if state == 72:
                                        state = (
                                            107 if x["sgscore1_med"] < 0.110202 else 108
                                        )
                                        if state == 107:
                                            return -0.351748854
                                        if state == 108:
                                            state = (
                                                149
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 75.9767685)
                                                else 150
                                            )
                                            if state == 149:
                                                state = (
                                                    203
                                                    if x["neargaia_med"] < 60.2383957
                                                    else 204
                                                )
                                                if state == 203:
                                                    state = (
                                                        269
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.834512711)
                                                        else 270
                                                    )
                                                    if state == 269:
                                                        state = (
                                                            345
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.2475014
                                                            )
                                                            else 346
                                                        )
                                                        if state == 345:
                                                            return 0.119377501
                                                        if state == 346:
                                                            return 0.327290952
                                                    if state == 270:
                                                        state = (
                                                            347
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.324501
                                                            )
                                                            else 348
                                                        )
                                                        if state == 347:
                                                            return -0.15098244
                                                        if state == 348:
                                                            return 0.133167386
                                                if state == 204:
                                                    state = (
                                                        271
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.940678596)
                                                        else 272
                                                    )
                                                    if state == 271:
                                                        state = (
                                                            349
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.3549995
                                                            )
                                                            else 350
                                                        )
                                                        if state == 349:
                                                            return -0.16130577
                                                        if state == 350:
                                                            return 0.231617734
                                                    if state == 272:
                                                        return -0.126161531
                                            if state == 150:
                                                state = (
                                                    205
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 39.5946121)
                                                    else 206
                                                )
                                                if state == 205:
                                                    return -0.151244581
                                                if state == 206:
                                                    return 0.153079152
                        if state == 20:
                            state = 33 if x["sgscore1_med"] < 0.174732 else 34
                            if state == 33:
                                state = 49 if x["neargaia_med"] < 0.937549353 else 50
                                if state == 49:
                                    state = (
                                        73 if x["neargaia_med"] < 0.654022753 else 74
                                    )
                                    if state == 73:
                                        state = (
                                            109
                                            if x["sgscore1_med"] < 0.0169375017
                                            else 110
                                        )
                                        if state == 109:
                                            state = (
                                                151
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 42.8589783)
                                                else 152
                                            )
                                            if state == 151:
                                                state = (
                                                    207
                                                    if x["neargaia_med"] < 0.112021476
                                                    else 208
                                                )
                                                if state == 207:
                                                    return -0.277405679
                                                if state == 208:
                                                    state = (
                                                        273
                                                        if x["col_last"] < 0.469467938
                                                        else 274
                                                    )
                                                    if state == 273:
                                                        state = (
                                                            351
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.2835007
                                                            )
                                                            else 352
                                                        )
                                                        if state == 351:
                                                            return 0.0463198088
                                                        if state == 352:
                                                            return -0.250285864
                                                    if state == 274:
                                                        state = (
                                                            353
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.0984993
                                                            )
                                                            else 354
                                                        )
                                                        if state == 353:
                                                            return 0.33624953
                                                        if state == 354:
                                                            return -0.215480134
                                            if state == 152:
                                                return -0.350512207
                                        if state == 110:
                                            state = (
                                                153
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 10.0652542)
                                                else 154
                                            )
                                            if state == 153:
                                                state = (
                                                    209
                                                    if x["neargaia_med"] < 0.321259856
                                                    else 210
                                                )
                                                if state == 209:
                                                    return 0.216624528
                                                if state == 210:
                                                    return -0.112660006
                                            if state == 154:
                                                state = (
                                                    211
                                                    if x["neargaia_med"] < 0.543084383
                                                    else 212
                                                )
                                                if state == 211:
                                                    state = (
                                                        275
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 1.11731243)
                                                        else 276
                                                    )
                                                    if state == 275:
                                                        state = (
                                                            355
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.0785007
                                                            )
                                                            else 356
                                                        )
                                                        if state == 355:
                                                            return -0.201941952
                                                        if state == 356:
                                                            return -0.372437775
                                                    if state == 276:
                                                        return 0.053051576
                                                if state == 212:
                                                    return 0.307055563
                                    if state == 74:
                                        return -0.43623364
                                if state == 50:
                                    state = 75 if x["neargaia_med"] < 11.613533 else 76
                                    if state == 75:
                                        state = (
                                            111
                                            if x["sgscore1_med"] < 0.078910701
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                155
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 19.8536911)
                                                else 156
                                            )
                                            if state == 155:
                                                state = (
                                                    213
                                                    if x["neargaia_med"] < 11.4264765
                                                    else 214
                                                )
                                                if state == 213:
                                                    state = (
                                                        277
                                                        if x["col_last"] < 0.116307944
                                                        else 278
                                                    )
                                                    if state == 277:
                                                        state = (
                                                            357
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.8634987
                                                            )
                                                            else 358
                                                        )
                                                        if state == 357:
                                                            return 0.112265475
                                                        if state == 358:
                                                            return -0.242753029
                                                    if state == 278:
                                                        state = (
                                                            359
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.5154991
                                                            )
                                                            else 360
                                                        )
                                                        if state == 359:
                                                            return -0.316177309
                                                        if state == 360:
                                                            return 0.0556666031
                                                if state == 214:
                                                    return 0.389962822
                                            if state == 156:
                                                state = (
                                                    215
                                                    if x["neargaia_med"] < 3.88188076
                                                    else 216
                                                )
                                                if state == 215:
                                                    state = (
                                                        279
                                                        if np.isnan(x["col_last"])
                                                        or (
                                                            x["col_last"]
                                                            < -0.0916442871
                                                        )
                                                        else 280
                                                    )
                                                    if state == 279:
                                                        state = (
                                                            361
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.5620003
                                                            )
                                                            else 362
                                                        )
                                                        if state == 361:
                                                            return -0.273979425
                                                        if state == 362:
                                                            return 0.221029475
                                                    if state == 280:
                                                        return 0.267475188
                                                if state == 216:
                                                    state = (
                                                        281
                                                        if np.isnan(x["col_last"])
                                                        or (
                                                            x["col_last"] < -0.039260231
                                                        )
                                                        else 282
                                                    )
                                                    if state == 281:
                                                        state = (
                                                            365
                                                            if np.isnan(x["magnr_med"])
                                                            or (x["magnr_med"] < 18.552)
                                                            else 366
                                                        )
                                                        if state == 365:
                                                            return -0.110351548
                                                        if state == 366:
                                                            return 0.140587002
                                                    if state == 282:
                                                        state = (
                                                            367
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.8185005
                                                            )
                                                            else 368
                                                        )
                                                        if state == 367:
                                                            return -0.0211438015
                                                        if state == 368:
                                                            return -0.318555713
                                        if state == 112:
                                            state = (
                                                157
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 8.96954918)
                                                else 158
                                            )
                                            if state == 157:
                                                return 0.0204346031
                                            if state == 158:
                                                return 0.297790349
                                    if state == 76:
                                        state = (
                                            113
                                            if x["sgscore1_med"] < 0.00204166491
                                            else 114
                                        )
                                        if state == 113:
                                            state = (
                                                159
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 14.9004459)
                                                else 160
                                            )
                                            if state == 159:
                                                state = (
                                                    217
                                                    if x["neargaia_med"] < 23.6586075
                                                    else 218
                                                )
                                                if state == 217:
                                                    state = (
                                                        283
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.140419483)
                                                        else 284
                                                    )
                                                    if state == 283:
                                                        state = (
                                                            369
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.9394989
                                                            )
                                                            else 370
                                                        )
                                                        if state == 369:
                                                            return 0.577261627
                                                        if state == 370:
                                                            return 0.160425782
                                                    if state == 284:
                                                        return 0.013521635
                                                if state == 218:
                                                    state = (
                                                        285
                                                        if x["col_last"] < 0.0488700867
                                                        else 286
                                                    )
                                                    if state == 285:
                                                        state = (
                                                            371
                                                            if np.isnan(x["magnr_med"])
                                                            or (x["magnr_med"] < 18.684)
                                                            else 372
                                                        )
                                                        if state == 371:
                                                            return 0.3509413
                                                        if state == 372:
                                                            return -0.0904655457
                                                    if state == 286:
                                                        state = (
                                                            373
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.4125004
                                                            )
                                                            else 374
                                                        )
                                                        if state == 373:
                                                            return 0.00575679354
                                                        if state == 374:
                                                            return -0.209795207
                                            if state == 160:
                                                state = (
                                                    219
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 57.2685966)
                                                    else 220
                                                )
                                                if state == 219:
                                                    state = (
                                                        287
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.125805378)
                                                        else 288
                                                    )
                                                    if state == 287:
                                                        state = (
                                                            375
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.3910007
                                                            )
                                                            else 376
                                                        )
                                                        if state == 375:
                                                            return -0.237021282
                                                        if state == 376:
                                                            return 0.0733297616
                                                    if state == 288:
                                                        state = (
                                                            377
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.3495007
                                                            )
                                                            else 378
                                                        )
                                                        if state == 377:
                                                            return -0.411180049
                                                        if state == 378:
                                                            return -0.00984729175
                                                if state == 220:
                                                    return 0.410813034
                                        if state == 114:
                                            state = (
                                                161
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 12.8502254)
                                                else 162
                                            )
                                            if state == 161:
                                                state = (
                                                    221
                                                    if x["neargaia_med"] < 36.5978394
                                                    else 222
                                                )
                                                if state == 221:
                                                    state = (
                                                        289
                                                        if x["col_last"] < 0.0479052886
                                                        else 290
                                                    )
                                                    if state == 289:
                                                        state = (
                                                            379
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.1189995
                                                            )
                                                            else 380
                                                        )
                                                        if state == 379:
                                                            return 0.238436535
                                                        if state == 380:
                                                            return -0.109990202
                                                    if state == 290:
                                                        state = (
                                                            381
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.5255013
                                                            )
                                                            else 382
                                                        )
                                                        if state == 381:
                                                            return -0.155237198
                                                        if state == 382:
                                                            return 0.0338842757
                                                if state == 222:
                                                    state = (
                                                        291
                                                        if x["col_last"] < -0.183163166
                                                        else 292
                                                    )
                                                    if state == 291:
                                                        state = (
                                                            383
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.1590004
                                                            )
                                                            else 384
                                                        )
                                                        if state == 383:
                                                            return 0.134360999
                                                        if state == 384:
                                                            return -0.146798536
                                                    if state == 292:
                                                        state = (
                                                            385
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"] < 21.1215
                                                            )
                                                            else 386
                                                        )
                                                        if state == 385:
                                                            return 0.189679697
                                                        if state == 386:
                                                            return -0.107012026
                                            if state == 162:
                                                state = (
                                                    223
                                                    if x["neargaia_med"] < 19.1887569
                                                    else 224
                                                )
                                                if state == 223:
                                                    state = (
                                                        293
                                                        if x["col_last"] < 0.660053253
                                                        else 294
                                                    )
                                                    if state == 293:
                                                        state = (
                                                            387
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.2639999
                                                            )
                                                            else 388
                                                        )
                                                        if state == 387:
                                                            return -0.304350197
                                                        if state == 388:
                                                            return 0.100444607
                                                    if state == 294:
                                                        state = (
                                                            389
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.2659988
                                                            )
                                                            else 390
                                                        )
                                                        if state == 389:
                                                            return 0.0744476765
                                                        if state == 390:
                                                            return -0.140209243
                                                if state == 224:
                                                    state = (
                                                        295
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.17863512)
                                                        else 296
                                                    )
                                                    if state == 295:
                                                        state = (
                                                            391
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.0574989
                                                            )
                                                            else 392
                                                        )
                                                        if state == 391:
                                                            return 0.136287481
                                                        if state == 392:
                                                            return -0.0418698303
                                                    if state == 296:
                                                        state = (
                                                            393
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.6087494
                                                            )
                                                            else 394
                                                        )
                                                        if state == 393:
                                                            return 0.219652146
                                                        if state == 394:
                                                            return 0.0126479845
                            if state == 34:
                                state = 51 if x["neargaia_med"] < 12.421402 else 52
                                if state == 51:
                                    state = 77 if x["neargaia_med"] < 11.7221842 else 78
                                    if state == 77:
                                        state = (
                                            115
                                            if x["sgscore1_med"] < 0.488702476
                                            else 116
                                        )
                                        if state == 115:
                                            state = (
                                                163
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 25.0459099)
                                                else 164
                                            )
                                            if state == 163:
                                                state = (
                                                    225
                                                    if x["neargaia_med"] < 4.6256361
                                                    else 226
                                                )
                                                if state == 225:
                                                    state = (
                                                        297
                                                        if np.isnan(x["col_last"])
                                                        or (
                                                            x["col_last"] < -0.011507988
                                                        )
                                                        else 298
                                                    )
                                                    if state == 297:
                                                        state = (
                                                            395
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.2145004
                                                            )
                                                            else 396
                                                        )
                                                        if state == 395:
                                                            return 0.157195166
                                                        if state == 396:
                                                            return -0.256593108
                                                    if state == 298:
                                                        return -0.287411928
                                                if state == 226:
                                                    return -0.370608777
                                            if state == 164:
                                                state = (
                                                    227
                                                    if x["neargaia_med"] < 5.67920017
                                                    else 228
                                                )
                                                if state == 227:
                                                    state = (
                                                        299
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.816845894)
                                                        else 300
                                                    )
                                                    if state == 299:
                                                        return -0.341743886
                                                    if state == 300:
                                                        return -0.0029380112
                                                if state == 228:
                                                    return -0.634869635
                                        if state == 116:
                                            state = (
                                                165
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 22.0013199)
                                                else 166
                                            )
                                            if state == 165:
                                                state = (
                                                    229
                                                    if x["neargaia_med"] < 0.216723025
                                                    else 230
                                                )
                                                if state == 229:
                                                    return 0.360936254
                                                if state == 230:
                                                    state = (
                                                        301
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.570981979)
                                                        else 302
                                                    )
                                                    if state == 301:
                                                        state = (
                                                            399
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.8274994
                                                            )
                                                            else 400
                                                        )
                                                        if state == 399:
                                                            return -0.394391596
                                                        if state == 400:
                                                            return -0.0484236777
                                                    if state == 302:
                                                        state = (
                                                            401
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.2029991
                                                            )
                                                            else 402
                                                        )
                                                        if state == 401:
                                                            return -0.176788807
                                                        if state == 402:
                                                            return 0.462908
                                            if state == 166:
                                                state = (
                                                    231
                                                    if x["neargaia_med"] < 4.83548737
                                                    else 232
                                                )
                                                if state == 231:
                                                    state = (
                                                        303
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.93757391)
                                                        else 304
                                                    )
                                                    if state == 303:
                                                        state = (
                                                            403
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.4604988
                                                            )
                                                            else 404
                                                        )
                                                        if state == 403:
                                                            return -0.0134710614
                                                        if state == 404:
                                                            return -0.387952954
                                                    if state == 304:
                                                        return 0.114053369
                                                if state == 232:
                                                    state = (
                                                        305
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.923819542)
                                                        else 306
                                                    )
                                                    if state == 305:
                                                        state = (
                                                            405
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.0559998
                                                            )
                                                            else 406
                                                        )
                                                        if state == 405:
                                                            return 0.0252212249
                                                        if state == 406:
                                                            return -0.142045662
                                                    if state == 306:
                                                        return 0.225175962
                                    if state == 78:
                                        return -0.495143145
                                if state == 52:
                                    state = 79 if x["neargaia_med"] < 13.1882286 else 80
                                    if state == 79:
                                        return 0.365869254
                                    if state == 80:
                                        state = (
                                            117
                                            if x["sgscore1_med"] < 0.186032504
                                            else 118
                                        )
                                        if state == 117:
                                            return -0.658437073
                                        if state == 118:
                                            state = (
                                                167
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 42.9519958)
                                                else 168
                                            )
                                            if state == 167:
                                                state = (
                                                    233
                                                    if x["neargaia_med"] < 13.6137524
                                                    else 234
                                                )
                                                if state == 233:
                                                    return -0.697350979
                                                if state == 234:
                                                    state = (
                                                        307
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.995914459)
                                                        else 308
                                                    )
                                                    if state == 307:
                                                        state = (
                                                            407
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.3204994
                                                            )
                                                            else 408
                                                        )
                                                        if state == 407:
                                                            return 0.0421123579
                                                        if state == 408:
                                                            return -0.109293744
                                                    if state == 308:
                                                        state = (
                                                            409
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.2325001
                                                            )
                                                            else 410
                                                        )
                                                        if state == 409:
                                                            return 0.215756834
                                                        if state == 410:
                                                            return -0.0976919606
                                            if state == 168:
                                                state = (
                                                    235
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 22.9252586)
                                                    else 236
                                                )
                                                if state == 235:
                                                    state = (
                                                        309
                                                        if x["col_last"] < 0.297504425
                                                        else 310
                                                    )
                                                    if state == 309:
                                                        return -0.129070967
                                                    if state == 310:
                                                        state = (
                                                            411
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.1650009
                                                            )
                                                            else 412
                                                        )
                                                        if state == 411:
                                                            return 0.289868593
                                                        if state == 412:
                                                            return 0.0532002859
                                                if state == 236:
                                                    state = (
                                                        311
                                                        if x["col_last"] < 0.970396042
                                                        else 312
                                                    )
                                                    if state == 311:
                                                        state = (
                                                            413
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.5014992
                                                            )
                                                            else 414
                                                        )
                                                        if state == 413:
                                                            return -0.217518315
                                                        if state == 414:
                                                            return 0.0293693356
                                                    if state == 312:
                                                        state = (
                                                            415
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.4934998
                                                            )
                                                            else 416
                                                        )
                                                        if state == 415:
                                                            return -0.0196718443
                                                        if state == 416:
                                                            return 0.13730602
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.99197197 else 6
                if state == 5:
                    state = 11 if x["col_last"] < -0.0787460804 else 12
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.592453)
                            else 22
                        )
                        if state == 21:
                            return -0.267578214
                        if state == 22:
                            state = 35 if x["sgscore1_med"] < 0.700856984 else 36
                            if state == 35:
                                return -0.170317918
                            if state == 36:
                                state = 53 if x["neargaia_med"] < 7.2978549 else 54
                                if state == 53:
                                    return -0.167393938
                                if state == 54:
                                    state = (
                                        81
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 11.2203255)
                                        else 82
                                    )
                                    if state == 81:
                                        return 0.346256465
                                    if state == 82:
                                        state = (
                                            119
                                            if x["sgscore1_med"] < 0.766294956
                                            else 120
                                        )
                                        if state == 119:
                                            return 0.252052903
                                        if state == 120:
                                            return -0.108071446
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.6117001)
                            else 24
                        )
                        if state == 23:
                            state = 37 if x["sgscore1_med"] < 0.991805494 else 38
                            if state == 37:
                                state = (
                                    55
                                    if np.isnan(x["neargaia_med"])
                                    or (x["neargaia_med"] < 31.9818058)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        83
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 9.30768108)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            121
                                            if x["sgscore1_med"] < 0.969863534
                                            else 122
                                        )
                                        if state == 121:
                                            return -0.476050526
                                        if state == 122:
                                            state = (
                                                171
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 82.9210663)
                                                else 172
                                            )
                                            if state == 171:
                                                state = (
                                                    237
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 5.23029709)
                                                    else 238
                                                )
                                                if state == 237:
                                                    return -0.332008958
                                                if state == 238:
                                                    state = (
                                                        313
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.387494087)
                                                        else 314
                                                    )
                                                    if state == 313:
                                                        return -0.133098111
                                                    if state == 314:
                                                        return 0.0475941636
                                            if state == 172:
                                                return -0.0364026502
                                    if state == 84:
                                        state = (
                                            123
                                            if x["sgscore1_med"] < 0.692385018
                                            else 124
                                        )
                                        if state == 123:
                                            state = (
                                                173
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 10.5765915)
                                                else 174
                                            )
                                            if state == 173:
                                                return -0.0347775742
                                            if state == 174:
                                                return 0.17128098
                                        if state == 124:
                                            state = (
                                                175
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 53.8507118)
                                                else 176
                                            )
                                            if state == 175:
                                                state = (
                                                    241
                                                    if x["neargaia_med"] < 9.73662376
                                                    else 242
                                                )
                                                if state == 241:
                                                    return 0.10190513
                                                if state == 242:
                                                    return -0.390576333
                                            if state == 176:
                                                return 0.0419768617
                                if state == 56:
                                    state = 85 if x["neargaia_med"] < 38.7842178 else 86
                                    if state == 85:
                                        return 0.276107997
                                    if state == 86:
                                        return 0.00909752306
                            if state == 38:
                                return 0.247876227
                        if state == 24:
                            state = 39 if x["sgscore1_med"] < 0.700856984 else 40
                            if state == 39:
                                return -0.337935388
                            if state == 40:
                                state = 57 if x["neargaia_med"] < 3.00910664 else 58
                                if state == 57:
                                    return -0.334739953
                                if state == 58:
                                    state = 87 if x["neargaia_med"] < 27.0267334 else 88
                                    if state == 87:
                                        state = (
                                            125
                                            if x["sgscore1_med"] < 0.952381015
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                177
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 16.0518112)
                                                else 178
                                            )
                                            if state == 177:
                                                state = (
                                                    243
                                                    if x["neargaia_med"] < 6.40886593
                                                    else 244
                                                )
                                                if state == 243:
                                                    return -0.148785472
                                                if state == 244:
                                                    state = (
                                                        315
                                                        if np.isnan(x["col_last"])
                                                        or (
                                                            x["col_last"]
                                                            < -0.0480295196
                                                        )
                                                        else 316
                                                    )
                                                    if state == 315:
                                                        state = (
                                                            419
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.675499
                                                            )
                                                            else 420
                                                        )
                                                        if state == 419:
                                                            return -0.140944675
                                                        if state == 420:
                                                            return 0.137439489
                                                    if state == 316:
                                                        return 0.184267297
                                            if state == 178:
                                                state = (
                                                    245
                                                    if x["neargaia_med"] < 6.421875
                                                    else 246
                                                )
                                                if state == 245:
                                                    state = (
                                                        317
                                                        if np.isnan(x["col_last"])
                                                        or (x["col_last"] < 0.073469162)
                                                        else 318
                                                    )
                                                    if state == 317:
                                                        state = (
                                                            421
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.2350006
                                                            )
                                                            else 422
                                                        )
                                                        if state == 421:
                                                            return 0.215678692
                                                        if state == 422:
                                                            return -0.199472085
                                                    if state == 318:
                                                        return -0.110754654
                                                if state == 246:
                                                    return 0.275513649
                                        if state == 126:
                                            return -0.23208189
                                    if state == 88:
                                        state = (
                                            127
                                            if x["sgscore1_med"] < 0.76195848
                                            else 128
                                        )
                                        if state == 127:
                                            return 0.334385037
                                        if state == 128:
                                            state = (
                                                179
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 28.9840164)
                                                else 180
                                            )
                                            if state == 179:
                                                return -0.223149762
                                            if state == 180:
                                                state = (
                                                    247
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 37.7518425)
                                                    else 248
                                                )
                                                if state == 247:
                                                    return 0.115818724
                                                if state == 248:
                                                    return -0.099797979
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["col_last"]) or (x["col_last"] < 0.596357822)
                        else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.3272514)
                            else 26
                        )
                        if state == 25:
                            return -0.396022081
                        if state == 26:
                            state = 41 if x["sgscore1_med"] < 0.999791503 else 42
                            if state == 41:
                                return -0.312032431
                            if state == 42:
                                state = (
                                    59
                                    if np.isnan(x["neargaia_med"])
                                    or (x["neargaia_med"] < 8.54782486)
                                    else 60
                                )
                                if state == 59:
                                    state = 89 if x["neargaia_med"] < 7.64197826 else 90
                                    if state == 89:
                                        return -0.219291404
                                    if state == 90:
                                        return 0.239335328
                                if state == 60:
                                    return -0.280628234
                    if state == 14:
                        return 0.0245419368
    elif num_booster == 13:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 0.560240448 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.6317482)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.0523274019)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["neargaia_med"] < 0.319359034 else 16
                        if state == 15:
                            state = 25 if x["maggaia_med"] < 18.6634674 else 26
                            if state == 25:
                                state = 39 if x["col_det"] < 1.92039967 else 40
                                if state == 39:
                                    return -0.316356719
                                if state == 40:
                                    state = (
                                        59
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.6716995)
                                        else 60
                                    )
                                    if state == 59:
                                        state = (
                                            85
                                            if x["sgscore1_med"] < 0.0483274013
                                            else 86
                                        )
                                        if state == 85:
                                            state = (
                                                125
                                                if x["sgscore1_med"] < 0.0104166502
                                                else 126
                                            )
                                            if state == 125:
                                                return -0.207445398
                                            if state == 126:
                                                state = (
                                                    171
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 35.9044189)
                                                    else 172
                                                )
                                                if state == 171:
                                                    state = (
                                                        219
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 23.4247055)
                                                        else 220
                                                    )
                                                    if state == 219:
                                                        return -0.0711142495
                                                    if state == 220:
                                                        return 0.133481637
                                                if state == 172:
                                                    return -0.141798094
                                        if state == 86:
                                            return 0.327721745
                                    if state == 60:
                                        return -0.326520205
                            if state == 26:
                                state = 41 if x["col_det"] < -0.147890091 else 42
                                if state == 41:
                                    return -0.116052814
                                if state == 42:
                                    state = (
                                        61
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.7932014)
                                        else 62
                                    )
                                    if state == 61:
                                        return 0.423123151
                                    if state == 62:
                                        state = (
                                            87
                                            if x["sgscore1_med"] < 0.0119791497
                                            else 88
                                        )
                                        if state == 87:
                                            state = (
                                                127
                                                if x["sgscore1_med"] < 0.00808333512
                                                else 128
                                            )
                                            if state == 127:
                                                state = (
                                                    173
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 38.9496651)
                                                    else 174
                                                )
                                                if state == 173:
                                                    state = (
                                                        221
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 20.4716206)
                                                        else 222
                                                    )
                                                    if state == 221:
                                                        return -0.168053627
                                                    if state == 222:
                                                        state = (
                                                            287
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.9745
                                                            )
                                                            else 288
                                                        )
                                                        if state == 287:
                                                            return -0.146516144
                                                        if state == 288:
                                                            return 0.305372894
                                                if state == 174:
                                                    return -0.19607462
                                            if state == 128:
                                                return 0.369495302
                                        if state == 88:
                                            return -0.315421522
                        if state == 16:
                            state = 27 if x["maggaia_med"] < 19.7227745 else 28
                            if state == 27:
                                state = 43 if x["col_det"] < 0.0187005997 else 44
                                if state == 43:
                                    return 0.313177317
                                if state == 44:
                                    state = (
                                        63
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.7561989)
                                        else 64
                                    )
                                    if state == 63:
                                        state = (
                                            89
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0127082998)
                                            else 90
                                        )
                                        if state == 89:
                                            return -0.315258831
                                        if state == 90:
                                            return 0.219831139
                                    if state == 64:
                                        return -0.349662691
                            if state == 28:
                                return 0.205397531
                    if state == 8:
                        state = 17 if x["neargaia_med"] < 0.140949935 else 18
                        if state == 17:
                            state = 29 if x["maggaia_med"] < 17.4063568 else 30
                            if state == 29:
                                state = 45 if x["col_det"] < 0.165471077 else 46
                                if state == 45:
                                    return 0.285228044
                                if state == 46:
                                    return -0.266601831
                            if state == 30:
                                return -0.324060112
                        if state == 18:
                            state = 31 if x["maggaia_med"] < 19.71245 else 32
                            if state == 31:
                                return -0.347868919
                            if state == 32:
                                return 0.376518667
                if state == 4:
                    state = 9 if x["sgscore1_med"] < 1.9975009 else 10
                    if state == 9:
                        return -0.37417382
                    if state == 10:
                        state = 19 if x["neargaia_med"] < 0.118823007 else 20
                        if state == 19:
                            return 0.140492946
                        if state == 20:
                            return -0.311856896
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 15.2460003)
                    else 6
                )
                if state == 5:
                    state = 11 if x["sgscore1_med"] < 0.479291499 else 12
                    if state == 11:
                        return 0.070820488
                    if state == 12:
                        return -0.34877494
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.0138541497)
                        else 14
                    )
                    if state == 13:
                        state = (
                            21
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 25.0110703)
                            else 22
                        )
                        if state == 21:
                            state = (
                                33
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 19.9434547)
                                else 34
                            )
                            if state == 33:
                                state = 47 if x["col_det"] < -0.305650711 else 48
                                if state == 47:
                                    state = (
                                        65
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.1338997)
                                        else 66
                                    )
                                    if state == 65:
                                        state = (
                                            91
                                            if x["sgscore1_med"] < 0.00841666479
                                            else 92
                                        )
                                        if state == 91:
                                            return 0.130115807
                                        if state == 92:
                                            return -0.190363929
                                    if state == 66:
                                        state = (
                                            93
                                            if x["sgscore1_med"] < 0.00354167004
                                            else 94
                                        )
                                        if state == 93:
                                            state = (
                                                129
                                                if x["sgscore1_med"] < 0.00239583501
                                                else 130
                                            )
                                            if state == 129:
                                                return -0.419234723
                                            if state == 130:
                                                return 0.244923159
                                        if state == 94:
                                            return -0.464411259
                                if state == 48:
                                    state = (
                                        67
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.4499512)
                                        else 68
                                    )
                                    if state == 67:
                                        state = (
                                            95
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0103749996)
                                            else 96
                                        )
                                        if state == 95:
                                            state = (
                                                131
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00558333518)
                                                else 132
                                            )
                                            if state == 131:
                                                state = (
                                                    175
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 9.05326939)
                                                    else 176
                                                )
                                                if state == 175:
                                                    return 0.268102467
                                                if state == 176:
                                                    state = (
                                                        223
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 10.8844442)
                                                        else 224
                                                    )
                                                    if state == 223:
                                                        state = (
                                                            289
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.981750011
                                                            )
                                                            else 290
                                                        )
                                                        if state == 289:
                                                            return -0.177918077
                                                        if state == 290:
                                                            return 0.0205513369
                                                    if state == 224:
                                                        state = (
                                                            291
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.969249964
                                                            )
                                                            else 292
                                                        )
                                                        if state == 291:
                                                            return -0.131301865
                                                        if state == 292:
                                                            return 0.162579253
                                            if state == 132:
                                                state = (
                                                    177
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 34.0013771)
                                                    else 178
                                                )
                                                if state == 177:
                                                    state = (
                                                        225
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 16.0059433)
                                                        else 226
                                                    )
                                                    if state == 225:
                                                        state = (
                                                            293
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.954249978
                                                            )
                                                            else 294
                                                        )
                                                        if state == 293:
                                                            return -0.111680917
                                                        if state == 294:
                                                            return 0.203417048
                                                    if state == 226:
                                                        state = (
                                                            295
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.970499992
                                                            )
                                                            else 296
                                                        )
                                                        if state == 295:
                                                            return -0.343770325
                                                        if state == 296:
                                                            return 0.0717978701
                                                if state == 178:
                                                    state = (
                                                        227
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 50.9236565)
                                                        else 228
                                                    )
                                                    if state == 227:
                                                        state = (
                                                            297
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.982249975
                                                            )
                                                            else 298
                                                        )
                                                        if state == 297:
                                                            return -0.31790641
                                                        if state == 298:
                                                            return 0.101183258
                                                    if state == 228:
                                                        state = (
                                                            299
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.846249998
                                                            )
                                                            else 300
                                                        )
                                                        if state == 299:
                                                            return 0.167495862
                                                        if state == 300:
                                                            return -0.0665182993
                                        if state == 96:
                                            state = (
                                                133
                                                if x["sgscore1_med"] < 0.0130000003
                                                else 134
                                            )
                                            if state == 133:
                                                return -0.420652598
                                            if state == 134:
                                                state = (
                                                    179
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 41.933239)
                                                    else 180
                                                )
                                                if state == 179:
                                                    state = (
                                                        229
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 25.4802361)
                                                        else 230
                                                    )
                                                    if state == 229:
                                                        state = (
                                                            301
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.982249975
                                                            )
                                                            else 302
                                                        )
                                                        if state == 301:
                                                            return -0.127606571
                                                        if state == 302:
                                                            return 0.109303206
                                                    if state == 230:
                                                        state = (
                                                            303
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.982249975
                                                            )
                                                            else 304
                                                        )
                                                        if state == 303:
                                                            return -0.434409887
                                                        if state == 304:
                                                            return 0.150179833
                                                if state == 180:
                                                    return 0.208282143
                                    if state == 68:
                                        state = (
                                            97
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.00427083485)
                                            else 98
                                        )
                                        if state == 97:
                                            state = (
                                                135
                                                if x["sgscore1_med"] < 0.00216666493
                                                else 136
                                            )
                                            if state == 135:
                                                state = (
                                                    181
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 15.001297)
                                                    else 182
                                                )
                                                if state == 181:
                                                    state = (
                                                        231
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 12.0066786)
                                                        else 232
                                                    )
                                                    if state == 231:
                                                        state = (
                                                            305
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.973999977
                                                            )
                                                            else 306
                                                        )
                                                        if state == 305:
                                                            return -0.174551353
                                                        if state == 306:
                                                            return 0.0259483159
                                                    if state == 232:
                                                        return 0.193547174
                                                if state == 182:
                                                    state = (
                                                        233
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 48.0195084)
                                                        else 234
                                                    )
                                                    if state == 233:
                                                        state = (
                                                            307
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.982499957
                                                            )
                                                            else 308
                                                        )
                                                        if state == 307:
                                                            return -0.374681801
                                                        if state == 308:
                                                            return 0.19965668
                                                    if state == 234:
                                                        state = (
                                                            309
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.960500002
                                                            )
                                                            else 310
                                                        )
                                                        if state == 309:
                                                            return -0.152078077
                                                        if state == 310:
                                                            return 0.169650152
                                            if state == 136:
                                                state = (
                                                    183
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 11.9892597)
                                                    else 184
                                                )
                                                if state == 183:
                                                    state = (
                                                        235
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 11.9825745)
                                                        else 236
                                                    )
                                                    if state == 235:
                                                        return -0.286189705
                                                    if state == 236:
                                                        return 0.313975513
                                                if state == 184:
                                                    return -0.387749761
                                        if state == 98:
                                            state = (
                                                137
                                                if x["sgscore1_med"] < 0.00447916519
                                                else 138
                                            )
                                            if state == 137:
                                                return 0.345981985
                                            if state == 138:
                                                state = (
                                                    185
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 41.4383812)
                                                    else 186
                                                )
                                                if state == 185:
                                                    state = (
                                                        237
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 14.9332638)
                                                        else 238
                                                    )
                                                    if state == 237:
                                                        state = (
                                                            311
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.975749969
                                                            )
                                                            else 312
                                                        )
                                                        if state == 311:
                                                            return -0.240899354
                                                        if state == 312:
                                                            return 0.0254863072
                                                    if state == 238:
                                                        state = (
                                                            313
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.97025001
                                                            )
                                                            else 314
                                                        )
                                                        if state == 313:
                                                            return -0.289497077
                                                        if state == 314:
                                                            return 0.203381315
                                                if state == 186:
                                                    return -0.266945839
                            if state == 34:
                                state = (
                                    49
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.112225533)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        69
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.4643497)
                                        else 70
                                    )
                                    if state == 69:
                                        state = (
                                            99
                                            if x["sgscore1_med"] < 0.0262509994
                                            else 100
                                        )
                                        if state == 99:
                                            state = (
                                                139
                                                if x["sgscore1_med"] < 0.0035625
                                                else 140
                                            )
                                            if state == 139:
                                                state = (
                                                    187
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 14.0186577)
                                                    else 188
                                                )
                                                if state == 187:
                                                    state = (
                                                        239
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 9.97430611)
                                                        else 240
                                                    )
                                                    if state == 239:
                                                        return 0.0440720543
                                                    if state == 240:
                                                        return -0.52077961
                                                if state == 188:
                                                    state = (
                                                        241
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 41.8720856)
                                                        else 242
                                                    )
                                                    if state == 241:
                                                        state = (
                                                            315
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.981000006
                                                            )
                                                            else 316
                                                        )
                                                        if state == 315:
                                                            return -0.26282388
                                                        if state == 316:
                                                            return 0.0685835034
                                                    if state == 242:
                                                        state = (
                                                            317
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.979000032
                                                            )
                                                            else 318
                                                        )
                                                        if state == 317:
                                                            return -0.0413133018
                                                        if state == 318:
                                                            return 0.16918011
                                            if state == 140:
                                                return -0.429555088
                                        if state == 100:
                                            return 0.0346772335
                                    if state == 70:
                                        state = (
                                            101
                                            if x["sgscore1_med"] < 0.0102500003
                                            else 102
                                        )
                                        if state == 101:
                                            state = (
                                                141
                                                if x["sgscore1_med"] < 0.00104166649
                                                else 142
                                            )
                                            if state == 141:
                                                return 0.452875018
                                            if state == 142:
                                                state = (
                                                    189
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 12.4765625)
                                                    else 190
                                                )
                                                if state == 189:
                                                    state = (
                                                        243
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 6.51193285)
                                                        else 244
                                                    )
                                                    if state == 243:
                                                        return 0.0473771766
                                                    if state == 244:
                                                        return -0.162054762
                                                if state == 190:
                                                    state = (
                                                        245
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 18.9758396)
                                                        else 246
                                                    )
                                                    if state == 245:
                                                        state = (
                                                            319
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.963750005
                                                            )
                                                            else 320
                                                        )
                                                        if state == 319:
                                                            return -0.112573393
                                                        if state == 320:
                                                            return 0.162776649
                                                    if state == 246:
                                                        state = (
                                                            321
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.973500013
                                                            )
                                                            else 322
                                                        )
                                                        if state == 321:
                                                            return -0.172981098
                                                        if state == 322:
                                                            return 0.319509566
                                        if state == 102:
                                            return -0.233750612
                                if state == 50:
                                    return -0.368115127
                        if state == 22:
                            state = 35 if x["maggaia_med"] < 15.6735992 else 36
                            if state == 35:
                                state = (
                                    51
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.132149696)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        71
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.6958504)
                                        else 72
                                    )
                                    if state == 71:
                                        return 0.309551418
                                    if state == 72:
                                        state = (
                                            103
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.00425000023)
                                            else 104
                                        )
                                        if state == 103:
                                            state = (
                                                143
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00404166989)
                                                else 144
                                            )
                                            if state == 143:
                                                state = (
                                                    191
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 24.9623318)
                                                    else 192
                                                )
                                                if state == 191:
                                                    return -0.250576049
                                                if state == 192:
                                                    state = (
                                                        247
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 25.5170784)
                                                        else 248
                                                    )
                                                    if state == 247:
                                                        return 0.14941366
                                                    if state == 248:
                                                        state = (
                                                            323
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.980250001
                                                            )
                                                            else 324
                                                        )
                                                        if state == 323:
                                                            return -0.242130935
                                                        if state == 324:
                                                            return 0.177571088
                                            if state == 144:
                                                return 0.296858549
                                        if state == 104:
                                            return -0.319542885
                                if state == 52:
                                    return 0.334743857
                            if state == 36:
                                state = (
                                    53
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.0104789734)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        73
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.2417488)
                                        else 74
                                    )
                                    if state == 73:
                                        state = (
                                            105
                                            if x["sgscore1_med"] < 0.00764583517
                                            else 106
                                        )
                                        if state == 105:
                                            state = (
                                                145
                                                if x["sgscore1_med"] < 0.00166666496
                                                else 146
                                            )
                                            if state == 145:
                                                return 0.231822848
                                            if state == 146:
                                                state = (
                                                    193
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 24.4442635)
                                                    else 194
                                                )
                                                if state == 193:
                                                    return -0.457595855
                                                if state == 194:
                                                    return 0.250000507
                                        if state == 106:
                                            return 0.305202663
                                    if state == 74:
                                        state = (
                                            107
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0116875004)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                147
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00991666503)
                                                else 148
                                            )
                                            if state == 147:
                                                state = (
                                                    195
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 27.9805832)
                                                    else 196
                                                )
                                                if state == 195:
                                                    state = (
                                                        251
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 17.0511913)
                                                        else 252
                                                    )
                                                    if state == 251:
                                                        state = (
                                                            325
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.979000032
                                                            )
                                                            else 326
                                                        )
                                                        if state == 325:
                                                            return -0.144840688
                                                        if state == 326:
                                                            return 0.0414458625
                                                    if state == 252:
                                                        state = (
                                                            327
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.972750008
                                                            )
                                                            else 328
                                                        )
                                                        if state == 327:
                                                            return -0.303527087
                                                        if state == 328:
                                                            return -0.169737533
                                                if state == 196:
                                                    state = (
                                                        253
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 28.0265846)
                                                        else 254
                                                    )
                                                    if state == 253:
                                                        state = (
                                                            329
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.981999993
                                                            )
                                                            else 330
                                                        )
                                                        if state == 329:
                                                            return 0.294857413
                                                        if state == 330:
                                                            return -0.113521777
                                                    if state == 254:
                                                        state = (
                                                            331
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.97874999
                                                            )
                                                            else 332
                                                        )
                                                        if state == 331:
                                                            return -0.176258251
                                                        if state == 332:
                                                            return -0.0110136596
                                            if state == 148:
                                                state = (
                                                    197
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 16.0219212)
                                                    else 198
                                                )
                                                if state == 197:
                                                    state = (
                                                        255
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 15.9695721)
                                                        else 256
                                                    )
                                                    if state == 255:
                                                        state = (
                                                            333
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.980000019
                                                            )
                                                            else 334
                                                        )
                                                        if state == 333:
                                                            return -0.192175359
                                                        if state == 334:
                                                            return 0.250891149
                                                    if state == 256:
                                                        return -0.145496339
                                                if state == 198:
                                                    return 0.278582007
                                        if state == 108:
                                            state = (
                                                149
                                                if x["sgscore1_med"] < 0.0134375002
                                                else 150
                                            )
                                            if state == 149:
                                                state = (
                                                    199
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 25.3953819)
                                                    else 200
                                                )
                                                if state == 199:
                                                    return -0.508698106
                                                if state == 200:
                                                    state = (
                                                        257
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 31.9152184)
                                                        else 258
                                                    )
                                                    if state == 257:
                                                        state = (
                                                            335
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.980999947
                                                            )
                                                            else 336
                                                        )
                                                        if state == 335:
                                                            return -0.131266624
                                                        if state == 336:
                                                            return 0.1508414
                                                    if state == 258:
                                                        return 0.143964306
                                            if state == 150:
                                                return -0.716032624
                                if state == 54:
                                    state = (
                                        75
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.7094994)
                                        else 76
                                    )
                                    if state == 75:
                                        return 0.326244593
                                    if state == 76:
                                        return -0.361207753
                    if state == 14:
                        state = (
                            23
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 81.9717865)
                            else 24
                        )
                        if state == 23:
                            state = 37 if x["maggaia_med"] < 15.8731422 else 38
                            if state == 37:
                                state = 55 if x["col_det"] < -0.0450325012 else 56
                                if state == 55:
                                    state = (
                                        77
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.8291016)
                                        else 78
                                    )
                                    if state == 77:
                                        state = (
                                            109
                                            if x["sgscore1_med"] < 0.546791494
                                            else 110
                                        )
                                        if state == 109:
                                            return 0.342701077
                                        if state == 110:
                                            state = (
                                                151
                                                if x["sgscore1_med"] < 0.728677034
                                                else 152
                                            )
                                            if state == 151:
                                                return -0.176751837
                                            if state == 152:
                                                return 0.266289204
                                    if state == 78:
                                        state = (
                                            111
                                            if x["sgscore1_med"] < 0.0365208499
                                            else 112
                                        )
                                        if state == 111:
                                            return 0.167238355
                                        if state == 112:
                                            return -0.26797089
                                if state == 56:
                                    state = (
                                        79
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.3878002)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            113
                                            if x["sgscore1_med"] < 0.018437501
                                            else 114
                                        )
                                        if state == 113:
                                            return 0.256692588
                                        if state == 114:
                                            state = (
                                                153
                                                if x["sgscore1_med"] < 0.047656253
                                                else 154
                                            )
                                            if state == 153:
                                                return -0.519167721
                                            if state == 154:
                                                state = (
                                                    201
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 17.5566444)
                                                    else 202
                                                )
                                                if state == 201:
                                                    state = (
                                                        259
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 6.61543989)
                                                        else 260
                                                    )
                                                    if state == 259:
                                                        state = (
                                                            337
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.919999957
                                                            )
                                                            else 338
                                                        )
                                                        if state == 337:
                                                            return 0.18595387
                                                        if state == 338:
                                                            return -0.213977486
                                                    if state == 260:
                                                        state = (
                                                            339
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.937749982
                                                            )
                                                            else 340
                                                        )
                                                        if state == 339:
                                                            return 0.0828950927
                                                        if state == 340:
                                                            return -0.551364779
                                                if state == 202:
                                                    state = (
                                                        261
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 32.9463539)
                                                        else 262
                                                    )
                                                    if state == 261:
                                                        state = (
                                                            341
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.981750011
                                                            )
                                                            else 342
                                                        )
                                                        if state == 341:
                                                            return 0.0365222655
                                                        if state == 342:
                                                            return -0.165511981
                                                    if state == 262:
                                                        state = (
                                                            343
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.97874999
                                                            )
                                                            else 344
                                                        )
                                                        if state == 343:
                                                            return -0.311778396
                                                        if state == 344:
                                                            return -0.0291731451
                                    if state == 80:
                                        state = (
                                            115
                                            if x["sgscore1_med"] < 0.0224166512
                                            else 116
                                        )
                                        if state == 115:
                                            state = (
                                                155
                                                if x["sgscore1_med"] < 0.0201458
                                                else 156
                                            )
                                            if state == 155:
                                                return -0.107708052
                                            if state == 156:
                                                return 0.296649247
                                        if state == 116:
                                            state = (
                                                157
                                                if x["sgscore1_med"] < 0.423413992
                                                else 158
                                            )
                                            if state == 157:
                                                return -0.340961665
                                            if state == 158:
                                                state = (
                                                    203
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 26.4484673)
                                                    else 204
                                                )
                                                if state == 203:
                                                    state = (
                                                        263
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 15.9959602)
                                                        else 264
                                                    )
                                                    if state == 263:
                                                        state = (
                                                            345
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.976249993
                                                            )
                                                            else 346
                                                        )
                                                        if state == 345:
                                                            return -0.116087489
                                                        if state == 346:
                                                            return 0.19107452
                                                    if state == 264:
                                                        state = (
                                                            347
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.981250048
                                                            )
                                                            else 348
                                                        )
                                                        if state == 347:
                                                            return -0.153866708
                                                        if state == 348:
                                                            return 0.2094713
                                                if state == 204:
                                                    return -0.23143211
                            if state == 38:
                                state = (
                                    57
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.38904953)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        81
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.4855995)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            117
                                            if x["sgscore1_med"] < 0.0289791487
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                159
                                                if x["sgscore1_med"] < 0.0167916492
                                                else 160
                                            )
                                            if state == 159:
                                                state = (
                                                    205
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 50.8830376)
                                                    else 206
                                                )
                                                if state == 205:
                                                    state = (
                                                        267
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 11.9285355)
                                                        else 268
                                                    )
                                                    if state == 267:
                                                        state = (
                                                            349
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.976750016
                                                            )
                                                            else 350
                                                        )
                                                        if state == 349:
                                                            return -0.417184442
                                                        if state == 350:
                                                            return 0.224642724
                                                    if state == 268:
                                                        state = (
                                                            351
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.981250048
                                                            )
                                                            else 352
                                                        )
                                                        if state == 351:
                                                            return -0.174365997
                                                        if state == 352:
                                                            return 0.196798041
                                                if state == 206:
                                                    return 0.281234324
                                            if state == 160:
                                                state = (
                                                    207
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 7.88792801)
                                                    else 208
                                                )
                                                if state == 207:
                                                    state = (
                                                        269
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 6.99041653)
                                                        else 270
                                                    )
                                                    if state == 269:
                                                        state = (
                                                            353
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.975499988
                                                            )
                                                            else 354
                                                        )
                                                        if state == 353:
                                                            return -0.162915453
                                                        if state == 354:
                                                            return 0.239259064
                                                    if state == 270:
                                                        return -0.244203731
                                                if state == 208:
                                                    state = (
                                                        271
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 49.0220833)
                                                        else 272
                                                    )
                                                    if state == 271:
                                                        state = (
                                                            355
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.980749965
                                                            )
                                                            else 356
                                                        )
                                                        if state == 355:
                                                            return 0.121004649
                                                        if state == 356:
                                                            return 0.331457078
                                                    if state == 272:
                                                        state = (
                                                            357
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.957249999
                                                            )
                                                            else 358
                                                        )
                                                        if state == 357:
                                                            return -0.131936803
                                                        if state == 358:
                                                            return 0.365332961
                                        if state == 118:
                                            state = (
                                                161
                                                if x["sgscore1_med"] < 0.0320119001
                                                else 162
                                            )
                                            if state == 161:
                                                state = (
                                                    209
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 37.5179863)
                                                    else 210
                                                )
                                                if state == 209:
                                                    state = (
                                                        273
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 17.4516029)
                                                        else 274
                                                    )
                                                    if state == 273:
                                                        return -0.376208305
                                                    if state == 274:
                                                        state = (
                                                            361
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.982749999
                                                            )
                                                            else 362
                                                        )
                                                        if state == 361:
                                                            return -0.255966783
                                                        if state == 362:
                                                            return 0.174159348
                                                if state == 210:
                                                    state = (
                                                        275
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 53.337677)
                                                        else 276
                                                    )
                                                    if state == 275:
                                                        state = (
                                                            363
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.979250014
                                                            )
                                                            else 364
                                                        )
                                                        if state == 363:
                                                            return -0.203102678
                                                        if state == 364:
                                                            return 0.183231845
                                                    if state == 276:
                                                        state = (
                                                            365
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.979000032
                                                            )
                                                            else 366
                                                        )
                                                        if state == 365:
                                                            return -0.140764624
                                                        if state == 366:
                                                            return 0.212102324
                                            if state == 162:
                                                state = (
                                                    211
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 46.8782883)
                                                    else 212
                                                )
                                                if state == 211:
                                                    state = (
                                                        277
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 12.0407467)
                                                        else 278
                                                    )
                                                    if state == 277:
                                                        state = (
                                                            367
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.967499971
                                                            )
                                                            else 368
                                                        )
                                                        if state == 367:
                                                            return -0.238257214
                                                        if state == 368:
                                                            return -0.00131478137
                                                    if state == 278:
                                                        state = (
                                                            369
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.982749999
                                                            )
                                                            else 370
                                                        )
                                                        if state == 369:
                                                            return -0.0492060557
                                                        if state == 370:
                                                            return 0.232230544
                                                if state == 212:
                                                    state = (
                                                        279
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 61.8022232)
                                                        else 280
                                                    )
                                                    if state == 279:
                                                        state = (
                                                            371
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.961500049
                                                            )
                                                            else 372
                                                        )
                                                        if state == 371:
                                                            return -0.154905245
                                                        if state == 372:
                                                            return 0.16871573
                                                    if state == 280:
                                                        state = (
                                                            373
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.974250019
                                                            )
                                                            else 374
                                                        )
                                                        if state == 373:
                                                            return -0.143037453
                                                        if state == 374:
                                                            return 0.142512098
                                    if state == 82:
                                        state = (
                                            119
                                            if x["sgscore1_med"] < 0.0228332989
                                            else 120
                                        )
                                        if state == 119:
                                            state = (
                                                163
                                                if x["sgscore1_med"] < 0.0145833502
                                                else 164
                                            )
                                            if state == 163:
                                                return 0.244086027
                                            if state == 164:
                                                return -0.443494916
                                        if state == 120:
                                            state = (
                                                165
                                                if x["sgscore1_med"] < 0.0257812515
                                                else 166
                                            )
                                            if state == 165:
                                                return 0.331242293
                                            if state == 166:
                                                state = (
                                                    213
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 27.9347267)
                                                    else 214
                                                )
                                                if state == 213:
                                                    state = (
                                                        281
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 11.0915508)
                                                        else 282
                                                    )
                                                    if state == 281:
                                                        state = (
                                                            375
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.96724999
                                                            )
                                                            else 376
                                                        )
                                                        if state == 375:
                                                            return -0.188550964
                                                        if state == 376:
                                                            return 0.319324911
                                                    if state == 282:
                                                        state = (
                                                            377
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.980250001
                                                            )
                                                            else 378
                                                        )
                                                        if state == 377:
                                                            return -0.241699755
                                                        if state == 378:
                                                            return 0.0982399881
                                                if state == 214:
                                                    state = (
                                                        283
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 27.9913654)
                                                        else 284
                                                    )
                                                    if state == 283:
                                                        state = (
                                                            379
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.802250028
                                                            )
                                                            else 380
                                                        )
                                                        if state == 379:
                                                            return 0.412919283
                                                        if state == 380:
                                                            return 0.0136365471
                                                    if state == 284:
                                                        state = (
                                                            381
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.951249957
                                                            )
                                                            else 382
                                                        )
                                                        if state == 381:
                                                            return -0.3441495
                                                        if state == 382:
                                                            return 0.0678424835
                                if state == 58:
                                    state = (
                                        83
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.7668991)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            121
                                            if x["sgscore1_med"] < 0.0441875011
                                            else 122
                                        )
                                        if state == 121:
                                            return -0.219391346
                                        if state == 122:
                                            state = (
                                                167
                                                if x["sgscore1_med"] < 0.0675892979
                                                else 168
                                            )
                                            if state == 167:
                                                return 0.334687918
                                            if state == 168:
                                                state = (
                                                    215
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 6.11625004)
                                                    else 216
                                                )
                                                if state == 215:
                                                    return -0.181866646
                                                if state == 216:
                                                    state = (
                                                        285
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 20.4661331)
                                                        else 286
                                                    )
                                                    if state == 285:
                                                        state = (
                                                            383
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.979249954
                                                            )
                                                            else 384
                                                        )
                                                        if state == 383:
                                                            return -0.0717616901
                                                        if state == 384:
                                                            return 0.265623242
                                                    if state == 286:
                                                        state = (
                                                            385
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.979249954
                                                            )
                                                            else 386
                                                        )
                                                        if state == 385:
                                                            return -0.249610364
                                                        if state == 386:
                                                            return 0.228520975
                                    if state == 84:
                                        state = (
                                            123
                                            if x["sgscore1_med"] < 0.192961499
                                            else 124
                                        )
                                        if state == 123:
                                            return 0.32298398
                                        if state == 124:
                                            state = (
                                                169
                                                if x["sgscore1_med"] < 0.627761483
                                                else 170
                                            )
                                            if state == 169:
                                                state = (
                                                    217
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 28.9895363)
                                                    else 218
                                                )
                                                if state == 217:
                                                    return -0.231554136
                                                if state == 218:
                                                    return 0.158713073
                                            if state == 170:
                                                return 0.256094187
                        if state == 24:
                            return -0.384957433
    elif num_booster == 14:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 0.926187694 else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.9789429) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.9652786)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6558743)
                            else 16
                        )
                        if state == 15:
                            return -0.316542178
                        if state == 16:
                            state = 31 if x["col_peak"] < -0.15245533 else 32
                            if state == 31:
                                return -0.254505157
                            if state == 32:
                                state = (
                                    57
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.977750003)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        97 if x["distpsnr1_med"] < 0.143147618 else 98
                                    )
                                    if state == 97:
                                        state = (
                                            163
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.763095081)
                                            else 164
                                        )
                                        if state == 163:
                                            return 0.185990587
                                        if state == 164:
                                            return -0.159316123
                                    if state == 98:
                                        state = (
                                            165
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.81928575)
                                            else 166
                                        )
                                        if state == 165:
                                            return -0.258468896
                                        if state == 166:
                                            return -0.071565263
                                if state == 58:
                                    state = (
                                        99 if x["distpsnr1_med"] < 0.686449051 else 100
                                    )
                                    if state == 99:
                                        state = (
                                            167
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.73309505)
                                            else 168
                                        )
                                        if state == 167:
                                            state = (
                                                249
                                                if x["col_peak"] < 0.0961432457
                                                else 250
                                            )
                                            if state == 249:
                                                return 0.0513014533
                                            if state == 250:
                                                state = (
                                                    339
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.95821762)
                                                    else 340
                                                )
                                                if state == 339:
                                                    state = (
                                                        441
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.649999976)
                                                        else 442
                                                    )
                                                    if state == 441:
                                                        return 0.167237312
                                                    if state == 442:
                                                        return -0.0142106917
                                                if state == 340:
                                                    return -0.269298375
                                        if state == 168:
                                            state = (
                                                251
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.181900024)
                                                else 252
                                            )
                                            if state == 251:
                                                state = (
                                                    341
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 1.48500001)
                                                    else 342
                                                )
                                                if state == 341:
                                                    state = (
                                                        443
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.853095055)
                                                        else 444
                                                    )
                                                    if state == 443:
                                                        state = (
                                                            563
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.0638008
                                                            )
                                                            else 564
                                                        )
                                                        if state == 563:
                                                            return 0.144862682
                                                        if state == 564:
                                                            return -0.149347723
                                                    if state == 444:
                                                        return -0.194090217
                                                if state == 342:
                                                    state = (
                                                        445
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.800833344)
                                                        else 446
                                                    )
                                                    if state == 445:
                                                        state = (
                                                            565
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.6681995
                                                            )
                                                            else 566
                                                        )
                                                        if state == 565:
                                                            return 0.250855237
                                                        if state == 566:
                                                            return -0.22096324
                                                    if state == 446:
                                                        return 0.32938695
                                            if state == 252:
                                                state = (
                                                    343
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.9631424)
                                                    else 344
                                                )
                                                if state == 343:
                                                    return -0.253443182
                                                if state == 344:
                                                    state = (
                                                        447
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.756666839)
                                                        else 448
                                                    )
                                                    if state == 447:
                                                        return 0.236531824
                                                    if state == 448:
                                                        state = (
                                                            567
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 18.8857002
                                                            )
                                                            else 568
                                                        )
                                                        if state == 567:
                                                            return -0.365066439
                                                        if state == 568:
                                                            return 0.14954707
                                    if state == 100:
                                        state = (
                                            169
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.820000052)
                                            else 170
                                        )
                                        if state == 169:
                                            state = (
                                                253
                                                if x["col_peak"] < 0.4512043
                                                else 254
                                            )
                                            if state == 253:
                                                return -0.119373403
                                            if state == 254:
                                                return -0.486005396
                                        if state == 170:
                                            return 0.19651635
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7612495)
                            else 18
                        )
                        if state == 17:
                            return -0.00876807608
                        if state == 18:
                            return 0.241110146
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.083046)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7691994)
                            else 20
                        )
                        if state == 19:
                            state = 33 if x["col_peak"] < 0.441848755 else 34
                            if state == 33:
                                state = (
                                    59
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.979750037)
                                    else 60
                                )
                                if state == 59:
                                    return -0.366143525
                                if state == 60:
                                    state = (
                                        101 if x["distpsnr1_med"] < 0.504875779 else 102
                                    )
                                    if state == 101:
                                        state = (
                                            171
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.769999862)
                                            else 172
                                        )
                                        if state == 171:
                                            return 0.232230335
                                        if state == 172:
                                            state = (
                                                255
                                                if x["col_peak"] < -0.155026436
                                                else 256
                                            )
                                            if state == 255:
                                                return -0.0583149455
                                            if state == 256:
                                                return 0.116146579
                                    if state == 102:
                                        return 0.0142278736
                            if state == 34:
                                state = (
                                    61
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.97724998)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        103 if x["distpsnr1_med"] < 0.269209325 else 104
                                    )
                                    if state == 103:
                                        state = (
                                            175
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.669166684)
                                            else 176
                                        )
                                        if state == 175:
                                            return -0.139991969
                                        if state == 176:
                                            state = (
                                                257
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.629484177)
                                                else 258
                                            )
                                            if state == 257:
                                                state = (
                                                    345
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.00144672)
                                                    else 346
                                                )
                                                if state == 345:
                                                    return -0.213336825
                                                if state == 346:
                                                    return 0.310127974
                                            if state == 258:
                                                return -0.0983963087
                                    if state == 104:
                                        state = (
                                            177
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.581547737)
                                            else 178
                                        )
                                        if state == 177:
                                            return 0.0737634897
                                        if state == 178:
                                            return -0.219168812
                                if state == 62:
                                    state = (
                                        105 if x["distpsnr1_med"] < 0.172273457 else 106
                                    )
                                    if state == 105:
                                        return -0.0244058687
                                    if state == 106:
                                        return -0.394821703
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < -0.130150795)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    63
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.978500009)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        107 if x["distpsnr1_med"] < 0.57867825 else 108
                                    )
                                    if state == 107:
                                        return -0.351456165
                                    if state == 108:
                                        return 0.209791735
                                if state == 64:
                                    state = (
                                        109 if x["distpsnr1_med"] < 0.112235159 else 110
                                    )
                                    if state == 109:
                                        return -0.219593108
                                    if state == 110:
                                        return 0.00463513983
                            if state == 36:
                                state = (
                                    65
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.973749995)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        111 if x["distpsnr1_med"] < 0.249794722 else 112
                                    )
                                    if state == 111:
                                        state = (
                                            183
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.762738168)
                                            else 184
                                        )
                                        if state == 183:
                                            return -0.19256334
                                        if state == 184:
                                            state = (
                                                259
                                                if x["col_peak"] < -0.125537872
                                                else 260
                                            )
                                            if state == 259:
                                                return 0.274572343
                                            if state == 260:
                                                return -0.148751676
                                    if state == 112:
                                        return -0.220504478
                                if state == 66:
                                    state = (
                                        113 if x["distpsnr1_med"] < 0.295161217 else 114
                                    )
                                    if state == 113:
                                        state = (
                                            185
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.758095264)
                                            else 186
                                        )
                                        if state == 185:
                                            return 0.0958645195
                                        if state == 186:
                                            return -0.209443435
                                    if state == 114:
                                        return 0.218902096
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.5929489)
                            else 22
                        )
                        if state == 21:
                            state = 37 if x["col_peak"] < 0.461637497 else 38
                            if state == 37:
                                return 0.209395736
                            if state == 38:
                                return -0.120939255
                        if state == 22:
                            state = 39 if x["col_peak"] < -0.127868652 else 40
                            if state == 39:
                                state = (
                                    67
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.86650002)
                                    else 68
                                )
                                if state == 67:
                                    return -0.137793332
                                if state == 68:
                                    state = (
                                        115 if x["distpsnr1_med"] < 0.273395211 else 116
                                    )
                                    if state == 115:
                                        return -0.0963893756
                                    if state == 116:
                                        return 0.144837767
                            if state == 40:
                                return -0.352104396
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0239334) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.6223145)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.5799503)
                            else 24
                        )
                        if state == 23:
                            state = 41 if x["col_peak"] < -0.251999855 else 42
                            if state == 41:
                                state = (
                                    69
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.984250069)
                                    else 70
                                )
                                if state == 69:
                                    return -0.262273818
                                if state == 70:
                                    return 0.0958131999
                            if state == 42:
                                state = (
                                    71
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.982749999)
                                    else 72
                                )
                                if state == 71:
                                    state = (
                                        117
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 2.53229094)
                                        else 118
                                    )
                                    if state == 117:
                                        state = (
                                            187
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.651785731)
                                            else 188
                                        )
                                        if state == 187:
                                            state = (
                                                261
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.0848622322)
                                                else 262
                                            )
                                            if state == 261:
                                                return -0.466623962
                                            if state == 262:
                                                state = (
                                                    347
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.00727367)
                                                    else 348
                                                )
                                                if state == 347:
                                                    return 0.176988333
                                                if state == 348:
                                                    return -0.229799449
                                        if state == 188:
                                            state = (
                                                263
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.0841674805)
                                                else 264
                                            )
                                            if state == 263:
                                                state = (
                                                    349
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.05143547)
                                                    else 350
                                                )
                                                if state == 349:
                                                    state = (
                                                        449
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.716666818)
                                                        else 450
                                                    )
                                                    if state == 449:
                                                        state = (
                                                            569
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.1487999
                                                            )
                                                            else 570
                                                        )
                                                        if state == 569:
                                                            return -0.079539746
                                                        if state == 570:
                                                            return 0.173995391
                                                    if state == 450:
                                                        state = (
                                                            571
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.4766502
                                                            )
                                                            else 572
                                                        )
                                                        if state == 571:
                                                            return -0.0251815487
                                                        if state == 572:
                                                            return -0.414423913
                                                if state == 350:
                                                    state = (
                                                        451
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.678928614)
                                                        else 452
                                                    )
                                                    if state == 451:
                                                        return 0.125496954
                                                    if state == 452:
                                                        return -0.391007781
                                            if state == 264:
                                                state = (
                                                    351
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.4388485)
                                                    else 352
                                                )
                                                if state == 351:
                                                    return 0.148441955
                                                if state == 352:
                                                    return -0.133449152
                                    if state == 118:
                                        state = (
                                            189
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.694999933)
                                            else 190
                                        )
                                        if state == 189:
                                            return 0.243648842
                                        if state == 190:
                                            state = (
                                                265
                                                if x["col_peak"] < 0.166862488
                                                else 266
                                            )
                                            if state == 265:
                                                return -0.224611744
                                            if state == 266:
                                                state = (
                                                    353
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.91301489)
                                                    else 354
                                                )
                                                if state == 353:
                                                    state = (
                                                        453
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.738214254)
                                                        else 454
                                                    )
                                                    if state == 453:
                                                        return -0.375093579
                                                    if state == 454:
                                                        return 0.185176685
                                                if state == 354:
                                                    return 0.245222151
                                if state == 72:
                                    state = (
                                        119 if x["distpsnr1_med"] < 2.73781204 else 120
                                    )
                                    if state == 119:
                                        state = (
                                            191
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.653571427)
                                            else 192
                                        )
                                        if state == 191:
                                            state = (
                                                267
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.150900841)
                                                else 268
                                            )
                                            if state == 267:
                                                state = (
                                                    355
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.95545673)
                                                    else 356
                                                )
                                                if state == 355:
                                                    state = (
                                                        455
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.538333356)
                                                        else 456
                                                    )
                                                    if state == 455:
                                                        state = (
                                                            573
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 18.3868484
                                                            )
                                                            else 574
                                                        )
                                                        if state == 573:
                                                            return -0.24988918
                                                        if state == 574:
                                                            return 0.245116532
                                                    if state == 456:
                                                        return -0.482360274
                                                if state == 356:
                                                    return 0.217397705
                                            if state == 268:
                                                return 0.153989986
                                        if state == 192:
                                            state = (
                                                269
                                                if x["col_peak"] < 0.198421478
                                                else 270
                                            )
                                            if state == 269:
                                                state = (
                                                    359
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.92791653)
                                                    else 360
                                                )
                                                if state == 359:
                                                    state = (
                                                        457
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.832619071)
                                                        else 458
                                                    )
                                                    if state == 457:
                                                        state = (
                                                            577
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 16.7767487
                                                            )
                                                            else 578
                                                        )
                                                        if state == 577:
                                                            return -0.111131929
                                                        if state == 578:
                                                            return 0.225614786
                                                    if state == 458:
                                                        state = (
                                                            579
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 18.0596657
                                                            )
                                                            else 580
                                                        )
                                                        if state == 579:
                                                            return -0.208617419
                                                        if state == 580:
                                                            return 0.257721782
                                                if state == 360:
                                                    return -0.259923398
                                            if state == 270:
                                                state = (
                                                    361
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.85597229)
                                                    else 362
                                                )
                                                if state == 361:
                                                    state = (
                                                        459
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.751666486)
                                                        else 460
                                                    )
                                                    if state == 459:
                                                        return -0.289936125
                                                    if state == 460:
                                                        return 0.146599934
                                                if state == 362:
                                                    return 0.265120298
                                    if state == 120:
                                        state = (
                                            193
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.926071405)
                                            else 194
                                        )
                                        if state == 193:
                                            return 0.347486734
                                        if state == 194:
                                            state = (
                                                271
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.127639294)
                                                else 272
                                            )
                                            if state == 271:
                                                state = (
                                                    363
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.45736694)
                                                    else 364
                                                )
                                                if state == 363:
                                                    state = (
                                                        461
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.943571329)
                                                        else 462
                                                    )
                                                    if state == 461:
                                                        return -0.202050567
                                                    if state == 462:
                                                        return 0.146106303
                                                if state == 364:
                                                    return 0.206847906
                                            if state == 272:
                                                return -0.00572074065
                        if state == 24:
                            state = 43 if x["col_peak"] < -0.210697651 else 44
                            if state == 43:
                                state = (
                                    73
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.982499957)
                                    else 74
                                )
                                if state == 73:
                                    return 0.268630445
                                if state == 74:
                                    state = (
                                        121 if x["distpsnr1_med"] < 2.16170216 else 122
                                    )
                                    if state == 121:
                                        state = (
                                            195
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.735833406)
                                            else 196
                                        )
                                        if state == 195:
                                            return -0.400211483
                                        if state == 196:
                                            state = (
                                                273
                                                if x["col_peak"] < -0.423514843
                                                else 274
                                            )
                                            if state == 273:
                                                return -0.117704734
                                            if state == 274:
                                                return 0.0574187189
                                    if state == 122:
                                        return 0.151264146
                            if state == 44:
                                state = (
                                    75
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.982249975)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        123
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 2.79761505)
                                        else 124
                                    )
                                    if state == 123:
                                        state = (
                                            197
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.699761868)
                                            else 198
                                        )
                                        if state == 197:
                                            state = (
                                                275
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.100924969)
                                                else 276
                                            )
                                            if state == 275:
                                                state = (
                                                    365
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.41706014)
                                                    else 366
                                                )
                                                if state == 365:
                                                    state = (
                                                        463
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.69071424)
                                                        else 464
                                                    )
                                                    if state == 463:
                                                        state = (
                                                            581
                                                            if np.isnan(x["mag_det"])
                                                            or (x["mag_det"] < 20.5112)
                                                            else 582
                                                        )
                                                        if state == 581:
                                                            return 0.223374769
                                                        if state == 582:
                                                            return 0.00577792013
                                                    if state == 464:
                                                        return -0.27913484
                                                if state == 366:
                                                    return 0.363295794
                                            if state == 276:
                                                return -0.151845381
                                        if state == 198:
                                            return 0.370109528
                                    if state == 124:
                                        state = (
                                            199
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.575000048)
                                            else 200
                                        )
                                        if state == 199:
                                            return 0.386785507
                                        if state == 200:
                                            state = (
                                                277
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.00536584854)
                                                else 278
                                            )
                                            if state == 277:
                                                state = (
                                                    367
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.96355343)
                                                    else 368
                                                )
                                                if state == 367:
                                                    state = (
                                                        465
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.646666408)
                                                        else 466
                                                    )
                                                    if state == 465:
                                                        state = (
                                                            583
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.7705994
                                                            )
                                                            else 584
                                                        )
                                                        if state == 583:
                                                            return -0.460103452
                                                        if state == 584:
                                                            return -0.175104856
                                                    if state == 466:
                                                        state = (
                                                            585
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.8189011
                                                            )
                                                            else 586
                                                        )
                                                        if state == 585:
                                                            return -0.267456561
                                                        if state == 586:
                                                            return 0.334261775
                                                if state == 368:
                                                    return 0.286405146
                                            if state == 278:
                                                return 0.231134593
                                if state == 76:
                                    state = (
                                        125
                                        if x["distpsnr1_med"] < 0.0815436542
                                        else 126
                                    )
                                    if state == 125:
                                        state = (
                                            201
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.935000181)
                                            else 202
                                        )
                                        if state == 201:
                                            return -0.214205429
                                        if state == 202:
                                            return 0.222795114
                                    if state == 126:
                                        return 0.357068688
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.8391037)
                            else 26
                        )
                        if state == 25:
                            state = (
                                45
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.102739334)
                                else 46
                            )
                            if state == 45:
                                state = (
                                    77
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.984250069)
                                    else 78
                                )
                                if state == 77:
                                    state = (
                                        127 if x["distpsnr1_med"] < 4.10803032 else 128
                                    )
                                    if state == 127:
                                        state = (
                                            203
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.616071463)
                                            else 204
                                        )
                                        if state == 203:
                                            return 0.125586778
                                        if state == 204:
                                            state = (
                                                279
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.0453019142)
                                                else 280
                                            )
                                            if state == 279:
                                                state = (
                                                    369
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.96978569)
                                                    else 370
                                                )
                                                if state == 369:
                                                    return -0.368991047
                                                if state == 370:
                                                    state = (
                                                        467
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.751785815)
                                                        else 468
                                                    )
                                                    if state == 467:
                                                        return 0.0847164392
                                                    if state == 468:
                                                        return -0.106667042
                                            if state == 280:
                                                return -0.683699787
                                    if state == 128:
                                        state = (
                                            205
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.27333349)
                                            else 206
                                        )
                                        if state == 205:
                                            return -0.183167651
                                        if state == 206:
                                            state = (
                                                281
                                                if x["col_peak"] < -0.217228889
                                                else 282
                                            )
                                            if state == 281:
                                                state = (
                                                    371
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.89524317)
                                                    else 372
                                                )
                                                if state == 371:
                                                    return 0.127864197
                                                if state == 372:
                                                    return -0.126943454
                                            if state == 282:
                                                state = (
                                                    373
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.9893055)
                                                    else 374
                                                )
                                                if state == 373:
                                                    state = (
                                                        471
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.856428385)
                                                        else 472
                                                    )
                                                    if state == 471:
                                                        return 0.131334499
                                                    if state == 472:
                                                        return -0.0760463774
                                                if state == 374:
                                                    return 0.215986192
                                if state == 78:
                                    return -0.00782850385
                            if state == 46:
                                state = (
                                    79
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.978999972)
                                    else 80
                                )
                                if state == 79:
                                    state = (
                                        129 if x["distpsnr1_med"] < 0.406137317 else 130
                                    )
                                    if state == 129:
                                        return 0.0805395171
                                    if state == 130:
                                        return -0.295658439
                                if state == 80:
                                    state = (
                                        131 if x["distpsnr1_med"] < 0.372314513 else 132
                                    )
                                    if state == 131:
                                        return -0.048583623
                                    if state == 132:
                                        state = (
                                            207
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.816428542)
                                            else 208
                                        )
                                        if state == 207:
                                            return 0.219549984
                                        if state == 208:
                                            state = (
                                                283
                                                if x["col_peak"] < 0.350218952
                                                else 284
                                            )
                                            if state == 283:
                                                return 0.129044235
                                            if state == 284:
                                                return -0.0927717686
                        if state == 26:
                            state = (
                                47
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.150333881)
                                else 48
                            )
                            if state == 47:
                                state = (
                                    81
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.976750016)
                                    else 82
                                )
                                if state == 81:
                                    state = (
                                        133
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 4.37570667)
                                        else 134
                                    )
                                    if state == 133:
                                        state = (
                                            209
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.439880967)
                                            else 210
                                        )
                                        if state == 209:
                                            return -0.270133168
                                        if state == 210:
                                            state = (
                                                285
                                                if x["col_peak"] < 0.120554447
                                                else 286
                                            )
                                            if state == 285:
                                                state = (
                                                    375
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 7.97605324)
                                                    else 376
                                                )
                                                if state == 375:
                                                    return -0.213676646
                                                if state == 376:
                                                    return 0.115089692
                                            if state == 286:
                                                state = (
                                                    377
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 7.95512152)
                                                    else 378
                                                )
                                                if state == 377:
                                                    state = (
                                                        475
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.586785674)
                                                        else 476
                                                    )
                                                    if state == 475:
                                                        state = (
                                                            587
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.2271996
                                                            )
                                                            else 588
                                                        )
                                                        if state == 587:
                                                            return -0.104500666
                                                        if state == 588:
                                                            return 0.356853783
                                                    if state == 476:
                                                        state = (
                                                            589
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.9675484
                                                            )
                                                            else 590
                                                        )
                                                        if state == 589:
                                                            return -0.0513371266
                                                        if state == 590:
                                                            return 0.0664264187
                                                if state == 378:
                                                    return -0.374191344
                                    if state == 134:
                                        state = (
                                            211
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.60535723)
                                            else 212
                                        )
                                        if state == 211:
                                            state = (
                                                287
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.0952401161)
                                                else 288
                                            )
                                            if state == 287:
                                                state = (
                                                    379
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0437615998)
                                                    else 380
                                                )
                                                if state == 379:
                                                    return -0.270338625
                                                if state == 380:
                                                    state = (
                                                        477
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.534166694)
                                                        else 478
                                                    )
                                                    if state == 477:
                                                        state = (
                                                            591
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.7386513
                                                            )
                                                            else 592
                                                        )
                                                        if state == 591:
                                                            return -0.134665102
                                                        if state == 592:
                                                            return 0.27392447
                                                    if state == 478:
                                                        state = (
                                                            593
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.1462002
                                                            )
                                                            else 594
                                                        )
                                                        if state == 593:
                                                            return -0.136089042
                                                        if state == 594:
                                                            return 0.24886319
                                            if state == 288:
                                                return 0.208540976
                                        if state == 212:
                                            return 0.327001482
                                if state == 82:
                                    state = (
                                        135 if x["distpsnr1_med"] < 0.274144113 else 136
                                    )
                                    if state == 135:
                                        state = (
                                            213
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.726666749)
                                            else 214
                                        )
                                        if state == 213:
                                            return 0.117752723
                                        if state == 214:
                                            state = (
                                                289
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.160018921)
                                                else 290
                                            )
                                            if state == 289:
                                                state = (
                                                    381
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.46994209)
                                                    else 382
                                                )
                                                if state == 381:
                                                    state = (
                                                        479
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.744523764)
                                                        else 480
                                                    )
                                                    if state == 479:
                                                        return -0.148194581
                                                    if state == 480:
                                                        return 0.0705787465
                                                if state == 382:
                                                    return -0.473288029
                                            if state == 290:
                                                return 0.18359606
                                    if state == 136:
                                        state = (
                                            215
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.568333328)
                                            else 216
                                        )
                                        if state == 215:
                                            state = (
                                                291
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.0568203926)
                                                else 292
                                            )
                                            if state == 291:
                                                state = (
                                                    383
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.99633121)
                                                    else 384
                                                )
                                                if state == 383:
                                                    state = (
                                                        481
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.226666585)
                                                        else 482
                                                    )
                                                    if state == 481:
                                                        state = (
                                                            597
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.3429985
                                                            )
                                                            else 598
                                                        )
                                                        if state == 597:
                                                            return -0.142249718
                                                        if state == 598:
                                                            return 0.132363558
                                                    if state == 482:
                                                        return 0.356681734
                                                if state == 384:
                                                    state = (
                                                        483
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.539285541)
                                                        else 484
                                                    )
                                                    if state == 483:
                                                        state = (
                                                            599
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.3649502
                                                            )
                                                            else 600
                                                        )
                                                        if state == 599:
                                                            return 0.170798853
                                                        if state == 600:
                                                            return -0.316438407
                                                    if state == 484:
                                                        return 0.243949905
                                            if state == 292:
                                                state = (
                                                    385
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.42895794)
                                                    else 386
                                                )
                                                if state == 385:
                                                    return -0.170278519
                                                if state == 386:
                                                    return 0.157892734
                                        if state == 216:
                                            state = (
                                                293
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.19183445)
                                                else 294
                                            )
                                            if state == 293:
                                                state = (
                                                    387
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0626851991)
                                                    else 388
                                                )
                                                if state == 387:
                                                    state = (
                                                        485
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.924999952)
                                                        else 486
                                                    )
                                                    if state == 485:
                                                        state = (
                                                            601
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.4425011
                                                            )
                                                            else 602
                                                        )
                                                        if state == 601:
                                                            return -0.0642516464
                                                        if state == 602:
                                                            return 0.253847629
                                                    if state == 486:
                                                        state = (
                                                            603
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.3768501
                                                            )
                                                            else 604
                                                        )
                                                        if state == 603:
                                                            return -0.423526168
                                                        if state == 604:
                                                            return 0.0138683468
                                                if state == 388:
                                                    state = (
                                                        487
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.691547513)
                                                        else 488
                                                    )
                                                    if state == 487:
                                                        state = (
                                                            605
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.1613998
                                                            )
                                                            else 606
                                                        )
                                                        if state == 605:
                                                            return -0.0228725951
                                                        if state == 606:
                                                            return 0.321834952
                                                    if state == 488:
                                                        state = (
                                                            607
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.2752991
                                                            )
                                                            else 608
                                                        )
                                                        if state == 607:
                                                            return 0.170551077
                                                        if state == 608:
                                                            return 0.318951339
                                            if state == 294:
                                                state = (
                                                    389
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.49309015)
                                                    else 390
                                                )
                                                if state == 389:
                                                    state = (
                                                        489
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.946071446)
                                                        else 490
                                                    )
                                                    if state == 489:
                                                        return 0.350638926
                                                    if state == 490:
                                                        state = (
                                                            609
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.1301003
                                                            )
                                                            else 610
                                                        )
                                                        if state == 609:
                                                            return 0.185387284
                                                        if state == 610:
                                                            return -0.00136707129
                                                if state == 390:
                                                    state = (
                                                        491
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.651785731)
                                                        else 492
                                                    )
                                                    if state == 491:
                                                        state = (
                                                            611
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.9845505
                                                            )
                                                            else 612
                                                        )
                                                        if state == 611:
                                                            return -0.351412892
                                                        if state == 612:
                                                            return 0.166893691
                                                    if state == 492:
                                                        state = (
                                                            613
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.5978508
                                                            )
                                                            else 614
                                                        )
                                                        if state == 613:
                                                            return 0.0923493877
                                                        if state == 614:
                                                            return 0.345507979
                            if state == 48:
                                state = (
                                    83
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.980250001)
                                    else 84
                                )
                                if state == 83:
                                    state = (
                                        137 if x["distpsnr1_med"] < 1.57258797 else 138
                                    )
                                    if state == 137:
                                        state = (
                                            217
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.813095152)
                                            else 218
                                        )
                                        if state == 217:
                                            return -0.33900696
                                        if state == 218:
                                            return 0.129273221
                                    if state == 138:
                                        state = (
                                            219
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.653809607)
                                            else 220
                                        )
                                        if state == 219:
                                            state = (
                                                295
                                                if x["col_peak"] < 0.262275994
                                                else 296
                                            )
                                            if state == 295:
                                                return 0.0299105775
                                            if state == 296:
                                                return -0.185360312
                                        if state == 220:
                                            return 0.140339598
                                if state == 84:
                                    state = (
                                        139 if x["distpsnr1_med"] < 8.02004242 else 140
                                    )
                                    if state == 139:
                                        state = (
                                            221
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.635357141)
                                            else 222
                                        )
                                        if state == 221:
                                            return 0.260596544
                                        if state == 222:
                                            state = (
                                                297
                                                if x["col_peak"] < 0.335248947
                                                else 298
                                            )
                                            if state == 297:
                                                state = (
                                                    391
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.96563625)
                                                    else 392
                                                )
                                                if state == 391:
                                                    return -0.334162802
                                                if state == 392:
                                                    return 0.148883417
                                            if state == 298:
                                                return 0.240077436
                                    if state == 140:
                                        return -0.373158276
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.526186)
                        else 14
                    )
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4859009)
                            else 28
                        )
                        if state == 27:
                            state = (
                                49
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.618556976)
                                else 50
                            )
                            if state == 49:
                                state = (
                                    85
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.982749999)
                                    else 86
                                )
                                if state == 85:
                                    state = (
                                        141 if x["distpsnr1_med"] < 1.38771558 else 142
                                    )
                                    if state == 141:
                                        state = (
                                            223
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.948928714)
                                            else 224
                                        )
                                        if state == 223:
                                            state = (
                                                299
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.250221252)
                                                else 300
                                            )
                                            if state == 299:
                                                state = (
                                                    393
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 1.48498845)
                                                    else 394
                                                )
                                                if state == 393:
                                                    state = (
                                                        495
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.509285688)
                                                        else 496
                                                    )
                                                    if state == 495:
                                                        return -0.306622684
                                                    if state == 496:
                                                        state = (
                                                            615
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"] < 20.088501
                                                            )
                                                            else 616
                                                        )
                                                        if state == 615:
                                                            return 0.0389060415
                                                        if state == 616:
                                                            return 0.343312174
                                                if state == 394:
                                                    state = (
                                                        497
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.892500281)
                                                        else 498
                                                    )
                                                    if state == 497:
                                                        state = (
                                                            617
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.4093494
                                                            )
                                                            else 618
                                                        )
                                                        if state == 617:
                                                            return -0.0901675001
                                                        if state == 618:
                                                            return 0.392681658
                                                    if state == 498:
                                                        state = (
                                                            619
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.1317997
                                                            )
                                                            else 620
                                                        )
                                                        if state == 619:
                                                            return -0.441439718
                                                        if state == 620:
                                                            return 0.0881334767
                                            if state == 300:
                                                state = (
                                                    395
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.04225683)
                                                    else 396
                                                )
                                                if state == 395:
                                                    state = (
                                                        499
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.762261868)
                                                        else 500
                                                    )
                                                    if state == 499:
                                                        state = (
                                                            621
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"] < 19.743351
                                                            )
                                                            else 622
                                                        )
                                                        if state == 621:
                                                            return -0.107227713
                                                        if state == 622:
                                                            return 0.0690544173
                                                    if state == 500:
                                                        state = (
                                                            623
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.6022987
                                                            )
                                                            else 624
                                                        )
                                                        if state == 623:
                                                            return 0.0309427548
                                                        if state == 624:
                                                            return 0.304497212
                                                if state == 396:
                                                    state = (
                                                        501
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.725357175)
                                                        else 502
                                                    )
                                                    if state == 501:
                                                        state = (
                                                            625
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.6753502
                                                            )
                                                            else 626
                                                        )
                                                        if state == 625:
                                                            return 0.106373146
                                                        if state == 626:
                                                            return 0.412165046
                                                    if state == 502:
                                                        state = (
                                                            627
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.3739014
                                                            )
                                                            else 628
                                                        )
                                                        if state == 627:
                                                            return -0.159277305
                                                        if state == 628:
                                                            return 0.215192854
                                        if state == 224:
                                            return 0.284965366
                                    if state == 142:
                                        state = (
                                            225
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.346190631)
                                            else 226
                                        )
                                        if state == 225:
                                            state = (
                                                301
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.293700218)
                                                else 302
                                            )
                                            if state == 301:
                                                return -0.430319369
                                            if state == 302:
                                                return 0.21377714
                                        if state == 226:
                                            state = (
                                                303
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.187279224)
                                                else 304
                                            )
                                            if state == 303:
                                                state = (
                                                    397
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.9997282)
                                                    else 398
                                                )
                                                if state == 397:
                                                    state = (
                                                        503
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.486666679)
                                                        else 504
                                                    )
                                                    if state == 503:
                                                        state = (
                                                            629
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.0792103
                                                            )
                                                            else 630
                                                        )
                                                        if state == 629:
                                                            return 0.319718361
                                                        if state == 630:
                                                            return 0.0746999905
                                                    if state == 504:
                                                        state = (
                                                            631
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 18.8452034
                                                            )
                                                            else 632
                                                        )
                                                        if state == 631:
                                                            return -0.524405658
                                                        if state == 632:
                                                            return 0.0139458869
                                                if state == 398:
                                                    state = (
                                                        505
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.724166691)
                                                        else 506
                                                    )
                                                    if state == 505:
                                                        state = (
                                                            633
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.6576996
                                                            )
                                                            else 634
                                                        )
                                                        if state == 633:
                                                            return -0.2645877
                                                        if state == 634:
                                                            return -0.035291452
                                                    if state == 506:
                                                        state = (
                                                            635
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.0356998
                                                            )
                                                            else 636
                                                        )
                                                        if state == 635:
                                                            return 0.145740166
                                                        if state == 636:
                                                            return -0.417679548
                                            if state == 304:
                                                state = (
                                                    399
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.97063065)
                                                    else 400
                                                )
                                                if state == 399:
                                                    state = (
                                                        507
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.628333569)
                                                        else 508
                                                    )
                                                    if state == 507:
                                                        state = (
                                                            637
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.8175011
                                                            )
                                                            else 638
                                                        )
                                                        if state == 637:
                                                            return 0.126676217
                                                        if state == 638:
                                                            return -0.19492875
                                                    if state == 508:
                                                        state = (
                                                            639
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.8511009
                                                            )
                                                            else 640
                                                        )
                                                        if state == 639:
                                                            return 0.0115656322
                                                        if state == 640:
                                                            return 0.185984939
                                                if state == 400:
                                                    state = (
                                                        509
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.953214288)
                                                        else 510
                                                    )
                                                    if state == 509:
                                                        state = (
                                                            641
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.9701996
                                                            )
                                                            else 642
                                                        )
                                                        if state == 641:
                                                            return -0.230204061
                                                        if state == 642:
                                                            return -0.570632458
                                                    if state == 510:
                                                        return -0.0558851287
                                if state == 86:
                                    state = (
                                        143 if x["distpsnr1_med"] < 1.22960162 else 144
                                    )
                                    if state == 143:
                                        state = (
                                            227
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.929642797)
                                            else 228
                                        )
                                        if state == 227:
                                            return 0.319198281
                                        if state == 228:
                                            state = (
                                                307
                                                if x["col_peak"] < 0.119792938
                                                else 308
                                            )
                                            if state == 307:
                                                return -0.17962037
                                            if state == 308:
                                                return 0.150489971
                                    if state == 144:
                                        state = (
                                            229
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.679166675)
                                            else 230
                                        )
                                        if state == 229:
                                            state = (
                                                309
                                                if x["col_peak"] < -0.0911717415
                                                else 310
                                            )
                                            if state == 309:
                                                state = (
                                                    401
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.93467617)
                                                    else 402
                                                )
                                                if state == 401:
                                                    return 0.158982232
                                                if state == 402:
                                                    state = (
                                                        511
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.632857144)
                                                        else 512
                                                    )
                                                    if state == 511:
                                                        state = (
                                                            643
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 17.7845497
                                                            )
                                                            else 644
                                                        )
                                                        if state == 643:
                                                            return -0.247561753
                                                        if state == 644:
                                                            return 0.151369259
                                                    if state == 512:
                                                        return -0.304879069
                                            if state == 310:
                                                state = (
                                                    403
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.47326946)
                                                    else 404
                                                )
                                                if state == 403:
                                                    state = (
                                                        513
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.534999967)
                                                        else 514
                                                    )
                                                    if state == 513:
                                                        return -0.137418449
                                                    if state == 514:
                                                        return 0.111271836
                                                if state == 404:
                                                    state = (
                                                        515
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.666666687)
                                                        else 516
                                                    )
                                                    if state == 515:
                                                        state = (
                                                            647
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.2663994
                                                            )
                                                            else 648
                                                        )
                                                        if state == 647:
                                                            return 0.334047407
                                                        if state == 648:
                                                            return -0.108470589
                                                    if state == 516:
                                                        return 0.0434208773
                                        if state == 230:
                                            state = (
                                                311
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.063765049)
                                                else 312
                                            )
                                            if state == 311:
                                                state = (
                                                    405
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.02248263)
                                                    else 406
                                                )
                                                if state == 405:
                                                    state = (
                                                        517
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.941785932)
                                                        else 518
                                                    )
                                                    if state == 517:
                                                        state = (
                                                            649
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.6825066
                                                            )
                                                            else 650
                                                        )
                                                        if state == 649:
                                                            return -0.363419771
                                                        if state == 650:
                                                            return -0.109609358
                                                    if state == 518:
                                                        return 0.0843797922
                                                if state == 406:
                                                    state = (
                                                        519
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.720833361)
                                                        else 520
                                                    )
                                                    if state == 519:
                                                        state = (
                                                            653
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.3754997
                                                            )
                                                            else 654
                                                        )
                                                        if state == 653:
                                                            return 0.166427016
                                                        if state == 654:
                                                            return -0.374489397
                                                    if state == 520:
                                                        state = (
                                                            655
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 17.9095001
                                                            )
                                                            else 656
                                                        )
                                                        if state == 655:
                                                            return -0.118496731
                                                        if state == 656:
                                                            return 0.231474891
                                            if state == 312:
                                                state = (
                                                    407
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.00831604)
                                                    else 408
                                                )
                                                if state == 407:
                                                    state = (
                                                        521
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.718571484)
                                                        else 522
                                                    )
                                                    if state == 521:
                                                        state = (
                                                            657
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.1708603
                                                            )
                                                            else 658
                                                        )
                                                        if state == 657:
                                                            return -0.275142074
                                                        if state == 658:
                                                            return 0.0361259691
                                                    if state == 522:
                                                        return 0.191580147
                                                if state == 408:
                                                    return 0.215453863
                            if state == 50:
                                return 0.321995527
                        if state == 28:
                            state = (
                                51
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.331720829)
                                else 52
                            )
                            if state == 51:
                                state = (
                                    87
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.982249975)
                                    else 88
                                )
                                if state == 87:
                                    state = (
                                        145 if x["distpsnr1_med"] < 1.05106783 else 146
                                    )
                                    if state == 145:
                                        state = (
                                            231
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.684642851)
                                            else 232
                                        )
                                        if state == 231:
                                            state = (
                                                313
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.181149483)
                                                else 314
                                            )
                                            if state == 313:
                                                state = (
                                                    409
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.996053219)
                                                    else 410
                                                )
                                                if state == 409:
                                                    return -0.23001495
                                                if state == 410:
                                                    state = (
                                                        523
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.654166698)
                                                        else 524
                                                    )
                                                    if state == 523:
                                                        state = (
                                                            659
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 21.3577499
                                                            )
                                                            else 660
                                                        )
                                                        if state == 659:
                                                            return -0.236912593
                                                        if state == 660:
                                                            return 0.374763161
                                                    if state == 524:
                                                        return 0.325056851
                                            if state == 314:
                                                return -0.142950445
                                        if state == 232:
                                            state = (
                                                315
                                                if x["col_peak"] < -0.00467904471
                                                else 316
                                            )
                                            if state == 315:
                                                return 0.234980732
                                            if state == 316:
                                                return -0.286270678
                                    if state == 146:
                                        state = (
                                            233
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.673452377)
                                            else 234
                                        )
                                        if state == 233:
                                            state = (
                                                317
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.126191139)
                                                else 318
                                            )
                                            if state == 317:
                                                state = (
                                                    411
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.950104237)
                                                    else 412
                                                )
                                                if state == 411:
                                                    return -0.426326811
                                                if state == 412:
                                                    state = (
                                                        525
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.582499743)
                                                        else 526
                                                    )
                                                    if state == 525:
                                                        state = (
                                                            661
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 21.0320511
                                                            )
                                                            else 662
                                                        )
                                                        if state == 661:
                                                            return -0.225347251
                                                        if state == 662:
                                                            return 0.126586571
                                                    if state == 526:
                                                        state = (
                                                            663
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 21.1273994
                                                            )
                                                            else 664
                                                        )
                                                        if state == 663:
                                                            return 0.22975187
                                                        if state == 664:
                                                            return -0.247816905
                                            if state == 318:
                                                return -0.351898849
                                        if state == 234:
                                            state = (
                                                319
                                                if x["col_peak"] < 0.123082161
                                                else 320
                                            )
                                            if state == 319:
                                                state = (
                                                    413
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0212268494)
                                                    else 414
                                                )
                                                if state == 413:
                                                    return -0.260712057
                                                if state == 414:
                                                    state = (
                                                        527
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.709166646)
                                                        else 528
                                                    )
                                                    if state == 527:
                                                        return -0.144814581
                                                    if state == 528:
                                                        state = (
                                                            665
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.8554497
                                                            )
                                                            else 666
                                                        )
                                                        if state == 665:
                                                            return 0.0121447127
                                                        if state == 666:
                                                            return 0.204015031
                                            if state == 320:
                                                state = (
                                                    415
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.50789928)
                                                    else 416
                                                )
                                                if state == 415:
                                                    state = (
                                                        529
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.69083333)
                                                        else 530
                                                    )
                                                    if state == 529:
                                                        state = (
                                                            667
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.6358986
                                                            )
                                                            else 668
                                                        )
                                                        if state == 667:
                                                            return 0.0792464688
                                                        if state == 668:
                                                            return -0.237372383
                                                    if state == 530:
                                                        state = (
                                                            669
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.9301491
                                                            )
                                                            else 670
                                                        )
                                                        if state == 669:
                                                            return -0.465160072
                                                        if state == 670:
                                                            return -0.20943895
                                                if state == 416:
                                                    return 0.144814387
                                if state == 88:
                                    state = (
                                        147 if x["distpsnr1_med"] < 1.33804142 else 148
                                    )
                                    if state == 147:
                                        return 0.00946321059
                                    if state == 148:
                                        return 0.320084244
                            if state == 52:
                                state = (
                                    89
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.974250019)
                                    else 90
                                )
                                if state == 89:
                                    state = (
                                        149 if x["distpsnr1_med"] < 3.04525518 else 150
                                    )
                                    if state == 149:
                                        return 0.0202939603
                                    if state == 150:
                                        return 0.418848872
                                if state == 90:
                                    state = (
                                        151 if x["distpsnr1_med"] < 3.04473352 else 152
                                    )
                                    if state == 151:
                                        return -0.170071125
                                    if state == 152:
                                        return 0.261978209
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.9007492)
                            else 30
                        )
                        if state == 29:
                            state = 53 if x["col_peak"] < 0.0526547432 else 54
                            if state == 53:
                                state = (
                                    91
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.981750011)
                                    else 92
                                )
                                if state == 91:
                                    state = (
                                        153 if x["distpsnr1_med"] < 4.78995514 else 154
                                    )
                                    if state == 153:
                                        state = (
                                            237
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.830714226)
                                            else 238
                                        )
                                        if state == 237:
                                            state = (
                                                321
                                                if x["col_peak"] < -0.212816238
                                                else 322
                                            )
                                            if state == 321:
                                                return -0.0525631644
                                            if state == 322:
                                                return 0.226719305
                                        if state == 238:
                                            return -0.295071572
                                    if state == 154:
                                        return 0.290902287
                                if state == 92:
                                    state = (
                                        155 if x["distpsnr1_med"] < 1.59854198 else 156
                                    )
                                    if state == 155:
                                        return -0.399015278
                                    if state == 156:
                                        state = (
                                            239
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.895357132)
                                            else 240
                                        )
                                        if state == 239:
                                            state = (
                                                323
                                                if x["col_peak"] < -0.137088776
                                                else 324
                                            )
                                            if state == 323:
                                                return 0.180970237
                                            if state == 324:
                                                state = (
                                                    419
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.93480301)
                                                    else 420
                                                )
                                                if state == 419:
                                                    return 0.173169881
                                                if state == 420:
                                                    return -0.20616965
                                        if state == 240:
                                            return -0.11823152
                            if state == 54:
                                return 0.27722314
                        if state == 30:
                            state = (
                                55
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.599546432)
                                else 56
                            )
                            if state == 55:
                                state = (
                                    93
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.980250001)
                                    else 94
                                )
                                if state == 93:
                                    state = (
                                        157 if x["distpsnr1_med"] < 6.95049143 else 158
                                    )
                                    if state == 157:
                                        state = (
                                            241
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.814285755)
                                            else 242
                                        )
                                        if state == 241:
                                            state = (
                                                327
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.21877861)
                                                else 328
                                            )
                                            if state == 327:
                                                state = (
                                                    421
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.92931747)
                                                    else 422
                                                )
                                                if state == 421:
                                                    state = (
                                                        531
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.573095083)
                                                        else 532
                                                    )
                                                    if state == 531:
                                                        state = (
                                                            671
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.1094494
                                                            )
                                                            else 672
                                                        )
                                                        if state == 671:
                                                            return 0.0701106191
                                                        if state == 672:
                                                            return -0.212643057
                                                    if state == 532:
                                                        state = (
                                                            673
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.4206009
                                                            )
                                                            else 674
                                                        )
                                                        if state == 673:
                                                            return 0.146933287
                                                        if state == 674:
                                                            return -0.103926159
                                                if state == 422:
                                                    state = (
                                                        533
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.775595069)
                                                        else 534
                                                    )
                                                    if state == 533:
                                                        state = (
                                                            675
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.2339497
                                                            )
                                                            else 676
                                                        )
                                                        if state == 675:
                                                            return 0.158516884
                                                        if state == 676:
                                                            return -0.338829666
                                                    if state == 534:
                                                        state = (
                                                            677
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.5811501
                                                            )
                                                            else 678
                                                        )
                                                        if state == 677:
                                                            return -0.238942966
                                                        if state == 678:
                                                            return 0.215810254
                                            if state == 328:
                                                state = (
                                                    423
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.982094884)
                                                    else 424
                                                )
                                                if state == 423:
                                                    state = (
                                                        535
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.554999828)
                                                        else 536
                                                    )
                                                    if state == 535:
                                                        return 0.108021416
                                                    if state == 536:
                                                        state = (
                                                            679
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.7338505
                                                            )
                                                            else 680
                                                        )
                                                        if state == 679:
                                                            return 0.0227328017
                                                        if state == 680:
                                                            return -0.187872529
                                                if state == 424:
                                                    return -0.347481757
                                        if state == 242:
                                            state = (
                                                329
                                                if x["col_peak"] < -0.330349445
                                                else 330
                                            )
                                            if state == 329:
                                                state = (
                                                    425
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.53478575)
                                                    else 426
                                                )
                                                if state == 425:
                                                    return -0.168181032
                                                if state == 426:
                                                    return 0.23381938
                                            if state == 330:
                                                state = (
                                                    427
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.04970455)
                                                    else 428
                                                )
                                                if state == 427:
                                                    state = (
                                                        537
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.955000043)
                                                        else 538
                                                    )
                                                    if state == 537:
                                                        state = (
                                                            681
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.5338001
                                                            )
                                                            else 682
                                                        )
                                                        if state == 681:
                                                            return -0.184145018
                                                        if state == 682:
                                                            return -0.384229779
                                                    if state == 538:
                                                        return 0.105760574
                                                if state == 428:
                                                    return -0.375707835
                                    if state == 158:
                                        state = (
                                            243
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.898928463)
                                            else 244
                                        )
                                        if state == 243:
                                            state = (
                                                331
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.0488080978)
                                                else 332
                                            )
                                            if state == 331:
                                                state = (
                                                    429
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.98354721)
                                                    else 430
                                                )
                                                if state == 429:
                                                    state = (
                                                        539
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.502499938)
                                                        else 540
                                                    )
                                                    if state == 539:
                                                        return -0.334611148
                                                    if state == 540:
                                                        state = (
                                                            683
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.9917984
                                                            )
                                                            else 684
                                                        )
                                                        if state == 683:
                                                            return 0.0584806204
                                                        if state == 684:
                                                            return -0.289487869
                                                if state == 430:
                                                    state = (
                                                        541
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.572857082)
                                                        else 542
                                                    )
                                                    if state == 541:
                                                        state = (
                                                            685
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.3946991
                                                            )
                                                            else 686
                                                        )
                                                        if state == 685:
                                                            return -0.0455845445
                                                        if state == 686:
                                                            return -0.348325014
                                                    if state == 542:
                                                        state = (
                                                            687
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.8023491
                                                            )
                                                            else 688
                                                        )
                                                        if state == 687:
                                                            return -0.762459934
                                                        if state == 688:
                                                            return -0.324444711
                                            if state == 332:
                                                state = (
                                                    431
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.97458315)
                                                    else 432
                                                )
                                                if state == 431:
                                                    state = (
                                                        543
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.43440485)
                                                        else 544
                                                    )
                                                    if state == 543:
                                                        return -0.186045855
                                                    if state == 544:
                                                        state = (
                                                            689
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.7758999
                                                            )
                                                            else 690
                                                        )
                                                        if state == 689:
                                                            return -0.218455359
                                                        if state == 690:
                                                            return 0.0698867217
                                                if state == 432:
                                                    return -0.261460721
                                        if state == 244:
                                            state = (
                                                333
                                                if x["col_peak"] < 1.08590031
                                                else 334
                                            )
                                            if state == 333:
                                                return -0.107319504
                                            if state == 334:
                                                return 0.344398767
                                if state == 94:
                                    state = (
                                        159
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 6.39447021)
                                        else 160
                                    )
                                    if state == 159:
                                        state = (
                                            245
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.673333347)
                                            else 246
                                        )
                                        if state == 245:
                                            state = (
                                                335
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.19219175)
                                                else 336
                                            )
                                            if state == 335:
                                                state = (
                                                    433
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 1.0300405)
                                                    else 434
                                                )
                                                if state == 433:
                                                    return -0.362206966
                                                if state == 434:
                                                    state = (
                                                        547
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.625357151)
                                                        else 548
                                                    )
                                                    if state == 547:
                                                        state = (
                                                            691
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.8126488
                                                            )
                                                            else 692
                                                        )
                                                        if state == 691:
                                                            return -0.0271850862
                                                        if state == 692:
                                                            return 0.207919821
                                                    if state == 548:
                                                        return 0.282880247
                                            if state == 336:
                                                state = (
                                                    435
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.00001717)
                                                    else 436
                                                )
                                                if state == 435:
                                                    state = (
                                                        549
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.566190481)
                                                        else 550
                                                    )
                                                    if state == 549:
                                                        return 0.00771059794
                                                    if state == 550:
                                                        return 0.345147192
                                                if state == 436:
                                                    state = (
                                                        551
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.288333505)
                                                        else 552
                                                    )
                                                    if state == 551:
                                                        return -0.233510837
                                                    if state == 552:
                                                        state = (
                                                            693
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.3028488
                                                            )
                                                            else 694
                                                        )
                                                        if state == 693:
                                                            return 0.189275905
                                                        if state == 694:
                                                            return -0.19673413
                                        if state == 246:
                                            state = (
                                                337
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.0063533783)
                                                else 338
                                            )
                                            if state == 337:
                                                state = (
                                                    437
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0377836004)
                                                    else 438
                                                )
                                                if state == 437:
                                                    state = (
                                                        553
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.816428542)
                                                        else 554
                                                    )
                                                    if state == 553:
                                                        state = (
                                                            695
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.1438503
                                                            )
                                                            else 696
                                                        )
                                                        if state == 695:
                                                            return 0.138116375
                                                        if state == 696:
                                                            return -0.0967966467
                                                    if state == 554:
                                                        return -0.370097399
                                                if state == 438:
                                                    state = (
                                                        555
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.723095179)
                                                        else 556
                                                    )
                                                    if state == 555:
                                                        state = (
                                                            697
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.6277561
                                                            )
                                                            else 698
                                                        )
                                                        if state == 697:
                                                            return -0.196020082
                                                        if state == 698:
                                                            return 0.0459616929
                                                    if state == 556:
                                                        state = (
                                                            699
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.7825508
                                                            )
                                                            else 700
                                                        )
                                                        if state == 699:
                                                            return 0.18338272
                                                        if state == 700:
                                                            return -0.111620009
                                            if state == 338:
                                                state = (
                                                    439
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.47815967)
                                                    else 440
                                                )
                                                if state == 439:
                                                    state = (
                                                        557
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.945356965)
                                                        else 558
                                                    )
                                                    if state == 557:
                                                        state = (
                                                            701
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.1784401
                                                            )
                                                            else 702
                                                        )
                                                        if state == 701:
                                                            return -0.183299407
                                                        if state == 702:
                                                            return 0.221605852
                                                    if state == 558:
                                                        return -0.336831152
                                                if state == 440:
                                                    state = (
                                                        559
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.944285572)
                                                        else 560
                                                    )
                                                    if state == 559:
                                                        state = (
                                                            703
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.1759987
                                                            )
                                                            else 704
                                                        )
                                                        if state == 703:
                                                            return 0.0813407823
                                                        if state == 704:
                                                            return -0.423528463
                                                    if state == 560:
                                                        return 0.00606615283
                                    if state == 160:
                                        state = (
                                            247
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.934285641)
                                            else 248
                                        )
                                        if state == 247:
                                            return 0.313065231
                                        if state == 248:
                                            return -0.00162667839
                            if state == 56:
                                state = (
                                    95
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.976750016)
                                    else 96
                                )
                                if state == 95:
                                    state = (
                                        161
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 3.51310873)
                                        else 162
                                    )
                                    if state == 161:
                                        return -0.27177307
                                    if state == 162:
                                        return 0.18896161
                                if state == 96:
                                    return 0.329814285
    elif num_booster == 15:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 1.99759281 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 6.99143076)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 5.94484949)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.681904793)
                            else 16
                        )
                        if state == 15:
                            state = 31 if x["sgscore1_med"] < 0.150012001 else 32
                            if state == 31:
                                state = (
                                    61
                                    if np.isnan(x["neargaia_med"])
                                    or (x["neargaia_med"] < 1.6333499)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        109
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.0478315353)
                                        else 110
                                    )
                                    if state == 109:
                                        state = (
                                            191
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.519166589)
                                            else 192
                                        )
                                        if state == 191:
                                            return -0.341605633
                                        if state == 192:
                                            state = (
                                                305
                                                if x["neargaia_med"] < 0.532227159
                                                else 306
                                            )
                                            if state == 305:
                                                return -0.301169783
                                            if state == 306:
                                                state = (
                                                    449
                                                    if x["sgscore1_med"] < 0.00489583518
                                                    else 450
                                                )
                                                if state == 449:
                                                    state = (
                                                        589
                                                        if x["sgscore1_med"]
                                                        < 0.00187499996
                                                        else 590
                                                    )
                                                    if state == 589:
                                                        state = (
                                                            715
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.2319984
                                                            )
                                                            else 716
                                                        )
                                                        if state == 715:
                                                            return 0.210076883
                                                        if state == 716:
                                                            return -0.155661613
                                                    if state == 590:
                                                        return -0.36076951
                                                if state == 450:
                                                    state = (
                                                        591
                                                        if x["sgscore1_med"]
                                                        < 0.0107083498
                                                        else 592
                                                    )
                                                    if state == 591:
                                                        return 0.347338647
                                                    if state == 592:
                                                        state = (
                                                            717
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 16.5494995
                                                            )
                                                            else 718
                                                        )
                                                        if state == 717:
                                                            return 0.302215576
                                                        if state == 718:
                                                            return -0.252375782
                                    if state == 110:
                                        state = (
                                            193
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.564523578)
                                            else 194
                                        )
                                        if state == 193:
                                            return 0.327379942
                                        if state == 194:
                                            state = (
                                                307
                                                if x["neargaia_med"] < 0.978679299
                                                else 308
                                            )
                                            if state == 307:
                                                return -0.27543062
                                            if state == 308:
                                                return 0.165452495
                                if state == 62:
                                    state = (
                                        111
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.0196523666)
                                        else 112
                                    )
                                    if state == 111:
                                        state = (
                                            195
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.665476322)
                                            else 196
                                        )
                                        if state == 195:
                                            return -0.455997854
                                        if state == 196:
                                            return -0.0445445515
                                    if state == 112:
                                        return -0.00478521269
                            if state == 32:
                                return -0.346570015
                        if state == 16:
                            state = (
                                33
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.214086503)
                                else 34
                            )
                            if state == 33:
                                state = 63 if x["neargaia_med"] < 0.937549353 else 64
                                if state == 63:
                                    state = 113 if x["col_det"] < -0.0121068954 else 114
                                    if state == 113:
                                        state = (
                                            199
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.955000043)
                                            else 200
                                        )
                                        if state == 199:
                                            return -0.4535321
                                        if state == 200:
                                            return 0.0954654738
                                    if state == 114:
                                        state = (
                                            201
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.952857018)
                                            else 202
                                        )
                                        if state == 201:
                                            state = (
                                                309
                                                if x["neargaia_med"] < 0.164762169
                                                else 310
                                            )
                                            if state == 309:
                                                state = (
                                                    455
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00270833494
                                                    )
                                                    else 456
                                                )
                                                if state == 455:
                                                    return 0.290663481
                                                if state == 456:
                                                    state = (
                                                        593
                                                        if x["sgscore1_med"]
                                                        < 0.00808333512
                                                        else 594
                                                    )
                                                    if state == 593:
                                                        return -0.270419836
                                                    if state == 594:
                                                        state = (
                                                            719
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.3470001
                                                            )
                                                            else 720
                                                        )
                                                        if state == 719:
                                                            return 0.252314925
                                                        if state == 720:
                                                            return -0.0537548698
                                            if state == 310:
                                                state = (
                                                    457
                                                    if x["sgscore1_med"] < 0.0141399
                                                    else 458
                                                )
                                                if state == 457:
                                                    state = (
                                                        595
                                                        if x["sgscore1_med"]
                                                        < 0.0113957999
                                                        else 596
                                                    )
                                                    if state == 595:
                                                        state = (
                                                            721
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.4365005
                                                            )
                                                            else 722
                                                        )
                                                        if state == 721:
                                                            return -0.165985703
                                                        if state == 722:
                                                            return 0.0444243401
                                                    if state == 596:
                                                        return 0.20136632
                                                if state == 458:
                                                    state = (
                                                        597
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.0410624966
                                                        )
                                                        else 598
                                                    )
                                                    if state == 597:
                                                        return -0.343112499
                                                    if state == 598:
                                                        state = (
                                                            723
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.4099998
                                                            )
                                                            else 724
                                                        )
                                                        if state == 723:
                                                            return 0.0659838468
                                                        if state == 724:
                                                            return -0.211464897
                                        if state == 202:
                                            return -0.283679724
                                if state == 64:
                                    state = 115 if x["col_det"] < -0.0289158821 else 116
                                    if state == 115:
                                        state = (
                                            203
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.73999989)
                                            else 204
                                        )
                                        if state == 203:
                                            state = (
                                                311
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 1.08779407)
                                                else 312
                                            )
                                            if state == 311:
                                                state = (
                                                    459
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00395833515
                                                    )
                                                    else 460
                                                )
                                                if state == 459:
                                                    return 0.34865725
                                                if state == 460:
                                                    state = (
                                                        599
                                                        if x["sgscore1_med"]
                                                        < 0.0594925508
                                                        else 600
                                                    )
                                                    if state == 599:
                                                        state = (
                                                            725
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.2714996
                                                            )
                                                            else 726
                                                        )
                                                        if state == 725:
                                                            return 0.069957681
                                                        if state == 726:
                                                            return -0.302654445
                                                    if state == 600:
                                                        return 0.223329514
                                            if state == 312:
                                                return -0.13813594
                                        if state == 204:
                                            state = (
                                                313
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 3.55195689)
                                                else 314
                                            )
                                            if state == 313:
                                                return 0.3434048
                                            if state == 314:
                                                return 0.0241595712
                                    if state == 116:
                                        state = (
                                            205
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.703809619)
                                            else 206
                                        )
                                        if state == 205:
                                            state = (
                                                315
                                                if x["neargaia_med"] < 1.98340952
                                                else 316
                                            )
                                            if state == 315:
                                                return 0.221906126
                                            if state == 316:
                                                state = (
                                                    461
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00856249966
                                                    )
                                                    else 462
                                                )
                                                if state == 461:
                                                    return 0.233781904
                                                if state == 462:
                                                    return -0.222946584
                                        if state == 206:
                                            state = (
                                                317
                                                if x["neargaia_med"] < 1.65156686
                                                else 318
                                            )
                                            if state == 317:
                                                state = (
                                                    463
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0188958496
                                                    )
                                                    else 464
                                                )
                                                if state == 463:
                                                    state = (
                                                        601
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.00641666539
                                                        )
                                                        else 602
                                                    )
                                                    if state == 601:
                                                        return -0.293249696
                                                    if state == 602:
                                                        state = (
                                                            727
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.6700001
                                                            )
                                                            else 728
                                                        )
                                                        if state == 727:
                                                            return 0.0593160503
                                                        if state == 728:
                                                            return -0.150790244
                                                if state == 464:
                                                    return 0.333135366
                                            if state == 318:
                                                state = (
                                                    465
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00552083505
                                                    )
                                                    else 466
                                                )
                                                if state == 465:
                                                    state = (
                                                        603
                                                        if x["sgscore1_med"]
                                                        < 0.00416666502
                                                        else 604
                                                    )
                                                    if state == 603:
                                                        state = (
                                                            729
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.9319992
                                                            )
                                                            else 730
                                                        )
                                                        if state == 729:
                                                            return 0.160262004
                                                        if state == 730:
                                                            return -0.196333617
                                                    if state == 604:
                                                        state = (
                                                            731
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.8994999
                                                            )
                                                            else 732
                                                        )
                                                        if state == 731:
                                                            return 0.249062672
                                                        if state == 732:
                                                            return 0.0465303473
                                                if state == 466:
                                                    state = (
                                                        605
                                                        if x["sgscore1_med"]
                                                        < 0.0338749997
                                                        else 606
                                                    )
                                                    if state == 605:
                                                        state = (
                                                            733
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.0712509
                                                            )
                                                            else 734
                                                        )
                                                        if state == 733:
                                                            return -0.365392059
                                                        if state == 734:
                                                            return 0.0056491266
                                                    if state == 606:
                                                        state = (
                                                            735
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.5699997
                                                            )
                                                            else 736
                                                        )
                                                        if state == 735:
                                                            return -0.232502773
                                                        if state == 736:
                                                            return 0.041915305
                            if state == 34:
                                state = (
                                    65
                                    if np.isnan(x["neargaia_med"])
                                    or (x["neargaia_med"] < 3.13252926)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        117
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.227278709)
                                        else 118
                                    )
                                    if state == 117:
                                        state = (
                                            207
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.922857106)
                                            else 208
                                        )
                                        if state == 207:
                                            return -0.361421406
                                        if state == 208:
                                            state = (
                                                319
                                                if x["neargaia_med"] < 1.60569024
                                                else 320
                                            )
                                            if state == 319:
                                                state = (
                                                    467
                                                    if x["sgscore1_med"] < 0.432370484
                                                    else 468
                                                )
                                                if state == 467:
                                                    state = (
                                                        607
                                                        if x["sgscore1_med"]
                                                        < 0.297618985
                                                        else 608
                                                    )
                                                    if state == 607:
                                                        return -0.0931538567
                                                    if state == 608:
                                                        return 0.184319362
                                                if state == 468:
                                                    return -0.185173571
                                            if state == 320:
                                                return -0.270069271
                                    if state == 118:
                                        state = (
                                            209
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.740833342)
                                            else 210
                                        )
                                        if state == 209:
                                            state = (
                                                321
                                                if x["neargaia_med"] < 0.224385113
                                                else 322
                                            )
                                            if state == 321:
                                                state = (
                                                    469
                                                    if x["sgscore1_med"] < 0.440872014
                                                    else 470
                                                )
                                                if state == 469:
                                                    return -0.106125876
                                                if state == 470:
                                                    return 0.136934608
                                            if state == 322:
                                                return 0.298654675
                                        if state == 210:
                                            state = (
                                                323
                                                if x["neargaia_med"] < 1.76601028
                                                else 324
                                            )
                                            if state == 323:
                                                return -0.209223554
                                            if state == 324:
                                                return 0.182377011
                                if state == 66:
                                    state = (
                                        119
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.281874657)
                                        else 120
                                    )
                                    if state == 119:
                                        return -0.053764455
                                    if state == 120:
                                        return -0.516817331
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.376666844)
                            else 18
                        )
                        if state == 17:
                            state = (
                                35
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.010062485)
                                else 36
                            )
                            if state == 35:
                                return -0.00308558065
                            if state == 36:
                                return 0.262019038
                        if state == 18:
                            state = (
                                37
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.100979)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    67
                                    if np.isnan(x["neargaia_med"])
                                    or (x["neargaia_med"] < 1.287678)
                                    else 68
                                )
                                if state == 67:
                                    state = 121 if x["col_det"] < 0.0627152175 else 122
                                    if state == 121:
                                        state = (
                                            211
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.465238005)
                                            else 212
                                        )
                                        if state == 211:
                                            return -0.211498305
                                        if state == 212:
                                            state = (
                                                325
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 0.374202669)
                                                else 326
                                            )
                                            if state == 325:
                                                state = (
                                                    471
                                                    if x["sgscore1_med"] < 0.0321458504
                                                    else 472
                                                )
                                                if state == 471:
                                                    return 0.0826716274
                                                if state == 472:
                                                    return -0.180032492
                                            if state == 326:
                                                return 0.189800084
                                    if state == 122:
                                        state = (
                                            213
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.775714159)
                                            else 214
                                        )
                                        if state == 213:
                                            state = (
                                                327
                                                if x["neargaia_med"] < 0.18016094
                                                else 328
                                            )
                                            if state == 327:
                                                return -0.227281556
                                            if state == 328:
                                                state = (
                                                    473
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0761666521
                                                    )
                                                    else 474
                                                )
                                                if state == 473:
                                                    state = (
                                                        609
                                                        if x["sgscore1_med"]
                                                        < 0.00824999996
                                                        else 610
                                                    )
                                                    if state == 609:
                                                        state = (
                                                            737
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.2224998
                                                            )
                                                            else 738
                                                        )
                                                        if state == 737:
                                                            return 0.212999254
                                                        if state == 738:
                                                            return -0.481695443
                                                    if state == 610:
                                                        state = (
                                                            739
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.7320004
                                                            )
                                                            else 740
                                                        )
                                                        if state == 739:
                                                            return 0.276040614
                                                        if state == 740:
                                                            return -0.178281471
                                                if state == 474:
                                                    return 0.0070032822
                                        if state == 214:
                                            state = (
                                                329
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 0.179955497)
                                                else 330
                                            )
                                            if state == 329:
                                                state = (
                                                    475
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0017708349
                                                    )
                                                    else 476
                                                )
                                                if state == 475:
                                                    return -0.174280167
                                                if state == 476:
                                                    state = (
                                                        611
                                                        if x["sgscore1_med"]
                                                        < 0.00218750001
                                                        else 612
                                                    )
                                                    if state == 611:
                                                        return 0.155179873
                                                    if state == 612:
                                                        return -0.0758967921
                                            if state == 330:
                                                return 0.315488964
                                if state == 68:
                                    state = 123 if x["col_det"] < 0.164769173 else 124
                                    if state == 123:
                                        return 0.0820258632
                                    if state == 124:
                                        return -0.326089263
                            if state == 38:
                                state = (
                                    69
                                    if np.isnan(x["neargaia_med"])
                                    or (x["neargaia_med"] < 0.932627082)
                                    else 70
                                )
                                if state == 69:
                                    state = 125 if x["col_det"] < -0.0946807861 else 126
                                    if state == 125:
                                        return 0.117217556
                                    if state == 126:
                                        state = (
                                            219
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.408809423)
                                            else 220
                                        )
                                        if state == 219:
                                            return -0.0156993866
                                        if state == 220:
                                            return -0.344811261
                                if state == 70:
                                    state = (
                                        127
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.284781218)
                                        else 128
                                    )
                                    if state == 127:
                                        state = (
                                            221
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.569999993)
                                            else 222
                                        )
                                        if state == 221:
                                            return -0.187366396
                                        if state == 222:
                                            return 0.357019097
                                    if state == 128:
                                        return -0.182860821
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 7.93887138)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.64809525)
                            else 20
                        )
                        if state == 19:
                            state = 39 if x["sgscore1_med"] < 0.00158333499 else 40
                            if state == 39:
                                state = 71 if x["neargaia_med"] < 15.328661 else 72
                                if state == 71:
                                    state = 129 if x["col_det"] < -0.106608391 else 130
                                    if state == 129:
                                        return 0.145433828
                                    if state == 130:
                                        return -0.201860458
                                if state == 72:
                                    return -0.536165953
                            if state == 40:
                                state = 73 if x["neargaia_med"] < 8.00150871 else 74
                                if state == 73:
                                    return 0.307518661
                                if state == 74:
                                    state = 131 if x["col_det"] < 0.236984253 else 132
                                    if state == 131:
                                        state = (
                                            223
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.580714405)
                                            else 224
                                        )
                                        if state == 223:
                                            state = (
                                                331
                                                if x["neargaia_med"] < 44.2963104
                                                else 332
                                            )
                                            if state == 331:
                                                state = (
                                                    477
                                                    if x["sgscore1_med"] < 0.0687530041
                                                    else 478
                                                )
                                                if state == 477:
                                                    return -0.305588394
                                                if state == 478:
                                                    state = (
                                                        613
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.269142985
                                                        )
                                                        else 614
                                                    )
                                                    if state == 613:
                                                        return 0.269696265
                                                    if state == 614:
                                                        state = (
                                                            743
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.2264996
                                                            )
                                                            else 744
                                                        )
                                                        if state == 743:
                                                            return 0.078135848
                                                        if state == 744:
                                                            return -0.145602852
                                            if state == 332:
                                                return -0.266959131
                                        if state == 224:
                                            state = (
                                                333
                                                if x["neargaia_med"] < 15.9590702
                                                else 334
                                            )
                                            if state == 333:
                                                return -0.187341422
                                            if state == 334:
                                                state = (
                                                    479
                                                    if x["sgscore1_med"] < 0.411931515
                                                    else 480
                                                )
                                                if state == 479:
                                                    state = (
                                                        615
                                                        if x["sgscore1_med"]
                                                        < 0.00291666482
                                                        else 616
                                                    )
                                                    if state == 615:
                                                        return -0.0129412413
                                                    if state == 616:
                                                        return 0.296686083
                                                if state == 480:
                                                    state = (
                                                        617
                                                        if x["sgscore1_med"]
                                                        < 0.55467248
                                                        else 618
                                                    )
                                                    if state == 617:
                                                        state = (
                                                            747
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.1199989
                                                            )
                                                            else 748
                                                        )
                                                        if state == 747:
                                                            return -0.0582549796
                                                        if state == 748:
                                                            return 0.257075846
                                                    if state == 618:
                                                        state = (
                                                            749
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.2637501
                                                            )
                                                            else 750
                                                        )
                                                        if state == 749:
                                                            return -0.177816212
                                                        if state == 750:
                                                            return 0.0865835324
                                    if state == 132:
                                        state = (
                                            225
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.540000021)
                                            else 226
                                        )
                                        if state == 225:
                                            state = (
                                                335
                                                if x["neargaia_med"] < 65.2920685
                                                else 336
                                            )
                                            if state == 335:
                                                state = (
                                                    481
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.182300508)
                                                    else 482
                                                )
                                                if state == 481:
                                                    return -0.42579779
                                                if state == 482:
                                                    state = (
                                                        619
                                                        if x["sgscore1_med"]
                                                        < 0.219279498
                                                        else 620
                                                    )
                                                    if state == 619:
                                                        return 0.131606802
                                                    if state == 620:
                                                        state = (
                                                            751
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.5345001
                                                            )
                                                            else 752
                                                        )
                                                        if state == 751:
                                                            return -0.319882751
                                                        if state == 752:
                                                            return -0.0546957105
                                            if state == 336:
                                                return 0.180044308
                                        if state == 226:
                                            state = (
                                                337
                                                if x["neargaia_med"] < 14.9397144
                                                else 338
                                            )
                                            if state == 337:
                                                state = (
                                                    483
                                                    if x["sgscore1_med"] < 0.0804791451
                                                    else 484
                                                )
                                                if state == 483:
                                                    state = (
                                                        621
                                                        if x["sgscore1_med"]
                                                        < 0.0794791505
                                                        else 622
                                                    )
                                                    if state == 621:
                                                        state = (
                                                            753
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.0029984
                                                            )
                                                            else 754
                                                        )
                                                        if state == 753:
                                                            return 0.143177137
                                                        if state == 754:
                                                            return -0.313231558
                                                    if state == 622:
                                                        return 0.468164295
                                                if state == 484:
                                                    return -0.494367778
                                            if state == 338:
                                                state = (
                                                    485
                                                    if x["sgscore1_med"] < 0.0100624999
                                                    else 486
                                                )
                                                if state == 485:
                                                    state = (
                                                        623
                                                        if x["sgscore1_med"]
                                                        < 0.00860416982
                                                        else 624
                                                    )
                                                    if state == 623:
                                                        state = (
                                                            755
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.3889999
                                                            )
                                                            else 756
                                                        )
                                                        if state == 755:
                                                            return 0.267208159
                                                        if state == 756:
                                                            return -0.498851776
                                                    if state == 624:
                                                        return 0.372510672
                                                if state == 486:
                                                    state = (
                                                        625
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.449508995
                                                        )
                                                        else 626
                                                    )
                                                    if state == 625:
                                                        state = (
                                                            757
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.59025
                                                            )
                                                            else 758
                                                        )
                                                        if state == 757:
                                                            return -0.18008782
                                                        if state == 758:
                                                            return -0.438780129
                                                    if state == 626:
                                                        state = (
                                                            759
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.2007504
                                                            )
                                                            else 760
                                                        )
                                                        if state == 759:
                                                            return 0.425341994
                                                        if state == 760:
                                                            return -0.182185858
                        if state == 20:
                            state = (
                                41
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0153541993)
                                else 42
                            )
                            if state == 41:
                                state = 75 if x["neargaia_med"] < 27.8882294 else 76
                                if state == 75:
                                    state = 133 if x["col_det"] < -0.297996521 else 134
                                    if state == 133:
                                        return -0.341863155
                                    if state == 134:
                                        state = (
                                            227
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.733333468)
                                            else 228
                                        )
                                        if state == 227:
                                            state = (
                                                339
                                                if x["neargaia_med"] < 27.0539131
                                                else 340
                                            )
                                            if state == 339:
                                                state = (
                                                    487
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0133958496
                                                    )
                                                    else 488
                                                )
                                                if state == 487:
                                                    state = (
                                                        627
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.0121042002
                                                        )
                                                        else 628
                                                    )
                                                    if state == 627:
                                                        state = (
                                                            761
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.0594997
                                                            )
                                                            else 762
                                                        )
                                                        if state == 761:
                                                            return -0.411346078
                                                        if state == 762:
                                                            return 0.0827966109
                                                    if state == 628:
                                                        return 0.331986427
                                                if state == 488:
                                                    return -0.47693941
                                            if state == 340:
                                                state = (
                                                    489
                                                    if x["sgscore1_med"] < 0.00416666502
                                                    else 490
                                                )
                                                if state == 489:
                                                    return 0.310149193
                                                if state == 490:
                                                    return -0.0970887691
                                        if state == 228:
                                            state = (
                                                341
                                                if x["neargaia_med"] < 10.6347313
                                                else 342
                                            )
                                            if state == 341:
                                                return -0.319238484
                                            if state == 342:
                                                state = (
                                                    491
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00720832963
                                                    )
                                                    else 492
                                                )
                                                if state == 491:
                                                    state = (
                                                        629
                                                        if x["sgscore1_med"]
                                                        < 0.00602083514
                                                        else 630
                                                    )
                                                    if state == 629:
                                                        state = (
                                                            763
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.0429993
                                                            )
                                                            else 764
                                                        )
                                                        if state == 763:
                                                            return -0.105604284
                                                        if state == 764:
                                                            return 0.210022688
                                                    if state == 630:
                                                        state = (
                                                            765
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.137001
                                                            )
                                                            else 766
                                                        )
                                                        if state == 765:
                                                            return 0.335849047
                                                        if state == 766:
                                                            return 0.0564362481
                                                if state == 492:
                                                    state = (
                                                        631
                                                        if x["sgscore1_med"]
                                                        < 0.0144375004
                                                        else 632
                                                    )
                                                    if state == 631:
                                                        state = (
                                                            767
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.8704987
                                                            )
                                                            else 768
                                                        )
                                                        if state == 767:
                                                            return 0.117365241
                                                        if state == 768:
                                                            return -0.295243293
                                                    if state == 632:
                                                        return 0.0820747539
                                if state == 76:
                                    state = (
                                        135
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.184985161)
                                        else 136
                                    )
                                    if state == 135:
                                        state = (
                                            229
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.957142889)
                                            else 230
                                        )
                                        if state == 229:
                                            state = (
                                                343
                                                if x["neargaia_med"] < 33.4372368
                                                else 344
                                            )
                                            if state == 343:
                                                state = (
                                                    493
                                                    if x["sgscore1_med"] < 0.00270833494
                                                    else 494
                                                )
                                                if state == 493:
                                                    return -0.0475351065
                                                if state == 494:
                                                    return -0.437029183
                                            if state == 344:
                                                state = (
                                                    495
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00297321496
                                                    )
                                                    else 496
                                                )
                                                if state == 495:
                                                    state = (
                                                        633
                                                        if x["sgscore1_med"]
                                                        < 0.00266071502
                                                        else 634
                                                    )
                                                    if state == 633:
                                                        state = (
                                                            769
                                                            if np.isnan(x["magnr_med"])
                                                            or (x["magnr_med"] < 20.757)
                                                            else 770
                                                        )
                                                        if state == 769:
                                                            return -0.239336565
                                                        if state == 770:
                                                            return 0.0702599064
                                                    if state == 634:
                                                        state = (
                                                            771
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.7827492
                                                            )
                                                            else 772
                                                        )
                                                        if state == 771:
                                                            return 0.14753142
                                                        if state == 772:
                                                            return -0.103637941
                                                if state == 496:
                                                    state = (
                                                        635
                                                        if x["sgscore1_med"]
                                                        < 0.00404166989
                                                        else 636
                                                    )
                                                    if state == 635:
                                                        return -0.509523869
                                                    if state == 636:
                                                        state = (
                                                            773
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.6392517
                                                            )
                                                            else 774
                                                        )
                                                        if state == 773:
                                                            return 0.233529761
                                                        if state == 774:
                                                            return -0.306024253
                                        if state == 230:
                                            state = (
                                                345
                                                if x["neargaia_med"] < 54.2714233
                                                else 346
                                            )
                                            if state == 345:
                                                return 0.36112538
                                            if state == 346:
                                                return -0.120748386
                                    if state == 136:
                                        state = (
                                            231
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.943928361)
                                            else 232
                                        )
                                        if state == 231:
                                            state = (
                                                347
                                                if x["neargaia_med"] < 43.9643517
                                                else 348
                                            )
                                            if state == 347:
                                                return -0.184536979
                                            if state == 348:
                                                return 0.194918409
                                        if state == 232:
                                            return 0.213723496
                            if state == 42:
                                state = 77 if x["neargaia_med"] < 7.75766945 else 78
                                if state == 77:
                                    return -0.30694893
                                if state == 78:
                                    state = (
                                        137
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.5228405)
                                        else 138
                                    )
                                    if state == 137:
                                        state = (
                                            233
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.671904922)
                                            else 234
                                        )
                                        if state == 233:
                                            state = (
                                                349
                                                if x["neargaia_med"] < 14.8590717
                                                else 350
                                            )
                                            if state == 349:
                                                state = (
                                                    497
                                                    if x["sgscore1_med"] < 0.159669504
                                                    else 498
                                                )
                                                if state == 497:
                                                    return 0.21858716
                                                if state == 498:
                                                    state = (
                                                        639
                                                        if x["sgscore1_med"]
                                                        < 0.470604002
                                                        else 640
                                                    )
                                                    if state == 639:
                                                        return -0.339756995
                                                    if state == 640:
                                                        state = (
                                                            775
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.9459991
                                                            )
                                                            else 776
                                                        )
                                                        if state == 775:
                                                            return 0.173842132
                                                        if state == 776:
                                                            return -0.155845433
                                            if state == 350:
                                                state = (
                                                    499
                                                    if x["sgscore1_med"] < 0.0529821515
                                                    else 500
                                                )
                                                if state == 499:
                                                    return 0.365774989
                                                if state == 500:
                                                    state = (
                                                        641
                                                        if x["sgscore1_med"]
                                                        < 0.488282502
                                                        else 642
                                                    )
                                                    if state == 641:
                                                        return -0.0918390006
                                                    if state == 642:
                                                        state = (
                                                            779
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.4064999
                                                            )
                                                            else 780
                                                        )
                                                        if state == 779:
                                                            return -0.12532784
                                                        if state == 780:
                                                            return 0.16835773
                                        if state == 234:
                                            state = (
                                                351
                                                if x["neargaia_med"] < 11.3551865
                                                else 352
                                            )
                                            if state == 351:
                                                state = (
                                                    501
                                                    if x["sgscore1_med"] < 0.0971456468
                                                    else 502
                                                )
                                                if state == 501:
                                                    return 0.426785171
                                                if state == 502:
                                                    state = (
                                                        643
                                                        if x["sgscore1_med"]
                                                        < 0.420568496
                                                        else 644
                                                    )
                                                    if state == 643:
                                                        return -0.229059622
                                                    if state == 644:
                                                        state = (
                                                            781
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.5429993
                                                            )
                                                            else 782
                                                        )
                                                        if state == 781:
                                                            return 0.0503025465
                                                        if state == 782:
                                                            return 0.386041194
                                            if state == 352:
                                                state = (
                                                    503
                                                    if x["sgscore1_med"] < 0.630806506
                                                    else 504
                                                )
                                                if state == 503:
                                                    state = (
                                                        645
                                                        if x["sgscore1_med"]
                                                        < 0.0205833502
                                                        else 646
                                                    )
                                                    if state == 645:
                                                        return 0.295246005
                                                    if state == 646:
                                                        state = (
                                                            785
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.1982498
                                                            )
                                                            else 786
                                                        )
                                                        if state == 785:
                                                            return 0.107758194
                                                        if state == 786:
                                                            return -0.263426363
                                                if state == 504:
                                                    return -0.32175675
                                    if state == 138:
                                        return -0.185137644
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.728571475)
                            else 22
                        )
                        if state == 21:
                            state = (
                                43
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.27527082)
                                else 44
                            )
                            if state == 43:
                                state = 79 if x["neargaia_med"] < 41.0851135 else 80
                                if state == 79:
                                    state = 139 if x["col_det"] < 0.27699852 else 140
                                    if state == 139:
                                        state = (
                                            235
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.726904631)
                                            else 236
                                        )
                                        if state == 235:
                                            state = (
                                                353
                                                if x["neargaia_med"] < 20.1282921
                                                else 354
                                            )
                                            if state == 353:
                                                return 0.382556975
                                            if state == 354:
                                                state = (
                                                    505
                                                    if x["sgscore1_med"] < 0.00839583017
                                                    else 506
                                                )
                                                if state == 505:
                                                    state = (
                                                        647
                                                        if x["sgscore1_med"]
                                                        < 0.0068333298
                                                        else 648
                                                    )
                                                    if state == 647:
                                                        return -0.188837349
                                                    if state == 648:
                                                        return 0.189221129
                                                if state == 506:
                                                    return -0.234901696
                                        if state == 236:
                                            return -0.122336149
                                    if state == 140:
                                        state = (
                                            237
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.721666574)
                                            else 238
                                        )
                                        if state == 237:
                                            state = (
                                                355
                                                if x["neargaia_med"] < 29.0255966
                                                else 356
                                            )
                                            if state == 355:
                                                state = (
                                                    507
                                                    if x["sgscore1_med"] < 0.0283332989
                                                    else 508
                                                )
                                                if state == 507:
                                                    state = (
                                                        649
                                                        if x["sgscore1_med"]
                                                        < 0.00312499981
                                                        else 650
                                                    )
                                                    if state == 649:
                                                        return 0.0940892994
                                                    if state == 650:
                                                        return -0.338528872
                                                if state == 508:
                                                    state = (
                                                        651
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.0556011498
                                                        )
                                                        else 652
                                                    )
                                                    if state == 651:
                                                        state = (
                                                            787
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.9144993
                                                            )
                                                            else 788
                                                        )
                                                        if state == 787:
                                                            return 0.256219894
                                                        if state == 788:
                                                            return 0.017559221
                                                    if state == 652:
                                                        state = (
                                                            789
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.1785011
                                                            )
                                                            else 790
                                                        )
                                                        if state == 789:
                                                            return 0.160759479
                                                        if state == 790:
                                                            return -0.201646551
                                            if state == 356:
                                                return -0.491584957
                                        if state == 238:
                                            return 0.191234797
                                if state == 80:
                                    state = 141 if x["col_det"] < -0.234031677 else 142
                                    if state == 141:
                                        return -0.150630906
                                    if state == 142:
                                        state = (
                                            239
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.650476217)
                                            else 240
                                        )
                                        if state == 239:
                                            return 0.355522215
                                        if state == 240:
                                            state = (
                                                357
                                                if x["neargaia_med"] < 64.978653
                                                else 358
                                            )
                                            if state == 357:
                                                state = (
                                                    509
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0136458501
                                                    )
                                                    else 510
                                                )
                                                if state == 509:
                                                    return -0.108710393
                                                if state == 510:
                                                    return 0.0810001418
                                            if state == 358:
                                                return 0.179575652
                            if state == 44:
                                state = 81 if x["neargaia_med"] < 23.7950172 else 82
                                if state == 81:
                                    state = (
                                        143
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.152233452)
                                        else 144
                                    )
                                    if state == 143:
                                        state = (
                                            241
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.716428578)
                                            else 242
                                        )
                                        if state == 241:
                                            state = (
                                                359
                                                if x["neargaia_med"] < 19.9594688
                                                else 360
                                            )
                                            if state == 359:
                                                return -0.325451523
                                            if state == 360:
                                                return 0.0564524308
                                        if state == 242:
                                            return 0.149010882
                                    if state == 144:
                                        return 0.133653745
                                if state == 82:
                                    state = 145 if x["col_det"] < -0.136572361 else 146
                                    if state == 145:
                                        return -0.0632296577
                                    if state == 146:
                                        return -0.500781417
                        if state == 22:
                            state = 45 if x["sgscore1_med"] < 0.038562499 else 46
                            if state == 45:
                                state = 83 if x["neargaia_med"] < 61.2955704 else 84
                                if state == 83:
                                    state = 147 if x["col_det"] < -0.524103642 else 148
                                    if state == 147:
                                        return 0.152318552
                                    if state == 148:
                                        state = (
                                            243
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.943571329)
                                            else 244
                                        )
                                        if state == 243:
                                            return -0.484243631
                                        if state == 244:
                                            return -0.0280449782
                                if state == 84:
                                    state = 149 if x["col_det"] < 0.000001 else 150
                                    if state == 149:
                                        return 0.122394472
                                    if state == 150:
                                        return -0.11492978
                            if state == 46:
                                state = 85 if x["neargaia_med"] < 31.8220825 else 86
                                if state == 85:
                                    state = 151 if x["col_det"] < -0.143607616 else 152
                                    if state == 151:
                                        state = (
                                            245
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.917500198)
                                            else 246
                                        )
                                        if state == 245:
                                            return 0.336195529
                                        if state == 246:
                                            return -0.106746718
                                    if state == 152:
                                        state = (
                                            247
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.741666675)
                                            else 248
                                        )
                                        if state == 247:
                                            return 0.119388521
                                        if state == 248:
                                            state = (
                                                361
                                                if x["neargaia_med"] < 10.8310156
                                                else 362
                                            )
                                            if state == 361:
                                                return -0.310395002
                                            if state == 362:
                                                state = (
                                                    511
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.534677029)
                                                    else 512
                                                )
                                                if state == 511:
                                                    state = (
                                                        655
                                                        if x["sgscore1_med"]
                                                        < 0.0458333492
                                                        else 656
                                                    )
                                                    if state == 655:
                                                        return 0.116122425
                                                    if state == 656:
                                                        state = (
                                                            791
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.2589989
                                                            )
                                                            else 792
                                                        )
                                                        if state == 791:
                                                            return 0.0356886685
                                                        if state == 792:
                                                            return -0.139913067
                                                if state == 512:
                                                    return 0.13181752
                                if state == 86:
                                    return -0.328072488
            if state == 2:
                state = 5 if x["neargaia_med"] < 18.0919189 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 5.03018522)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.798214078)
                            else 24
                        )
                        if state == 23:
                            state = 47 if x["sgscore1_med"] < 0.310276985 else 48
                            if state == 47:
                                state = 87 if x["neargaia_med"] < 11.8895264 else 88
                                if state == 87:
                                    state = 153 if x["col_det"] < -0.134438515 else 154
                                    if state == 153:
                                        return 0.351882845
                                    if state == 154:
                                        state = (
                                            249
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.434523523)
                                            else 250
                                        )
                                        if state == 249:
                                            return -0.173297465
                                        if state == 250:
                                            state = (
                                                365
                                                if x["neargaia_med"] < 10.2943573
                                                else 366
                                            )
                                            if state == 365:
                                                state = (
                                                    513
                                                    if x["sgscore1_med"] < 0.0865298063
                                                    else 514
                                                )
                                                if state == 513:
                                                    state = (
                                                        657
                                                        if x["sgscore1_med"]
                                                        < 0.0405000001
                                                        else 658
                                                    )
                                                    if state == 657:
                                                        state = (
                                                            793
                                                            if np.isnan(x["magnr_med"])
                                                            or (x["magnr_med"] < 20.934)
                                                            else 794
                                                        )
                                                        if state == 793:
                                                            return 0.207879931
                                                        if state == 794:
                                                            return -0.303528309
                                                    if state == 658:
                                                        state = (
                                                            795
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.7674999
                                                            )
                                                            else 796
                                                        )
                                                        if state == 795:
                                                            return -0.317174703
                                                        if state == 796:
                                                            return -0.068945311
                                                if state == 514:
                                                    return 0.310406297
                                            if state == 366:
                                                state = (
                                                    515
                                                    if x["sgscore1_med"] < 0.0182916503
                                                    else 516
                                                )
                                                if state == 515:
                                                    return -0.250540584
                                                if state == 516:
                                                    return 0.411706328
                                if state == 88:
                                    state = 155 if x["col_det"] < -0.290804863 else 156
                                    if state == 155:
                                        state = (
                                            251
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.566666663)
                                            else 252
                                        )
                                        if state == 251:
                                            return -0.255434126
                                        if state == 252:
                                            return 0.0833240896
                                    if state == 156:
                                        return -0.437167674
                            if state == 48:
                                state = 89 if x["neargaia_med"] < 13.6729832 else 90
                                if state == 89:
                                    state = 157 if x["col_det"] < -0.169341594 else 158
                                    if state == 157:
                                        return -0.540984392
                                    if state == 158:
                                        state = (
                                            253
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.677500129)
                                            else 254
                                        )
                                        if state == 253:
                                            state = (
                                                367
                                                if x["neargaia_med"] < 1.48642111
                                                else 368
                                            )
                                            if state == 367:
                                                return 0.159988239
                                            if state == 368:
                                                state = (
                                                    517
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.342988014)
                                                    else 518
                                                )
                                                if state == 517:
                                                    return -0.367873877
                                                if state == 518:
                                                    state = (
                                                        659
                                                        if x["sgscore1_med"]
                                                        < 0.501249909
                                                        else 660
                                                    )
                                                    if state == 659:
                                                        state = (
                                                            797
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.1517487
                                                            )
                                                            else 798
                                                        )
                                                        if state == 797:
                                                            return -0.170810178
                                                        if state == 798:
                                                            return 0.0881150439
                                                    if state == 660:
                                                        return -0.338062316
                                        if state == 254:
                                            state = (
                                                369
                                                if x["neargaia_med"] < 6.52885437
                                                else 370
                                            )
                                            if state == 369:
                                                return 0.236042961
                                            if state == 370:
                                                state = (
                                                    519
                                                    if x["sgscore1_med"] < 0.640437484
                                                    else 520
                                                )
                                                if state == 519:
                                                    state = (
                                                        661
                                                        if x["sgscore1_med"]
                                                        < 0.541416526
                                                        else 662
                                                    )
                                                    if state == 661:
                                                        state = (
                                                            799
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.4484997
                                                            )
                                                            else 800
                                                        )
                                                        if state == 799:
                                                            return -0.142926559
                                                        if state == 800:
                                                            return 0.0682925582
                                                    if state == 662:
                                                        return 0.0944699049
                                                if state == 520:
                                                    return -0.216118127
                                if state == 90:
                                    state = (
                                        159
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.103075027)
                                        else 160
                                    )
                                    if state == 159:
                                        state = (
                                            255
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.558333337)
                                            else 256
                                        )
                                        if state == 255:
                                            state = (
                                                371
                                                if x["neargaia_med"] < 17.0515518
                                                else 372
                                            )
                                            if state == 371:
                                                state = (
                                                    521
                                                    if x["sgscore1_med"] < 0.541080475
                                                    else 522
                                                )
                                                if state == 521:
                                                    return 0.0298718289
                                                if state == 522:
                                                    return -0.125674024
                                            if state == 372:
                                                return 0.263669819
                                        if state == 256:
                                            state = (
                                                373
                                                if x["neargaia_med"] < 15.0451927
                                                else 374
                                            )
                                            if state == 373:
                                                return 0.199569121
                                            if state == 374:
                                                state = (
                                                    523
                                                    if x["sgscore1_med"] < 0.462848008
                                                    else 524
                                                )
                                                if state == 523:
                                                    return -0.414468884
                                                if state == 524:
                                                    state = (
                                                        663
                                                        if x["sgscore1_med"]
                                                        < 1.96783495
                                                        else 664
                                                    )
                                                    if state == 663:
                                                        state = (
                                                            801
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.1990013
                                                            )
                                                            else 802
                                                        )
                                                        if state == 801:
                                                            return 0.0467597991
                                                        if state == 802:
                                                            return -0.137398988
                                                    if state == 664:
                                                        return 0.0259285793
                                    if state == 160:
                                        return 0.478133857
                        if state == 24:
                            state = 49 if x["sgscore1_med"] < 0.0119375 else 50
                            if state == 49:
                                return -0.470236897
                            if state == 50:
                                state = 91 if x["neargaia_med"] < 3.71659899 else 92
                                if state == 91:
                                    return 0.288879246
                                if state == 92:
                                    state = 161 if x["col_det"] < -0.259300232 else 162
                                    if state == 161:
                                        return 0.19771339
                                    if state == 162:
                                        state = (
                                            259
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.837499976)
                                            else 260
                                        )
                                        if state == 259:
                                            state = (
                                                375
                                                if x["neargaia_med"] < 4.74837589
                                                else 376
                                            )
                                            if state == 375:
                                                return -0.0507513247
                                            if state == 376:
                                                return -0.457935691
                                        if state == 260:
                                            state = (
                                                377
                                                if x["neargaia_med"] < 9.1434164
                                                else 378
                                            )
                                            if state == 377:
                                                state = (
                                                    525
                                                    if x["sgscore1_med"] < 0.494827509
                                                    else 526
                                                )
                                                if state == 525:
                                                    state = (
                                                        665
                                                        if x["sgscore1_med"]
                                                        < 0.365990996
                                                        else 666
                                                    )
                                                    if state == 665:
                                                        state = (
                                                            803
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.526001
                                                            )
                                                            else 804
                                                        )
                                                        if state == 803:
                                                            return -0.000024
                                                        if state == 804:
                                                            return -0.300070524
                                                    if state == 666:
                                                        return 0.268076628
                                                if state == 526:
                                                    return -0.425787479
                                            if state == 378:
                                                state = (
                                                    527
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.964318514)
                                                    else 528
                                                )
                                                if state == 527:
                                                    state = (
                                                        667
                                                        if x["sgscore1_med"]
                                                        < 0.655538499
                                                        else 668
                                                    )
                                                    if state == 667:
                                                        state = (
                                                            805
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.6644993
                                                            )
                                                            else 806
                                                        )
                                                        if state == 805:
                                                            return 0.126095921
                                                        if state == 806:
                                                            return -0.268918097
                                                    if state == 668:
                                                        return 0.336521387
                                                if state == 528:
                                                    return -0.260056198
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.470833331)
                            else 26
                        )
                        if state == 25:
                            return -0.246223822
                        if state == 26:
                            state = 51 if x["sgscore1_med"] < 0.00758333504 else 52
                            if state == 51:
                                state = 93 if x["neargaia_med"] < 8.20524788 else 94
                                if state == 93:
                                    state = 163 if x["col_det"] < 0.76800257 else 164
                                    if state == 163:
                                        return -0.302692711
                                    if state == 164:
                                        state = (
                                            261
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.601428628)
                                            else 262
                                        )
                                        if state == 261:
                                            return -0.157153547
                                        if state == 262:
                                            state = (
                                                379
                                                if x["neargaia_med"] < 3.79954624
                                                else 380
                                            )
                                            if state == 379:
                                                return 0.378410667
                                            if state == 380:
                                                return -0.129751399
                                if state == 94:
                                    return 0.421105325
                            if state == 52:
                                state = 95 if x["neargaia_med"] < 5.12551641 else 96
                                if state == 95:
                                    return -0.442626327
                                if state == 96:
                                    state = (
                                        165
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.17387104)
                                        else 166
                                    )
                                    if state == 165:
                                        state = (
                                            263
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.533333182)
                                            else 264
                                        )
                                        if state == 263:
                                            state = (
                                                381
                                                if x["neargaia_med"] < 8.02347851
                                                else 382
                                            )
                                            if state == 381:
                                                return 0.130207226
                                            if state == 382:
                                                return -0.116384253
                                        if state == 264:
                                            state = (
                                                383
                                                if x["neargaia_med"] < 10.8029404
                                                else 384
                                            )
                                            if state == 383:
                                                state = (
                                                    531
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0264583491
                                                    )
                                                    else 532
                                                )
                                                if state == 531:
                                                    return -0.354709536
                                                if state == 532:
                                                    state = (
                                                        669
                                                        if x["sgscore1_med"]
                                                        < 0.529999971
                                                        else 670
                                                    )
                                                    if state == 669:
                                                        state = (
                                                            807
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.7939987
                                                            )
                                                            else 808
                                                        )
                                                        if state == 807:
                                                            return -0.12522161
                                                        if state == 808:
                                                            return 0.0889037549
                                                    if state == 670:
                                                        return 0.295598239
                                            if state == 384:
                                                state = (
                                                    533
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0178125016
                                                    )
                                                    else 534
                                                )
                                                if state == 533:
                                                    return -0.408555806
                                                if state == 534:
                                                    state = (
                                                        671
                                                        if x["sgscore1_med"]
                                                        < 0.742004514
                                                        else 672
                                                    )
                                                    if state == 671:
                                                        state = (
                                                            809
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.5750008
                                                            )
                                                            else 810
                                                        )
                                                        if state == 809:
                                                            return 0.0145939402
                                                        if state == 810:
                                                            return 0.429064363
                                                    if state == 672:
                                                        state = (
                                                            811
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.6520004
                                                            )
                                                            else 812
                                                        )
                                                        if state == 811:
                                                            return 0.311282635
                                                        if state == 812:
                                                            return -0.210961998
                                    if state == 166:
                                        state = (
                                            265
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.675000012)
                                            else 266
                                        )
                                        if state == 265:
                                            state = (
                                                385
                                                if x["neargaia_med"] < 10.9275789
                                                else 386
                                            )
                                            if state == 385:
                                                state = (
                                                    535
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.115943648)
                                                    else 536
                                                )
                                                if state == 535:
                                                    return -0.192409635
                                                if state == 536:
                                                    state = (
                                                        673
                                                        if x["sgscore1_med"]
                                                        < 0.473627985
                                                        else 674
                                                    )
                                                    if state == 673:
                                                        return 0.297391653
                                                    if state == 674:
                                                        state = (
                                                            813
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.2115002
                                                            )
                                                            else 814
                                                        )
                                                        if state == 813:
                                                            return -0.165277883
                                                        if state == 814:
                                                            return 0.217532471
                                            if state == 386:
                                                state = (
                                                    537
                                                    if x["sgscore1_med"] < 0.372775495
                                                    else 538
                                                )
                                                if state == 537:
                                                    return 0.205583528
                                                if state == 538:
                                                    return -0.395729631
                                        if state == 266:
                                            state = (
                                                387
                                                if x["neargaia_med"] < 5.74666882
                                                else 388
                                            )
                                            if state == 387:
                                                return 0.201725051
                                            if state == 388:
                                                return -0.391078562
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.9586401)
                        else 14
                    )
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.769999921)
                            else 28
                        )
                        if state == 27:
                            state = (
                                53
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0164791495)
                                else 54
                            )
                            if state == 53:
                                state = 97 if x["neargaia_med"] < 41.8658981 else 98
                                if state == 97:
                                    state = (
                                        167
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.258739471)
                                        else 168
                                    )
                                    if state == 167:
                                        state = (
                                            267
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.542380929)
                                            else 268
                                        )
                                        if state == 267:
                                            state = (
                                                389
                                                if x["neargaia_med"] < 24.0175819
                                                else 390
                                            )
                                            if state == 389:
                                                state = (
                                                    539
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00183333154
                                                    )
                                                    else 540
                                                )
                                                if state == 539:
                                                    return 0.403016061
                                                if state == 540:
                                                    return -0.10497994
                                            if state == 390:
                                                return -0.226681337
                                        if state == 268:
                                            state = (
                                                391
                                                if x["neargaia_med"] < 37.2924423
                                                else 392
                                            )
                                            if state == 391:
                                                state = (
                                                    541
                                                    if x["sgscore1_med"] < 0.0137291495
                                                    else 542
                                                )
                                                if state == 541:
                                                    state = (
                                                        675
                                                        if x["sgscore1_med"]
                                                        < 0.00145833497
                                                        else 676
                                                    )
                                                    if state == 675:
                                                        return 0.0590384863
                                                    if state == 676:
                                                        state = (
                                                            817
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.9160004
                                                            )
                                                            else 818
                                                        )
                                                        if state == 817:
                                                            return -0.468795031
                                                        if state == 818:
                                                            return -0.026882045
                                                if state == 542:
                                                    return 0.159763724
                                            if state == 392:
                                                return 0.25856185
                                    if state == 168:
                                        state = (
                                            269
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.548333526)
                                            else 270
                                        )
                                        if state == 269:
                                            state = (
                                                393
                                                if x["neargaia_med"] < 23.2582512
                                                else 394
                                            )
                                            if state == 393:
                                                return -0.0892405361
                                            if state == 394:
                                                return 0.253012985
                                        if state == 270:
                                            state = (
                                                395
                                                if x["neargaia_med"] < 29.1862831
                                                else 396
                                            )
                                            if state == 395:
                                                return 0.447784632
                                            if state == 396:
                                                state = (
                                                    545
                                                    if x["sgscore1_med"] < 0.00281249988
                                                    else 546
                                                )
                                                if state == 545:
                                                    return -0.135233849
                                                if state == 546:
                                                    return 0.219022408
                                if state == 98:
                                    state = 169 if x["col_det"] < -0.0502328873 else 170
                                    if state == 169:
                                        return -0.366141677
                                    if state == 170:
                                        state = (
                                            271
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.627499998)
                                            else 272
                                        )
                                        if state == 271:
                                            return -0.271546811
                                        if state == 272:
                                            state = (
                                                397
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 56.2707672)
                                                else 398
                                            )
                                            if state == 397:
                                                state = (
                                                    547
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0077083353
                                                    )
                                                    else 548
                                                )
                                                if state == 547:
                                                    return -0.326916814
                                                if state == 548:
                                                    state = (
                                                        677
                                                        if x["sgscore1_med"]
                                                        < 0.00838988461
                                                        else 678
                                                    )
                                                    if state == 677:
                                                        return 0.173333302
                                                    if state == 678:
                                                        state = (
                                                            819
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.6420002
                                                            )
                                                            else 820
                                                        )
                                                        if state == 819:
                                                            return -0.24101235
                                                        if state == 820:
                                                            return 0.157731622
                                            if state == 398:
                                                return 0.156019256
                            if state == 54:
                                state = 99 if x["neargaia_med"] < 20.5894909 else 100
                                if state == 99:
                                    state = 171 if x["col_det"] < 0.365797043 else 172
                                    if state == 171:
                                        state = (
                                            273
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.636904955)
                                            else 274
                                        )
                                        if state == 273:
                                            return 0.361128807
                                        if state == 274:
                                            return -0.0188902523
                                    if state == 172:
                                        state = (
                                            275
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.606428564)
                                            else 276
                                        )
                                        if state == 275:
                                            state = (
                                                401
                                                if x["neargaia_med"] < 20.1544819
                                                else 402
                                            )
                                            if state == 401:
                                                return -0.562085152
                                            if state == 402:
                                                return -0.0229349285
                                        if state == 276:
                                            state = (
                                                403
                                                if x["neargaia_med"] < 19.3476868
                                                else 404
                                            )
                                            if state == 403:
                                                return 0.278420895
                                            if state == 404:
                                                return -0.391194969
                                if state == 100:
                                    state = 173 if x["col_det"] < -0.207270622 else 174
                                    if state == 173:
                                        state = (
                                            277
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.657500029)
                                            else 278
                                        )
                                        if state == 277:
                                            state = (
                                                405
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 22.3399467)
                                                else 406
                                            )
                                            if state == 405:
                                                return 0.0841163322
                                            if state == 406:
                                                return -0.412810743
                                        if state == 278:
                                            return 0.269652575
                                    if state == 174:
                                        state = (
                                            279
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.573095143)
                                            else 280
                                        )
                                        if state == 279:
                                            state = (
                                                409
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 50.9260788)
                                                else 410
                                            )
                                            if state == 409:
                                                state = (
                                                    551
                                                    if x["sgscore1_med"] < 0.245344996
                                                    else 552
                                                )
                                                if state == 551:
                                                    return 0.352130979
                                                if state == 552:
                                                    state = (
                                                        679
                                                        if x["sgscore1_med"]
                                                        < 0.395208478
                                                        else 680
                                                    )
                                                    if state == 679:
                                                        return -0.22495237
                                                    if state == 680:
                                                        state = (
                                                            821
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.3192501
                                                            )
                                                            else 822
                                                        )
                                                        if state == 821:
                                                            return -0.100957945
                                                        if state == 822:
                                                            return 0.264086008
                                            if state == 410:
                                                state = (
                                                    553
                                                    if x["sgscore1_med"] < 0.198247001
                                                    else 554
                                                )
                                                if state == 553:
                                                    state = (
                                                        681
                                                        if x["sgscore1_med"]
                                                        < 0.084035702
                                                        else 682
                                                    )
                                                    if state == 681:
                                                        return -0.120451987
                                                    if state == 682:
                                                        return 0.104868561
                                                if state == 554:
                                                    return -0.18252942
                                        if state == 280:
                                            state = (
                                                411
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 45.4714127)
                                                else 412
                                            )
                                            if state == 411:
                                                state = (
                                                    555
                                                    if x["sgscore1_med"] < 0.0879881009
                                                    else 556
                                                )
                                                if state == 555:
                                                    state = (
                                                        683
                                                        if x["sgscore1_med"]
                                                        < 0.04701785
                                                        else 684
                                                    )
                                                    if state == 683:
                                                        state = (
                                                            823
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 17.8037491
                                                            )
                                                            else 824
                                                        )
                                                        if state == 823:
                                                            return 0.0100725582
                                                        if state == 824:
                                                            return 0.329440624
                                                    if state == 684:
                                                        return -0.305881917
                                                if state == 556:
                                                    state = (
                                                        685
                                                        if x["sgscore1_med"]
                                                        < 0.0921220481
                                                        else 686
                                                    )
                                                    if state == 685:
                                                        return 0.727725923
                                                    if state == 686:
                                                        state = (
                                                            825
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.5079994
                                                            )
                                                            else 826
                                                        )
                                                        if state == 825:
                                                            return 0.194836542
                                                        if state == 826:
                                                            return 0.422518849
                                            if state == 412:
                                                state = (
                                                    557
                                                    if x["sgscore1_med"] < 0.170023501
                                                    else 558
                                                )
                                                if state == 557:
                                                    state = (
                                                        687
                                                        if x["sgscore1_med"]
                                                        < 0.164342001
                                                        else 688
                                                    )
                                                    if state == 687:
                                                        state = (
                                                            827
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.2045002
                                                            )
                                                            else 828
                                                        )
                                                        if state == 827:
                                                            return 0.228369772
                                                        if state == 828:
                                                            return -0.183147073
                                                    if state == 688:
                                                        return -0.50936234
                                                if state == 558:
                                                    return 0.282450527
                        if state == 28:
                            state = (
                                55
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.483624995)
                                else 56
                            )
                            if state == 55:
                                state = (
                                    101
                                    if np.isnan(x["neargaia_med"])
                                    or (x["neargaia_med"] < 35.5394287)
                                    else 102
                                )
                                if state == 101:
                                    state = 175 if x["col_det"] < 0.235720634 else 176
                                    if state == 175:
                                        state = (
                                            281
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.943571448)
                                            else 282
                                        )
                                        if state == 281:
                                            state = (
                                                413
                                                if x["neargaia_med"] < 21.3727493
                                                else 414
                                            )
                                            if state == 413:
                                                return 0.117877163
                                            if state == 414:
                                                return -0.399383068
                                        if state == 282:
                                            state = (
                                                415
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 33.7516403)
                                                else 416
                                            )
                                            if state == 415:
                                                state = (
                                                    559
                                                    if x["sgscore1_med"] < 0.0208749995
                                                    else 560
                                                )
                                                if state == 559:
                                                    return -0.199202821
                                                if state == 560:
                                                    return 0.260167599
                                            if state == 416:
                                                return -0.228106931
                                    if state == 176:
                                        state = (
                                            283
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.896785617)
                                            else 284
                                        )
                                        if state == 283:
                                            state = (
                                                417
                                                if x["neargaia_med"] < 21.7077312
                                                else 418
                                            )
                                            if state == 417:
                                                return 0.0930540189
                                            if state == 418:
                                                state = (
                                                    561
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.177483395)
                                                    else 562
                                                )
                                                if state == 561:
                                                    return -0.323414773
                                                if state == 562:
                                                    return 0.0863345936
                                        if state == 284:
                                            state = (
                                                419
                                                if x["neargaia_med"] < 29.1106529
                                                else 420
                                            )
                                            if state == 419:
                                                state = (
                                                    563
                                                    if x["sgscore1_med"] < 0.0615565553
                                                    else 564
                                                )
                                                if state == 563:
                                                    state = (
                                                        689
                                                        if x["sgscore1_med"]
                                                        < 0.00499999989
                                                        else 690
                                                    )
                                                    if state == 689:
                                                        return -0.0820171088
                                                    if state == 690:
                                                        return 0.236597821
                                                if state == 564:
                                                    return -0.19910112
                                            if state == 420:
                                                return 0.306977808
                                if state == 102:
                                    state = (
                                        177
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.00220870972)
                                        else 178
                                    )
                                    if state == 177:
                                        state = (
                                            285
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.937856913)
                                            else 286
                                        )
                                        if state == 285:
                                            state = (
                                                421
                                                if x["neargaia_med"] < 36.859684
                                                else 422
                                            )
                                            if state == 421:
                                                return 0.242925793
                                            if state == 422:
                                                state = (
                                                    565
                                                    if x["sgscore1_med"] < 0.44847697
                                                    else 566
                                                )
                                                if state == 565:
                                                    state = (
                                                        691
                                                        if x["sgscore1_med"]
                                                        < 0.0339166522
                                                        else 692
                                                    )
                                                    if state == 691:
                                                        state = (
                                                            829
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.2915001
                                                            )
                                                            else 830
                                                        )
                                                        if state == 829:
                                                            return 0.0759195313
                                                        if state == 830:
                                                            return -0.178184569
                                                    if state == 692:
                                                        return -0.335152566
                                                if state == 566:
                                                    return 0.246089116
                                        if state == 286:
                                            return -0.149628296
                                    if state == 178:
                                        state = (
                                            287
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.811071455)
                                            else 288
                                        )
                                        if state == 287:
                                            return 0.0595135763
                                        if state == 288:
                                            return 0.363241822
                            if state == 56:
                                state = 103 if x["neargaia_med"] < 30.3080635 else 104
                                if state == 103:
                                    state = (
                                        179
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.1477108)
                                        else 180
                                    )
                                    if state == 179:
                                        state = (
                                            289
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.920714378)
                                            else 290
                                        )
                                        if state == 289:
                                            state = (
                                                425
                                                if x["neargaia_med"] < 20.3797379
                                                else 426
                                            )
                                            if state == 425:
                                                return 0.0276547465
                                            if state == 426:
                                                return -0.575134039
                                        if state == 290:
                                            state = (
                                                427
                                                if x["neargaia_med"] < 24.0189457
                                                else 428
                                            )
                                            if state == 427:
                                                return -0.245661736
                                            if state == 428:
                                                return 0.153190523
                                    if state == 180:
                                        return 0.120282881
                                if state == 104:
                                    state = 181 if x["col_det"] < 0.113617942 else 182
                                    if state == 181:
                                        state = (
                                            291
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.879642963)
                                            else 292
                                        )
                                        if state == 291:
                                            return -0.0341873132
                                        if state == 292:
                                            return 0.203229129
                                    if state == 182:
                                        state = (
                                            293
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.910714269)
                                            else 294
                                        )
                                        if state == 293:
                                            state = (
                                                429
                                                if x["neargaia_med"] < 120.812782
                                                else 430
                                            )
                                            if state == 429:
                                                return -0.428436249
                                            if state == 430:
                                                return 0.0611328483
                                        if state == 294:
                                            return 0.201448008
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.257500231)
                            else 30
                        )
                        if state == 29:
                            state = (
                                57
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0070208353)
                                else 58
                            )
                            if state == 57:
                                return 0.0394467153
                            if state == 58:
                                return -0.323952794
                        if state == 30:
                            state = 59 if x["sgscore1_med"] < 0.094827354 else 60
                            if state == 59:
                                state = 105 if x["neargaia_med"] < 76.4273682 else 106
                                if state == 105:
                                    state = 183 if x["col_det"] < -0.261349678 else 184
                                    if state == 183:
                                        state = (
                                            295
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.646428585)
                                            else 296
                                        )
                                        if state == 295:
                                            return 0.0246988274
                                        if state == 296:
                                            state = (
                                                433
                                                if x["neargaia_med"] < 46.0332489
                                                else 434
                                            )
                                            if state == 433:
                                                return 0.244915724
                                            if state == 434:
                                                return -0.0694065243
                                    if state == 184:
                                        state = (
                                            297
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.798214197)
                                            else 298
                                        )
                                        if state == 297:
                                            state = (
                                                435
                                                if x["neargaia_med"] < 21.0207767
                                                else 436
                                            )
                                            if state == 435:
                                                state = (
                                                    567
                                                    if x["sgscore1_med"] < 0.00181249995
                                                    else 568
                                                )
                                                if state == 567:
                                                    return 0.220128074
                                                if state == 568:
                                                    state = (
                                                        693
                                                        if x["sgscore1_med"]
                                                        < 0.01260415
                                                        else 694
                                                    )
                                                    if state == 693:
                                                        return -0.222539723
                                                    if state == 694:
                                                        return 0.206499502
                                            if state == 436:
                                                state = (
                                                    569
                                                    if x["sgscore1_med"] < 0.0163124986
                                                    else 570
                                                )
                                                if state == 569:
                                                    state = (
                                                        695
                                                        if x["sgscore1_med"]
                                                        < 0.0151518006
                                                        else 696
                                                    )
                                                    if state == 695:
                                                        state = (
                                                            831
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.9000015
                                                            )
                                                            else 832
                                                        )
                                                        if state == 831:
                                                            return -0.305654675
                                                        if state == 832:
                                                            return 0.0270377025
                                                    if state == 696:
                                                        return 0.287477285
                                                if state == 570:
                                                    state = (
                                                        697
                                                        if x["sgscore1_med"]
                                                        < 0.0903154463
                                                        else 698
                                                    )
                                                    if state == 697:
                                                        state = (
                                                            833
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.1824989
                                                            )
                                                            else 834
                                                        )
                                                        if state == 833:
                                                            return -0.0546102114
                                                        if state == 834:
                                                            return -0.383876055
                                                    if state == 698:
                                                        return -0.723188996
                                        if state == 298:
                                            state = (
                                                437
                                                if x["neargaia_med"] < 22.9004478
                                                else 438
                                            )
                                            if state == 437:
                                                state = (
                                                    571
                                                    if x["sgscore1_med"] < 0.0542708002
                                                    else 572
                                                )
                                                if state == 571:
                                                    return -0.472373724
                                                if state == 572:
                                                    return 0.0484582782
                                            if state == 438:
                                                state = (
                                                    573
                                                    if x["sgscore1_med"] < 0.0318749994
                                                    else 574
                                                )
                                                if state == 573:
                                                    state = (
                                                        699
                                                        if x["sgscore1_med"]
                                                        < 0.00270833494
                                                        else 700
                                                    )
                                                    if state == 699:
                                                        return -0.114561647
                                                    if state == 700:
                                                        state = (
                                                            835
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.9075012
                                                            )
                                                            else 836
                                                        )
                                                        if state == 835:
                                                            return 0.355968535
                                                        if state == 836:
                                                            return -0.0825119242
                                                if state == 574:
                                                    state = (
                                                        701
                                                        if x["sgscore1_med"]
                                                        < 0.0539821498
                                                        else 702
                                                    )
                                                    if state == 701:
                                                        return -0.344597936
                                                    if state == 702:
                                                        state = (
                                                            837
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.4055004
                                                            )
                                                            else 838
                                                        )
                                                        if state == 837:
                                                            return -0.203995794
                                                        if state == 838:
                                                            return 0.217673197
                                if state == 106:
                                    state = 185 if x["col_det"] < -0.395448685 else 186
                                    if state == 185:
                                        return -0.261124253
                                    if state == 186:
                                        return 0.298025012
                            if state == 60:
                                state = 107 if x["neargaia_med"] < 34.5356445 else 108
                                if state == 107:
                                    state = (
                                        187
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.0103867855)
                                        else 188
                                    )
                                    if state == 187:
                                        state = (
                                            299
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.670000196)
                                            else 300
                                        )
                                        if state == 299:
                                            state = (
                                                439
                                                if x["neargaia_med"] < 27.0470657
                                                else 440
                                            )
                                            if state == 439:
                                                state = (
                                                    575
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.906574965)
                                                    else 576
                                                )
                                                if state == 575:
                                                    state = (
                                                        703
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.108377993
                                                        )
                                                        else 704
                                                    )
                                                    if state == 703:
                                                        state = (
                                                            839
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.9209995
                                                            )
                                                            else 840
                                                        )
                                                        if state == 839:
                                                            return -0.101025417
                                                        if state == 840:
                                                            return 0.105040051
                                                    if state == 704:
                                                        return 0.251822799
                                                if state == 576:
                                                    return -0.176092878
                                            if state == 440:
                                                state = (
                                                    577
                                                    if x["sgscore1_med"] < 0.54253149
                                                    else 578
                                                )
                                                if state == 577:
                                                    state = (
                                                        705
                                                        if x["sgscore1_med"]
                                                        < 0.462199509
                                                        else 706
                                                    )
                                                    if state == 705:
                                                        return 0.182744876
                                                    if state == 706:
                                                        state = (
                                                            841
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.3435001
                                                            )
                                                            else 842
                                                        )
                                                        if state == 841:
                                                            return -0.141521677
                                                        if state == 842:
                                                            return 0.157931373
                                                if state == 578:
                                                    return 0.378103405
                                        if state == 300:
                                            state = (
                                                441
                                                if x["neargaia_med"] < 18.2787971
                                                else 442
                                            )
                                            if state == 441:
                                                return -0.189497426
                                            if state == 442:
                                                state = (
                                                    579
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.30390048)
                                                    else 580
                                                )
                                                if state == 579:
                                                    return -0.0418840908
                                                if state == 580:
                                                    return 0.183919027
                                    if state == 188:
                                        state = (
                                            301
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.69392848)
                                            else 302
                                        )
                                        if state == 301:
                                            state = (
                                                443
                                                if x["neargaia_med"] < 18.6431046
                                                else 444
                                            )
                                            if state == 443:
                                                return 0.18287766
                                            if state == 444:
                                                return -0.311872393
                                        if state == 302:
                                            return 0.161559612
                                if state == 108:
                                    state = (
                                        189
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.0382490158)
                                        else 190
                                    )
                                    if state == 189:
                                        state = (
                                            303
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.629285693)
                                            else 304
                                        )
                                        if state == 303:
                                            state = (
                                                445
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 49.6756287)
                                                else 446
                                            )
                                            if state == 445:
                                                state = (
                                                    581
                                                    if x["sgscore1_med"] < 0.519338965
                                                    else 582
                                                )
                                                if state == 581:
                                                    state = (
                                                        707
                                                        if x["sgscore1_med"]
                                                        < 0.134407997
                                                        else 708
                                                    )
                                                    if state == 707:
                                                        return 0.00462457305
                                                    if state == 708:
                                                        state = (
                                                            843
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 22.5125008
                                                            )
                                                            else 844
                                                        )
                                                        if state == 843:
                                                            return 0.247132346
                                                        if state == 844:
                                                            return -0.210652962
                                                if state == 582:
                                                    state = (
                                                        709
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.634258986
                                                        )
                                                        else 710
                                                    )
                                                    if state == 709:
                                                        state = (
                                                            845
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.1072502
                                                            )
                                                            else 846
                                                        )
                                                        if state == 845:
                                                            return 0.134385839
                                                        if state == 846:
                                                            return -0.189816549
                                                    if state == 710:
                                                        return 0.185847446
                                            if state == 446:
                                                state = (
                                                    583
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.388401985)
                                                    else 584
                                                )
                                                if state == 583:
                                                    return 0.196494266
                                                if state == 584:
                                                    return -0.430539548
                                        if state == 304:
                                            state = (
                                                447
                                                if x["neargaia_med"] < 48.8372498
                                                else 448
                                            )
                                            if state == 447:
                                                state = (
                                                    585
                                                    if x["sgscore1_med"] < 0.394455492
                                                    else 586
                                                )
                                                if state == 585:
                                                    state = (
                                                        711
                                                        if x["sgscore1_med"]
                                                        < 0.217196494
                                                        else 712
                                                    )
                                                    if state == 711:
                                                        return 0.0605456755
                                                    if state == 712:
                                                        return -0.117760666
                                                if state == 586:
                                                    return 0.112997167
                                            if state == 448:
                                                state = (
                                                    587
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.179508999)
                                                    else 588
                                                )
                                                if state == 587:
                                                    state = (
                                                        713
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.159267992
                                                        )
                                                        else 714
                                                    )
                                                    if state == 713:
                                                        return 0.238447919
                                                    if state == 714:
                                                        return -0.292307556
                                                if state == 588:
                                                    return 0.333706468
                                    if state == 190:
                                        return -0.454342753
    elif num_booster == 16:
        state = 0
        if state == 0:
            state = 1 if x["col_last"] < -0.126642227 else 2
            if state == 1:
                state = 3 if x["mag_peak"] < 17.3767815 else 4
                if state == 3:
                    return -0.272338092
                if state == 4:
                    state = 9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 11.0428181) else 10
                    if state == 9:
                        state = 17 if x["col_last"] < -0.351015091 else 18
                        if state == 17:
                            return -0.187359303
                        if state == 18:
                            state = (
                                31
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.6205997)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    49
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.76447773)
                                    else 50
                                )
                                if state == 49:
                                    return 0.228154376
                                if state == 50:
                                    state = 73 if x["col_last"] < -0.244660854 else 74
                                    if state == 73:
                                        state = (
                                            103 if x["col_last"] < -0.338608116 else 104
                                        )
                                        if state == 103:
                                            return 0.0799345002
                                        if state == 104:
                                            return -0.129179195
                                    if state == 74:
                                        state = (
                                            105 if x["col_last"] < -0.188562393 else 106
                                        )
                                        if state == 105:
                                            return 0.183882222
                                        if state == 106:
                                            return -0.0086058192
                            if state == 32:
                                state = (
                                    51
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 2.49942756)
                                    else 52
                                )
                                if state == 51:
                                    return -0.189883575
                                if state == 52:
                                    state = 75 if x["col_last"] < -0.13983345 else 76
                                    if state == 75:
                                        return 0.0366949365
                                    if state == 76:
                                        return -0.148650065
                    if state == 10:
                        state = 19 if x["col_last"] < -0.820677757 else 20
                        if state == 19:
                            return 0.149595916
                        if state == 20:
                            state = (
                                33
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.427)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    53
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.163137585)
                                    else 54
                                )
                                if state == 53:
                                    return 0.0927007422
                                if state == 54:
                                    state = 79 if x["col_last"] < -0.139871597 else 80
                                    if state == 79:
                                        return -0.259136617
                                    if state == 80:
                                        state = (
                                            109 if x["col_last"] < -0.135485977 else 110
                                        )
                                        if state == 109:
                                            return 0.26987195
                                        if state == 110:
                                            return -0.254844517
                            if state == 34:
                                state = (
                                    55
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.370399565)
                                    else 56
                                )
                                if state == 55:
                                    return -0.203911752
                                if state == 56:
                                    state = 81 if x["col_last"] < -0.186356544 else 82
                                    if state == 81:
                                        state = (
                                            111 if x["col_last"] < -0.216183662 else 112
                                        )
                                        if state == 111:
                                            state = (
                                                143
                                                if x["col_peak"] < -0.125665665
                                                else 144
                                            )
                                            if state == 143:
                                                return 0.141055018
                                            if state == 144:
                                                return -0.080766432
                                        if state == 112:
                                            return 0.144280612
                                    if state == 82:
                                        return -0.0725767836
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.9933681) else 6
                )
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 20.9145317) else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["col_last"]) or (x["col_last"] < 0.768351555)
                            else 22
                        )
                        if state == 21:
                            state = (
                                35
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.9268494)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    57
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 2.62078953)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        83
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.0802836418)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            115
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < -0.0511636734)
                                            else 116
                                        )
                                        if state == 115:
                                            state = (
                                                145
                                                if x["col_peak"] < 1.31914997
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    185
                                                    if x["distpsnr1_med"] < 2.34087706
                                                    else 186
                                                )
                                                if state == 185:
                                                    return -0.204345852
                                                if state == 186:
                                                    return 0.0369665027
                                            if state == 146:
                                                state = (
                                                    187
                                                    if x["distpsnr1_med"] < 2.0395298
                                                    else 188
                                                )
                                                if state == 187:
                                                    return -0.126778424
                                                if state == 188:
                                                    return 0.171370551
                                        if state == 116:
                                            state = (
                                                147
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.162352085)
                                                else 148
                                            )
                                            if state == 147:
                                                return 0.113060243
                                            if state == 148:
                                                return -0.0640595481
                                    if state == 84:
                                        return -0.165823847
                                if state == 58:
                                    return -0.264648825
                            if state == 36:
                                state = (
                                    59
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 2.21675158)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        85
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.4376297)
                                        else 86
                                    )
                                    if state == 85:
                                        state = (
                                            117
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.350072861)
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                149
                                                if x["col_peak"] < 0.0848855972
                                                else 150
                                            )
                                            if state == 149:
                                                state = (
                                                    189
                                                    if x["distpsnr1_med"] < 1.5068121
                                                    else 190
                                                )
                                                if state == 189:
                                                    state = (
                                                        239
                                                        if x["col_peak"] < -0.207936287
                                                        else 240
                                                    )
                                                    if state == 239:
                                                        state = (
                                                            295
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 15.9154911)
                                                            else 296
                                                        )
                                                        if state == 295:
                                                            return 0.064050287
                                                        if state == 296:
                                                            return -0.165065095
                                                    if state == 240:
                                                        state = (
                                                            297
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 15.0570889)
                                                            else 298
                                                        )
                                                        if state == 297:
                                                            return 0.103150502
                                                        if state == 298:
                                                            return 0.307037055
                                                if state == 190:
                                                    state = (
                                                        241
                                                        if x["col_peak"] < 0.0385255814
                                                        else 242
                                                    )
                                                    if state == 241:
                                                        state = (
                                                            299
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 16.8352146)
                                                            else 300
                                                        )
                                                        if state == 299:
                                                            return 0.0402519442
                                                        if state == 300:
                                                            return -0.0876890495
                                                    if state == 242:
                                                        return 0.231368482
                                            if state == 150:
                                                state = (
                                                    191
                                                    if x["distpsnr1_med"] < 1.99198151
                                                    else 192
                                                )
                                                if state == 191:
                                                    state = (
                                                        243
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.383770943)
                                                        else 244
                                                    )
                                                    if state == 243:
                                                        state = (
                                                            301
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 14.9992542)
                                                            else 302
                                                        )
                                                        if state == 301:
                                                            return 0.00843194872
                                                        if state == 302:
                                                            return -0.0728719831
                                                    if state == 244:
                                                        state = (
                                                            303
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 14.9424076)
                                                            else 304
                                                        )
                                                        if state == 303:
                                                            return 0.0332201011
                                                        if state == 304:
                                                            return 0.209524244
                                                if state == 192:
                                                    state = (
                                                        245
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.196604252)
                                                        else 246
                                                    )
                                                    if state == 245:
                                                        state = (
                                                            305
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 9.00017929)
                                                            else 306
                                                        )
                                                        if state == 305:
                                                            return 0.29233861
                                                        if state == 306:
                                                            return 0.102771945
                                                    if state == 246:
                                                        return -0.0834729075
                                        if state == 118:
                                            return 0.230259597
                                    if state == 86:
                                        state = (
                                            119 if x["col_last"] < 0.584944725 else 120
                                        )
                                        if state == 119:
                                            state = (
                                                151
                                                if x["col_peak"] < 0.349699497
                                                else 152
                                            )
                                            if state == 151:
                                                return 0.104300104
                                            if state == 152:
                                                state = (
                                                    193
                                                    if x["distpsnr1_med"] < 0.277399182
                                                    else 194
                                                )
                                                if state == 193:
                                                    return 0.0445727743
                                                if state == 194:
                                                    return -0.2594558
                                        if state == 120:
                                            return 0.0308175534
                                if state == 60:
                                    state = 87 if x["col_last"] < -0.0242061615 else 88
                                    if state == 87:
                                        state = (
                                            121
                                            if x["col_last"] < -0.0291290283
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                155
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.171809196)
                                                else 156
                                            )
                                            if state == 155:
                                                state = (
                                                    197
                                                    if x["distpsnr1_med"] < 6.74024582
                                                    else 198
                                                )
                                                if state == 197:
                                                    state = (
                                                        247
                                                        if x["col_peak"] < -0.198328495
                                                        else 248
                                                    )
                                                    if state == 247:
                                                        return 0.0255187806
                                                    if state == 248:
                                                        state = (
                                                            309
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 17.9791336)
                                                            else 310
                                                        )
                                                        if state == 309:
                                                            return -0.167135581
                                                        if state == 310:
                                                            return 0.122374415
                                                if state == 198:
                                                    return 0.158770353
                                            if state == 156:
                                                state = (
                                                    199
                                                    if x["distpsnr1_med"] < 3.82119417
                                                    else 200
                                                )
                                                if state == 199:
                                                    return 0.157329455
                                                if state == 200:
                                                    return -0.0329397209
                                        if state == 122:
                                            return 0.288675338
                                    if state == 88:
                                        state = (
                                            123
                                            if x["col_last"] < -0.00358772278
                                            else 124
                                        )
                                        if state == 123:
                                            return -0.28684032
                                        if state == 124:
                                            state = (
                                                157
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.290036201)
                                                else 158
                                            )
                                            if state == 157:
                                                state = (
                                                    201
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 9.06147385)
                                                    else 202
                                                )
                                                if state == 201:
                                                    state = (
                                                        249
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"] < 0.0540218353
                                                        )
                                                        else 250
                                                    )
                                                    if state == 249:
                                                        state = (
                                                            311
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 9.95847225)
                                                            else 312
                                                        )
                                                        if state == 311:
                                                            return -0.0276509542
                                                        if state == 312:
                                                            return -0.141443327
                                                    if state == 250:
                                                        state = (
                                                            313
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 11.9660645)
                                                            else 314
                                                        )
                                                        if state == 313:
                                                            return -0.0262711998
                                                        if state == 314:
                                                            return -0.387304932
                                                if state == 202:
                                                    state = (
                                                        251
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"]
                                                            < -0.0445785522
                                                        )
                                                        else 252
                                                    )
                                                    if state == 251:
                                                        state = (
                                                            315
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 9.06172466)
                                                            else 316
                                                        )
                                                        if state == 315:
                                                            return 0.00358434906
                                                        if state == 316:
                                                            return 0.224770457
                                                    if state == 252:
                                                        return -0.0196942668
                                            if state == 158:
                                                return 0.24439387
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4977989)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    61
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.14398706)
                                    else 62
                                )
                                if state == 61:
                                    state = 89 if x["col_last"] < 0.874797821 else 90
                                    if state == 89:
                                        return 0.0739911273
                                    if state == 90:
                                        return -0.0899491087
                                if state == 62:
                                    state = 91 if x["col_last"] < 1.36377478 else 92
                                    if state == 91:
                                        return 0.299137741
                                    if state == 92:
                                        return 0.000566202565
                            if state == 38:
                                return -0.169482484
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["col_last"]) or (x["col_last"] < 1.33204174)
                            else 24
                        )
                        if state == 23:
                            state = (
                                39
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3049507)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    63
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.243016019)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        93
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.364944458)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            125 if x["col_last"] < 0.726922095 else 126
                                        )
                                        if state == 125:
                                            return -0.221207246
                                        if state == 126:
                                            state = (
                                                159
                                                if x["col_peak"] < -0.0875911713
                                                else 160
                                            )
                                            if state == 159:
                                                state = (
                                                    203
                                                    if x["distpsnr1_med"] < 0.0462844223
                                                    else 204
                                                )
                                                if state == 203:
                                                    return 0.289764404
                                                if state == 204:
                                                    state = (
                                                        253
                                                        if x["col_peak"] < -0.152586132
                                                        else 254
                                                    )
                                                    if state == 253:
                                                        return -0.095618479
                                                    if state == 254:
                                                        state = (
                                                            319
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 26.0065041)
                                                            else 320
                                                        )
                                                        if state == 319:
                                                            return -0.0636337548
                                                        if state == 320:
                                                            return 0.178557843
                                            if state == 160:
                                                state = (
                                                    205
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (
                                                        x["distpsnr1_med"] < 0.273739308
                                                    )
                                                    else 206
                                                )
                                                if state == 205:
                                                    state = (
                                                        255
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.968187332)
                                                        else 256
                                                    )
                                                    if state == 255:
                                                        state = (
                                                            321
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 34.9723549)
                                                            else 322
                                                        )
                                                        if state == 321:
                                                            return -0.130789146
                                                        if state == 322:
                                                            return -0.309980333
                                                    if state == 256:
                                                        return 0.155363604
                                                if state == 206:
                                                    return 0.237830967
                                    if state == 94:
                                        state = (
                                            127 if x["col_last"] < 0.455515862 else 128
                                        )
                                        if state == 127:
                                            return 0.21677044
                                        if state == 128:
                                            state = (
                                                161
                                                if x["col_peak"] < 0.222221375
                                                else 162
                                            )
                                            if state == 161:
                                                return -0.143207818
                                            if state == 162:
                                                state = (
                                                    207
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (
                                                        x["distpsnr1_med"] < 0.117142618
                                                    )
                                                    else 208
                                                )
                                                if state == 207:
                                                    return -0.103854999
                                                if state == 208:
                                                    return 0.14031902
                                if state == 64:
                                    state = 95 if x["col_last"] < 0.734443188 else 96
                                    if state == 95:
                                        state = (
                                            129 if x["col_last"] < 0.641820908 else 130
                                        )
                                        if state == 129:
                                            state = (
                                                163
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.0462870598)
                                                else 164
                                            )
                                            if state == 163:
                                                state = (
                                                    209
                                                    if x["distpsnr1_med"] < 14.1920776
                                                    else 210
                                                )
                                                if state == 209:
                                                    state = (
                                                        259
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"] < -0.164498329
                                                        )
                                                        else 260
                                                    )
                                                    if state == 259:
                                                        state = (
                                                            323
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 27.9819908)
                                                            else 324
                                                        )
                                                        if state == 323:
                                                            return 0.126141131
                                                        if state == 324:
                                                            return 0.00931629073
                                                    if state == 260:
                                                        state = (
                                                            325
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 22.8138485)
                                                            else 326
                                                        )
                                                        if state == 325:
                                                            return 0.0306289513
                                                        if state == 326:
                                                            return 0.246677697
                                                if state == 210:
                                                    return 0.295049012
                                            if state == 164:
                                                state = (
                                                    211
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 3.9507308)
                                                    else 212
                                                )
                                                if state == 211:
                                                    state = (
                                                        261
                                                        if x["col_peak"] < 0.0869693756
                                                        else 262
                                                    )
                                                    if state == 261:
                                                        return -0.234227836
                                                    if state == 262:
                                                        state = (
                                                            329
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 22.0241375)
                                                            else 330
                                                        )
                                                        if state == 329:
                                                            return 0.122927643
                                                        if state == 330:
                                                            return -0.064119406
                                                if state == 212:
                                                    state = (
                                                        263
                                                        if x["col_peak"] < 0.0830221176
                                                        else 264
                                                    )
                                                    if state == 263:
                                                        return -0.190008193
                                                    if state == 264:
                                                        return 0.224946499
                                        if state == 130:
                                            state = (
                                                165
                                                if x["col_peak"] < 0.458106041
                                                else 166
                                            )
                                            if state == 165:
                                                state = (
                                                    213
                                                    if x["distpsnr1_med"] < 7.00496387
                                                    else 214
                                                )
                                                if state == 213:
                                                    return 0.288342267
                                                if state == 214:
                                                    state = (
                                                        265
                                                        if x["col_peak"] < -0.0845031738
                                                        else 266
                                                    )
                                                    if state == 265:
                                                        return -0.0791323036
                                                    if state == 266:
                                                        return 0.169825956
                                            if state == 166:
                                                state = (
                                                    215
                                                    if x["distpsnr1_med"] < 3.0873239
                                                    else 216
                                                )
                                                if state == 215:
                                                    return 0.168674737
                                                if state == 216:
                                                    return -0.13626717
                                    if state == 96:
                                        state = (
                                            131 if x["col_last"] < 1.05345964 else 132
                                        )
                                        if state == 131:
                                            state = (
                                                167
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.0662045479)
                                                else 168
                                            )
                                            if state == 167:
                                                state = (
                                                    217
                                                    if x["distpsnr1_med"] < 3.00527143
                                                    else 218
                                                )
                                                if state == 217:
                                                    state = (
                                                        267
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"]
                                                            < -0.0892877579
                                                        )
                                                        else 268
                                                    )
                                                    if state == 267:
                                                        state = (
                                                            331
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 49.4367523)
                                                            else 332
                                                        )
                                                        if state == 331:
                                                            return -0.151671767
                                                        if state == 332:
                                                            return 0.18028532
                                                    if state == 268:
                                                        return 0.164290339
                                                if state == 218:
                                                    state = (
                                                        269
                                                        if x["col_peak"] < -0.130356789
                                                        else 270
                                                    )
                                                    if state == 269:
                                                        return 0.0438595302
                                                    if state == 270:
                                                        state = (
                                                            335
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 48.4895363)
                                                            else 336
                                                        )
                                                        if state == 335:
                                                            return 0.25565663
                                                        if state == 336:
                                                            return 0.0319462381
                                            if state == 168:
                                                state = (
                                                    219
                                                    if x["distpsnr1_med"] < 1.11120129
                                                    else 220
                                                )
                                                if state == 219:
                                                    return 0.165183604
                                                if state == 220:
                                                    state = (
                                                        273
                                                        if x["col_peak"] < 0.130854607
                                                        else 274
                                                    )
                                                    if state == 273:
                                                        state = (
                                                            337
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 34.0592194)
                                                            else 338
                                                        )
                                                        if state == 337:
                                                            return -0.422534823
                                                        if state == 338:
                                                            return -0.0302794445
                                                    if state == 274:
                                                        state = (
                                                            339
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 31.9327011)
                                                            else 340
                                                        )
                                                        if state == 339:
                                                            return -0.158795983
                                                        if state == 340:
                                                            return 0.120513797
                                        if state == 132:
                                            state = (
                                                169
                                                if x["col_peak"] < 0.0462870598
                                                else 170
                                            )
                                            if state == 169:
                                                state = (
                                                    221
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 6.95038319)
                                                    else 222
                                                )
                                                if state == 221:
                                                    state = (
                                                        275
                                                        if x["col_peak"] < -0.453751564
                                                        else 276
                                                    )
                                                    if state == 275:
                                                        return -0.135813832
                                                    if state == 276:
                                                        state = (
                                                            341
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 41.892128)
                                                            else 342
                                                        )
                                                        if state == 341:
                                                            return 0.0859402493
                                                        if state == 342:
                                                            return 0.292527437
                                                if state == 222:
                                                    state = (
                                                        277
                                                        if x["col_peak"] < -0.0529251099
                                                        else 278
                                                    )
                                                    if state == 277:
                                                        state = (
                                                            343
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 39.8017731)
                                                            else 344
                                                        )
                                                        if state == 343:
                                                            return -0.137374863
                                                        if state == 344:
                                                            return 0.128084928
                                                    if state == 278:
                                                        return 0.265188187
                                            if state == 170:
                                                state = (
                                                    223
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 1.3870877)
                                                    else 224
                                                )
                                                if state == 223:
                                                    state = (
                                                        279
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.382285118)
                                                        else 280
                                                    )
                                                    if state == 279:
                                                        state = (
                                                            345
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 70.9518967)
                                                            else 346
                                                        )
                                                        if state == 345:
                                                            return 0.106937394
                                                        if state == 346:
                                                            return -0.0445118435
                                                    if state == 280:
                                                        state = (
                                                            347
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 49.8951035)
                                                            else 348
                                                        )
                                                        if state == 347:
                                                            return 0.262916625
                                                        if state == 348:
                                                            return 0.0434582382
                                                if state == 224:
                                                    state = (
                                                        281
                                                        if x["col_peak"] < 0.063688755
                                                        else 282
                                                    )
                                                    if state == 281:
                                                        return -0.385473192
                                                    if state == 282:
                                                        state = (
                                                            349
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 48.899334)
                                                            else 350
                                                        )
                                                        if state == 349:
                                                            return -0.00355361868
                                                        if state == 350:
                                                            return 0.108384892
                            if state == 40:
                                state = (
                                    65
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.453059793)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        97
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.0230941772)
                                        else 98
                                    )
                                    if state == 97:
                                        state = (
                                            133
                                            if x["col_last"] < 0.00454998016
                                            else 134
                                        )
                                        if state == 133:
                                            return -0.0207813587
                                        if state == 134:
                                            state = (
                                                171
                                                if x["col_peak"] < -0.06808424
                                                else 172
                                            )
                                            if state == 171:
                                                return 0.202316955
                                            if state == 172:
                                                state = (
                                                    225
                                                    if x["distpsnr1_med"] < 0.0989212543
                                                    else 226
                                                )
                                                if state == 225:
                                                    return 0.0700400323
                                                if state == 226:
                                                    return -0.317310035
                                    if state == 98:
                                        state = (
                                            135 if x["col_last"] < 0.582554817 else 136
                                        )
                                        if state == 135:
                                            state = (
                                                173
                                                if x["col_peak"] < 0.142254069
                                                else 174
                                            )
                                            if state == 173:
                                                return 0.131775096
                                            if state == 174:
                                                state = (
                                                    227
                                                    if x["distpsnr1_med"] < 0.0893816501
                                                    else 228
                                                )
                                                if state == 227:
                                                    return 0.178688154
                                                if state == 228:
                                                    return -0.199280083
                                        if state == 136:
                                            return 0.157367021
                                if state == 66:
                                    state = (
                                        99
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.764627457)
                                        else 100
                                    )
                                    if state == 99:
                                        state = (
                                            137
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.629489422)
                                            else 138
                                        )
                                        if state == 137:
                                            state = (
                                                175
                                                if x["col_peak"] < 0.147607327
                                                else 176
                                            )
                                            if state == 175:
                                                state = (
                                                    229
                                                    if x["distpsnr1_med"] < 12.9384642
                                                    else 230
                                                )
                                                if state == 229:
                                                    state = (
                                                        283
                                                        if x["col_peak"] < -0.175553322
                                                        else 284
                                                    )
                                                    if state == 283:
                                                        state = (
                                                            351
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 27.9267197)
                                                            else 352
                                                        )
                                                        if state == 351:
                                                            return -0.177170783
                                                        if state == 352:
                                                            return 0.24670206
                                                    if state == 284:
                                                        state = (
                                                            353
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 20.9631538)
                                                            else 354
                                                        )
                                                        if state == 353:
                                                            return -0.0562836155
                                                        if state == 354:
                                                            return 0.31244868
                                                if state == 230:
                                                    state = (
                                                        285
                                                        if x["col_peak"] < -0.0548243523
                                                        else 286
                                                    )
                                                    if state == 285:
                                                        return 0.116188981
                                                    if state == 286:
                                                        return -0.181505978
                                            if state == 176:
                                                state = (
                                                    231
                                                    if x["distpsnr1_med"] < 8.08931351
                                                    else 232
                                                )
                                                if state == 231:
                                                    state = (
                                                        287
                                                        if x["col_peak"] < 0.287229061
                                                        else 288
                                                    )
                                                    if state == 287:
                                                        return -0.269109517
                                                    if state == 288:
                                                        state = (
                                                            357
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 25.9991436)
                                                            else 358
                                                        )
                                                        if state == 357:
                                                            return 0.0250062104
                                                        if state == 358:
                                                            return 0.190809995
                                                if state == 232:
                                                    state = (
                                                        289
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.177476883)
                                                        else 290
                                                    )
                                                    if state == 289:
                                                        state = (
                                                            359
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 29.0785942)
                                                            else 360
                                                        )
                                                        if state == 359:
                                                            return -0.00716313254
                                                        if state == 360:
                                                            return -0.329224467
                                                    if state == 290:
                                                        return 0.231103927
                                        if state == 138:
                                            state = (
                                                177
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.147607327)
                                                else 178
                                            )
                                            if state == 177:
                                                state = (
                                                    233
                                                    if x["distpsnr1_med"] < 4.96886158
                                                    else 234
                                                )
                                                if state == 233:
                                                    state = (
                                                        291
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"]
                                                            < -0.0382523537
                                                        )
                                                        else 292
                                                    )
                                                    if state == 291:
                                                        state = (
                                                            361
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 41.9582825)
                                                            else 362
                                                        )
                                                        if state == 361:
                                                            return 0.0929035097
                                                        if state == 362:
                                                            return -0.0684472322
                                                    if state == 292:
                                                        return 0.159330472
                                                if state == 234:
                                                    return -0.108427733
                                            if state == 178:
                                                return -0.185698137
                                    if state == 100:
                                        return 0.292477846
                        if state == 24:
                            state = (
                                41
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.5904503)
                                else 42
                            )
                            if state == 41:
                                return -0.152832806
                            if state == 42:
                                state = (
                                    67
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 2.08945322)
                                    else 68
                                )
                                if state == 67:
                                    return -0.0702757314
                                if state == 68:
                                    return 0.170919761
                if state == 6:
                    state = (
                        13 if np.isnan(x["t_lc"]) or (x["t_lc"] < 11.9829636) else 14
                    )
                    if state == 13:
                        state = 25 if x["col_last"] < 1.67759991 else 26
                        if state == 25:
                            return -0.286317885
                        if state == 26:
                            state = (
                                43
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.2756004)
                                else 44
                            )
                            if state == 43:
                                return -0.213689208
                            if state == 44:
                                return 0.156649649
                    if state == 14:
                        state = 27 if x["col_last"] < 0.421111584 else 28
                        if state == 27:
                            state = (
                                45
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1278992)
                                else 46
                            )
                            if state == 45:
                                state = (
                                    69
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.1301533)
                                    else 70
                                )
                                if state == 69:
                                    return -0.333773941
                                if state == 70:
                                    state = 101 if x["col_last"] < 0.312184334 else 102
                                    if state == 101:
                                        state = (
                                            139 if x["col_last"] < 0.255302131 else 140
                                        )
                                        if state == 139:
                                            state = (
                                                179
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.0743098259)
                                                else 180
                                            )
                                            if state == 179:
                                                state = (
                                                    235
                                                    if x["distpsnr1_med"] < 1.47964442
                                                    else 236
                                                )
                                                if state == 235:
                                                    return -0.0129458355
                                                if state == 236:
                                                    return -0.271858543
                                            if state == 180:
                                                state = (
                                                    237
                                                    if x["distpsnr1_med"] < 1.233006
                                                    else 238
                                                )
                                                if state == 237:
                                                    return 0.218252197
                                                if state == 238:
                                                    state = (
                                                        293
                                                        if x["col_peak"] < -0.0661978722
                                                        else 294
                                                    )
                                                    if state == 293:
                                                        return 0.144385114
                                                    if state == 294:
                                                        return -0.181312993
                                        if state == 140:
                                            state = (
                                                181
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.0747847557)
                                                else 182
                                            )
                                            if state == 181:
                                                return -0.0951514766
                                            if state == 182:
                                                return 0.197586641
                                    if state == 102:
                                        state = (
                                            141 if x["col_last"] < 0.413486183 else 142
                                        )
                                        if state == 141:
                                            return -0.25356397
                                        if state == 142:
                                            return 0.00574208936
                            if state == 46:
                                return -0.335324854
                        if state == 28:
                            state = (
                                47
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1054001)
                                else 48
                            )
                            if state == 47:
                                return -0.402592123
                            if state == 48:
                                state = (
                                    71
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.13641572)
                                    else 72
                                )
                                if state == 71:
                                    return -0.363991469
                                if state == 72:
                                    return -0.214021116
    elif num_booster == 17:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.504097998)
                else 2
            )
            if state == 1:
                state = 3 if x["sgscore1_med"] < 0.00095833349 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.9908276)
                        else 8
                    )
                    if state == 7:
                        return 0.217655644
                    if state == 8:
                        state = 15 if x["col_det"] < -0.106608391 else 16
                        if state == 15:
                            state = 27 if x["distpsnr1_med"] < 0.398552477 else 28
                            if state == 27:
                                return -0.163004234
                            if state == 28:
                                state = 49 if x["maggaia_med"] < 17.4325218 else 50
                                if state == 49:
                                    return -0.0719241425
                                if state == 50:
                                    return 0.209678382
                        if state == 16:
                            state = 29 if x["distpsnr1_med"] < 2.53427458 else 30
                            if state == 29:
                                state = 51 if x["maggaia_med"] < 15.4260674 else 52
                                if state == 51:
                                    return 0.0677815303
                                if state == 52:
                                    return -0.4547638
                            if state == 30:
                                return 0.184030518
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.5174999)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["col_det"] < 0.190662384 else 18
                        if state == 17:
                            state = 31 if x["distpsnr1_med"] < 0.101776376 else 32
                            if state == 31:
                                state = (
                                    53
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.1239052)
                                    else 54
                                )
                                if state == 53:
                                    return -0.233540922
                                if state == 54:
                                    state = (
                                        75 if x["sgscore1_med"] < 0.284987986 else 76
                                    )
                                    if state == 75:
                                        return -0.159510136
                                    if state == 76:
                                        return 0.181245223
                            if state == 32:
                                state = 55 if x["maggaia_med"] < 19.8492718 else 56
                                if state == 55:
                                    state = (
                                        77 if x["sgscore1_med"] < 0.0314375013 else 78
                                    )
                                    if state == 77:
                                        state = (
                                            107
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.2104988)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                147
                                                if x["sgscore1_med"] < 0.0182917006
                                                else 148
                                            )
                                            if state == 147:
                                                return 0.247982398
                                            if state == 148:
                                                state = (
                                                    195
                                                    if x["mag_peak"] < 19.0610199
                                                    else 196
                                                )
                                                if state == 195:
                                                    return 0.159787714
                                                if state == 196:
                                                    return -0.194272235
                                        if state == 108:
                                            state = (
                                                149
                                                if x["sgscore1_med"] < 0.0275089499
                                                else 150
                                            )
                                            if state == 149:
                                                state = (
                                                    197
                                                    if x["mag_peak"] < 18.648838
                                                    else 198
                                                )
                                                if state == 197:
                                                    state = (
                                                        253
                                                        if x["mag_peak"] < 17.3231239
                                                        else 254
                                                    )
                                                    if state == 253:
                                                        return -0.205109388
                                                    if state == 254:
                                                        state = (
                                                            303
                                                            if x["sgscore1_med"]
                                                            < 0.0017708349
                                                            else 304
                                                        )
                                                        if state == 303:
                                                            return -0.0159910973
                                                        if state == 304:
                                                            return 0.325801849
                                                if state == 198:
                                                    state = (
                                                        255
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.7613964)
                                                        else 256
                                                    )
                                                    if state == 255:
                                                        state = (
                                                            305
                                                            if x["sgscore1_med"]
                                                            < 0.0125000002
                                                            else 306
                                                        )
                                                        if state == 305:
                                                            return -0.163407028
                                                        if state == 306:
                                                            return 0.196751118
                                                    if state == 256:
                                                        return -0.276915789
                                            if state == 150:
                                                return -0.367388964
                                    if state == 78:
                                        state = (
                                            109
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.5247498)
                                            else 110
                                        )
                                        if state == 109:
                                            state = (
                                                151
                                                if x["sgscore1_med"] < 0.0420485996
                                                else 152
                                            )
                                            if state == 151:
                                                return 0.341663241
                                            if state == 152:
                                                state = (
                                                    199
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.9942818)
                                                    else 200
                                                )
                                                if state == 199:
                                                    state = (
                                                        257
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 16.3289757)
                                                        else 258
                                                    )
                                                    if state == 257:
                                                        state = (
                                                            307
                                                            if x["sgscore1_med"]
                                                            < 0.0475625023
                                                            else 308
                                                        )
                                                        if state == 307:
                                                            return -0.237031057
                                                        if state == 308:
                                                            return 0.125132248
                                                    if state == 258:
                                                        state = (
                                                            309
                                                            if x["sgscore1_med"]
                                                            < 0.0973898992
                                                            else 310
                                                        )
                                                        if state == 309:
                                                            return 0.140169352
                                                        if state == 310:
                                                            return 0.320976943
                                                if state == 200:
                                                    return -0.311513811
                                        if state == 110:
                                            return -0.293911994
                                if state == 56:
                                    state = (
                                        79
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.0260207988)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            111
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.4654999)
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                153
                                                if x["sgscore1_med"] < 0.0222500004
                                                else 154
                                            )
                                            if state == 153:
                                                return 0.252791256
                                            if state == 154:
                                                state = (
                                                    203
                                                    if x["mag_peak"] < 18.7463856
                                                    else 204
                                                )
                                                if state == 203:
                                                    return 0.22476466
                                                if state == 204:
                                                    return -0.0943548232
                                        if state == 112:
                                            state = (
                                                155
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00568750035)
                                                else 156
                                            )
                                            if state == 155:
                                                state = (
                                                    205
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.6987)
                                                    else 206
                                                )
                                                if state == 205:
                                                    state = (
                                                        259
                                                        if x["mag_peak"] < 18.1153488
                                                        else 260
                                                    )
                                                    if state == 259:
                                                        return -0.135965273
                                                    if state == 260:
                                                        return 0.268111497
                                                if state == 206:
                                                    return -0.200919017
                                            if state == 156:
                                                return -0.167827621
                                    if state == 80:
                                        state = (
                                            113
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.5279999)
                                            else 114
                                        )
                                        if state == 113:
                                            return 0.331247091
                                        if state == 114:
                                            return -0.23446174
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 1.81474686)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    57
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 20.4224205)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        81
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.02575)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            115
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.4295006)
                                            else 116
                                        )
                                        if state == 115:
                                            state = (
                                                157
                                                if x["sgscore1_med"] < 0.0131250005
                                                else 158
                                            )
                                            if state == 157:
                                                state = (
                                                    207
                                                    if x["mag_peak"] < 18.6823387
                                                    else 208
                                                )
                                                if state == 207:
                                                    state = (
                                                        261
                                                        if x["mag_peak"] < 17.9393425
                                                        else 262
                                                    )
                                                    if state == 261:
                                                        return 0.0263246167
                                                    if state == 262:
                                                        return 0.328144312
                                                if state == 208:
                                                    state = (
                                                        263
                                                        if x["mag_peak"] < 18.9535522
                                                        else 264
                                                    )
                                                    if state == 263:
                                                        return -0.343810767
                                                    if state == 264:
                                                        state = (
                                                            311
                                                            if x["sgscore1_med"]
                                                            < 0.00218750001
                                                            else 312
                                                        )
                                                        if state == 311:
                                                            return 0.213130742
                                                        if state == 312:
                                                            return -0.211129233
                                            if state == 158:
                                                state = (
                                                    209
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.969389)
                                                    else 210
                                                )
                                                if state == 209:
                                                    return 0.330835342
                                                if state == 210:
                                                    return -0.181062937
                                        if state == 116:
                                            state = (
                                                159
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00208333507)
                                                else 160
                                            )
                                            if state == 159:
                                                return -0.526952028
                                            if state == 160:
                                                state = (
                                                    211
                                                    if x["mag_peak"] < 18.2619534
                                                    else 212
                                                )
                                                if state == 211:
                                                    return 0.197597563
                                                if state == 212:
                                                    return -0.291635662
                                    if state == 82:
                                        state = (
                                            117
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.1009998)
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                161
                                                if x["sgscore1_med"] < 0.394718498
                                                else 162
                                            )
                                            if state == 161:
                                                state = (
                                                    213
                                                    if x["mag_peak"] < 17.7675476
                                                    else 214
                                                )
                                                if state == 213:
                                                    state = (
                                                        265
                                                        if x["mag_peak"] < 17.6082001
                                                        else 266
                                                    )
                                                    if state == 265:
                                                        return 0.228232071
                                                    if state == 266:
                                                        state = (
                                                            315
                                                            if x["sgscore1_med"]
                                                            < 0.115026504
                                                            else 316
                                                        )
                                                        if state == 315:
                                                            return 0.144947857
                                                        if state == 316:
                                                            return -0.120663956
                                                if state == 214:
                                                    state = (
                                                        267
                                                        if x["mag_peak"] < 17.8472519
                                                        else 268
                                                    )
                                                    if state == 267:
                                                        return -0.122252412
                                                    if state == 268:
                                                        state = (
                                                            317
                                                            if x["sgscore1_med"]
                                                            < 0.099931702
                                                            else 318
                                                        )
                                                        if state == 317:
                                                            return -0.207280457
                                                        if state == 318:
                                                            return -0.39859125
                                            if state == 162:
                                                state = (
                                                    215
                                                    if x["mag_peak"] < 16.3384094
                                                    else 216
                                                )
                                                if state == 215:
                                                    return -0.13101016
                                                if state == 216:
                                                    return 0.245304421
                                        if state == 118:
                                            state = (
                                                163
                                                if x["sgscore1_med"] < 0.03959525
                                                else 164
                                            )
                                            if state == 163:
                                                return -0.253136933
                                            if state == 164:
                                                state = (
                                                    217
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.394455)
                                                    else 218
                                                )
                                                if state == 217:
                                                    state = (
                                                        271
                                                        if x["mag_peak"] < 17.8876534
                                                        else 272
                                                    )
                                                    if state == 271:
                                                        state = (
                                                            321
                                                            if x["sgscore1_med"]
                                                            < 0.124512002
                                                            else 322
                                                        )
                                                        if state == 321:
                                                            return 0.107299618
                                                        if state == 322:
                                                            return -0.0808843374
                                                    if state == 272:
                                                        return 0.251748353
                                                if state == 218:
                                                    state = (
                                                        273
                                                        if x["mag_peak"] < 18.7033463
                                                        else 274
                                                    )
                                                    if state == 273:
                                                        return -0.301658303
                                                    if state == 274:
                                                        state = (
                                                            325
                                                            if x["sgscore1_med"]
                                                            < 0.407895982
                                                            else 326
                                                        )
                                                        if state == 325:
                                                            return -0.190350339
                                                        if state == 326:
                                                            return 0.0270675868
                                if state == 58:
                                    return -0.483539551
                            if state == 34:
                                state = 59 if x["maggaia_med"] < 19.3678322 else 60
                                if state == 59:
                                    state = (
                                        83
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.332556486)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            119
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.0165005)
                                            else 120
                                        )
                                        if state == 119:
                                            return 0.292365819
                                        if state == 120:
                                            state = (
                                                165
                                                if x["sgscore1_med"] < 0.084771648
                                                else 166
                                            )
                                            if state == 165:
                                                return 0.28944692
                                            if state == 166:
                                                state = (
                                                    219
                                                    if x["mag_peak"] < 14.9928446
                                                    else 220
                                                )
                                                if state == 219:
                                                    return 0.146699369
                                                if state == 220:
                                                    return -0.29286623
                                    if state == 84:
                                        state = (
                                            121
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.5810013)
                                            else 122
                                        )
                                        if state == 121:
                                            return -0.333879679
                                        if state == 122:
                                            state = (
                                                167
                                                if x["sgscore1_med"] < 0.494827509
                                                else 168
                                            )
                                            if state == 167:
                                                return 0.118463472
                                            if state == 168:
                                                state = (
                                                    221
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.6773491)
                                                    else 222
                                                )
                                                if state == 221:
                                                    return 0.217278302
                                                if state == 222:
                                                    return -0.327256054
                                if state == 60:
                                    state = (
                                        85 if x["sgscore1_med"] < 0.0472053513 else 86
                                    )
                                    if state == 85:
                                        state = (
                                            123
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.8892498)
                                            else 124
                                        )
                                        if state == 123:
                                            return 0.366550505
                                        if state == 124:
                                            state = (
                                                169
                                                if x["sgscore1_med"] < 0.0314761996
                                                else 170
                                            )
                                            if state == 169:
                                                state = (
                                                    223
                                                    if x["mag_peak"] < 18.1504517
                                                    else 224
                                                )
                                                if state == 223:
                                                    return 0.197290361
                                                if state == 224:
                                                    return -0.329734325
                                            if state == 170:
                                                return 0.18172051
                                    if state == 86:
                                        state = (
                                            125
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.0750008)
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                171
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.104889646)
                                                else 172
                                            )
                                            if state == 171:
                                                return -0.401955545
                                            if state == 172:
                                                state = (
                                                    225
                                                    if x["mag_peak"] < 17.8526039
                                                    else 226
                                                )
                                                if state == 225:
                                                    return 0.215812594
                                                if state == 226:
                                                    state = (
                                                        279
                                                        if x["mag_peak"] < 18.0323486
                                                        else 280
                                                    )
                                                    if state == 279:
                                                        return -0.3247343
                                                    if state == 280:
                                                        state = (
                                                            327
                                                            if x["sgscore1_med"]
                                                            < 0.432492495
                                                            else 328
                                                        )
                                                        if state == 327:
                                                            return 0.130990595
                                                        if state == 328:
                                                            return -0.20716697
                                        if state == 126:
                                            state = (
                                                173
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.108416498)
                                                else 174
                                            )
                                            if state == 173:
                                                return -0.467390925
                                            if state == 174:
                                                state = (
                                                    227
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.1999626)
                                                    else 228
                                                )
                                                if state == 227:
                                                    return 0.285726994
                                                if state == 228:
                                                    state = (
                                                        281
                                                        if x["mag_peak"] < 18.9160995
                                                        else 282
                                                    )
                                                    if state == 281:
                                                        return -0.302936524
                                                    if state == 282:
                                                        return 0.181213826
                    if state == 10:
                        state = 19 if x["col_det"] < -0.39133358 else 20
                        if state == 19:
                            state = (
                                35
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 1.91000414)
                                else 36
                            )
                            if state == 35:
                                state = 61 if x["maggaia_med"] < 16.5291157 else 62
                                if state == 61:
                                    return 0.0891529694
                                if state == 62:
                                    state = (
                                        87 if x["sgscore1_med"] < 0.00697916467 else 88
                                    )
                                    if state == 87:
                                        return -0.0158459935
                                    if state == 88:
                                        return -0.402929246
                            if state == 36:
                                state = 63 if x["maggaia_med"] < 18.0665398 else 64
                                if state == 63:
                                    state = (
                                        89 if x["sgscore1_med"] < 0.059193451 else 90
                                    )
                                    if state == 89:
                                        return 0.328784913
                                    if state == 90:
                                        return -0.0975707918
                                if state == 64:
                                    state = (
                                        91
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.0939228535)
                                        else 92
                                    )
                                    if state == 91:
                                        return -0.283207655
                                    if state == 92:
                                        state = (
                                            127
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.4192505)
                                            else 128
                                        )
                                        if state == 127:
                                            state = (
                                                175
                                                if x["sgscore1_med"] < 0.320339501
                                                else 176
                                            )
                                            if state == 175:
                                                return 0.128816053
                                            if state == 176:
                                                return -0.116705053
                                        if state == 128:
                                            return -0.098826237
                        if state == 20:
                            state = 37 if x["distpsnr1_med"] < 0.0459469557 else 38
                            if state == 37:
                                return 0.311061025
                            if state == 38:
                                state = 65 if x["maggaia_med"] < 15.7611485 else 66
                                if state == 65:
                                    state = (
                                        93
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.00614583492)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            129
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.8570004)
                                            else 130
                                        )
                                        if state == 129:
                                            state = (
                                                177
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00337499985)
                                                else 178
                                            )
                                            if state == 177:
                                                state = (
                                                    229
                                                    if x["mag_peak"] < 18.7616234
                                                    else 230
                                                )
                                                if state == 229:
                                                    return 0.184520409
                                                if state == 230:
                                                    return -0.311202765
                                            if state == 178:
                                                return 0.219177172
                                        if state == 130:
                                            state = (
                                                179
                                                if x["sgscore1_med"] < 0.00595139014
                                                else 180
                                            )
                                            if state == 179:
                                                state = (
                                                    231
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 19.0921059)
                                                    else 232
                                                )
                                                if state == 231:
                                                    state = (
                                                        283
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.8020172)
                                                        else 284
                                                    )
                                                    if state == 283:
                                                        state = (
                                                            329
                                                            if x["sgscore1_med"]
                                                            < 0.00395833515
                                                            else 330
                                                        )
                                                        if state == 329:
                                                            return 0.026682334
                                                        if state == 330:
                                                            return -0.190270826
                                                    if state == 284:
                                                        return 0.132541388
                                                if state == 232:
                                                    return -0.118563659
                                            if state == 180:
                                                return 0.267886877
                                    if state == 94:
                                        state = (
                                            131
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.9692497)
                                            else 132
                                        )
                                        if state == 131:
                                            state = (
                                                181
                                                if x["sgscore1_med"] < 0.00854166504
                                                else 182
                                            )
                                            if state == 181:
                                                state = (
                                                    233
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.5627556)
                                                    else 234
                                                )
                                                if state == 233:
                                                    return -0.25229314
                                                if state == 234:
                                                    state = (
                                                        285
                                                        if x["mag_peak"] < 18.837307
                                                        else 286
                                                    )
                                                    if state == 285:
                                                        return 0.224396467
                                                    if state == 286:
                                                        return -0.108012035
                                            if state == 182:
                                                state = (
                                                    235
                                                    if x["mag_peak"] < 18.2828369
                                                    else 236
                                                )
                                                if state == 235:
                                                    state = (
                                                        287
                                                        if x["mag_peak"] < 18.0651627
                                                        else 288
                                                    )
                                                    if state == 287:
                                                        return -0.138258889
                                                    if state == 288:
                                                        return 0.182807252
                                                if state == 236:
                                                    return -0.430684417
                                        if state == 132:
                                            state = (
                                                183
                                                if x["sgscore1_med"] < 0.175258994
                                                else 184
                                            )
                                            if state == 183:
                                                state = (
                                                    237
                                                    if x["mag_peak"] < 39.4021988
                                                    else 238
                                                )
                                                if state == 237:
                                                    return -0.220933929
                                                if state == 238:
                                                    return 0.0089323502
                                            if state == 184:
                                                state = (
                                                    239
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.6668358)
                                                    else 240
                                                )
                                                if state == 239:
                                                    return 0.219635695
                                                if state == 240:
                                                    return -0.095815964
                                if state == 66:
                                    state = (
                                        95 if x["sgscore1_med"] < 0.0031458349 else 96
                                    )
                                    if state == 95:
                                        state = (
                                            133
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.7084999)
                                            else 134
                                        )
                                        if state == 133:
                                            state = (
                                                185
                                                if x["sgscore1_med"] < 0.00241666497
                                                else 186
                                            )
                                            if state == 185:
                                                state = (
                                                    241
                                                    if x["mag_peak"] < 18.913784
                                                    else 242
                                                )
                                                if state == 241:
                                                    state = (
                                                        289
                                                        if x["mag_peak"] < 18.7780075
                                                        else 290
                                                    )
                                                    if state == 289:
                                                        state = (
                                                            331
                                                            if x["sgscore1_med"]
                                                            < 0.00218750001
                                                            else 332
                                                        )
                                                        if state == 331:
                                                            return 0.276835084
                                                        if state == 332:
                                                            return -0.0673147365
                                                    if state == 290:
                                                        return 0.0456656739
                                                if state == 242:
                                                    state = (
                                                        291
                                                        if x["mag_peak"] < 40.6434021
                                                        else 292
                                                    )
                                                    if state == 291:
                                                        return -0.343608081
                                                    if state == 292:
                                                        state = (
                                                            335
                                                            if x["sgscore1_med"]
                                                            < 0.00135416491
                                                            else 336
                                                        )
                                                        if state == 335:
                                                            return -0.125022247
                                                        if state == 336:
                                                            return -0.30005151
                                            if state == 186:
                                                state = (
                                                    243
                                                    if x["mag_peak"] < 18.7131348
                                                    else 244
                                                )
                                                if state == 243:
                                                    return 0.327516913
                                                if state == 244:
                                                    state = (
                                                        293
                                                        if x["mag_peak"] < 40.5658035
                                                        else 294
                                                    )
                                                    if state == 293:
                                                        return -0.281905115
                                                    if state == 294:
                                                        state = (
                                                            337
                                                            if x["sgscore1_med"]
                                                            < 0.00254166499
                                                            else 338
                                                        )
                                                        if state == 337:
                                                            return 0.111942746
                                                        if state == 338:
                                                            return -0.170688316
                                        if state == 134:
                                            state = (
                                                187
                                                if x["sgscore1_med"] < 0.00293154991
                                                else 188
                                            )
                                            if state == 187:
                                                state = (
                                                    245
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.9988403)
                                                    else 246
                                                )
                                                if state == 245:
                                                    state = (
                                                        295
                                                        if x["mag_peak"] < 37.9866257
                                                        else 296
                                                    )
                                                    if state == 295:
                                                        return 0.320973188
                                                    if state == 296:
                                                        state = (
                                                            339
                                                            if x["sgscore1_med"]
                                                            < 0.00231250003
                                                            else 340
                                                        )
                                                        if state == 339:
                                                            return 0.184991479
                                                        if state == 340:
                                                            return -0.123104632
                                                if state == 246:
                                                    return -0.305042416
                                            if state == 188:
                                                return 0.334595412
                                    if state == 96:
                                        state = (
                                            135
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.7874985)
                                            else 136
                                        )
                                        if state == 135:
                                            state = (
                                                189
                                                if x["sgscore1_med"] < 0.003354165
                                                else 190
                                            )
                                            if state == 189:
                                                return -0.426674157
                                            if state == 190:
                                                state = (
                                                    247
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 19.0851231)
                                                    else 248
                                                )
                                                if state == 247:
                                                    state = (
                                                        297
                                                        if x["mag_peak"] < 18.9365311
                                                        else 298
                                                    )
                                                    if state == 297:
                                                        state = (
                                                            341
                                                            if x["sgscore1_med"]
                                                            < 0.0178541504
                                                            else 342
                                                        )
                                                        if state == 341:
                                                            return -0.00243551005
                                                        if state == 342:
                                                            return 0.153038755
                                                    if state == 298:
                                                        state = (
                                                            343
                                                            if x["sgscore1_med"]
                                                            < 0.00508333463
                                                            else 344
                                                        )
                                                        if state == 343:
                                                            return 0.132709891
                                                        if state == 344:
                                                            return -0.068325825
                                                if state == 248:
                                                    state = (
                                                        299
                                                        if x["mag_peak"] < 20.0413017
                                                        else 300
                                                    )
                                                    if state == 299:
                                                        return -0.353558838
                                                    if state == 300:
                                                        state = (
                                                            345
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.0902395993
                                                            )
                                                            else 346
                                                        )
                                                        if state == 345:
                                                            return -0.212133825
                                                        if state == 346:
                                                            return 0.315299869
                                        if state == 136:
                                            state = (
                                                191
                                                if x["sgscore1_med"] < 0.006645835
                                                else 192
                                            )
                                            if state == 191:
                                                return -0.199067891
                                            if state == 192:
                                                state = (
                                                    249
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 19.012825)
                                                    else 250
                                                )
                                                if state == 249:
                                                    state = (
                                                        301
                                                        if x["mag_peak"] < 18.0909348
                                                        else 302
                                                    )
                                                    if state == 301:
                                                        state = (
                                                            347
                                                            if x["sgscore1_med"]
                                                            < 0.196211353
                                                            else 348
                                                        )
                                                        if state == 347:
                                                            return -0.142539367
                                                        if state == 348:
                                                            return 0.205376446
                                                    if state == 302:
                                                        return 0.311585993
                                                if state == 250:
                                                    return -0.179586798
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.600973487 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.1280499)
                        else 12
                    )
                    if state == 11:
                        state = 21 if x["col_det"] < -0.108136177 else 22
                        if state == 21:
                            return -0.31807819
                        if state == 22:
                            state = 39 if x["distpsnr1_med"] < 2.79803228 else 40
                            if state == 39:
                                return 0.22144185
                            if state == 40:
                                return -0.0564893745
                    if state == 12:
                        return -0.363082141
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.59445)
                        else 14
                    )
                    if state == 13:
                        state = 23 if x["col_det"] < -0.300148964 else 24
                        if state == 23:
                            state = 41 if x["distpsnr1_med"] < 17.0233479 else 42
                            if state == 41:
                                return -0.00886853877
                            if state == 42:
                                return 0.215167969
                        if state == 24:
                            state = 43 if x["distpsnr1_med"] < 6.81430769 else 44
                            if state == 43:
                                return -0.339319944
                            if state == 44:
                                state = 67 if x["maggaia_med"] < 19.8280602 else 68
                                if state == 67:
                                    state = (
                                        97 if x["sgscore1_med"] < 0.978963971 else 98
                                    )
                                    if state == 97:
                                        return 0.128251597
                                    if state == 98:
                                        state = (
                                            139
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.8805008)
                                            else 140
                                        )
                                        if state == 139:
                                            return -0.274609834
                                        if state == 140:
                                            return 0.0382956266
                                if state == 68:
                                    state = (
                                        99 if x["sgscore1_med"] < 0.695366025 else 100
                                    )
                                    if state == 99:
                                        return 0.238247573
                                    if state == 100:
                                        return -0.182099238
                    if state == 14:
                        state = 25 if x["col_det"] < -0.00615024567 else 26
                        if state == 25:
                            state = 45 if x["distpsnr1_med"] < 13.042551 else 46
                            if state == 45:
                                return -0.273647845
                            if state == 46:
                                state = 69 if x["maggaia_med"] < 15.8626575 else 70
                                if state == 69:
                                    return 0.21652022
                                if state == 70:
                                    return -0.206163496
                        if state == 26:
                            state = 47 if x["distpsnr1_med"] < 3.10074997 else 48
                            if state == 47:
                                state = 71 if x["maggaia_med"] < 17.4165306 else 72
                                if state == 71:
                                    state = (
                                        101 if x["sgscore1_med"] < 0.640576959 else 102
                                    )
                                    if state == 101:
                                        return 0.0915651545
                                    if state == 102:
                                        return -0.167290911
                                if state == 72:
                                    return -0.322387159
                            if state == 48:
                                state = 73 if x["maggaia_med"] < 18.9946823 else 74
                                if state == 73:
                                    state = (
                                        103 if x["sgscore1_med"] < 0.806087494 else 104
                                    )
                                    if state == 103:
                                        state = (
                                            141
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 21.5424995)
                                            else 142
                                        )
                                        if state == 141:
                                            return -0.163530529
                                        if state == 142:
                                            return 0.181235269
                                    if state == 104:
                                        return -0.256842434
                                if state == 74:
                                    state = (
                                        105 if x["sgscore1_med"] < 0.957613468 else 106
                                    )
                                    if state == 105:
                                        state = (
                                            143
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.6085014)
                                            else 144
                                        )
                                        if state == 143:
                                            return 0.317183137
                                        if state == 144:
                                            return 0.0247131065
                                    if state == 106:
                                        state = (
                                            145
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 21.9489994)
                                            else 146
                                        )
                                        if state == 145:
                                            state = (
                                                193
                                                if x["sgscore1_med"] < 0.974362969
                                                else 194
                                            )
                                            if state == 193:
                                                return -0.221233308
                                            if state == 194:
                                                state = (
                                                    251
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.5876045)
                                                    else 252
                                                )
                                                if state == 251:
                                                    return 0.30644539
                                                if state == 252:
                                                    return -0.101184979
                                        if state == 146:
                                            return -0.250104249
    elif num_booster == 18:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < 0.119942665) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.115356952)
                    else 4
                )
                if state == 3:
                    return 0.326719344
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 19.0851231)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3764)
                            else 14
                        )
                        if state == 13:
                            state = (
                                23
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.6183949)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    39
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 16.1082497)
                                    else 40
                                )
                                if state == 39:
                                    return -0.226285309
                                if state == 40:
                                    state = 61 if x["col_last"] < -0.20938015 else 62
                                    if state == 61:
                                        state = (
                                            85 if x["col_last"] < -0.270994186 else 86
                                        )
                                        if state == 85:
                                            state = (
                                                121
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.74333334)
                                                else 122
                                            )
                                            if state == 121:
                                                return 0.173186392
                                            if state == 122:
                                                return -0.129244328
                                        if state == 86:
                                            state = (
                                                123
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.661666632)
                                                else 124
                                            )
                                            if state == 123:
                                                return 0.0140793454
                                            if state == 124:
                                                state = (
                                                    181
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00581250014
                                                    )
                                                    else 182
                                                )
                                                if state == 181:
                                                    return -0.406906635
                                                if state == 182:
                                                    state = (
                                                        247
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.298248291)
                                                        else 248
                                                    )
                                                    if state == 247:
                                                        return -0.0750674009
                                                    if state == 248:
                                                        return 0.0912836939
                                    if state == 62:
                                        state = (
                                            87
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 1.23317146)
                                            else 88
                                        )
                                        if state == 87:
                                            state = (
                                                125
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.628095269)
                                                else 126
                                            )
                                            if state == 125:
                                                state = (
                                                    183
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.16129449)
                                                    else 184
                                                )
                                                if state == 183:
                                                    return 0.317670286
                                                if state == 184:
                                                    state = (
                                                        249
                                                        if x["col_det"] < 0.0292272568
                                                        else 250
                                                    )
                                                    if state == 249:
                                                        return 0.279717147
                                                    if state == 250:
                                                        state = (
                                                            323
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.08637047
                                                            )
                                                            else 324
                                                        )
                                                        if state == 323:
                                                            return 0.25252226
                                                        if state == 324:
                                                            return -0.0799638703
                                            if state == 126:
                                                state = (
                                                    185
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.588)
                                                    else 186
                                                )
                                                if state == 185:
                                                    state = (
                                                        251
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.0989522934)
                                                        else 252
                                                    )
                                                    if state == 251:
                                                        state = (
                                                            325
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.24646616
                                                            )
                                                            else 326
                                                        )
                                                        if state == 325:
                                                            return -0.00717911217
                                                        if state == 326:
                                                            return 0.168423221
                                                    if state == 252:
                                                        state = (
                                                            327
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.66746998
                                                            )
                                                            else 328
                                                        )
                                                        if state == 327:
                                                            return 0.0355553217
                                                        if state == 328:
                                                            return -0.223968819
                                                if state == 186:
                                                    state = (
                                                        253
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.192832947)
                                                        else 254
                                                    )
                                                    if state == 253:
                                                        state = (
                                                            329
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.95720315
                                                            )
                                                            else 330
                                                        )
                                                        if state == 329:
                                                            return -0.194914669
                                                        if state == 330:
                                                            return 0.0839032829
                                                    if state == 254:
                                                        return -0.327063769
                                        if state == 88:
                                            return -0.0672870204
                            if state == 24:
                                state = (
                                    41
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.7665005)
                                    else 42
                                )
                                if state == 41:
                                    state = 63 if x["col_last"] < -0.105044842 else 64
                                    if state == 63:
                                        state = (
                                            89 if x["col_last"] < -0.206367016 else 90
                                        )
                                        if state == 89:
                                            state = (
                                                129
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.558333397)
                                                else 130
                                            )
                                            if state == 129:
                                                return -0.0203375053
                                            if state == 130:
                                                state = (
                                                    187
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0598750003
                                                    )
                                                    else 188
                                                )
                                                if state == 187:
                                                    state = (
                                                        255
                                                        if x["col_det"] < -0.205168724
                                                        else 256
                                                    )
                                                    if state == 255:
                                                        return 0.160609528
                                                    if state == 256:
                                                        return -0.178018972
                                                if state == 188:
                                                    return -0.271368295
                                        if state == 90:
                                            state = (
                                                131
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.816428661)
                                                else 132
                                            )
                                            if state == 131:
                                                state = (
                                                    189
                                                    if x["sgscore1_med"] < 0.0107142851
                                                    else 190
                                                )
                                                if state == 189:
                                                    return 0.340434313
                                                if state == 190:
                                                    state = (
                                                        257
                                                        if np.isnan(x["col_det"])
                                                        or (
                                                            x["col_det"] < -0.0920944214
                                                        )
                                                        else 258
                                                    )
                                                    if state == 257:
                                                        state = (
                                                            331
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.895767689
                                                            )
                                                            else 332
                                                        )
                                                        if state == 331:
                                                            return -0.1370105
                                                        if state == 332:
                                                            return 0.290250391
                                                    if state == 258:
                                                        return -0.0948619097
                                            if state == 132:
                                                return -0.0665597841
                                    if state == 64:
                                        state = (
                                            91 if x["col_last"] < -0.0295748711 else 92
                                        )
                                        if state == 91:
                                            state = (
                                                133
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.633452415)
                                                else 134
                                            )
                                            if state == 133:
                                                state = (
                                                    193
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.10524115)
                                                    else 194
                                                )
                                                if state == 193:
                                                    return -0.11320252
                                                if state == 194:
                                                    state = (
                                                        259
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.415150166)
                                                        else 260
                                                    )
                                                    if state == 259:
                                                        return -0.134804845
                                                    if state == 260:
                                                        return 0.164706498
                                            if state == 134:
                                                state = (
                                                    195
                                                    if x["sgscore1_med"] < 0.0104017854
                                                    else 196
                                                )
                                                if state == 195:
                                                    state = (
                                                        261
                                                        if x["col_det"] < -0.0437223129
                                                        else 262
                                                    )
                                                    if state == 261:
                                                        return 0.151490659
                                                    if state == 262:
                                                        state = (
                                                            335
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.853807509
                                                            )
                                                            else 336
                                                        )
                                                        if state == 335:
                                                            return -0.122278124
                                                        if state == 336:
                                                            return 0.0415229611
                                                if state == 196:
                                                    state = (
                                                        263
                                                        if x["col_det"] < -0.256530762
                                                        else 264
                                                    )
                                                    if state == 263:
                                                        return -0.0391022786
                                                    if state == 264:
                                                        return -0.372503787
                                        if state == 92:
                                            state = (
                                                135
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.710000098)
                                                else 136
                                            )
                                            if state == 135:
                                                state = (
                                                    197
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.504097998)
                                                    else 198
                                                )
                                                if state == 197:
                                                    state = (
                                                        265
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.077735588)
                                                        else 266
                                                    )
                                                    if state == 265:
                                                        state = (
                                                            339
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.960440993
                                                            )
                                                            else 340
                                                        )
                                                        if state == 339:
                                                            return -0.0973405614
                                                        if state == 340:
                                                            return 0.0723928288
                                                    if state == 266:
                                                        return -0.326226026
                                                if state == 198:
                                                    return -0.312625378
                                            if state == 136:
                                                state = (
                                                    199
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0336041525
                                                    )
                                                    else 200
                                                )
                                                if state == 199:
                                                    state = (
                                                        267
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.117789268)
                                                        else 268
                                                    )
                                                    if state == 267:
                                                        state = (
                                                            341
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.27818131
                                                            )
                                                            else 342
                                                        )
                                                        if state == 341:
                                                            return 0.0768532306
                                                        if state == 342:
                                                            return -0.218818694
                                                    if state == 268:
                                                        state = (
                                                            343
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.46828246
                                                            )
                                                            else 344
                                                        )
                                                        if state == 343:
                                                            return -0.124078043
                                                        if state == 344:
                                                            return -0.312851518
                                                if state == 200:
                                                    state = (
                                                        269
                                                        if x["col_det"] < -0.251441479
                                                        else 270
                                                    )
                                                    if state == 269:
                                                        return 0.286746353
                                                    if state == 270:
                                                        state = (
                                                            347
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.41337055
                                                            )
                                                            else 348
                                                        )
                                                        if state == 347:
                                                            return -0.24706541
                                                        if state == 348:
                                                            return 0.04921351
                                if state == 42:
                                    state = 65 if x["col_last"] < 0.0252180099 else 66
                                    if state == 65:
                                        state = (
                                            93 if x["col_last"] < -0.0263290405 else 94
                                        )
                                        if state == 93:
                                            state = (
                                                137
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.710714221)
                                                else 138
                                            )
                                            if state == 137:
                                                state = (
                                                    201
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00204166491
                                                    )
                                                    else 202
                                                )
                                                if state == 201:
                                                    state = (
                                                        271
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.154444695)
                                                        else 272
                                                    )
                                                    if state == 271:
                                                        state = (
                                                            349
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.31273735
                                                            )
                                                            else 350
                                                        )
                                                        if state == 349:
                                                            return -0.111682124
                                                        if state == 350:
                                                            return 0.0676120818
                                                    if state == 272:
                                                        return 0.337783933
                                                if state == 202:
                                                    state = (
                                                        273
                                                        if np.isnan(x["col_det"])
                                                        or (
                                                            x["col_det"]
                                                            < -0.00601148605
                                                        )
                                                        else 274
                                                    )
                                                    if state == 273:
                                                        state = (
                                                            351
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 11.3907146
                                                            )
                                                            else 352
                                                        )
                                                        if state == 351:
                                                            return -0.107179008
                                                        if state == 352:
                                                            return 0.155171856
                                                    if state == 274:
                                                        return -0.280989259
                                            if state == 138:
                                                state = (
                                                    203
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.931957483)
                                                    else 204
                                                )
                                                if state == 203:
                                                    state = (
                                                        275
                                                        if x["col_det"] < -0.310161591
                                                        else 276
                                                    )
                                                    if state == 275:
                                                        return -0.0445515402
                                                    if state == 276:
                                                        state = (
                                                            353
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.39523125
                                                            )
                                                            else 354
                                                        )
                                                        if state == 353:
                                                            return -0.108308256
                                                        if state == 354:
                                                            return -0.449012846
                                                if state == 204:
                                                    return 0.12957789
                                        if state == 94:
                                            state = (
                                                139
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.558452487)
                                                else 140
                                            )
                                            if state == 139:
                                                return -0.124887027
                                            if state == 140:
                                                return -0.400953323
                                    if state == 66:
                                        state = (
                                            95 if x["col_last"] < 0.112598419 else 96
                                        )
                                        if state == 95:
                                            state = (
                                                141
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.710000038)
                                                else 142
                                            )
                                            if state == 141:
                                                state = (
                                                    205
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00204166491
                                                    )
                                                    else 206
                                                )
                                                if state == 205:
                                                    return 0.225708827
                                                if state == 206:
                                                    state = (
                                                        277
                                                        if x["col_det"] < 0.0642075539
                                                        else 278
                                                    )
                                                    if state == 277:
                                                        return 0.135044426
                                                    if state == 278:
                                                        return -0.104124807
                                            if state == 142:
                                                state = (
                                                    207
                                                    if x["sgscore1_med"] < 0.276392996
                                                    else 208
                                                )
                                                if state == 207:
                                                    return -0.0790528581
                                                if state == 208:
                                                    state = (
                                                        281
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.184752464)
                                                        else 282
                                                    )
                                                    if state == 281:
                                                        return 0.107253321
                                                    if state == 282:
                                                        return -0.096172072
                                        if state == 96:
                                            state = (
                                                143
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.281666517)
                                                else 144
                                            )
                                            if state == 143:
                                                state = (
                                                    209
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00568750035
                                                    )
                                                    else 210
                                                )
                                                if state == 209:
                                                    state = (
                                                        283
                                                        if x["col_det"] < -0.228449821
                                                        else 284
                                                    )
                                                    if state == 283:
                                                        return 0.159676865
                                                    if state == 284:
                                                        return -0.162736356
                                                if state == 210:
                                                    return -0.419745922
                                            if state == 144:
                                                state = (
                                                    211
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0910952538
                                                    )
                                                    else 212
                                                )
                                                if state == 211:
                                                    state = (
                                                        285
                                                        if np.isnan(x["col_det"])
                                                        or (
                                                            x["col_det"] < -0.0771684647
                                                        )
                                                        else 286
                                                    )
                                                    if state == 285:
                                                        state = (
                                                            361
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.45448613
                                                            )
                                                            else 362
                                                        )
                                                        if state == 361:
                                                            return 0.0486651435
                                                        if state == 362:
                                                            return -0.105009012
                                                    if state == 286:
                                                        state = (
                                                            363
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.8291657
                                                            )
                                                            else 364
                                                        )
                                                        if state == 363:
                                                            return -0.016785996
                                                        if state == 364:
                                                            return 0.296164274
                                                if state == 212:
                                                    state = (
                                                        287
                                                        if x["col_det"] < -0.0369796753
                                                        else 288
                                                    )
                                                    if state == 287:
                                                        state = (
                                                            365
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.3555274
                                                            )
                                                            else 366
                                                        )
                                                        if state == 365:
                                                            return -0.216004014
                                                        if state == 366:
                                                            return 0.0540642589
                                                    if state == 288:
                                                        state = (
                                                            367
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.34622478
                                                            )
                                                            else 368
                                                        )
                                                        if state == 367:
                                                            return -0.0709289312
                                                        if state == 368:
                                                            return -0.293228149
                        if state == 14:
                            state = (
                                25
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.0087128)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    43
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 21.3502502)
                                    else 44
                                )
                                if state == 43:
                                    state = 67 if x["col_last"] < -0.123712063 else 68
                                    if state == 67:
                                        state = (
                                            97 if x["col_last"] < -0.196398735 else 98
                                        )
                                        if state == 97:
                                            return 0.0370032154
                                        if state == 98:
                                            state = (
                                                145
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.72035718)
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    213
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00758333504
                                                    )
                                                    else 214
                                                )
                                                if state == 213:
                                                    return -0.244597539
                                                if state == 214:
                                                    return -0.0191304106
                                            if state == 146:
                                                return 0.0991037339
                                    if state == 68:
                                        state = (
                                            99
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < -0.0302562714)
                                            else 100
                                        )
                                        if state == 99:
                                            return 0.232213467
                                        if state == 100:
                                            state = (
                                                147
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.603333354)
                                                else 148
                                            )
                                            if state == 147:
                                                state = (
                                                    215
                                                    if x["sgscore1_med"] < 0.0330416486
                                                    else 216
                                                )
                                                if state == 215:
                                                    return 0.224378198
                                                if state == 216:
                                                    state = (
                                                        289
                                                        if x["col_det"] < 0.0372019261
                                                        else 290
                                                    )
                                                    if state == 289:
                                                        return 0.122026853
                                                    if state == 290:
                                                        return -0.277534366
                                            if state == 148:
                                                state = (
                                                    217
                                                    if x["sgscore1_med"] < 0.0220208
                                                    else 218
                                                )
                                                if state == 217:
                                                    state = (
                                                        291
                                                        if x["col_det"] < 0.145649955
                                                        else 292
                                                    )
                                                    if state == 291:
                                                        return -0.224584207
                                                    if state == 292:
                                                        return 0.268550664
                                                if state == 218:
                                                    return 0.2777403
                                if state == 44:
                                    return 0.35330984
                            if state == 26:
                                state = (
                                    45
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 20.0065002)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        69
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.698325157)
                                        else 70
                                    )
                                    if state == 69:
                                        state = (
                                            101
                                            if x["col_last"] < -0.0534062386
                                            else 102
                                        )
                                        if state == 101:
                                            return -0.258184105
                                        if state == 102:
                                            state = (
                                                149
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.601666808)
                                                else 150
                                            )
                                            if state == 149:
                                                state = (
                                                    219
                                                    if x["sgscore1_med"] < 0.00385416998
                                                    else 220
                                                )
                                                if state == 219:
                                                    return 0.289137572
                                                if state == 220:
                                                    state = (
                                                        293
                                                        if x["col_det"] < 0.188401267
                                                        else 294
                                                    )
                                                    if state == 293:
                                                        return -0.177736744
                                                    if state == 294:
                                                        state = (
                                                            369
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.43063593
                                                            )
                                                            else 370
                                                        )
                                                        if state == 369:
                                                            return -0.232536778
                                                        if state == 370:
                                                            return 0.129451126
                                            if state == 150:
                                                state = (
                                                    221
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.01166665)
                                                    else 222
                                                )
                                                if state == 221:
                                                    state = (
                                                        295
                                                        if x["col_det"] < -0.115249634
                                                        else 296
                                                    )
                                                    if state == 295:
                                                        return -0.200626865
                                                    if state == 296:
                                                        state = (
                                                            371
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.12605238
                                                            )
                                                            else 372
                                                        )
                                                        if state == 371:
                                                            return 0.0791643634
                                                        if state == 372:
                                                            return -0.210760117
                                                if state == 222:
                                                    state = (
                                                        297
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.67024374)
                                                        else 298
                                                    )
                                                    if state == 297:
                                                        state = (
                                                            373
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.69335854
                                                            )
                                                            else 374
                                                        )
                                                        if state == 373:
                                                            return -0.286840886
                                                        if state == 374:
                                                            return -0.0594147295
                                                    if state == 298:
                                                        return -0.324513704
                                    if state == 70:
                                        state = (
                                            103 if x["col_last"] < 0.868477345 else 104
                                        )
                                        if state == 103:
                                            state = (
                                                151
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.762143016)
                                                else 152
                                            )
                                            if state == 151:
                                                return 0.219759583
                                            if state == 152:
                                                return -0.0483774319
                                        if state == 104:
                                            state = (
                                                153
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.745000005)
                                                else 154
                                            )
                                            if state == 153:
                                                return -0.0907130018
                                            if state == 154:
                                                return 0.155204609
                                if state == 46:
                                    state = (
                                        71
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.00134944916)
                                        else 72
                                    )
                                    if state == 71:
                                        state = (
                                            105
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < -0.0678129196)
                                            else 106
                                        )
                                        if state == 105:
                                            state = (
                                                155
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.653333187)
                                                else 156
                                            )
                                            if state == 155:
                                                state = (
                                                    223
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00839583483
                                                    )
                                                    else 224
                                                )
                                                if state == 223:
                                                    return -0.240449101
                                                if state == 224:
                                                    state = (
                                                        299
                                                        if x["col_det"] < -0.154399872
                                                        else 300
                                                    )
                                                    if state == 299:
                                                        return 0.291184366
                                                    if state == 300:
                                                        state = (
                                                            375
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.31427312
                                                            )
                                                            else 376
                                                        )
                                                        if state == 375:
                                                            return -0.258785814
                                                        if state == 376:
                                                            return 0.0731111318
                                            if state == 156:
                                                state = (
                                                    225
                                                    if x["sgscore1_med"] < 0.507887006
                                                    else 226
                                                )
                                                if state == 225:
                                                    state = (
                                                        301
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.145400047)
                                                        else 302
                                                    )
                                                    if state == 301:
                                                        state = (
                                                            377
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.465033263
                                                            )
                                                            else 378
                                                        )
                                                        if state == 377:
                                                            return -0.104893334
                                                        if state == 378:
                                                            return 0.259768456
                                                    if state == 302:
                                                        return -0.103059515
                                                if state == 226:
                                                    return -0.258265793
                                        if state == 106:
                                            return -0.254033059
                                    if state == 72:
                                        state = (
                                            107
                                            if x["col_last"] < 0.00216674805
                                            else 108
                                        )
                                        if state == 107:
                                            return 0.432822466
                                        if state == 108:
                                            state = (
                                                159
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.516190469)
                                                else 160
                                            )
                                            if state == 159:
                                                state = (
                                                    229
                                                    if x["sgscore1_med"] < 0.509478986
                                                    else 230
                                                )
                                                if state == 229:
                                                    state = (
                                                        303
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.335748672)
                                                        else 304
                                                    )
                                                    if state == 303:
                                                        state = (
                                                            381
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.52297497
                                                            )
                                                            else 382
                                                        )
                                                        if state == 381:
                                                            return -0.0882016793
                                                        if state == 382:
                                                            return 0.0884958729
                                                    if state == 304:
                                                        return -0.04124441
                                                if state == 230:
                                                    return -0.228149652
                                            if state == 160:
                                                state = (
                                                    231
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0077083353
                                                    )
                                                    else 232
                                                )
                                                if state == 231:
                                                    return -0.210939199
                                                if state == 232:
                                                    state = (
                                                        307
                                                        if x["col_det"] < 0.0546073914
                                                        else 308
                                                    )
                                                    if state == 307:
                                                        return 0.0666811913
                                                    if state == 308:
                                                        state = (
                                                            385
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.86942035
                                                            )
                                                            else 386
                                                        )
                                                        if state == 385:
                                                            return -0.110336103
                                                        if state == 386:
                                                            return 0.286648303
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.6185493)
                            else 16
                        )
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.3610344)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    47
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 18.9705009)
                                    else 48
                                )
                                if state == 47:
                                    return 0.178938687
                                if state == 48:
                                    return -0.10501571
                            if state == 28:
                                return -0.382730871
                        if state == 16:
                            state = (
                                29
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.6039524)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    49
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.5649986)
                                    else 50
                                )
                                if state == 49:
                                    return 0.172938436
                                if state == 50:
                                    return -0.117662244
                            if state == 30:
                                state = (
                                    51
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.9130001)
                                    else 52
                                )
                                if state == 51:
                                    return -0.295025319
                                if state == 52:
                                    state = 73 if x["col_last"] < 0.583323479 else 74
                                    if state == 73:
                                        return -0.206428736
                                    if state == 74:
                                        state = (
                                            109 if x["col_last"] < 0.586098671 else 110
                                        )
                                        if state == 109:
                                            return 0.123383231
                                        if state == 110:
                                            state = (
                                                161
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.737499714)
                                                else 162
                                            )
                                            if state == 161:
                                                return -0.25181058
                                            if state == 162:
                                                state = (
                                                    233
                                                    if x["sgscore1_med"] < 0.0972230509
                                                    else 234
                                                )
                                                if state == 233:
                                                    return 0.394785166
                                                if state == 234:
                                                    return -0.108996779
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.240366161)
                    else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 17.5688553)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.6352997)
                            else 18
                        )
                        if state == 17:
                            return 0.126742855
                        if state == 18:
                            return -0.130032271
                    if state == 10:
                        return -0.305137604
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.9914818)
                        else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.9820518)
                            else 22
                        )
                        if state == 21:
                            state = (
                                35
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 20.0718994)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    53
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 20.0535011)
                                    else 54
                                )
                                if state == 53:
                                    state = 75 if x["col_last"] < 1.10541725 else 76
                                    if state == 75:
                                        state = (
                                            111 if x["col_last"] < 0.210526466 else 112
                                        )
                                        if state == 111:
                                            return -0.0387055241
                                        if state == 112:
                                            state = (
                                                165
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.62821424)
                                                else 166
                                            )
                                            if state == 165:
                                                state = (
                                                    235
                                                    if x["sgscore1_med"] < 0.3403005
                                                    else 236
                                                )
                                                if state == 235:
                                                    return 0.0290441643
                                                if state == 236:
                                                    return -0.214719385
                                            if state == 166:
                                                return -0.266272396
                                    if state == 76:
                                        state = (
                                            113 if x["col_last"] < 1.98656464 else 114
                                        )
                                        if state == 113:
                                            return 0.0908610076
                                        if state == 114:
                                            state = (
                                                167
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.511071444)
                                                else 168
                                            )
                                            if state == 167:
                                                return -0.289808244
                                            if state == 168:
                                                state = (
                                                    237
                                                    if x["sgscore1_med"] < 0.356711507
                                                    else 238
                                                )
                                                if state == 237:
                                                    state = (
                                                        309
                                                        if x["col_det"] < 0.413455486
                                                        else 310
                                                    )
                                                    if state == 309:
                                                        state = (
                                                            387
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.738618553
                                                            )
                                                            else 388
                                                        )
                                                        if state == 387:
                                                            return -0.0445533358
                                                        if state == 388:
                                                            return 0.11960797
                                                    if state == 310:
                                                        return 0.137886047
                                                if state == 238:
                                                    state = (
                                                        311
                                                        if x["col_det"] < 0.513897896
                                                        else 312
                                                    )
                                                    if state == 311:
                                                        state = (
                                                            391
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.62486327
                                                            )
                                                            else 392
                                                        )
                                                        if state == 391:
                                                            return 0.0403895006
                                                        if state == 392:
                                                            return -0.210824639
                                                    if state == 312:
                                                        return -0.00208177394
                                if state == 54:
                                    return 0.220153257
                            if state == 36:
                                return -0.169177085
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.7868881)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    57
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 21.4952507)
                                    else 58
                                )
                                if state == 57:
                                    return 0.264015704
                                if state == 58:
                                    state = (
                                        79
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.0586004257)
                                        else 80
                                    )
                                    if state == 79:
                                        return 0.155798703
                                    if state == 80:
                                        return -0.0624105781
                            if state == 38:
                                state = (
                                    59
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.3584995)
                                    else 60
                                )
                                if state == 59:
                                    state = 81 if x["col_last"] < 0.253704071 else 82
                                    if state == 81:
                                        state = (
                                            115 if x["col_last"] < 0.0570030212 else 116
                                        )
                                        if state == 115:
                                            state = (
                                                169
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.679166675)
                                                else 170
                                            )
                                            if state == 169:
                                                return 0.157032281
                                            if state == 170:
                                                return -0.0598971136
                                        if state == 116:
                                            return -0.192136571
                                    if state == 82:
                                        state = (
                                            117 if x["col_last"] < 0.318601131 else 118
                                        )
                                        if state == 117:
                                            return 0.427353859
                                        if state == 118:
                                            state = (
                                                173
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.767857075)
                                                else 174
                                            )
                                            if state == 173:
                                                state = (
                                                    239
                                                    if x["sgscore1_med"] < 0.00995833427
                                                    else 240
                                                )
                                                if state == 239:
                                                    return -0.277697355
                                                if state == 240:
                                                    state = (
                                                        313
                                                        if x["col_det"] < 0.238613129
                                                        else 314
                                                    )
                                                    if state == 313:
                                                        return 0.263181299
                                                    if state == 314:
                                                        state = (
                                                            395
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.639560997
                                                            )
                                                            else 396
                                                        )
                                                        if state == 395:
                                                            return -0.19635649
                                                        if state == 396:
                                                            return 0.0742895156
                                            if state == 174:
                                                state = (
                                                    241
                                                    if x["sgscore1_med"] < 0.00156249991
                                                    else 242
                                                )
                                                if state == 241:
                                                    return -0.130850315
                                                if state == 242:
                                                    state = (
                                                        315
                                                        if x["col_det"] < 0.80477047
                                                        else 316
                                                    )
                                                    if state == 315:
                                                        return 0.281351924
                                                    if state == 316:
                                                        return -0.142195687
                                if state == 60:
                                    state = 83 if x["col_last"] < 0.239544868 else 84
                                    if state == 83:
                                        return -0.305974573
                                    if state == 84:
                                        state = (
                                            119 if x["col_last"] < 0.937161446 else 120
                                        )
                                        if state == 119:
                                            state = (
                                                175
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.887857139)
                                                else 176
                                            )
                                            if state == 175:
                                                state = (
                                                    243
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0159166493
                                                    )
                                                    else 244
                                                )
                                                if state == 243:
                                                    state = (
                                                        317
                                                        if x["col_det"] < 0.230286598
                                                        else 318
                                                    )
                                                    if state == 317:
                                                        return 0.249182194
                                                    if state == 318:
                                                        state = (
                                                            399
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.703647554
                                                            )
                                                            else 400
                                                        )
                                                        if state == 399:
                                                            return 0.102595754
                                                        if state == 400:
                                                            return -0.154619113
                                                if state == 244:
                                                    state = (
                                                        319
                                                        if x["col_det"] < 0.244106293
                                                        else 320
                                                    )
                                                    if state == 319:
                                                        return 0.122935206
                                                    if state == 320:
                                                        return -0.224124953
                                            if state == 176:
                                                return 0.381132066
                                        if state == 120:
                                            state = (
                                                177
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.555000007)
                                                else 178
                                            )
                                            if state == 177:
                                                return -0.220817357
                                            if state == 178:
                                                state = (
                                                    245
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.440507501)
                                                    else 246
                                                )
                                                if state == 245:
                                                    state = (
                                                        321
                                                        if x["col_det"] < 0.237723351
                                                        else 322
                                                    )
                                                    if state == 321:
                                                        state = (
                                                            401
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.61356974
                                                            )
                                                            else 402
                                                        )
                                                        if state == 401:
                                                            return 0.162083238
                                                        if state == 402:
                                                            return -0.0348591469
                                                    if state == 322:
                                                        state = (
                                                            403
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.66715884
                                                            )
                                                            else 404
                                                        )
                                                        if state == 403:
                                                            return -0.33821857
                                                        if state == 404:
                                                            return 0.0480907895
                                                if state == 246:
                                                    return 0.244337022
                    if state == 12:
                        return -0.330143631
    elif num_booster == 19:
        state = 0
        if state == 0:
            state = 1 if x["col_last"] < -0.294481754 else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.676190495) else 4
                if state == 3:
                    return -0.027593052
                if state == 4:
                    state = 9 if x["col_det"] < -0.107364014 else 10
                    if state == 9:
                        return -0.0197838116
                    if state == 10:
                        return -0.252310276
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.928571522) else 6
                if state == 5:
                    state = 11 if x["col_det"] < -0.367617607 else 12
                    if state == 11:
                        state = 17 if x["col_det"] < -0.383153915 else 18
                        if state == 17:
                            state = 25 if x["col_peak"] < -0.150685936 else 26
                            if state == 25:
                                state = (
                                    35
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.493206)
                                    else 36
                                )
                                if state == 35:
                                    return -0.204447016
                                if state == 36:
                                    return 0.14907974
                            if state == 26:
                                state = 37 if x["maggaia_med"] < 18.6437302 else 38
                                if state == 37:
                                    state = 53 if x["col_det"] < -0.469531059 else 54
                                    if state == 53:
                                        state = (
                                            75
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.773333311)
                                            else 76
                                        )
                                        if state == 75:
                                            return -0.150095299
                                        if state == 76:
                                            return 0.0975215286
                                    if state == 54:
                                        state = (
                                            77
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.767619014)
                                            else 78
                                        )
                                        if state == 77:
                                            state = (
                                                109
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.94524288)
                                                else 110
                                            )
                                            if state == 109:
                                                return -0.171907872
                                            if state == 110:
                                                return 0.310377747
                                        if state == 78:
                                            return -0.0397743545
                                if state == 38:
                                    return -0.28774485
                        if state == 18:
                            return -0.370405883
                    if state == 12:
                        state = 19 if x["col_det"] < -0.292696953 else 20
                        if state == 19:
                            state = 27 if x["col_peak"] < -0.303849697 else 28
                            if state == 27:
                                return -0.169440538
                            if state == 28:
                                state = (
                                    39
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 17.420105)
                                    else 40
                                )
                                if state == 39:
                                    state = 55 if x["col_det"] < -0.355449677 else 56
                                    if state == 55:
                                        return 0.229996726
                                    if state == 56:
                                        state = (
                                            79
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.595714331)
                                            else 80
                                        )
                                        if state == 79:
                                            state = (
                                                111
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.94442701)
                                                else 112
                                            )
                                            if state == 111:
                                                return -0.114295289
                                            if state == 112:
                                                state = (
                                                    149
                                                    if x["distpsnr1_med"] < 9.41134453
                                                    else 150
                                                )
                                                if state == 149:
                                                    return 0.256080687
                                                if state == 150:
                                                    return -0.146208167
                                        if state == 80:
                                            state = (
                                                113
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 3.94464111)
                                                else 114
                                            )
                                            if state == 113:
                                                return -0.294555902
                                            if state == 114:
                                                state = (
                                                    153
                                                    if x["distpsnr1_med"] < 2.98337173
                                                    else 154
                                                )
                                                if state == 153:
                                                    return -0.0994480327
                                                if state == 154:
                                                    return 0.115591697
                                if state == 40:
                                    state = 57 if x["col_det"] < -0.335191727 else 58
                                    if state == 57:
                                        state = (
                                            81
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.606547594)
                                            else 82
                                        )
                                        if state == 81:
                                            return -0.207207158
                                        if state == 82:
                                            state = (
                                                115
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.97137165)
                                                else 116
                                            )
                                            if state == 115:
                                                state = (
                                                    155
                                                    if x["distpsnr1_med"] < 4.5525775
                                                    else 156
                                                )
                                                if state == 155:
                                                    state = (
                                                        203
                                                        if x["col_peak"] < -0.0939855576
                                                        else 204
                                                    )
                                                    if state == 203:
                                                        return 0.0985470861
                                                    if state == 204:
                                                        state = (
                                                            227
                                                            if x["col_last"]
                                                            < -0.0750846863
                                                            else 228
                                                        )
                                                        if state == 227:
                                                            return 0.0894096494
                                                        if state == 228:
                                                            return -0.12079408
                                                if state == 156:
                                                    return 0.148880959
                                            if state == 116:
                                                return -0.112519629
                                    if state == 58:
                                        state = (
                                            83
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.588333309)
                                            else 84
                                        )
                                        if state == 83:
                                            state = (
                                                117
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 8.9604454)
                                                else 118
                                            )
                                            if state == 117:
                                                state = (
                                                    157
                                                    if x["distpsnr1_med"] < 7.74562883
                                                    else 158
                                                )
                                                if state == 157:
                                                    state = (
                                                        205
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"] < 0.0286188126
                                                        )
                                                        else 206
                                                    )
                                                    if state == 205:
                                                        return -0.251240969
                                                    if state == 206:
                                                        return 0.10726811
                                                if state == 158:
                                                    return 0.160683289
                                            if state == 118:
                                                return 0.198706046
                                        if state == 84:
                                            return 0.347646624
                        if state == 20:
                            state = (
                                29
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.599546432)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    41
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 20.6515484)
                                    else 42
                                )
                                if state == 41:
                                    state = (
                                        59
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.295680046)
                                        else 60
                                    )
                                    if state == 59:
                                        state = (
                                            85
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.251547754)
                                            else 86
                                        )
                                        if state == 85:
                                            state = (
                                                119
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 5.92128468)
                                                else 120
                                            )
                                            if state == 119:
                                                state = (
                                                    159
                                                    if x["distpsnr1_med"] < 1.2150346
                                                    else 160
                                                )
                                                if state == 159:
                                                    return 0.0328406468
                                                if state == 160:
                                                    return -0.317662001
                                            if state == 120:
                                                state = (
                                                    161
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 11.3634338)
                                                    else 162
                                                )
                                                if state == 161:
                                                    state = (
                                                        207
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"] < -0.200275898
                                                        )
                                                        else 208
                                                    )
                                                    if state == 207:
                                                        return 0.145903677
                                                    if state == 208:
                                                        return -0.233342201
                                                if state == 162:
                                                    return 0.164130732
                                        if state == 86:
                                            state = (
                                                121
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0166088007)
                                                else 122
                                            )
                                            if state == 121:
                                                state = (
                                                    163
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 7.49497509)
                                                    else 164
                                                )
                                                if state == 163:
                                                    state = (
                                                        209
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"] < -0.105692863
                                                        )
                                                        else 210
                                                    )
                                                    if state == 209:
                                                        state = (
                                                            229
                                                            if x["col_last"]
                                                            < -0.073964119
                                                            else 230
                                                        )
                                                        if state == 229:
                                                            return -0.0128694726
                                                        if state == 230:
                                                            return -0.38079077
                                                    if state == 210:
                                                        state = (
                                                            231
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.484942436
                                                            )
                                                            else 232
                                                        )
                                                        if state == 231:
                                                            return -0.0660067722
                                                        if state == 232:
                                                            return 0.0886358097
                                                if state == 164:
                                                    return 0.169206649
                                            if state == 122:
                                                state = (
                                                    165
                                                    if x["distpsnr1_med"] < 17.6395931
                                                    else 166
                                                )
                                                if state == 165:
                                                    state = (
                                                        211
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.45250845)
                                                        else 212
                                                    )
                                                    if state == 211:
                                                        state = (
                                                            233
                                                            if x["col_last"]
                                                            < -0.271766663
                                                            else 234
                                                        )
                                                        if state == 233:
                                                            return 0.172090739
                                                        if state == 234:
                                                            return 0.00464432314
                                                    if state == 212:
                                                        state = (
                                                            235
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.769082069
                                                            )
                                                            else 236
                                                        )
                                                        if state == 235:
                                                            return -0.310901821
                                                        if state == 236:
                                                            return 0.103009127
                                                if state == 166:
                                                    state = (
                                                        213
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"] < -0.287240982
                                                        )
                                                        else 214
                                                    )
                                                    if state == 213:
                                                        state = (
                                                            237
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.122075081
                                                            )
                                                            else 238
                                                        )
                                                        if state == 237:
                                                            return 0.0360512584
                                                        if state == 238:
                                                            return 0.173850387
                                                    if state == 214:
                                                        return 0.238894984
                                    if state == 60:
                                        state = (
                                            87
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.567857027)
                                            else 88
                                        )
                                        if state == 87:
                                            state = (
                                                123
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.96229744)
                                                else 124
                                            )
                                            if state == 123:
                                                state = (
                                                    167
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 5.84006977)
                                                    else 168
                                                )
                                                if state == 167:
                                                    return -0.15708591
                                                if state == 168:
                                                    return 0.212915614
                                            if state == 124:
                                                state = (
                                                    169
                                                    if x["distpsnr1_med"] < 2.15773678
                                                    else 170
                                                )
                                                if state == 169:
                                                    return -0.012131473
                                                if state == 170:
                                                    return -0.390312403
                                        if state == 88:
                                            state = (
                                                125
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0161168501)
                                                else 126
                                            )
                                            if state == 125:
                                                return 0.172645658
                                            if state == 126:
                                                state = (
                                                    173
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 1.56102562)
                                                    else 174
                                                )
                                                if state == 173:
                                                    state = (
                                                        215
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.149980545)
                                                        else 216
                                                    )
                                                    if state == 215:
                                                        return -0.268777966
                                                    if state == 216:
                                                        state = (
                                                            241
                                                            if x["col_last"] < 1.0080719
                                                            else 242
                                                        )
                                                        if state == 241:
                                                            return 0.00793568883
                                                        if state == 242:
                                                            return -0.106754839
                                                if state == 174:
                                                    state = (
                                                        217
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"]
                                                            < -0.0414028168
                                                        )
                                                        else 218
                                                    )
                                                    if state == 217:
                                                        state = (
                                                            243
                                                            if x["col_last"]
                                                            < 0.570727348
                                                            else 244
                                                        )
                                                        if state == 243:
                                                            return -0.0481950939
                                                        if state == 244:
                                                            return 0.112390235
                                                    if state == 218:
                                                        return -0.178879157
                                if state == 42:
                                    state = 61 if x["col_det"] < 0.911641121 else 62
                                    if state == 61:
                                        state = (
                                            89
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.687857389)
                                            else 90
                                        )
                                        if state == 89:
                                            state = (
                                                127
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 6.00470495)
                                                else 128
                                            )
                                            if state == 127:
                                                return -0.265631288
                                            if state == 128:
                                                return 0.132959664
                                        if state == 90:
                                            return -0.401181102
                                    if state == 62:
                                        state = (
                                            91
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.610714316)
                                            else 92
                                        )
                                        if state == 91:
                                            state = (
                                                129
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.9383738)
                                                else 130
                                            )
                                            if state == 129:
                                                state = (
                                                    175
                                                    if x["distpsnr1_med"] < 4.46186066
                                                    else 176
                                                )
                                                if state == 175:
                                                    return -0.136033088
                                                if state == 176:
                                                    return 0.091157712
                                            if state == 130:
                                                return -0.292244405
                                        if state == 92:
                                            state = (
                                                131
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.9754281)
                                                else 132
                                            )
                                            if state == 131:
                                                state = (
                                                    179
                                                    if x["distpsnr1_med"] < 1.87745857
                                                    else 180
                                                )
                                                if state == 179:
                                                    return -0.141592368
                                                if state == 180:
                                                    return 0.18873477
                                            if state == 132:
                                                return -0.210201263
                            if state == 30:
                                state = 43 if x["maggaia_med"] < 18.8701477 else 44
                                if state == 43:
                                    state = (
                                        63
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.0307536125)
                                        else 64
                                    )
                                    if state == 63:
                                        state = (
                                            93
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.668571472)
                                            else 94
                                        )
                                        if state == 93:
                                            return -0.197831854
                                        if state == 94:
                                            state = (
                                                133
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0529918969)
                                                else 134
                                            )
                                            if state == 133:
                                                return 0.116232671
                                            if state == 134:
                                                state = (
                                                    183
                                                    if x["distpsnr1_med"] < 2.07001042
                                                    else 184
                                                )
                                                if state == 183:
                                                    state = (
                                                        219
                                                        if x["col_peak"] < 0.623244286
                                                        else 220
                                                    )
                                                    if state == 219:
                                                        return 0.154967383
                                                    if state == 220:
                                                        return -0.0413151793
                                                if state == 184:
                                                    return -0.241804615
                                    if state == 64:
                                        return 0.18213959
                                if state == 44:
                                    return 0.229205683
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["col_det"]) or (x["col_det"] < 0.0854096413)
                        else 14
                    )
                    if state == 13:
                        state = (
                            21
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.0644478798)
                            else 22
                        )
                        if state == 21:
                            state = 31 if x["col_peak"] < 0.233460903 else 32
                            if state == 31:
                                state = 45 if x["maggaia_med"] < 19.4483109 else 46
                                if state == 45:
                                    state = (
                                        67
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.198589325)
                                        else 68
                                    )
                                    if state == 67:
                                        state = (
                                            99
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.9375)
                                            else 100
                                        )
                                        if state == 99:
                                            return -0.0273532495
                                        if state == 100:
                                            state = (
                                                137
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.89964104)
                                                else 138
                                            )
                                            if state == 137:
                                                state = (
                                                    187
                                                    if x["distpsnr1_med"] < 6.43828392
                                                    else 188
                                                )
                                                if state == 187:
                                                    return 0.078363806
                                                if state == 188:
                                                    return -0.0799393058
                                            if state == 138:
                                                return 0.288656235
                                    if state == 68:
                                        state = (
                                            101
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.945357203)
                                            else 102
                                        )
                                        if state == 101:
                                            state = (
                                                139
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 5.41105938)
                                                else 140
                                            )
                                            if state == 139:
                                                return -0.299721152
                                            if state == 140:
                                                return 0.110991135
                                        if state == 102:
                                            return 0.181258887
                                if state == 46:
                                    state = (
                                        69
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.110079765)
                                        else 70
                                    )
                                    if state == 69:
                                        state = (
                                            103
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.94749999)
                                            else 104
                                        )
                                        if state == 103:
                                            state = (
                                                141
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 3.93612289)
                                                else 142
                                            )
                                            if state == 141:
                                                return -0.150964171
                                            if state == 142:
                                                state = (
                                                    193
                                                    if x["distpsnr1_med"] < 1.578439
                                                    else 194
                                                )
                                                if state == 193:
                                                    return -0.0379514582
                                                if state == 194:
                                                    return 0.154981107
                                        if state == 104:
                                            state = (
                                                143
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.95642936)
                                                else 144
                                            )
                                            if state == 143:
                                                return 0.12244951
                                            if state == 144:
                                                state = (
                                                    195
                                                    if x["distpsnr1_med"] < 0.378889561
                                                    else 196
                                                )
                                                if state == 195:
                                                    state = (
                                                        221
                                                        if x["col_peak"] < -0.0203790665
                                                        else 222
                                                    )
                                                    if state == 221:
                                                        return 0.00871755648
                                                    if state == 222:
                                                        return -0.195896953
                                                if state == 196:
                                                    return -0.412050873
                                    if state == 70:
                                        return 0.141253114
                            if state == 32:
                                state = 47 if x["maggaia_med"] < 20.4341507 else 48
                                if state == 47:
                                    state = 71 if x["col_det"] < -0.312619686 else 72
                                    if state == 71:
                                        return 0.225018784
                                    if state == 72:
                                        state = (
                                            107
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.96035713)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                145
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0477720499)
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    197
                                                    if x["distpsnr1_med"] < 4.43069649
                                                    else 198
                                                )
                                                if state == 197:
                                                    return -0.194192156
                                                if state == 198:
                                                    return 0.131324679
                                            if state == 146:
                                                state = (
                                                    199
                                                    if x["distpsnr1_med"] < 0.392302632
                                                    else 200
                                                )
                                                if state == 199:
                                                    return -0.06625925
                                                if state == 200:
                                                    state = (
                                                        225
                                                        if x["col_peak"] < 1.86139774
                                                        else 226
                                                    )
                                                    if state == 225:
                                                        return 0.28105399
                                                    if state == 226:
                                                        state = (
                                                            247
                                                            if x["col_last"]
                                                            < 0.245082855
                                                            else 248
                                                        )
                                                        if state == 247:
                                                            return 0.245672539
                                                        if state == 248:
                                                            return 0.0770157129
                                        if state == 108:
                                            state = (
                                                147
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 4.02562475)
                                                else 148
                                            )
                                            if state == 147:
                                                state = (
                                                    201
                                                    if x["distpsnr1_med"] < 0.870663881
                                                    else 202
                                                )
                                                if state == 201:
                                                    return 0.193472534
                                                if state == 202:
                                                    return -0.0894795954
                                            if state == 148:
                                                return -0.324818939
                                if state == 48:
                                    return 0.280449361
                        if state == 22:
                            return -0.371476799
                    if state == 14:
                        state = 23 if x["col_det"] < 0.828258514 else 24
                        if state == 23:
                            state = 33 if x["col_peak"] < 0.570474625 else 34
                            if state == 33:
                                state = 49 if x["maggaia_med"] < 19.2137451 else 50
                                if state == 49:
                                    return 0.153141707
                                if state == 50:
                                    state = 73 if x["col_det"] < 0.149950981 else 74
                                    if state == 73:
                                        return -0.11040213
                                    if state == 74:
                                        return 0.142998502
                            if state == 34:
                                state = 51 if x["maggaia_med"] < 16.2246666 else 52
                                if state == 51:
                                    return -0.095983319
                                if state == 52:
                                    return 0.376241982
                        if state == 24:
                            return -0.187904239
    elif num_booster == 20:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 19.0851231) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.8064995)
                    else 4
                )
                if state == 3:
                    state = 5 if x["col_peak"] < 0.0447359085 else 6
                    if state == 5:
                        state = 9 if x["sgscore1_med"] < 0.00104166649 else 10
                        if state == 9:
                            state = (
                                17
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 38.0123329)
                                else 18
                            )
                            if state == 17:
                                return -0.37106967
                            if state == 18:
                                return -0.0356655084
                        if state == 10:
                            state = (
                                19
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 45.8155823)
                                else 20
                            )
                            if state == 19:
                                state = (
                                    35
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.0239086)
                                    else 36
                                )
                                if state == 35:
                                    state = (
                                        57
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 16.9496002)
                                        else 58
                                    )
                                    if state == 57:
                                        return -0.127547234
                                    if state == 58:
                                        state = (
                                            89
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.981750011)
                                            else 90
                                        )
                                        if state == 89:
                                            state = (
                                                133
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.975250006)
                                                else 134
                                            )
                                            if state == 133:
                                                return -0.113144234
                                            if state == 134:
                                                state = (
                                                    187
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00170833501
                                                    )
                                                    else 188
                                                )
                                                if state == 187:
                                                    state = (
                                                        261
                                                        if x["mag_peak"] < 18.5915413
                                                        else 262
                                                    )
                                                    if state == 261:
                                                        state = (
                                                            349
                                                            if x["distpsnr1_med"]
                                                            < 0.370360851
                                                            else 350
                                                        )
                                                        if state == 349:
                                                            return 0.100628659
                                                        if state == 350:
                                                            return -0.257202536
                                                    if state == 262:
                                                        return 0.100744545
                                                if state == 188:
                                                    state = (
                                                        263
                                                        if x["mag_peak"] < 18.7410259
                                                        else 264
                                                    )
                                                    if state == 263:
                                                        state = (
                                                            351
                                                            if x["distpsnr1_med"]
                                                            < 2.85390854
                                                            else 352
                                                        )
                                                        if state == 351:
                                                            return 0.256740898
                                                        if state == 352:
                                                            return 0.0489729382
                                                    if state == 264:
                                                        return -0.0804913417
                                        if state == 90:
                                            return 0.20253408
                                if state == 36:
                                    state = (
                                        59
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.3405991)
                                        else 60
                                    )
                                    if state == 59:
                                        state = (
                                            91
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982249975)
                                            else 92
                                        )
                                        if state == 91:
                                            return -0.22718972
                                        if state == 92:
                                            state = (
                                                135
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.98300004)
                                                else 136
                                            )
                                            if state == 135:
                                                state = (
                                                    189
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.165264994)
                                                    else 190
                                                )
                                                if state == 189:
                                                    return 0.192115426
                                                if state == 190:
                                                    return -0.103880174
                                            if state == 136:
                                                return -0.0468620099
                                    if state == 60:
                                        state = (
                                            93
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.979750037)
                                            else 94
                                        )
                                        if state == 93:
                                            state = (
                                                137
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.95875001)
                                                else 138
                                            )
                                            if state == 137:
                                                state = (
                                                    193
                                                    if x["sgscore1_med"] < 0.01591965
                                                    else 194
                                                )
                                                if state == 193:
                                                    state = (
                                                        265
                                                        if x["mag_peak"] < 18.8954697
                                                        else 266
                                                    )
                                                    if state == 265:
                                                        return -0.0312978849
                                                    if state == 266:
                                                        return 0.170001388
                                                if state == 194:
                                                    return -0.20104228
                                            if state == 138:
                                                state = (
                                                    195
                                                    if x["sgscore1_med"] < 1.97970891
                                                    else 196
                                                )
                                                if state == 195:
                                                    state = (
                                                        267
                                                        if x["mag_peak"] < 18.998455
                                                        else 268
                                                    )
                                                    if state == 267:
                                                        state = (
                                                            353
                                                            if x["distpsnr1_med"]
                                                            < 0.86465627
                                                            else 354
                                                        )
                                                        if state == 353:
                                                            return 0.347563297
                                                        if state == 354:
                                                            return 0.168967396
                                                    if state == 268:
                                                        return -0.251628369
                                                if state == 196:
                                                    state = (
                                                        269
                                                        if x["mag_peak"] < 18.8910236
                                                        else 270
                                                    )
                                                    if state == 269:
                                                        state = (
                                                            355
                                                            if np.isnan(
                                                                x["distpsnr1_med"]
                                                            )
                                                            or (
                                                                x["distpsnr1_med"]
                                                                < 0.257362366
                                                            )
                                                            else 356
                                                        )
                                                        if state == 355:
                                                            return -0.104339354
                                                        if state == 356:
                                                            return 0.150446922
                                                    if state == 270:
                                                        return -0.189652577
                                        if state == 94:
                                            state = (
                                                139
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981250048)
                                                else 140
                                            )
                                            if state == 139:
                                                state = (
                                                    197
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0189791508
                                                    )
                                                    else 198
                                                )
                                                if state == 197:
                                                    state = (
                                                        271
                                                        if x["mag_peak"] < 18.9087696
                                                        else 272
                                                    )
                                                    if state == 271:
                                                        return 0.258633226
                                                    if state == 272:
                                                        state = (
                                                            359
                                                            if x["distpsnr1_med"]
                                                            < 2.36514115
                                                            else 360
                                                        )
                                                        if state == 359:
                                                            return 0.178504154
                                                        if state == 360:
                                                            return -0.137464613
                                                if state == 198:
                                                    state = (
                                                        273
                                                        if x["mag_peak"] < 18.8057671
                                                        else 274
                                                    )
                                                    if state == 273:
                                                        state = (
                                                            361
                                                            if x["distpsnr1_med"]
                                                            < 2.41071534
                                                            else 362
                                                        )
                                                        if state == 361:
                                                            return 0.193733349
                                                        if state == 362:
                                                            return -0.168230534
                                                    if state == 274:
                                                        return -0.348087043
                                            if state == 140:
                                                state = (
                                                    199
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0122499997
                                                    )
                                                    else 200
                                                )
                                                if state == 199:
                                                    state = (
                                                        275
                                                        if x["mag_peak"] < 18.8323116
                                                        else 276
                                                    )
                                                    if state == 275:
                                                        state = (
                                                            363
                                                            if x["distpsnr1_med"]
                                                            < 1.5934267
                                                            else 364
                                                        )
                                                        if state == 363:
                                                            return 0.154789746
                                                        if state == 364:
                                                            return 0.320810199
                                                    if state == 276:
                                                        state = (
                                                            365
                                                            if x["distpsnr1_med"]
                                                            < 1.53423774
                                                            else 366
                                                        )
                                                        if state == 365:
                                                            return 0.160226166
                                                        if state == 366:
                                                            return -0.275234312
                                                if state == 200:
                                                    state = (
                                                        277
                                                        if x["mag_peak"] < 18.5724602
                                                        else 278
                                                    )
                                                    if state == 277:
                                                        state = (
                                                            367
                                                            if x["distpsnr1_med"]
                                                            < 1.16578937
                                                            else 368
                                                        )
                                                        if state == 367:
                                                            return 0.0451214574
                                                        if state == 368:
                                                            return 0.310120344
                                                    if state == 278:
                                                        state = (
                                                            369
                                                            if x["distpsnr1_med"]
                                                            < 0.640827179
                                                            else 370
                                                        )
                                                        if state == 369:
                                                            return 0.178640842
                                                        if state == 370:
                                                            return -0.316081166
                            if state == 20:
                                state = (
                                    37
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.95854)
                                    else 38
                                )
                                if state == 37:
                                    state = (
                                        61
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.964901)
                                        else 62
                                    )
                                    if state == 61:
                                        return 0.243123204
                                    if state == 62:
                                        state = (
                                            95
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.97724998)
                                            else 96
                                        )
                                        if state == 95:
                                            state = (
                                                141
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.971750021)
                                                else 142
                                            )
                                            if state == 141:
                                                state = (
                                                    201
                                                    if x["sgscore1_med"] < 0.0277708005
                                                    else 202
                                                )
                                                if state == 201:
                                                    return 0.216246739
                                                if state == 202:
                                                    return -0.197204337
                                            if state == 142:
                                                state = (
                                                    203
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0294791497
                                                    )
                                                    else 204
                                                )
                                                if state == 203:
                                                    return 0.0760216787
                                                if state == 204:
                                                    return -0.216377527
                                        if state == 96:
                                            state = (
                                                143
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.979750037)
                                                else 144
                                            )
                                            if state == 143:
                                                return 0.0357274115
                                            if state == 144:
                                                state = (
                                                    205
                                                    if x["sgscore1_med"] < 0.879510522
                                                    else 206
                                                )
                                                if state == 205:
                                                    return 0.255357593
                                                if state == 206:
                                                    state = (
                                                        281
                                                        if x["mag_peak"] < 18.1245499
                                                        else 282
                                                    )
                                                    if state == 281:
                                                        return 0.109183826
                                                    if state == 282:
                                                        return -0.0988969579
                                if state == 38:
                                    return 0.301843464
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.663600981)
                            else 12
                        )
                        if state == 11:
                            state = (
                                21
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 20.9208508)
                                else 22
                            )
                            if state == 21:
                                state = (
                                    39
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.9967213)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        63
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.312851)
                                        else 64
                                    )
                                    if state == 63:
                                        state = (
                                            97
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.981250048)
                                            else 98
                                        )
                                        if state == 97:
                                            return -0.143792152
                                        if state == 98:
                                            state = (
                                                145
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.98574996)
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    207
                                                    if x["sgscore1_med"] < 0.0017708349
                                                    else 208
                                                )
                                                if state == 207:
                                                    state = (
                                                        283
                                                        if x["mag_peak"] < 18.4475174
                                                        else 284
                                                    )
                                                    if state == 283:
                                                        return -0.359051287
                                                    if state == 284:
                                                        return 0.134306833
                                                if state == 208:
                                                    state = (
                                                        285
                                                        if x["mag_peak"] < 18.2082214
                                                        else 286
                                                    )
                                                    if state == 285:
                                                        state = (
                                                            373
                                                            if x["distpsnr1_med"]
                                                            < 1.4366188
                                                            else 374
                                                        )
                                                        if state == 373:
                                                            return -0.150780708
                                                        if state == 374:
                                                            return 0.137271345
                                                    if state == 286:
                                                        state = (
                                                            375
                                                            if x["distpsnr1_med"]
                                                            < 2.11038303
                                                            else 376
                                                        )
                                                        if state == 375:
                                                            return 0.139018342
                                                        if state == 376:
                                                            return 0.324045092
                                            if state == 146:
                                                state = (
                                                    209
                                                    if x["sgscore1_med"] < 0.126041502
                                                    else 210
                                                )
                                                if state == 209:
                                                    return -0.365778804
                                                if state == 210:
                                                    return 0.0415168479
                                    if state == 64:
                                        state = (
                                            99
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982249975)
                                            else 100
                                        )
                                        if state == 99:
                                            state = (
                                                147
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.979250014)
                                                else 148
                                            )
                                            if state == 147:
                                                state = (
                                                    211
                                                    if x["sgscore1_med"] < 0.0405000001
                                                    else 212
                                                )
                                                if state == 211:
                                                    state = (
                                                        287
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.2465725)
                                                        else 288
                                                    )
                                                    if state == 287:
                                                        state = (
                                                            377
                                                            if x["distpsnr1_med"]
                                                            < 1.51704693
                                                            else 378
                                                        )
                                                        if state == 377:
                                                            return 0.278102934
                                                        if state == 378:
                                                            return 0.108096324
                                                    if state == 288:
                                                        return 0.0358142704
                                                if state == 212:
                                                    state = (
                                                        289
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 17.9247875)
                                                        else 290
                                                    )
                                                    if state == 289:
                                                        state = (
                                                            379
                                                            if x["distpsnr1_med"]
                                                            < 0.418882459
                                                            else 380
                                                        )
                                                        if state == 379:
                                                            return -0.230949819
                                                        if state == 380:
                                                            return 0.160116747
                                                    if state == 290:
                                                        state = (
                                                            381
                                                            if x["distpsnr1_med"]
                                                            < 1.5767777
                                                            else 382
                                                        )
                                                        if state == 381:
                                                            return -0.196579844
                                                        if state == 382:
                                                            return 0.056181293
                                            if state == 148:
                                                state = (
                                                    213
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0602440499
                                                    )
                                                    else 214
                                                )
                                                if state == 213:
                                                    state = (
                                                        291
                                                        if x["mag_peak"] < 17.963686
                                                        else 292
                                                    )
                                                    if state == 291:
                                                        return -0.365514487
                                                    if state == 292:
                                                        state = (
                                                            383
                                                            if np.isnan(
                                                                x["distpsnr1_med"]
                                                            )
                                                            or (
                                                                x["distpsnr1_med"]
                                                                < 0.686982155
                                                            )
                                                            else 384
                                                        )
                                                        if state == 383:
                                                            return 0.272442788
                                                        if state == 384:
                                                            return 0.0874439999
                                                if state == 214:
                                                    state = (
                                                        293
                                                        if x["mag_peak"] < 18.6589279
                                                        else 294
                                                    )
                                                    if state == 293:
                                                        return -0.313915759
                                                    if state == 294:
                                                        state = (
                                                            385
                                                            if x["distpsnr1_med"]
                                                            < 8.91433334
                                                            else 386
                                                        )
                                                        if state == 385:
                                                            return 0.0767275169
                                                        if state == 386:
                                                            return -0.40534696
                                        if state == 100:
                                            return 0.229503721
                                if state == 40:
                                    state = (
                                        65
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 21.1022491)
                                        else 66
                                    )
                                    if state == 65:
                                        state = (
                                            101
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.981250048)
                                            else 102
                                        )
                                        if state == 101:
                                            state = (
                                                149
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.859500051)
                                                else 150
                                            )
                                            if state == 149:
                                                return -0.309429049
                                            if state == 150:
                                                state = (
                                                    215
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00193749997
                                                    )
                                                    else 216
                                                )
                                                if state == 215:
                                                    state = (
                                                        295
                                                        if x["mag_peak"] < 18.7983379
                                                        else 296
                                                    )
                                                    if state == 295:
                                                        return 0.173108652
                                                    if state == 296:
                                                        state = (
                                                            387
                                                            if x["distpsnr1_med"]
                                                            < 0.385393322
                                                            else 388
                                                        )
                                                        if state == 387:
                                                            return -0.0434955098
                                                        if state == 388:
                                                            return -0.381693929
                                                if state == 216:
                                                    state = (
                                                        297
                                                        if x["mag_peak"] < 18.9451218
                                                        else 298
                                                    )
                                                    if state == 297:
                                                        state = (
                                                            389
                                                            if x["distpsnr1_med"]
                                                            < 1.17233324
                                                            else 390
                                                        )
                                                        if state == 389:
                                                            return -0.039248541
                                                        if state == 390:
                                                            return 0.141734585
                                                    if state == 298:
                                                        state = (
                                                            391
                                                            if x["distpsnr1_med"]
                                                            < 1.12203956
                                                            else 392
                                                        )
                                                        if state == 391:
                                                            return -0.26570648
                                                        if state == 392:
                                                            return -0.103645615
                                        if state == 102:
                                            state = (
                                                151
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982249975)
                                                else 152
                                            )
                                            if state == 151:
                                                state = (
                                                    217
                                                    if x["sgscore1_med"] < 0.0141041502
                                                    else 218
                                                )
                                                if state == 217:
                                                    state = (
                                                        299
                                                        if x["mag_peak"] < 18.9086037
                                                        else 300
                                                    )
                                                    if state == 299:
                                                        return 0.0555222668
                                                    if state == 300:
                                                        return -0.211407855
                                                if state == 218:
                                                    state = (
                                                        301
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.3210983)
                                                        else 302
                                                    )
                                                    if state == 301:
                                                        state = (
                                                            395
                                                            if x["distpsnr1_med"]
                                                            < 4.4363203
                                                            else 396
                                                        )
                                                        if state == 395:
                                                            return -0.0702684671
                                                        if state == 396:
                                                            return -0.367070287
                                                    if state == 302:
                                                        state = (
                                                            397
                                                            if x["distpsnr1_med"]
                                                            < 0.851408958
                                                            else 398
                                                        )
                                                        if state == 397:
                                                            return 0.0212574825
                                                        if state == 398:
                                                            return 0.300697058
                                            if state == 152:
                                                state = (
                                                    219
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0340208001
                                                    )
                                                    else 220
                                                )
                                                if state == 219:
                                                    state = (
                                                        303
                                                        if x["mag_peak"] < 18.9029102
                                                        else 304
                                                    )
                                                    if state == 303:
                                                        return 0.278366953
                                                    if state == 304:
                                                        state = (
                                                            399
                                                            if x["distpsnr1_med"]
                                                            < 1.16981041
                                                            else 400
                                                        )
                                                        if state == 399:
                                                            return -0.154752895
                                                        if state == 400:
                                                            return 0.0886925086
                                                if state == 220:
                                                    state = (
                                                        305
                                                        if x["mag_peak"] < 37.7155151
                                                        else 306
                                                    )
                                                    if state == 305:
                                                        return 0.149987787
                                                    if state == 306:
                                                        return -0.298729807
                                    if state == 66:
                                        state = (
                                            103
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.979499996)
                                            else 104
                                        )
                                        if state == 103:
                                            return 0.221189782
                                        if state == 104:
                                            return -0.0277965683
                            if state == 22:
                                state = (
                                    41
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.7903252)
                                    else 42
                                )
                                if state == 41:
                                    state = (
                                        67
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.7317505)
                                        else 68
                                    )
                                    if state == 67:
                                        state = (
                                            105
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.983749986)
                                            else 106
                                        )
                                        if state == 105:
                                            state = (
                                                153
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.979249954)
                                                else 154
                                            )
                                            if state == 153:
                                                state = (
                                                    221
                                                    if x["sgscore1_med"] < 0.157836497
                                                    else 222
                                                )
                                                if state == 221:
                                                    state = (
                                                        307
                                                        if x["mag_peak"] < 17.90415
                                                        else 308
                                                    )
                                                    if state == 307:
                                                        state = (
                                                            403
                                                            if x["distpsnr1_med"]
                                                            < 0.686449051
                                                            else 404
                                                        )
                                                        if state == 403:
                                                            return -0.0692563131
                                                        if state == 404:
                                                            return 0.103642233
                                                    if state == 308:
                                                        return 0.212899461
                                                if state == 222:
                                                    return -0.144133434
                                            if state == 154:
                                                state = (
                                                    223
                                                    if x["sgscore1_med"] < 0.401219994
                                                    else 224
                                                )
                                                if state == 223:
                                                    state = (
                                                        309
                                                        if x["mag_peak"] < 16.8153
                                                        else 310
                                                    )
                                                    if state == 309:
                                                        return -0.334935278
                                                    if state == 310:
                                                        state = (
                                                            407
                                                            if x["distpsnr1_med"]
                                                            < 1.50810814
                                                            else 408
                                                        )
                                                        if state == 407:
                                                            return -0.276293099
                                                        if state == 408:
                                                            return 0.235394806
                                                if state == 224:
                                                    state = (
                                                        311
                                                        if x["mag_peak"] < 17.5316849
                                                        else 312
                                                    )
                                                    if state == 311:
                                                        state = (
                                                            409
                                                            if x["distpsnr1_med"]
                                                            < 2.1393714
                                                            else 410
                                                        )
                                                        if state == 409:
                                                            return -0.263844281
                                                        if state == 410:
                                                            return 0.17061615
                                                    if state == 312:
                                                        state = (
                                                            411
                                                            if x["distpsnr1_med"]
                                                            < 8.68778801
                                                            else 412
                                                        )
                                                        if state == 411:
                                                            return 0.266170442
                                                        if state == 412:
                                                            return -0.123609439
                                        if state == 106:
                                            state = (
                                                155
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.985249996)
                                                else 156
                                            )
                                            if state == 155:
                                                return 0.299172342
                                            if state == 156:
                                                state = (
                                                    225
                                                    if x["sgscore1_med"] < 0.130833507
                                                    else 226
                                                )
                                                if state == 225:
                                                    return 0.0839404985
                                                if state == 226:
                                                    return -0.160412714
                                    if state == 68:
                                        state = (
                                            107
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982749999)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                157
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.973749995)
                                                else 158
                                            )
                                            if state == 157:
                                                state = (
                                                    227
                                                    if x["sgscore1_med"] < 0.14270851
                                                    else 228
                                                )
                                                if state == 227:
                                                    return 0.271762282
                                                if state == 228:
                                                    return -0.0108518023
                                            if state == 158:
                                                state = (
                                                    229
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0428274013
                                                    )
                                                    else 230
                                                )
                                                if state == 229:
                                                    state = (
                                                        313
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.3281059)
                                                        else 314
                                                    )
                                                    if state == 313:
                                                        return 0.250712574
                                                    if state == 314:
                                                        return -0.175693423
                                                if state == 230:
                                                    state = (
                                                        315
                                                        if x["mag_peak"] < 18.3918762
                                                        else 316
                                                    )
                                                    if state == 315:
                                                        return -0.148169011
                                                    if state == 316:
                                                        state = (
                                                            415
                                                            if x["distpsnr1_med"]
                                                            < 1.11318779
                                                            else 416
                                                        )
                                                        if state == 415:
                                                            return -0.126572028
                                                        if state == 416:
                                                            return 0.224986792
                                        if state == 108:
                                            state = (
                                                159
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.984500051)
                                                else 160
                                            )
                                            if state == 159:
                                                return 0.312903762
                                            if state == 160:
                                                return -0.0744293854
                                if state == 42:
                                    state = (
                                        69
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.4698505)
                                        else 70
                                    )
                                    if state == 69:
                                        state = (
                                            109
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.964249969)
                                            else 110
                                        )
                                        if state == 109:
                                            state = (
                                                161
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.917250037)
                                                else 162
                                            )
                                            if state == 161:
                                                return -0.299511969
                                            if state == 162:
                                                state = (
                                                    231
                                                    if x["sgscore1_med"] < 0.0342499986
                                                    else 232
                                                )
                                                if state == 231:
                                                    state = (
                                                        317
                                                        if x["mag_peak"] < 18.7004032
                                                        else 318
                                                    )
                                                    if state == 317:
                                                        return 0.312547565
                                                    if state == 318:
                                                        return -0.207267836
                                                if state == 232:
                                                    state = (
                                                        319
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.7057152)
                                                        else 320
                                                    )
                                                    if state == 319:
                                                        return -0.321466535
                                                    if state == 320:
                                                        state = (
                                                            417
                                                            if x["distpsnr1_med"]
                                                            < 2.1436832
                                                            else 418
                                                        )
                                                        if state == 417:
                                                            return 0.0771045983
                                                        if state == 418:
                                                            return -0.132258072
                                        if state == 110:
                                            state = (
                                                163
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982749999)
                                                else 164
                                            )
                                            if state == 163:
                                                state = (
                                                    233
                                                    if x["sgscore1_med"] < 0.0523125008
                                                    else 234
                                                )
                                                if state == 233:
                                                    state = (
                                                        321
                                                        if x["mag_peak"] < 18.835638
                                                        else 322
                                                    )
                                                    if state == 321:
                                                        state = (
                                                            419
                                                            if x["distpsnr1_med"]
                                                            < 0.138613582
                                                            else 420
                                                        )
                                                        if state == 419:
                                                            return -0.132040516
                                                        if state == 420:
                                                            return 0.315342963
                                                    if state == 322:
                                                        state = (
                                                            421
                                                            if x["distpsnr1_med"]
                                                            < 2.2162199
                                                            else 422
                                                        )
                                                        if state == 421:
                                                            return -0.200030595
                                                        if state == 422:
                                                            return 0.144116178
                                                if state == 234:
                                                    state = (
                                                        323
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.1329937)
                                                        else 324
                                                    )
                                                    if state == 323:
                                                        state = (
                                                            423
                                                            if np.isnan(
                                                                x["distpsnr1_med"]
                                                            )
                                                            or (
                                                                x["distpsnr1_med"]
                                                                < 0.686449051
                                                            )
                                                            else 424
                                                        )
                                                        if state == 423:
                                                            return 0.0807866976
                                                        if state == 424:
                                                            return -0.294052452
                                                    if state == 324:
                                                        state = (
                                                            425
                                                            if x["distpsnr1_med"]
                                                            < 1.89186454
                                                            else 426
                                                        )
                                                        if state == 425:
                                                            return 0.242952183
                                                        if state == 426:
                                                            return -0.0289822444
                                            if state == 164:
                                                state = (
                                                    235
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.505678535)
                                                    else 236
                                                )
                                                if state == 235:
                                                    state = (
                                                        325
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.3114014)
                                                        else 326
                                                    )
                                                    if state == 325:
                                                        state = (
                                                            427
                                                            if x["distpsnr1_med"]
                                                            < 1.40271306
                                                            else 428
                                                        )
                                                        if state == 427:
                                                            return 0.141182765
                                                        if state == 428:
                                                            return 0.340673923
                                                    if state == 326:
                                                        state = (
                                                            429
                                                            if x["distpsnr1_med"]
                                                            < 1.47680354
                                                            else 430
                                                        )
                                                        if state == 429:
                                                            return -0.307098925
                                                        if state == 430:
                                                            return 0.190143541
                                                if state == 236:
                                                    state = (
                                                        327
                                                        if x["mag_peak"] < 17.8423691
                                                        else 328
                                                    )
                                                    if state == 327:
                                                        state = (
                                                            431
                                                            if x["distpsnr1_med"]
                                                            < 1.9336648
                                                            else 432
                                                        )
                                                        if state == 431:
                                                            return -0.116164781
                                                        if state == 432:
                                                            return 0.156932905
                                                    if state == 328:
                                                        return -0.288229853
                                    if state == 70:
                                        state = (
                                            111
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.949500024)
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                165
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.838750005)
                                                else 166
                                            )
                                            if state == 165:
                                                state = (
                                                    237
                                                    if x["sgscore1_med"]
                                                    < 0.000916666526
                                                    else 238
                                                )
                                                if state == 237:
                                                    return 0.187446728
                                                if state == 238:
                                                    return -0.287858337
                                            if state == 166:
                                                state = (
                                                    239
                                                    if x["sgscore1_med"] < 0.00835416466
                                                    else 240
                                                )
                                                if state == 239:
                                                    state = (
                                                        329
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.2238503)
                                                        else 330
                                                    )
                                                    if state == 329:
                                                        state = (
                                                            433
                                                            if x["distpsnr1_med"]
                                                            < 1.08971167
                                                            else 434
                                                        )
                                                        if state == 433:
                                                            return 0.149872109
                                                        if state == 434:
                                                            return -0.187678143
                                                    if state == 330:
                                                        state = (
                                                            435
                                                            if x["distpsnr1_med"]
                                                            < 0.730934501
                                                            else 436
                                                        )
                                                        if state == 435:
                                                            return 0.299051285
                                                        if state == 436:
                                                            return -0.134779438
                                                if state == 240:
                                                    state = (
                                                        331
                                                        if x["mag_peak"] < 18.8888092
                                                        else 332
                                                    )
                                                    if state == 331:
                                                        state = (
                                                            437
                                                            if x["distpsnr1_med"]
                                                            < 1.48039794
                                                            else 438
                                                        )
                                                        if state == 437:
                                                            return -0.187367424
                                                        if state == 438:
                                                            return 0.289758027
                                                    if state == 332:
                                                        return -0.331111193
                                        if state == 112:
                                            state = (
                                                167
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.953249991)
                                                else 168
                                            )
                                            if state == 167:
                                                state = (
                                                    241
                                                    if x["sgscore1_med"] < 0.0351815522
                                                    else 242
                                                )
                                                if state == 241:
                                                    return 0.00751165114
                                                if state == 242:
                                                    state = (
                                                        335
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.4101124)
                                                        else 336
                                                    )
                                                    if state == 335:
                                                        state = (
                                                            439
                                                            if np.isnan(
                                                                x["distpsnr1_med"]
                                                            )
                                                            or (
                                                                x["distpsnr1_med"]
                                                                < 3.52948785
                                                            )
                                                            else 440
                                                        )
                                                        if state == 439:
                                                            return -0.12982139
                                                        if state == 440:
                                                            return 0.24832885
                                                    if state == 336:
                                                        return 0.408165693
                                            if state == 168:
                                                state = (
                                                    243
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.153369993)
                                                    else 244
                                                )
                                                if state == 243:
                                                    state = (
                                                        337
                                                        if x["mag_peak"] < 19.0781116
                                                        else 338
                                                    )
                                                    if state == 337:
                                                        state = (
                                                            441
                                                            if np.isnan(
                                                                x["distpsnr1_med"]
                                                            )
                                                            or (
                                                                x["distpsnr1_med"]
                                                                < 1.39340854
                                                            )
                                                            else 442
                                                        )
                                                        if state == 441:
                                                            return 0.196983561
                                                        if state == 442:
                                                            return 0.0196547508
                                                    if state == 338:
                                                        state = (
                                                            443
                                                            if x["distpsnr1_med"]
                                                            < 1.27764845
                                                            else 444
                                                        )
                                                        if state == 443:
                                                            return -0.0921500027
                                                        if state == 444:
                                                            return -0.313907534
                                                if state == 244:
                                                    state = (
                                                        339
                                                        if x["mag_peak"] < 18.5650787
                                                        else 340
                                                    )
                                                    if state == 339:
                                                        state = (
                                                            445
                                                            if x["distpsnr1_med"]
                                                            < 2.68090606
                                                            else 446
                                                        )
                                                        if state == 445:
                                                            return 0.24360624
                                                        if state == 446:
                                                            return -0.0878509209
                                                    if state == 340:
                                                        state = (
                                                            447
                                                            if x["distpsnr1_med"]
                                                            < 2.26480198
                                                            else 448
                                                        )
                                                        if state == 447:
                                                            return -0.36749205
                                                        if state == 448:
                                                            return -0.0191543605
                        if state == 12:
                            state = (
                                23
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 18.0479279)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    43
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.5475998)
                                    else 44
                                )
                                if state == 43:
                                    state = (
                                        71
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.705349)
                                        else 72
                                    )
                                    if state == 71:
                                        return -0.0510053411
                                    if state == 72:
                                        return 0.161302686
                                if state == 44:
                                    return -0.248782843
                            if state == 24:
                                return -0.327553183
                if state == 4:
                    state = 7 if x["col_peak"] < -0.116565704 else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.731657982)
                            else 14
                        )
                        if state == 13:
                            state = (
                                25
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 46.9102669)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    45
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 17.7061367)
                                    else 46
                                )
                                if state == 45:
                                    return 0.0167828649
                                if state == 46:
                                    state = (
                                        73
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.0522995)
                                        else 74
                                    )
                                    if state == 73:
                                        return -0.321977168
                                    if state == 74:
                                        return 0.0541712567
                            if state == 26:
                                return -0.0355937481
                        if state == 14:
                            state = (
                                27
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 13.0415688)
                                else 28
                            )
                            if state == 27:
                                return -0.148617133
                            if state == 28:
                                return 0.236369535
                    if state == 8:
                        state = 15 if x["sgscore1_med"] < 0.489187479 else 16
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 9.03598404)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    49
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.5557499)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        75
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.2807999)
                                        else 76
                                    )
                                    if state == 75:
                                        return -0.167431772
                                    if state == 76:
                                        return 0.355123848
                                if state == 50:
                                    return -0.165482581
                            if state == 30:
                                state = (
                                    51
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.006546)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        77
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.0494995)
                                        else 78
                                    )
                                    if state == 77:
                                        state = (
                                            121
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.983250022)
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                173
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981750011)
                                                else 174
                                            )
                                            if state == 173:
                                                state = (
                                                    245
                                                    if x["sgscore1_med"] < 0.00687499996
                                                    else 246
                                                )
                                                if state == 245:
                                                    return 0.110214844
                                                if state == 246:
                                                    return -0.108883947
                                            if state == 174:
                                                state = (
                                                    247
                                                    if x["sgscore1_med"] < 0.111033849
                                                    else 248
                                                )
                                                if state == 247:
                                                    return 0.158438742
                                                if state == 248:
                                                    return -0.383551568
                                        if state == 122:
                                            return 0.11082121
                                    if state == 78:
                                        state = (
                                            123
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.981750011)
                                            else 124
                                        )
                                        if state == 123:
                                            return 0.198643833
                                        if state == 124:
                                            state = (
                                                175
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982249975)
                                                else 176
                                            )
                                            if state == 175:
                                                return -0.126931354
                                            if state == 176:
                                                return 0.178934813
                                if state == 52:
                                    state = (
                                        79
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.4888)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            125
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982749999)
                                            else 126
                                        )
                                        if state == 125:
                                            return -0.223901376
                                        if state == 126:
                                            return -0.0130034704
                                    if state == 80:
                                        return -0.372628719
                        if state == 16:
                            state = (
                                31
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 23.9630203)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    53
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.1224861)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        81
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.6893997)
                                        else 82
                                    )
                                    if state == 81:
                                        return -0.167356521
                                    if state == 82:
                                        state = (
                                            127
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.963500023)
                                            else 128
                                        )
                                        if state == 127:
                                            state = (
                                                177
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.959500015)
                                                else 178
                                            )
                                            if state == 177:
                                                return 0.198069692
                                            if state == 178:
                                                return -0.139224827
                                        if state == 128:
                                            state = (
                                                179
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.977750003)
                                                else 180
                                            )
                                            if state == 179:
                                                return 0.37709868
                                            if state == 180:
                                                state = (
                                                    251
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.554510474)
                                                    else 252
                                                )
                                                if state == 251:
                                                    return 0.23219882
                                                if state == 252:
                                                    return -0.0356643014
                                if state == 54:
                                    state = (
                                        83
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.3519516)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            129
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.971249998)
                                            else 130
                                        )
                                        if state == 129:
                                            return -0.20214577
                                        if state == 130:
                                            state = (
                                                181
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.979750037)
                                                else 182
                                            )
                                            if state == 181:
                                                state = (
                                                    253
                                                    if x["sgscore1_med"] < 0.960672975
                                                    else 254
                                                )
                                                if state == 253:
                                                    return 0.231167987
                                                if state == 254:
                                                    return -0.115411639
                                            if state == 182:
                                                state = (
                                                    255
                                                    if x["sgscore1_med"] < 0.618071496
                                                    else 256
                                                )
                                                if state == 255:
                                                    state = (
                                                        343
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.6827221)
                                                        else 344
                                                    )
                                                    if state == 343:
                                                        return -0.12971133
                                                    if state == 344:
                                                        return 0.129266486
                                                if state == 256:
                                                    return -0.146955922
                                    if state == 84:
                                        return -0.300120443
                            if state == 32:
                                state = (
                                    55
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.3419075)
                                    else 56
                                )
                                if state == 55:
                                    return 0.247737214
                                if state == 56:
                                    state = (
                                        87
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.6504002)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            131
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.978249967)
                                            else 132
                                        )
                                        if state == 131:
                                            state = (
                                                183
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.976500034)
                                                else 184
                                            )
                                            if state == 183:
                                                state = (
                                                    257
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.897550464)
                                                    else 258
                                                )
                                                if state == 257:
                                                    return -0.184638515
                                                if state == 258:
                                                    return 0.0925007015
                                            if state == 184:
                                                return -0.207186073
                                        if state == 132:
                                            return 0.200138271
                                    if state == 88:
                                        return -0.115013689
            if state == 2:
                return -0.335062712
    elif num_booster == 21:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.569804192) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.963500023)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4507751)
                        else 8
                    )
                    if state == 7:
                        state = 13 if x["sgscore1_med"] < 0.0036249999 else 14
                        if state == 13:
                            state = 23 if x["mag_peak"] < 18.8910828 else 24
                            if state == 23:
                                return -0.0918680206
                            if state == 24:
                                state = 39 if x["col_last"] < 0.0447435379 else 40
                                if state == 39:
                                    state = (
                                        59
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.467619032)
                                        else 60
                                    )
                                    if state == 59:
                                        return -0.00492859771
                                    if state == 60:
                                        return 0.426600516
                                if state == 40:
                                    state = (
                                        61
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.688333333)
                                        else 62
                                    )
                                    if state == 61:
                                        return 0.254815817
                                    if state == 62:
                                        return -0.201412305
                        if state == 14:
                            state = 25 if x["mag_peak"] < 18.6546478 else 26
                            if state == 25:
                                state = (
                                    41
                                    if np.isnan(x["col_last"])
                                    or (x["col_last"] < 0.585561752)
                                    else 42
                                )
                                if state == 41:
                                    state = (
                                        63
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.449999988)
                                        else 64
                                    )
                                    if state == 63:
                                        state = (
                                            89
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.7940083)
                                            else 90
                                        )
                                        if state == 89:
                                            return -0.0977398679
                                        if state == 90:
                                            return 0.0986932367
                                    if state == 64:
                                        state = (
                                            91
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.8365631)
                                            else 92
                                        )
                                        if state == 91:
                                            return 0.00218378822
                                        if state == 92:
                                            return -0.265367866
                                if state == 42:
                                    return 0.0221270639
                            if state == 26:
                                state = 43 if x["col_last"] < -0.0818634033 else 44
                                if state == 43:
                                    state = (
                                        65
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.402500093)
                                        else 66
                                    )
                                    if state == 65:
                                        return 0.0768297613
                                    if state == 66:
                                        return -0.24426733
                                if state == 44:
                                    state = (
                                        67
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.578571498)
                                        else 68
                                    )
                                    if state == 67:
                                        state = (
                                            93
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.4314423)
                                            else 94
                                        )
                                        if state == 93:
                                            return 0.0703930557
                                        if state == 94:
                                            return 0.420807242
                                    if state == 68:
                                        state = (
                                            95
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.5980759)
                                            else 96
                                        )
                                        if state == 95:
                                            return 0.201794177
                                        if state == 96:
                                            state = (
                                                125
                                                if x["col_peak"] < 1.08985233
                                                else 126
                                            )
                                            if state == 125:
                                                return -0.278650403
                                            if state == 126:
                                                state = (
                                                    165
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.96034098)
                                                    else 166
                                                )
                                                if state == 165:
                                                    state = (
                                                        211
                                                        if x["mag_peak"] < 18.6592484
                                                        else 212
                                                    )
                                                    if state == 211:
                                                        return 0.147277355
                                                    if state == 212:
                                                        state = (
                                                            271
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"] < 0.70071429
                                                            )
                                                            else 272
                                                        )
                                                        if state == 271:
                                                            return 0.00215874519
                                                        if state == 272:
                                                            return -0.259355307
                                                if state == 166:
                                                    return -0.351471305
                    if state == 8:
                        state = 15 if x["sgscore1_med"] < 0.000875000027 else 16
                        if state == 15:
                            state = 27 if x["mag_peak"] < 18.5026436 else 28
                            if state == 27:
                                return 0.297568917
                            if state == 28:
                                return -0.154828891
                        if state == 16:
                            state = 29 if x["mag_peak"] < 18.9262505 else 30
                            if state == 29:
                                state = (
                                    45
                                    if np.isnan(x["col_last"])
                                    or (x["col_last"] < -0.161618233)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        69
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.447618723)
                                        else 70
                                    )
                                    if state == 69:
                                        return -0.234114006
                                    if state == 70:
                                        state = (
                                            97
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.8616371)
                                            else 98
                                        )
                                        if state == 97:
                                            state = (
                                                127
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.196324021)
                                                else 128
                                            )
                                            if state == 127:
                                                state = (
                                                    167
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.923650026)
                                                    else 168
                                                )
                                                if state == 167:
                                                    state = (
                                                        213
                                                        if x["mag_peak"] < 18.2715721
                                                        else 214
                                                    )
                                                    if state == 213:
                                                        return 0.183402583
                                                    if state == 214:
                                                        return -0.196171761
                                                if state == 168:
                                                    return 0.207655117
                                            if state == 128:
                                                return -0.147929311
                                        if state == 98:
                                            state = (
                                                129
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.107480526)
                                                else 130
                                            )
                                            if state == 129:
                                                state = (
                                                    171
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.484874815)
                                                    else 172
                                                )
                                                if state == 171:
                                                    return -0.0132282637
                                                if state == 172:
                                                    state = (
                                                        215
                                                        if x["mag_peak"] < 18.8934402
                                                        else 216
                                                    )
                                                    if state == 215:
                                                        state = (
                                                            273
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.543571472
                                                            )
                                                            else 274
                                                        )
                                                        if state == 273:
                                                            return 0.0948072448
                                                        if state == 274:
                                                            return 0.345053285
                                                    if state == 216:
                                                        return 0.0124574872
                                            if state == 130:
                                                return -0.126537889
                                if state == 46:
                                    state = (
                                        71
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.512261868)
                                        else 72
                                    )
                                    if state == 71:
                                        return -0.15980351
                                    if state == 72:
                                        state = (
                                            99
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.7438622)
                                            else 100
                                        )
                                        if state == 99:
                                            return -0.0868347958
                                        if state == 100:
                                            return 0.105832532
                            if state == 30:
                                return -0.315792292
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.1658325)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["sgscore1_med"] < 0.00570833031 else 18
                        if state == 17:
                            state = 31 if x["mag_peak"] < 17.3932228 else 32
                            if state == 31:
                                return -0.250526994
                            if state == 32:
                                state = 49 if x["col_last"] < -0.158408165 else 50
                                if state == 49:
                                    return -0.333657414
                                if state == 50:
                                    state = (
                                        73
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.726190448)
                                        else 74
                                    )
                                    if state == 73:
                                        return 0.198425218
                                    if state == 74:
                                        state = (
                                            101
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 17.4770279)
                                            else 102
                                        )
                                        if state == 101:
                                            return -0.177988023
                                        if state == 102:
                                            return 0.139978573
                        if state == 18:
                            state = 33 if x["mag_peak"] < 16.9128304 else 34
                            if state == 33:
                                state = 51 if x["col_last"] < -0.115380764 else 52
                                if state == 51:
                                    state = (
                                        75
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.63166678)
                                        else 76
                                    )
                                    if state == 75:
                                        return 0.0277709011
                                    if state == 76:
                                        return -0.269948781
                                if state == 52:
                                    state = (
                                        77
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.596071422)
                                        else 78
                                    )
                                    if state == 77:
                                        state = (
                                            103
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 16.688448)
                                            else 104
                                        )
                                        if state == 103:
                                            return 0.124018088
                                        if state == 104:
                                            state = (
                                                131
                                                if x["col_peak"] < 0.110124588
                                                else 132
                                            )
                                            if state == 131:
                                                return 0.149623007
                                            if state == 132:
                                                state = (
                                                    173
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.86906481)
                                                    else 174
                                                )
                                                if state == 173:
                                                    return 0.0574983768
                                                if state == 174:
                                                    return -0.191737413
                                    if state == 78:
                                        state = (
                                            105
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 17.79776)
                                            else 106
                                        )
                                        if state == 105:
                                            state = (
                                                133
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.289935589)
                                                else 134
                                            )
                                            if state == 133:
                                                state = (
                                                    175
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.635224164)
                                                    else 176
                                                )
                                                if state == 175:
                                                    return -0.13817136
                                                if state == 176:
                                                    state = (
                                                        217
                                                        if x["mag_peak"] < 16.5405769
                                                        else 218
                                                    )
                                                    if state == 217:
                                                        return 0.136093915
                                                    if state == 218:
                                                        return -0.0370922759
                                            if state == 134:
                                                return 0.227299303
                                        if state == 106:
                                            return 0.0365096964
                            if state == 34:
                                state = 53 if x["col_last"] < -0.242170334 else 54
                                if state == 53:
                                    return 0.0351068303
                                if state == 54:
                                    state = (
                                        79
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.646666825)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            107
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 17.8735504)
                                            else 108
                                        )
                                        if state == 107:
                                            return 0.203490898
                                        if state == 108:
                                            state = (
                                                137
                                                if x["col_peak"] < 0.0240716934
                                                else 138
                                            )
                                            if state == 137:
                                                return 0.12000116
                                            if state == 138:
                                                state = (
                                                    177
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.22725749)
                                                    else 178
                                                )
                                                if state == 177:
                                                    state = (
                                                        219
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 17.7440834)
                                                        else 220
                                                    )
                                                    if state == 219:
                                                        state = (
                                                            277
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.631666839
                                                            )
                                                            else 278
                                                        )
                                                        if state == 277:
                                                            return 0.0229903739
                                                        if state == 278:
                                                            return -0.292835087
                                                    if state == 220:
                                                        return -0.00749103911
                                                if state == 178:
                                                    state = (
                                                        221
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 17.86063)
                                                        else 222
                                                    )
                                                    if state == 221:
                                                        return 0.245660901
                                                    if state == 222:
                                                        return -0.104858793
                                    if state == 80:
                                        state = (
                                            109
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 17.8150692)
                                            else 110
                                        )
                                        if state == 109:
                                            return 0.326624393
                                        if state == 110:
                                            state = (
                                                139
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.260505199)
                                                else 140
                                            )
                                            if state == 139:
                                                state = (
                                                    179
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 4.22701263)
                                                    else 180
                                                )
                                                if state == 179:
                                                    state = (
                                                        223
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 17.9416199)
                                                        else 224
                                                    )
                                                    if state == 223:
                                                        return 0.239892825
                                                    if state == 224:
                                                        return -0.0393944196
                                                if state == 180:
                                                    return -0.0546930507
                                            if state == 140:
                                                return -0.0152900927
                    if state == 10:
                        state = 19 if x["sgscore1_med"] < 0.00095833349 else 20
                        if state == 19:
                            state = 35 if x["mag_peak"] < 18.2994423 else 36
                            if state == 35:
                                return 0.194414243
                            if state == 36:
                                return -0.217521533
                        if state == 20:
                            state = (
                                37
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 18.9997444)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    55
                                    if np.isnan(x["col_last"])
                                    or (x["col_last"] < 0.236886978)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        81
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.490714312)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            111
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.8113556)
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                141
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.193062305)
                                                else 142
                                            )
                                            if state == 141:
                                                state = (
                                                    181
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.52495003)
                                                    else 182
                                                )
                                                if state == 181:
                                                    state = (
                                                        225
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.2629013)
                                                        else 226
                                                    )
                                                    if state == 225:
                                                        state = (
                                                            279
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.428333163
                                                            )
                                                            else 280
                                                        )
                                                        if state == 279:
                                                            return 0.166811243
                                                        if state == 280:
                                                            return -0.032682009
                                                    if state == 226:
                                                        state = (
                                                            281
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.395000219
                                                            )
                                                            else 282
                                                        )
                                                        if state == 281:
                                                            return -0.28058216
                                                        if state == 282:
                                                            return 0.150538549
                                                if state == 182:
                                                    state = (
                                                        227
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.8128662)
                                                        else 228
                                                    )
                                                    if state == 227:
                                                        state = (
                                                            283
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.468452394
                                                            )
                                                            else 284
                                                        )
                                                        if state == 283:
                                                            return 0.105158694
                                                        if state == 284:
                                                            return 0.268924117
                                                    if state == 228:
                                                        return -0.178871691
                                            if state == 142:
                                                state = (
                                                    183
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.07265663)
                                                    else 184
                                                )
                                                if state == 183:
                                                    state = (
                                                        229
                                                        if x["mag_peak"] < 18.9467621
                                                        else 230
                                                    )
                                                    if state == 229:
                                                        return -0.339214414
                                                    if state == 230:
                                                        return 0.134628668
                                                if state == 184:
                                                    state = (
                                                        231
                                                        if x["mag_peak"] < 18.6716919
                                                        else 232
                                                    )
                                                    if state == 231:
                                                        state = (
                                                            287
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.251666486
                                                            )
                                                            else 288
                                                        )
                                                        if state == 287:
                                                            return -0.10961543
                                                        if state == 288:
                                                            return 0.244678974
                                                    if state == 232:
                                                        return -0.182684377
                                        if state == 112:
                                            state = (
                                                143
                                                if x["col_peak"] < -0.258618355
                                                else 144
                                            )
                                            if state == 143:
                                                return 0.0323826931
                                            if state == 144:
                                                state = (
                                                    185
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.72482157)
                                                    else 186
                                                )
                                                if state == 185:
                                                    return 0.270135939
                                                if state == 186:
                                                    state = (
                                                        233
                                                        if x["mag_peak"] < 18.5825768
                                                        else 234
                                                    )
                                                    if state == 233:
                                                        return 0.24074997
                                                    if state == 234:
                                                        return -0.164947465
                                    if state == 82:
                                        state = (
                                            113
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.8632965)
                                            else 114
                                        )
                                        if state == 113:
                                            state = (
                                                145
                                                if x["col_peak"] < 0.0447359085
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    187
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.55417824)
                                                    else 188
                                                )
                                                if state == 187:
                                                    state = (
                                                        235
                                                        if x["mag_peak"] < 18.9543343
                                                        else 236
                                                    )
                                                    if state == 235:
                                                        state = (
                                                            289
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.755714357
                                                            )
                                                            else 290
                                                        )
                                                        if state == 289:
                                                            return 0.0158780497
                                                        if state == 290:
                                                            return 0.173708946
                                                    if state == 236:
                                                        return 0.271430075
                                                if state == 188:
                                                    state = (
                                                        237
                                                        if x["mag_peak"] < 18.5704651
                                                        else 238
                                                    )
                                                    if state == 237:
                                                        state = (
                                                            293
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.905000091
                                                            )
                                                            else 294
                                                        )
                                                        if state == 293:
                                                            return 0.161370218
                                                        if state == 294:
                                                            return -0.097847715
                                                    if state == 238:
                                                        state = (
                                                            295
                                                            if np.isnan(x["rb_med"])
                                                            or (x["rb_med"] < 0.625)
                                                            else 296
                                                        )
                                                        if state == 295:
                                                            return -0.0521238931
                                                        if state == 296:
                                                            return -0.335662603
                                            if state == 146:
                                                state = (
                                                    189
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.38019848)
                                                    else 190
                                                )
                                                if state == 189:
                                                    state = (
                                                        239
                                                        if x["mag_peak"] < 17.4641151
                                                        else 240
                                                    )
                                                    if state == 239:
                                                        state = (
                                                            297
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.784166753
                                                            )
                                                            else 298
                                                        )
                                                        if state == 297:
                                                            return 0.285396159
                                                        if state == 298:
                                                            return -0.0150146075
                                                    if state == 240:
                                                        state = (
                                                            299
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.622261763
                                                            )
                                                            else 300
                                                        )
                                                        if state == 299:
                                                            return -0.0940200537
                                                        if state == 300:
                                                            return 0.0435322635
                                                if state == 190:
                                                    state = (
                                                        241
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.7856255)
                                                        else 242
                                                    )
                                                    if state == 241:
                                                        state = (
                                                            301
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.523928463
                                                            )
                                                            else 302
                                                        )
                                                        if state == 301:
                                                            return 0.0927198157
                                                        if state == 302:
                                                            return -0.0918417573
                                                    if state == 242:
                                                        state = (
                                                            303
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.702499986
                                                            )
                                                            else 304
                                                        )
                                                        if state == 303:
                                                            return 0.197935745
                                                        if state == 304:
                                                            return -0.0123859709
                                        if state == 114:
                                            state = (
                                                147
                                                if x["col_peak"] < 0.362915993
                                                else 148
                                            )
                                            if state == 147:
                                                state = (
                                                    191
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.2859633)
                                                    else 192
                                                )
                                                if state == 191:
                                                    state = (
                                                        243
                                                        if x["mag_peak"] < 18.8160381
                                                        else 244
                                                    )
                                                    if state == 243:
                                                        state = (
                                                            305
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.596071541
                                                            )
                                                            else 306
                                                        )
                                                        if state == 305:
                                                            return -0.0224151053
                                                        if state == 306:
                                                            return 0.254181176
                                                    if state == 244:
                                                        state = (
                                                            307
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.598571539
                                                            )
                                                            else 308
                                                        )
                                                        if state == 307:
                                                            return -0.223741904
                                                        if state == 308:
                                                            return 0.0693020076
                                                if state == 192:
                                                    state = (
                                                        245
                                                        if x["mag_peak"] < 18.7201233
                                                        else 246
                                                    )
                                                    if state == 245:
                                                        state = (
                                                            309
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.673452377
                                                            )
                                                            else 310
                                                        )
                                                        if state == 309:
                                                            return -0.0416297652
                                                        if state == 310:
                                                            return 0.155970827
                                                    if state == 246:
                                                        state = (
                                                            311
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.642976403
                                                            )
                                                            else 312
                                                        )
                                                        if state == 311:
                                                            return 0.0984982103
                                                        if state == 312:
                                                            return -0.332844019
                                            if state == 148:
                                                state = (
                                                    193
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 5.36353302)
                                                    else 194
                                                )
                                                if state == 193:
                                                    state = (
                                                        247
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 16.4161568)
                                                        else 248
                                                    )
                                                    if state == 247:
                                                        return -0.190811023
                                                    if state == 248:
                                                        state = (
                                                            313
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.542261899
                                                            )
                                                            else 314
                                                        )
                                                        if state == 313:
                                                            return -0.0329694115
                                                        if state == 314:
                                                            return 0.247210056
                                                if state == 194:
                                                    state = (
                                                        249
                                                        if x["mag_peak"] < 18.3996468
                                                        else 250
                                                    )
                                                    if state == 249:
                                                        return 0.0302124154
                                                    if state == 250:
                                                        return -0.361135244
                                if state == 56:
                                    state = (
                                        83
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.747142911)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            115
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.4375687)
                                            else 116
                                        )
                                        if state == 115:
                                            state = (
                                                149
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.129175186)
                                                else 150
                                            )
                                            if state == 149:
                                                state = (
                                                    195
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.19823146)
                                                    else 196
                                                )
                                                if state == 195:
                                                    state = (
                                                        251
                                                        if x["mag_peak"] < 18.3606091
                                                        else 252
                                                    )
                                                    if state == 251:
                                                        state = (
                                                            315
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.725000024
                                                            )
                                                            else 316
                                                        )
                                                        if state == 315:
                                                            return 0.163390994
                                                        if state == 316:
                                                            return -0.147050858
                                                    if state == 252:
                                                        state = (
                                                            317
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.597857237
                                                            )
                                                            else 318
                                                        )
                                                        if state == 317:
                                                            return 0.136086553
                                                        if state == 318:
                                                            return -0.208243921
                                                if state == 196:
                                                    state = (
                                                        253
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.9087486)
                                                        else 254
                                                    )
                                                    if state == 253:
                                                        state = (
                                                            319
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.696547627
                                                            )
                                                            else 320
                                                        )
                                                        if state == 319:
                                                            return 0.0711810216
                                                        if state == 320:
                                                            return 0.249293447
                                                    if state == 254:
                                                        return -0.0777305737
                                            if state == 150:
                                                state = (
                                                    197
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.5587492)
                                                    else 198
                                                )
                                                if state == 197:
                                                    state = (
                                                        255
                                                        if x["mag_peak"] < 17.9062653
                                                        else 256
                                                    )
                                                    if state == 255:
                                                        return -0.0422650836
                                                    if state == 256:
                                                        state = (
                                                            325
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.634166956
                                                            )
                                                            else 326
                                                        )
                                                        if state == 325:
                                                            return -0.21746701
                                                        if state == 326:
                                                            return -0.0391634107
                                                if state == 198:
                                                    return 0.0419898257
                                        if state == 116:
                                            state = (
                                                151
                                                if x["col_peak"] < -0.17713356
                                                else 152
                                            )
                                            if state == 151:
                                                state = (
                                                    199
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.34816432)
                                                    else 200
                                                )
                                                if state == 199:
                                                    state = (
                                                        257
                                                        if x["mag_peak"] < 18.4721909
                                                        else 258
                                                    )
                                                    if state == 257:
                                                        return 0.0573523566
                                                    if state == 258:
                                                        return -0.290858835
                                                if state == 200:
                                                    return 0.105496734
                                            if state == 152:
                                                state = (
                                                    201
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.96155787)
                                                    else 202
                                                )
                                                if state == 201:
                                                    state = (
                                                        259
                                                        if x["mag_peak"] < 18.7567825
                                                        else 260
                                                    )
                                                    if state == 259:
                                                        state = (
                                                            327
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.566190362
                                                            )
                                                            else 328
                                                        )
                                                        if state == 327:
                                                            return 0.00289894082
                                                        if state == 328:
                                                            return 0.268612027
                                                    if state == 260:
                                                        state = (
                                                            329
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"] < 0.50345242
                                                            )
                                                            else 330
                                                        )
                                                        if state == 329:
                                                            return 0.263484925
                                                        if state == 330:
                                                            return -0.0772526413
                                                if state == 202:
                                                    state = (
                                                        261
                                                        if x["mag_peak"] < 18.9825935
                                                        else 262
                                                    )
                                                    if state == 261:
                                                        state = (
                                                            331
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.534285545
                                                            )
                                                            else 332
                                                        )
                                                        if state == 331:
                                                            return -0.010047392
                                                        if state == 332:
                                                            return 0.19006452
                                                    if state == 262:
                                                        return -0.25528571
                                    if state == 84:
                                        state = (
                                            117
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.9424877)
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                153
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.415140331)
                                                else 154
                                            )
                                            if state == 153:
                                                state = (
                                                    203
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.204109788)
                                                    else 204
                                                )
                                                if state == 203:
                                                    return -0.113041066
                                                if state == 204:
                                                    state = (
                                                        263
                                                        if x["mag_peak"] < 18.5768452
                                                        else 264
                                                    )
                                                    if state == 263:
                                                        return 0.328999311
                                                    if state == 264:
                                                        state = (
                                                            333
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.796071529
                                                            )
                                                            else 334
                                                        )
                                                        if state == 333:
                                                            return 0.208175316
                                                        if state == 334:
                                                            return 0.0356916897
                                            if state == 154:
                                                return -0.173138648
                                        if state == 118:
                                            state = (
                                                155
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.134417534)
                                                else 156
                                            )
                                            if state == 155:
                                                state = (
                                                    205
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 4.29719973)
                                                    else 206
                                                )
                                                if state == 205:
                                                    state = (
                                                        265
                                                        if x["mag_peak"] < 18.8504333
                                                        else 266
                                                    )
                                                    if state == 265:
                                                        state = (
                                                            335
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.919285655
                                                            )
                                                            else 336
                                                        )
                                                        if state == 335:
                                                            return 0.188313991
                                                        if state == 336:
                                                            return -0.101176858
                                                    if state == 266:
                                                        return -0.114181928
                                                if state == 206:
                                                    return -0.176658928
                                            if state == 156:
                                                return 0.107761316
                            if state == 38:
                                state = 57 if x["col_last"] < 0.41183728 else 58
                                if state == 57:
                                    state = (
                                        85
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.690000057)
                                        else 86
                                    )
                                    if state == 85:
                                        state = (
                                            119
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.5533085)
                                            else 120
                                        )
                                        if state == 119:
                                            state = (
                                                157
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.077814579)
                                                else 158
                                            )
                                            if state == 157:
                                                return -0.192498133
                                            if state == 158:
                                                return 0.22521843
                                        if state == 120:
                                            state = (
                                                159
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.0747847557)
                                                else 160
                                            )
                                            if state == 159:
                                                return -0.195902705
                                            if state == 160:
                                                return 0.0677204877
                                    if state == 86:
                                        return -0.241039693
                                if state == 58:
                                    state = (
                                        87
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.710000038)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            121
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.3223076)
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                161
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.080303669)
                                                else 162
                                            )
                                            if state == 161:
                                                return -0.131998315
                                            if state == 162:
                                                return 0.24237819
                                        if state == 122:
                                            state = (
                                                163
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.0747847557)
                                                else 164
                                            )
                                            if state == 163:
                                                state = (
                                                    207
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.4050312)
                                                    else 208
                                                )
                                                if state == 207:
                                                    return -0.352151573
                                                if state == 208:
                                                    state = (
                                                        267
                                                        if x["mag_peak"] < 19.0876522
                                                        else 268
                                                    )
                                                    if state == 267:
                                                        state = (
                                                            337
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.624166727
                                                            )
                                                            else 338
                                                        )
                                                        if state == 337:
                                                            return -0.207698986
                                                        if state == 338:
                                                            return 0.281270474
                                                    if state == 268:
                                                        return -0.245501965
                                            if state == 164:
                                                state = (
                                                    209
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.16621709)
                                                    else 210
                                                )
                                                if state == 209:
                                                    state = (
                                                        269
                                                        if x["mag_peak"] < 19.0348511
                                                        else 270
                                                    )
                                                    if state == 269:
                                                        return 0.253673494
                                                    if state == 270:
                                                        return -0.0973132625
                                                if state == 210:
                                                    return -0.245542407
                                    if state == 88:
                                        return -0.366775781
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.911499977)
                    else 6
                )
                if state == 5:
                    return -0.196353674
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.4465485)
                        else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.696333051)
                            else 22
                        )
                        if state == 21:
                            return 0.199328527
                        if state == 22:
                            return -0.0384762511
                    if state == 12:
                        return -0.0789169073
    elif num_booster == 22:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.948571086) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.963500023)
                    else 4
                )
                if state == 3:
                    state = 7 if x["col_peak"] < 0.618776321 else 8
                    if state == 7:
                        state = 13 if x["mag_peak"] < 18.32337 else 14
                        if state == 13:
                            state = (
                                25
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 19.6864338)
                                else 26
                            )
                            if state == 25:
                                return -0.107761063
                            if state == 26:
                                return 0.193810925
                        if state == 14:
                            state = 27 if x["neargaia_med"] < 0.28326118 else 28
                            if state == 27:
                                return -0.000080
                            if state == 28:
                                return -0.309499979
                    if state == 8:
                        state = 15 if x["mag_peak"] < 18.8977013 else 16
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 4.66979313)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    53
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 20.0809746)
                                    else 54
                                )
                                if state == 53:
                                    return -0.243650734
                                if state == 54:
                                    return 0.0720356554
                            if state == 30:
                                state = (
                                    55
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.8091087)
                                    else 56
                                )
                                if state == 55:
                                    return -0.0491945148
                                if state == 56:
                                    return 0.284816265
                        if state == 16:
                            state = 31 if x["neargaia_med"] < 21.6387463 else 32
                            if state == 31:
                                state = (
                                    57
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.4331226)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        85
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.4142513)
                                        else 86
                                    )
                                    if state == 85:
                                        state = (
                                            117
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.70071429)
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                167
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 15.999155)
                                                else 168
                                            )
                                            if state == 167:
                                                state = (
                                                    235
                                                    if x["maggaia_med"] < 18.1051712
                                                    else 236
                                                )
                                                if state == 235:
                                                    return -0.17769286
                                                if state == 236:
                                                    return 0.172523856
                                            if state == 168:
                                                return -0.221103832
                                        if state == 118:
                                            return -0.277125865
                                    if state == 86:
                                        return 0.286569536
                                if state == 58:
                                    return -0.345482737
                            if state == 32:
                                state = (
                                    59
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.6421661)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        87
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.650568)
                                        else 88
                                    )
                                    if state == 87:
                                        return 0.23511526
                                    if state == 88:
                                        state = (
                                            119
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.656904817)
                                            else 120
                                        )
                                        if state == 119:
                                            state = (
                                                169
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 12.8748093)
                                                else 170
                                            )
                                            if state == 169:
                                                state = (
                                                    237
                                                    if x["maggaia_med"] < 18.8884792
                                                    else 238
                                                )
                                                if state == 237:
                                                    state = (
                                                        323
                                                        if x["neargaia_med"]
                                                        < 42.7873993
                                                        else 324
                                                    )
                                                    if state == 323:
                                                        return 0.18873693
                                                    if state == 324:
                                                        return -0.0938553289
                                                if state == 238:
                                                    state = (
                                                        325
                                                        if x["neargaia_med"]
                                                        < 24.5343285
                                                        else 326
                                                    )
                                                    if state == 325:
                                                        return 0.394468874
                                                    if state == 326:
                                                        return 0.126320273
                                            if state == 170:
                                                state = (
                                                    239
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 19.2050743)
                                                    else 240
                                                )
                                                if state == 239:
                                                    state = (
                                                        327
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 53.6004677
                                                        )
                                                        else 328
                                                    )
                                                    if state == 327:
                                                        state = (
                                                            437
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.1648254
                                                            )
                                                            else 438
                                                        )
                                                        if state == 437:
                                                            return 0.119347975
                                                        if state == 438:
                                                            return -0.0615202561
                                                    if state == 328:
                                                        state = (
                                                            439
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.0285263
                                                            )
                                                            else 440
                                                        )
                                                        if state == 439:
                                                            return -0.0475634001
                                                        if state == 440:
                                                            return 0.252943605
                                                if state == 240:
                                                    return -0.2036791
                                        if state == 120:
                                            state = (
                                                171
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 9.05328751)
                                                else 172
                                            )
                                            if state == 171:
                                                state = (
                                                    241
                                                    if x["maggaia_med"] < 18.4524498
                                                    else 242
                                                )
                                                if state == 241:
                                                    return 0.082206443
                                                if state == 242:
                                                    state = (
                                                        329
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 33.8772125
                                                        )
                                                        else 330
                                                    )
                                                    if state == 329:
                                                        return -0.150798962
                                                    if state == 330:
                                                        return 0.0732820034
                                            if state == 172:
                                                state = (
                                                    243
                                                    if x["maggaia_med"] < 41.8495636
                                                    else 244
                                                )
                                                if state == 243:
                                                    return -0.311484754
                                                if state == 244:
                                                    return 0.0294673778
                                if state == 60:
                                    state = (
                                        89
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.4476109)
                                        else 90
                                    )
                                    if state == 89:
                                        state = (
                                            121
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.901428461)
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                173
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 3.05942726)
                                                else 174
                                            )
                                            if state == 173:
                                                return 0.130455464
                                            if state == 174:
                                                state = (
                                                    245
                                                    if x["maggaia_med"] < 17.3424873
                                                    else 246
                                                )
                                                if state == 245:
                                                    state = (
                                                        331
                                                        if x["neargaia_med"]
                                                        < 39.7428665
                                                        else 332
                                                    )
                                                    if state == 331:
                                                        return -0.199194729
                                                    if state == 332:
                                                        state = (
                                                            441
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 20.0845871
                                                            )
                                                            else 442
                                                        )
                                                        if state == 441:
                                                            return -0.148384869
                                                        if state == 442:
                                                            return 0.167623073
                                                if state == 246:
                                                    return -0.326325834
                                        if state == 122:
                                            return 0.0119221443
                                    if state == 90:
                                        state = (
                                            123
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.737142742)
                                            else 124
                                        )
                                        if state == 123:
                                            return -0.230449229
                                        if state == 124:
                                            return 0.398261279
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.150333881)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["mag_peak"] < 18.8032494 else 18
                        if state == 17:
                            state = 33 if x["neargaia_med"] < 15.9197197 else 34
                            if state == 33:
                                state = (
                                    61
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.6931152)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        91
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 16.5926361)
                                        else 92
                                    )
                                    if state == 91:
                                        return 0.115372911
                                    if state == 92:
                                        state = (
                                            125
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.597262084)
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                175
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 26.8883209)
                                                else 176
                                            )
                                            if state == 175:
                                                state = (
                                                    247
                                                    if x["maggaia_med"] < 19.492754
                                                    else 248
                                                )
                                                if state == 247:
                                                    state = (
                                                        333
                                                        if x["neargaia_med"]
                                                        < 11.5811243
                                                        else 334
                                                    )
                                                    if state == 333:
                                                        return -0.00192658918
                                                    if state == 334:
                                                        return -0.206693202
                                                if state == 248:
                                                    return 0.0872015804
                                            if state == 176:
                                                state = (
                                                    249
                                                    if x["maggaia_med"] < 18.4311581
                                                    else 250
                                                )
                                                if state == 249:
                                                    return -0.0475707985
                                                if state == 250:
                                                    state = (
                                                        335
                                                        if x["neargaia_med"]
                                                        < 6.55087423
                                                        else 336
                                                    )
                                                    if state == 335:
                                                        return -0.488907337
                                                    if state == 336:
                                                        state = (
                                                            445
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.5283356
                                                            )
                                                            else 446
                                                        )
                                                        if state == 445:
                                                            return 0.108512595
                                                        if state == 446:
                                                            return -0.116751172
                                        if state == 126:
                                            state = (
                                                177
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 16.085804)
                                                else 178
                                            )
                                            if state == 177:
                                                return -0.228978083
                                            if state == 178:
                                                state = (
                                                    251
                                                    if x["maggaia_med"] < 19.3744354
                                                    else 252
                                                )
                                                if state == 251:
                                                    state = (
                                                        337
                                                        if x["neargaia_med"]
                                                        < 8.14593124
                                                        else 338
                                                    )
                                                    if state == 337:
                                                        return 0.155502751
                                                    if state == 338:
                                                        state = (
                                                            447
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.178463
                                                            )
                                                            else 448
                                                        )
                                                        if state == 447:
                                                            return 0.100728534
                                                        if state == 448:
                                                            return -0.110348731
                                                if state == 252:
                                                    return -0.220892698
                                if state == 62:
                                    state = (
                                        93
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.4504852)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            127
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.939285636)
                                            else 128
                                        )
                                        if state == 127:
                                            state = (
                                                179
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 13.0204515)
                                                else 180
                                            )
                                            if state == 179:
                                                return -0.168361619
                                            if state == 180:
                                                state = (
                                                    253
                                                    if x["maggaia_med"] < 19.3802071
                                                    else 254
                                                )
                                                if state == 253:
                                                    state = (
                                                        339
                                                        if x["neargaia_med"] < 2.8738656
                                                        else 340
                                                    )
                                                    if state == 339:
                                                        state = (
                                                            449
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.0126724
                                                            )
                                                            else 450
                                                        )
                                                        if state == 449:
                                                            return 0.0735512078
                                                        if state == 450:
                                                            return 0.274683446
                                                    if state == 340:
                                                        state = (
                                                            451
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.4130154
                                                            )
                                                            else 452
                                                        )
                                                        if state == 451:
                                                            return 0.0576238595
                                                        if state == 452:
                                                            return 0.147026151
                                                if state == 254:
                                                    state = (
                                                        341
                                                        if x["neargaia_med"]
                                                        < 12.9126396
                                                        else 342
                                                    )
                                                    if state == 341:
                                                        state = (
                                                            453
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.2865105
                                                            )
                                                            else 454
                                                        )
                                                        if state == 453:
                                                            return 0.153191254
                                                        if state == 454:
                                                            return 0.0232765395
                                                    if state == 342:
                                                        return -0.444561154
                                        if state == 128:
                                            return -0.175865412
                                    if state == 94:
                                        state = (
                                            129
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.584047675)
                                            else 130
                                        )
                                        if state == 129:
                                            return 0.12917088
                                        if state == 130:
                                            state = (
                                                183
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 49.8778534)
                                                else 184
                                            )
                                            if state == 183:
                                                state = (
                                                    257
                                                    if x["maggaia_med"] < 19.5452576
                                                    else 258
                                                )
                                                if state == 257:
                                                    return 0.0498459823
                                                if state == 258:
                                                    return -0.319088876
                                            if state == 184:
                                                return 0.0129902279
                            if state == 34:
                                state = (
                                    63
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.9225845)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        95
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 17.6528816)
                                        else 96
                                    )
                                    if state == 95:
                                        return 0.260266662
                                    if state == 96:
                                        state = (
                                            133
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.599642873)
                                            else 134
                                        )
                                        if state == 133:
                                            state = (
                                                185
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 13.9877605)
                                                else 186
                                            )
                                            if state == 185:
                                                return -0.109565839
                                            if state == 186:
                                                state = (
                                                    259
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 19.8003769)
                                                    else 260
                                                )
                                                if state == 259:
                                                    return 0.257686943
                                                if state == 260:
                                                    return -0.158768252
                                        if state == 134:
                                            state = (
                                                187
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 20.0633049)
                                                else 188
                                            )
                                            if state == 187:
                                                state = (
                                                    261
                                                    if x["maggaia_med"] < 19.9128685
                                                    else 262
                                                )
                                                if state == 261:
                                                    state = (
                                                        345
                                                        if x["neargaia_med"]
                                                        < 69.9666443
                                                        else 346
                                                    )
                                                    if state == 345:
                                                        state = (
                                                            455
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.7860565
                                                            )
                                                            else 456
                                                        )
                                                        if state == 455:
                                                            return -0.27442652
                                                        if state == 456:
                                                            return 0.00396760041
                                                    if state == 346:
                                                        return 0.121445768
                                                if state == 262:
                                                    state = (
                                                        347
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 22.6821785
                                                        )
                                                        else 348
                                                    )
                                                    if state == 347:
                                                        return 0.166740298
                                                    if state == 348:
                                                        return -0.0115349218
                                            if state == 188:
                                                state = (
                                                    263
                                                    if x["maggaia_med"] < 19.4102058
                                                    else 264
                                                )
                                                if state == 263:
                                                    state = (
                                                        349
                                                        if x["neargaia_med"]
                                                        < 61.5029373
                                                        else 350
                                                    )
                                                    if state == 349:
                                                        state = (
                                                            459
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.9055195
                                                            )
                                                            else 460
                                                        )
                                                        if state == 459:
                                                            return 0.264546454
                                                        if state == 460:
                                                            return -0.0123623312
                                                    if state == 350:
                                                        return 0.0231545828
                                                if state == 264:
                                                    state = (
                                                        351
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 38.0239716
                                                        )
                                                        else 352
                                                    )
                                                    if state == 351:
                                                        state = (
                                                            463
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.6646385
                                                            )
                                                            else 464
                                                        )
                                                        if state == 463:
                                                            return -0.0623649359
                                                        if state == 464:
                                                            return 0.0946418643
                                                    if state == 352:
                                                        return -0.316265702
                                if state == 64:
                                    state = (
                                        97
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.1784687)
                                        else 98
                                    )
                                    if state == 97:
                                        state = (
                                            135
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.278333485)
                                            else 136
                                        )
                                        if state == 135:
                                            state = (
                                                189
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 27.0264015)
                                                else 190
                                            )
                                            if state == 189:
                                                return -0.322102934
                                            if state == 190:
                                                return 0.0651367754
                                        if state == 136:
                                            state = (
                                                191
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 51.9063568)
                                                else 192
                                            )
                                            if state == 191:
                                                state = (
                                                    265
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 20.4194775)
                                                    else 266
                                                )
                                                if state == 265:
                                                    state = (
                                                        353
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 43.4243927
                                                        )
                                                        else 354
                                                    )
                                                    if state == 353:
                                                        state = (
                                                            465
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.1082802
                                                            )
                                                            else 466
                                                        )
                                                        if state == 465:
                                                            return 0.130287543
                                                        if state == 466:
                                                            return 0.228636444
                                                    if state == 354:
                                                        state = (
                                                            467
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.3961868
                                                            )
                                                            else 468
                                                        )
                                                        if state == 467:
                                                            return 0.0912993476
                                                        if state == 468:
                                                            return -0.191709518
                                                if state == 266:
                                                    state = (
                                                        355
                                                        if x["neargaia_med"]
                                                        < 19.3799896
                                                        else 356
                                                    )
                                                    if state == 355:
                                                        state = (
                                                            469
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.5489941
                                                            )
                                                            else 470
                                                        )
                                                        if state == 469:
                                                            return 0.180652574
                                                        if state == 470:
                                                            return -0.0632162094
                                                    if state == 356:
                                                        return -0.252038538
                                            if state == 192:
                                                state = (
                                                    267
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 20.7249184)
                                                    else 268
                                                )
                                                if state == 267:
                                                    state = (
                                                        357
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 54.7768707
                                                        )
                                                        else 358
                                                    )
                                                    if state == 357:
                                                        state = (
                                                            471
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.0884876
                                                            )
                                                            else 472
                                                        )
                                                        if state == 471:
                                                            return 0.0905010402
                                                        if state == 472:
                                                            return 0.337935954
                                                    if state == 358:
                                                        return 0.105657831
                                                if state == 268:
                                                    return -0.0902996957
                                    if state == 98:
                                        state = (
                                            137
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.746071398)
                                            else 138
                                        )
                                        if state == 137:
                                            state = (
                                                193
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 65.9298935)
                                                else 194
                                            )
                                            if state == 193:
                                                state = (
                                                    269
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 19.7162952)
                                                    else 270
                                                )
                                                if state == 269:
                                                    state = (
                                                        359
                                                        if x["neargaia_med"]
                                                        < 17.5033684
                                                        else 360
                                                    )
                                                    if state == 359:
                                                        return 0.134847239
                                                    if state == 360:
                                                        state = (
                                                            473
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 20.3904915
                                                            )
                                                            else 474
                                                        )
                                                        if state == 473:
                                                            return -0.169613227
                                                        if state == 474:
                                                            return 0.0672008023
                                                if state == 270:
                                                    return 0.165162429
                                            if state == 194:
                                                return 0.207181096
                                        if state == 138:
                                            return 0.214369833
                        if state == 18:
                            state = (
                                35
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 28.2047806)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    65
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.1090851)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        99
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.6814194)
                                        else 100
                                    )
                                    if state == 99:
                                        state = (
                                            139
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.766904771)
                                            else 140
                                        )
                                        if state == 139:
                                            state = (
                                                195
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 8.97632504)
                                                else 196
                                            )
                                            if state == 195:
                                                state = (
                                                    271
                                                    if x["maggaia_med"] < 19.5741806
                                                    else 272
                                                )
                                                if state == 271:
                                                    state = (
                                                        361
                                                        if x["neargaia_med"] < 13.496479
                                                        else 362
                                                    )
                                                    if state == 361:
                                                        state = (
                                                            475
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.0360699
                                                            )
                                                            else 476
                                                        )
                                                        if state == 475:
                                                            return -0.294371367
                                                        if state == 476:
                                                            return -0.0415199362
                                                    if state == 362:
                                                        return 0.0165690612
                                                if state == 272:
                                                    return 0.183649644
                                            if state == 196:
                                                state = (
                                                    273
                                                    if x["maggaia_med"] < 15.2225628
                                                    else 274
                                                )
                                                if state == 273:
                                                    return -0.140190065
                                                if state == 274:
                                                    state = (
                                                        363
                                                        if x["neargaia_med"]
                                                        < 6.26829004
                                                        else 364
                                                    )
                                                    if state == 363:
                                                        state = (
                                                            477
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.1905098
                                                            )
                                                            else 478
                                                        )
                                                        if state == 477:
                                                            return 0.0604706369
                                                        if state == 478:
                                                            return -0.194112271
                                                    if state == 364:
                                                        state = (
                                                            479
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.4820976
                                                            )
                                                            else 480
                                                        )
                                                        if state == 479:
                                                            return 0.170137063
                                                        if state == 480:
                                                            return 0.291745454
                                        if state == 140:
                                            state = (
                                                197
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 27.9243279)
                                                else 198
                                            )
                                            if state == 197:
                                                return 0.302595526
                                            if state == 198:
                                                state = (
                                                    275
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 18.4370842)
                                                    else 276
                                                )
                                                if state == 275:
                                                    return -0.133682042
                                                if state == 276:
                                                    return 0.0769679099
                                    if state == 100:
                                        state = (
                                            141
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.565833151)
                                            else 142
                                        )
                                        if state == 141:
                                            state = (
                                                199
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 14.8965797)
                                                else 200
                                            )
                                            if state == 199:
                                                state = (
                                                    277
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 16.1812553)
                                                    else 278
                                                )
                                                if state == 277:
                                                    return 0.0155877769
                                                if state == 278:
                                                    state = (
                                                        369
                                                        if x["neargaia_med"]
                                                        < 6.36903048
                                                        else 370
                                                    )
                                                    if state == 369:
                                                        return -0.0920403451
                                                    if state == 370:
                                                        state = (
                                                            483
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.7496452
                                                            )
                                                            else 484
                                                        )
                                                        if state == 483:
                                                            return -0.108557895
                                                        if state == 484:
                                                            return 0.362148732
                                            if state == 200:
                                                state = (
                                                    279
                                                    if x["maggaia_med"] < 19.866497
                                                    else 280
                                                )
                                                if state == 279:
                                                    state = (
                                                        371
                                                        if x["neargaia_med"]
                                                        < 13.6730614
                                                        else 372
                                                    )
                                                    if state == 371:
                                                        return -0.0639453977
                                                    if state == 372:
                                                        state = (
                                                            487
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.9428902
                                                            )
                                                            else 488
                                                        )
                                                        if state == 487:
                                                            return 0.023702519
                                                        if state == 488:
                                                            return 0.277741551
                                                if state == 280:
                                                    state = (
                                                        373
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 14.8708477
                                                        )
                                                        else 374
                                                    )
                                                    if state == 373:
                                                        state = (
                                                            489
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.8240433
                                                            )
                                                            else 490
                                                        )
                                                        if state == 489:
                                                            return 0.163761586
                                                        if state == 490:
                                                            return -0.153421417
                                                    if state == 374:
                                                        return -0.178683281
                                        if state == 142:
                                            state = (
                                                201
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 13.0001678)
                                                else 202
                                            )
                                            if state == 201:
                                                state = (
                                                    281
                                                    if x["maggaia_med"] < 18.5132942
                                                    else 282
                                                )
                                                if state == 281:
                                                    state = (
                                                        375
                                                        if x["neargaia_med"]
                                                        < 13.5732479
                                                        else 376
                                                    )
                                                    if state == 375:
                                                        state = (
                                                            491
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.7152863
                                                            )
                                                            else 492
                                                        )
                                                        if state == 491:
                                                            return -0.276049942
                                                        if state == 492:
                                                            return -0.0478211269
                                                    if state == 376:
                                                        state = (
                                                            493
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.0765572
                                                            )
                                                            else 494
                                                        )
                                                        if state == 493:
                                                            return 0.25238961
                                                        if state == 494:
                                                            return -0.0462846011
                                                if state == 282:
                                                    state = (
                                                        377
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 12.2388878
                                                        )
                                                        else 378
                                                    )
                                                    if state == 377:
                                                        return 0.281341523
                                                    if state == 378:
                                                        state = (
                                                            495
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.8513298
                                                            )
                                                            else 496
                                                        )
                                                        if state == 495:
                                                            return -0.135712475
                                                        if state == 496:
                                                            return 0.0509701595
                                            if state == 202:
                                                state = (
                                                    283
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 19.9376526)
                                                    else 284
                                                )
                                                if state == 283:
                                                    state = (
                                                        379
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 17.6164856
                                                        )
                                                        else 380
                                                    )
                                                    if state == 379:
                                                        state = (
                                                            497
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.7853394
                                                            )
                                                            else 498
                                                        )
                                                        if state == 497:
                                                            return 0.0658172294
                                                        if state == 498:
                                                            return -0.154815704
                                                    if state == 380:
                                                        state = (
                                                            499
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.0395126
                                                            )
                                                            else 500
                                                        )
                                                        if state == 499:
                                                            return 0.176007792
                                                        if state == 500:
                                                            return -0.136180058
                                                if state == 284:
                                                    state = (
                                                        381
                                                        if x["neargaia_med"]
                                                        < 9.58382988
                                                        else 382
                                                    )
                                                    if state == 381:
                                                        return -0.0270164423
                                                    if state == 382:
                                                        return 0.215410903
                                if state == 66:
                                    state = (
                                        101
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.1647491)
                                        else 102
                                    )
                                    if state == 101:
                                        state = (
                                            143
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.703452349)
                                            else 144
                                        )
                                        if state == 143:
                                            state = (
                                                203
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 6.98917818)
                                                else 204
                                            )
                                            if state == 203:
                                                return 0.349564403
                                            if state == 204:
                                                state = (
                                                    287
                                                    if x["maggaia_med"] < 18.4089432
                                                    else 288
                                                )
                                                if state == 287:
                                                    state = (
                                                        383
                                                        if x["neargaia_med"]
                                                        < 12.4036446
                                                        else 384
                                                    )
                                                    if state == 383:
                                                        state = (
                                                            501
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.5925922
                                                            )
                                                            else 502
                                                        )
                                                        if state == 501:
                                                            return -0.0160841793
                                                        if state == 502:
                                                            return -0.258824617
                                                    if state == 384:
                                                        return 0.142472297
                                                if state == 288:
                                                    state = (
                                                        385
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 16.3087044
                                                        )
                                                        else 386
                                                    )
                                                    if state == 385:
                                                        state = (
                                                            505
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.697485
                                                            )
                                                            else 506
                                                        )
                                                        if state == 505:
                                                            return -0.0522290841
                                                        if state == 506:
                                                            return -0.167116851
                                                    if state == 386:
                                                        state = (
                                                            507
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.9312172
                                                            )
                                                            else 508
                                                        )
                                                        if state == 507:
                                                            return -0.250004888
                                                        if state == 508:
                                                            return 0.0488207564
                                        if state == 144:
                                            state = (
                                                205
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 9.03565979)
                                                else 206
                                            )
                                            if state == 205:
                                                state = (
                                                    289
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 13.926424)
                                                    else 290
                                                )
                                                if state == 289:
                                                    return -0.123369493
                                                if state == 290:
                                                    state = (
                                                        387
                                                        if x["neargaia_med"]
                                                        < 18.8975639
                                                        else 388
                                                    )
                                                    if state == 387:
                                                        state = (
                                                            509
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.538414
                                                            )
                                                            else 510
                                                        )
                                                        if state == 509:
                                                            return 0.266828597
                                                        if state == 510:
                                                            return -0.0274940412
                                                    if state == 388:
                                                        return -0.0736215562
                                            if state == 206:
                                                state = (
                                                    291
                                                    if x["maggaia_med"] < 18.775322
                                                    else 292
                                                )
                                                if state == 291:
                                                    state = (
                                                        389
                                                        if x["neargaia_med"]
                                                        < 10.8291292
                                                        else 390
                                                    )
                                                    if state == 389:
                                                        state = (
                                                            511
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.2177639
                                                            )
                                                            else 512
                                                        )
                                                        if state == 511:
                                                            return 0.129800379
                                                        if state == 512:
                                                            return -0.0515130721
                                                    if state == 390:
                                                        state = (
                                                            513
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.6511269
                                                            )
                                                            else 514
                                                        )
                                                        if state == 513:
                                                            return -0.254990518
                                                        if state == 514:
                                                            return -0.0744261071
                                                if state == 292:
                                                    state = (
                                                        391
                                                        if x["neargaia_med"]
                                                        < 2.20444822
                                                        else 392
                                                    )
                                                    if state == 391:
                                                        state = (
                                                            515
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.4229202
                                                            )
                                                            else 516
                                                        )
                                                        if state == 515:
                                                            return -0.22808294
                                                        if state == 516:
                                                            return 0.135557041
                                                    if state == 392:
                                                        return -0.416294962
                                    if state == 102:
                                        state = (
                                            145
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.691428542)
                                            else 146
                                        )
                                        if state == 145:
                                            state = (
                                                207
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 37.8859901)
                                                else 208
                                            )
                                            if state == 207:
                                                state = (
                                                    293
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 19.2966614)
                                                    else 294
                                                )
                                                if state == 293:
                                                    return -0.18961449
                                                if state == 294:
                                                    return 0.295148581
                                            if state == 208:
                                                state = (
                                                    295
                                                    if x["maggaia_med"] < 19.9859142
                                                    else 296
                                                )
                                                if state == 295:
                                                    return 0.0300746467
                                                if state == 296:
                                                    return 0.311344653
                                        if state == 146:
                                            return -0.247200072
                            if state == 36:
                                state = (
                                    67
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.966404)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        103
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.3718452)
                                        else 104
                                    )
                                    if state == 103:
                                        state = (
                                            147
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.680357158)
                                            else 148
                                        )
                                        if state == 147:
                                            return 0.301635206
                                        if state == 148:
                                            state = (
                                                209
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 20.9336929)
                                                else 210
                                            )
                                            if state == 209:
                                                state = (
                                                    297
                                                    if x["maggaia_med"] < 15.9213562
                                                    else 298
                                                )
                                                if state == 297:
                                                    return -0.222453862
                                                if state == 298:
                                                    state = (
                                                        397
                                                        if x["neargaia_med"]
                                                        < 41.1663589
                                                        else 398
                                                    )
                                                    if state == 397:
                                                        state = (
                                                            517
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 17.5617371
                                                            )
                                                            else 518
                                                        )
                                                        if state == 517:
                                                            return -0.0595247112
                                                        if state == 518:
                                                            return 0.112044372
                                                    if state == 398:
                                                        return 0.269996136
                                            if state == 210:
                                                return -0.185830802
                                    if state == 104:
                                        state = (
                                            149
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.625714302)
                                            else 150
                                        )
                                        if state == 149:
                                            state = (
                                                211
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 24.8903427)
                                                else 212
                                            )
                                            if state == 211:
                                                state = (
                                                    299
                                                    if x["maggaia_med"] < 18.9568539
                                                    else 300
                                                )
                                                if state == 299:
                                                    state = (
                                                        399
                                                        if x["neargaia_med"] < 55.276474
                                                        else 400
                                                    )
                                                    if state == 399:
                                                        state = (
                                                            519
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.9027672
                                                            )
                                                            else 520
                                                        )
                                                        if state == 519:
                                                            return -0.441185594
                                                        if state == 520:
                                                            return -0.0241873004
                                                    if state == 400:
                                                        state = (
                                                            521
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.7977753
                                                            )
                                                            else 522
                                                        )
                                                        if state == 521:
                                                            return 0.0500278138
                                                        if state == 522:
                                                            return -0.116456769
                                                if state == 300:
                                                    state = (
                                                        401
                                                        if x["neargaia_med"] < 40.445549
                                                        else 402
                                                    )
                                                    if state == 401:
                                                        return 0.180081919
                                                    if state == 402:
                                                        return -0.0741961673
                                            if state == 212:
                                                return 0.136185452
                                        if state == 150:
                                            state = (
                                                213
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 21.4758148)
                                                else 214
                                            )
                                            if state == 213:
                                                state = (
                                                    301
                                                    if x["maggaia_med"] < 19.2255154
                                                    else 302
                                                )
                                                if state == 301:
                                                    state = (
                                                        403
                                                        if x["neargaia_med"]
                                                        < 48.7022514
                                                        else 404
                                                    )
                                                    if state == 403:
                                                        state = (
                                                            523
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.9213963
                                                            )
                                                            else 524
                                                        )
                                                        if state == 523:
                                                            return -0.297485977
                                                        if state == 524:
                                                            return 0.174779966
                                                    if state == 404:
                                                        return 0.167874262
                                                if state == 302:
                                                    state = (
                                                        405
                                                        if x["neargaia_med"]
                                                        < 66.4307709
                                                        else 406
                                                    )
                                                    if state == 405:
                                                        state = (
                                                            525
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.5950203
                                                            )
                                                            else 526
                                                        )
                                                        if state == 525:
                                                            return -0.0645260289
                                                        if state == 526:
                                                            return 0.101816878
                                                    if state == 406:
                                                        return 0.236654952
                                            if state == 214:
                                                return 0.197106153
                                if state == 68:
                                    state = (
                                        105
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.7387733)
                                        else 106
                                    )
                                    if state == 105:
                                        state = (
                                            151
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.708095312)
                                            else 152
                                        )
                                        if state == 151:
                                            state = (
                                                215
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 35.8999405)
                                                else 216
                                            )
                                            if state == 215:
                                                state = (
                                                    303
                                                    if x["maggaia_med"] < 18.9118252
                                                    else 304
                                                )
                                                if state == 303:
                                                    state = (
                                                        407
                                                        if x["neargaia_med"]
                                                        < 38.4369125
                                                        else 408
                                                    )
                                                    if state == 407:
                                                        return -0.281928509
                                                    if state == 408:
                                                        state = (
                                                            527
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.1961327
                                                            )
                                                            else 528
                                                        )
                                                        if state == 527:
                                                            return 0.0453946516
                                                        if state == 528:
                                                            return 0.218720049
                                                if state == 304:
                                                    state = (
                                                        409
                                                        if x["neargaia_med"]
                                                        < 34.5881805
                                                        else 410
                                                    )
                                                    if state == 409:
                                                        return -0.445970744
                                                    if state == 410:
                                                        state = (
                                                            529
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.1453915
                                                            )
                                                            else 530
                                                        )
                                                        if state == 529:
                                                            return 0.0724049062
                                                        if state == 530:
                                                            return -0.219825193
                                            if state == 216:
                                                state = (
                                                    305
                                                    if x["maggaia_med"] < 20.5503387
                                                    else 306
                                                )
                                                if state == 305:
                                                    state = (
                                                        411
                                                        if x["neargaia_med"]
                                                        < 54.1737671
                                                        else 412
                                                    )
                                                    if state == 411:
                                                        state = (
                                                            531
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.527668
                                                            )
                                                            else 532
                                                        )
                                                        if state == 531:
                                                            return -0.484995872
                                                        if state == 532:
                                                            return -0.0550077707
                                                    if state == 412:
                                                        return -0.0561107546
                                                if state == 306:
                                                    state = (
                                                        413
                                                        if x["neargaia_med"]
                                                        < 39.8119392
                                                        else 414
                                                    )
                                                    if state == 413:
                                                        return -0.0733990893
                                                    if state == 414:
                                                        return 0.17839396
                                        if state == 152:
                                            state = (
                                                217
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 21.9840851)
                                                else 218
                                            )
                                            if state == 217:
                                                state = (
                                                    307
                                                    if x["maggaia_med"] < 19.4195366
                                                    else 308
                                                )
                                                if state == 307:
                                                    return -0.368141472
                                                if state == 308:
                                                    return -0.168684378
                                            if state == 218:
                                                state = (
                                                    309
                                                    if x["maggaia_med"] < 19.3854599
                                                    else 310
                                                )
                                                if state == 309:
                                                    state = (
                                                        417
                                                        if x["neargaia_med"] < 42.902771
                                                        else 418
                                                    )
                                                    if state == 417:
                                                        state = (
                                                            537
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.5423565
                                                            )
                                                            else 538
                                                        )
                                                        if state == 537:
                                                            return 0.186116517
                                                        if state == 538:
                                                            return -0.099833779
                                                    if state == 418:
                                                        state = (
                                                            539
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.5475597
                                                            )
                                                            else 540
                                                        )
                                                        if state == 539:
                                                            return -0.286603719
                                                        if state == 540:
                                                            return -0.0102055063
                                                if state == 310:
                                                    return -0.27327764
                                    if state == 106:
                                        return -0.262455553
                    if state == 10:
                        state = 19 if x["mag_peak"] < 17.6611652 else 20
                        if state == 19:
                            state = (
                                37
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 1.51978183)
                                else 38
                            )
                            if state == 37:
                                return -0.134465843
                            if state == 38:
                                return 0.188056484
                        if state == 20:
                            state = 39 if x["neargaia_med"] < 48.3658829 else 40
                            if state == 39:
                                state = (
                                    69
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.8209038)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        107
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.1688213)
                                        else 108
                                    )
                                    if state == 107:
                                        return 0.0666710362
                                    if state == 108:
                                        state = (
                                            153
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.916071415)
                                            else 154
                                        )
                                        if state == 153:
                                            state = (
                                                219
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 39.8748627)
                                                else 220
                                            )
                                            if state == 219:
                                                state = (
                                                    311
                                                    if x["maggaia_med"] < 17.4961166
                                                    else 312
                                                )
                                                if state == 311:
                                                    state = (
                                                        419
                                                        if x["neargaia_med"]
                                                        < 0.672370434
                                                        else 420
                                                    )
                                                    if state == 419:
                                                        return -0.260622472
                                                    if state == 420:
                                                        state = (
                                                            541
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.6641235
                                                            )
                                                            else 542
                                                        )
                                                        if state == 541:
                                                            return 0.0406271629
                                                        if state == 542:
                                                            return -0.151951954
                                                if state == 312:
                                                    state = (
                                                        421
                                                        if x["neargaia_med"]
                                                        < 31.8109169
                                                        else 422
                                                    )
                                                    if state == 421:
                                                        state = (
                                                            543
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.5294189
                                                            )
                                                            else 544
                                                        )
                                                        if state == 543:
                                                            return 0.0608601049
                                                        if state == 544:
                                                            return -0.171612844
                                                    if state == 422:
                                                        return -0.473114431
                                            if state == 220:
                                                state = (
                                                    313
                                                    if x["maggaia_med"] < 19.7704563
                                                    else 314
                                                )
                                                if state == 313:
                                                    state = (
                                                        423
                                                        if x["neargaia_med"] < 29.216568
                                                        else 424
                                                    )
                                                    if state == 423:
                                                        state = (
                                                            545
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 19.7878799
                                                            )
                                                            else 546
                                                        )
                                                        if state == 545:
                                                            return 0.0927758664
                                                        if state == 546:
                                                            return -0.0622069985
                                                    if state == 424:
                                                        return -0.140042752
                                                if state == 314:
                                                    state = (
                                                        425
                                                        if x["neargaia_med"]
                                                        < 18.3864937
                                                        else 426
                                                    )
                                                    if state == 425:
                                                        return 0.015190837
                                                    if state == 426:
                                                        return -0.234374732
                                        if state == 154:
                                            state = (
                                                221
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 30.9860706)
                                                else 222
                                            )
                                            if state == 221:
                                                return 0.201808617
                                            if state == 222:
                                                return -0.0800233409
                                if state == 70:
                                    state = (
                                        109
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.9199104)
                                        else 110
                                    )
                                    if state == 109:
                                        return 0.151490152
                                    if state == 110:
                                        state = (
                                            157
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.864999771)
                                            else 158
                                        )
                                        if state == 157:
                                            state = (
                                                223
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 41.9834671)
                                                else 224
                                            )
                                            if state == 223:
                                                state = (
                                                    315
                                                    if x["maggaia_med"] < 18.5348434
                                                    else 316
                                                )
                                                if state == 315:
                                                    return -0.0567419529
                                                if state == 316:
                                                    state = (
                                                        429
                                                        if x["neargaia_med"]
                                                        < 20.6780663
                                                        else 430
                                                    )
                                                    if state == 429:
                                                        return -0.287779689
                                                    if state == 430:
                                                        return 0.104564004
                                            if state == 224:
                                                state = (
                                                    317
                                                    if x["maggaia_med"] < 16.661375
                                                    else 318
                                                )
                                                if state == 317:
                                                    return 0.158632889
                                                if state == 318:
                                                    state = (
                                                        431
                                                        if x["neargaia_med"]
                                                        < 31.8384781
                                                        else 432
                                                    )
                                                    if state == 431:
                                                        state = (
                                                            551
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 20.3343716
                                                            )
                                                            else 552
                                                        )
                                                        if state == 551:
                                                            return -0.00979418308
                                                        if state == 552:
                                                            return 0.166351557
                                                    if state == 432:
                                                        return -0.299628705
                                        if state == 158:
                                            return 0.154682592
                            if state == 40:
                                state = (
                                    71
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.8464298)
                                    else 72
                                )
                                if state == 71:
                                    state = (
                                        111
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.7906895)
                                        else 112
                                    )
                                    if state == 111:
                                        return 0.000601181237
                                    if state == 112:
                                        return -0.177018538
                                if state == 72:
                                    state = (
                                        113
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.4641495)
                                        else 114
                                    )
                                    if state == 113:
                                        state = (
                                            161
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.752976298)
                                            else 162
                                        )
                                        if state == 161:
                                            return 0.167501777
                                        if state == 162:
                                            return -0.166379347
                                    if state == 114:
                                        state = (
                                            163
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.723571539)
                                            else 164
                                        )
                                        if state == 163:
                                            return 0.198933318
                                        if state == 164:
                                            state = (
                                                233
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 12.013813)
                                                else 234
                                            )
                                            if state == 233:
                                                return 0.181019396
                                            if state == 234:
                                                return -0.123750366
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.985499978)
                    else 6
                )
                if state == 5:
                    state = 11 if x["col_peak"] < 0.101011276 else 12
                    if state == 11:
                        state = 21 if x["mag_peak"] < 18.5753326 else 22
                        if state == 21:
                            return 0.18120636
                        if state == 22:
                            state = 43 if x["neargaia_med"] < 12.2669678 else 44
                            if state == 43:
                                return 0.0586199202
                            if state == 44:
                                return -0.282172561
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.6710587)
                            else 24
                        )
                        if state == 23:
                            state = 45 if x["neargaia_med"] < 4.45267868 else 46
                            if state == 45:
                                return -0.152796879
                            if state == 46:
                                state = (
                                    77
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.1355133)
                                    else 78
                                )
                                if state == 77:
                                    return 0.263700515
                                if state == 78:
                                    return 0.0734059289
                        if state == 24:
                            state = (
                                47
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 19.6207943)
                                else 48
                            )
                            if state == 47:
                                return -0.264500052
                            if state == 48:
                                return 0.247346297
                if state == 6:
                    return -0.124805748
    elif num_booster == 23:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < 0.38904953) else 2
            if state == 1:
                state = 3 if x["col_last"] < -0.194990486 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.386834592)
                        else 8
                    )
                    if state == 7:
                        return -0.142360941
                    if state == 8:
                        state = 15 if x["col_peak"] < -0.247587204 else 16
                        if state == 15:
                            return -0.0986120254
                        if state == 16:
                            state = (
                                29
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.0909996)
                                else 30
                            )
                            if state == 29:
                                return -0.133859947
                            if state == 30:
                                state = (
                                    49
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.85214293)
                                    else 50
                                )
                                if state == 49:
                                    return 0.211789474
                                if state == 50:
                                    return -0.0114016263
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.962789476)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.497541428)
                            else 18
                        )
                        if state == 17:
                            state = (
                                31
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.6404991)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    51
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.586666584)
                                    else 52
                                )
                                if state == 51:
                                    state = 67 if x["col_peak"] < -0.222213745 else 68
                                    if state == 67:
                                        return 0.168351352
                                    if state == 68:
                                        state = (
                                            85
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 17.0912342)
                                            else 86
                                        )
                                        if state == 85:
                                            return 0.0266386922
                                        if state == 86:
                                            state = (
                                                111
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.644405365)
                                                else 112
                                            )
                                            if state == 111:
                                                state = (
                                                    153
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.552)
                                                    else 154
                                                )
                                                if state == 153:
                                                    state = (
                                                        217
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.115771003
                                                        )
                                                        else 218
                                                    )
                                                    if state == 217:
                                                        return -0.0453365333
                                                    if state == 218:
                                                        return -0.24713403
                                                if state == 154:
                                                    state = (
                                                        219
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.692611516
                                                        )
                                                        else 220
                                                    )
                                                    if state == 219:
                                                        return -0.395556778
                                                    if state == 220:
                                                        return 0.00780418003
                                            if state == 112:
                                                return 0.0199045781
                                if state == 52:
                                    state = 69 if x["col_peak"] < 0.0576820374 else 70
                                    if state == 69:
                                        state = (
                                            87
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.1887779)
                                            else 88
                                        )
                                        if state == 87:
                                            state = (
                                                113
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.0330425873)
                                                else 114
                                            )
                                            if state == 113:
                                                state = (
                                                    157
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.1085014)
                                                    else 158
                                                )
                                                if state == 157:
                                                    state = (
                                                        221
                                                        if x["sgscore1_med"]
                                                        < 0.217589498
                                                        else 222
                                                    )
                                                    if state == 221:
                                                        return 0.0108236903
                                                    if state == 222:
                                                        return -0.164978936
                                                if state == 158:
                                                    state = (
                                                        223
                                                        if x["sgscore1_med"]
                                                        < 0.0148333497
                                                        else 224
                                                    )
                                                    if state == 223:
                                                        return -0.0223556515
                                                    if state == 224:
                                                        return 0.172555536
                                            if state == 114:
                                                state = (
                                                    159
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 20.0857506)
                                                    else 160
                                                )
                                                if state == 159:
                                                    state = (
                                                        225
                                                        if x["sgscore1_med"]
                                                        < 0.443603992
                                                        else 226
                                                    )
                                                    if state == 225:
                                                        return -0.244951114
                                                    if state == 226:
                                                        return 0.00841261074
                                                if state == 160:
                                                    return 0.127760261
                                        if state == 88:
                                            state = (
                                                115
                                                if x["col_last"] < 0.0911407471
                                                else 116
                                            )
                                            if state == 115:
                                                return -0.0208259616
                                            if state == 116:
                                                state = (
                                                    163
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.5314999)
                                                    else 164
                                                )
                                                if state == 163:
                                                    state = (
                                                        229
                                                        if x["sgscore1_med"]
                                                        < 0.0298154503
                                                        else 230
                                                    )
                                                    if state == 229:
                                                        return 0.272722661
                                                    if state == 230:
                                                        return 0.0461980887
                                                if state == 164:
                                                    state = (
                                                        231
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.00178571499
                                                        )
                                                        else 232
                                                    )
                                                    if state == 231:
                                                        state = (
                                                            305
                                                            if x["col_last"]
                                                            < 0.251630783
                                                            else 306
                                                        )
                                                        if state == 305:
                                                            return 0.0791652873
                                                        if state == 306:
                                                            return -0.221696705
                                                    if state == 232:
                                                        state = (
                                                            307
                                                            if x["col_last"]
                                                            < 0.223958492
                                                            else 308
                                                        )
                                                        if state == 307:
                                                            return 0.135729343
                                                        if state == 308:
                                                            return -0.00897878315
                                    if state == 70:
                                        state = (
                                            89
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.0781021)
                                            else 90
                                        )
                                        if state == 89:
                                            state = (
                                                117
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < -0.137926102)
                                                else 118
                                            )
                                            if state == 117:
                                                state = (
                                                    165
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.9679985)
                                                    else 166
                                                )
                                                if state == 165:
                                                    state = (
                                                        233
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.146547496
                                                        )
                                                        else 234
                                                    )
                                                    if state == 233:
                                                        state = (
                                                            309
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.160197258
                                                            )
                                                            else 310
                                                        )
                                                        if state == 309:
                                                            return -0.00177769631
                                                        if state == 310:
                                                            return -0.193207622
                                                    if state == 234:
                                                        return -0.210448563
                                                if state == 166:
                                                    state = (
                                                        235
                                                        if x["sgscore1_med"]
                                                        < 0.00135416654
                                                        else 236
                                                    )
                                                    if state == 235:
                                                        return -0.179400802
                                                    if state == 236:
                                                        return 0.249510378
                                            if state == 118:
                                                state = (
                                                    167
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 17.338501)
                                                    else 168
                                                )
                                                if state == 167:
                                                    state = (
                                                        237
                                                        if x["sgscore1_med"]
                                                        < 0.0676607043
                                                        else 238
                                                    )
                                                    if state == 237:
                                                        return 0.155921876
                                                    if state == 238:
                                                        state = (
                                                            311
                                                            if x["col_last"]
                                                            < 0.912701607
                                                            else 312
                                                        )
                                                        if state == 311:
                                                            return -0.267234474
                                                        if state == 312:
                                                            return 0.0552978106
                                                if state == 168:
                                                    state = (
                                                        239
                                                        if x["sgscore1_med"]
                                                        < 0.00104166649
                                                        else 240
                                                    )
                                                    if state == 239:
                                                        return -0.102478281
                                                    if state == 240:
                                                        state = (
                                                            313
                                                            if x["col_last"]
                                                            < -0.0920114517
                                                            else 314
                                                        )
                                                        if state == 313:
                                                            return 0.269054353
                                                        if state == 314:
                                                            return 0.129389569
                                        if state == 90:
                                            state = (
                                                119
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.580957413)
                                                else 120
                                            )
                                            if state == 119:
                                                state = (
                                                    169
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 21.0234985)
                                                    else 170
                                                )
                                                if state == 169:
                                                    state = (
                                                        241
                                                        if x["sgscore1_med"]
                                                        < 0.0100416504
                                                        else 242
                                                    )
                                                    if state == 241:
                                                        state = (
                                                            315
                                                            if x["col_last"]
                                                            < 0.141372681
                                                            else 316
                                                        )
                                                        if state == 315:
                                                            return 0.098940298
                                                        if state == 316:
                                                            return -0.011047028
                                                    if state == 242:
                                                        state = (
                                                            317
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.111208916
                                                            )
                                                            else 318
                                                        )
                                                        if state == 317:
                                                            return -0.114502512
                                                        if state == 318:
                                                            return -0.229100019
                                                if state == 170:
                                                    state = (
                                                        243
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.0137499999
                                                        )
                                                        else 244
                                                    )
                                                    if state == 243:
                                                        return -0.274000347
                                                    if state == 244:
                                                        return 0.0112482421
                                            if state == 120:
                                                state = (
                                                    171
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 20.4764996)
                                                    else 172
                                                )
                                                if state == 171:
                                                    state = (
                                                        245
                                                        if x["sgscore1_med"]
                                                        < 0.0154791996
                                                        else 246
                                                    )
                                                    if state == 245:
                                                        state = (
                                                            319
                                                            if x["col_last"]
                                                            < 0.716284275
                                                            else 320
                                                        )
                                                        if state == 319:
                                                            return 0.114704072
                                                        if state == 320:
                                                            return -0.203242123
                                                    if state == 246:
                                                        return 0.0818547159
                                                if state == 172:
                                                    return 0.196705267
                            if state == 32:
                                state = (
                                    53
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.638452411)
                                    else 54
                                )
                                if state == 53:
                                    state = 71 if x["col_peak"] < -0.196799755 else 72
                                    if state == 71:
                                        return -0.0292419549
                                    if state == 72:
                                        state = (
                                            91
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.108799)
                                            else 92
                                        )
                                        if state == 91:
                                            state = (
                                                121
                                                if x["col_last"] < 0.00615978241
                                                else 122
                                            )
                                            if state == 121:
                                                return 0.0289991423
                                            if state == 122:
                                                state = (
                                                    173
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 21.9060001)
                                                    else 174
                                                )
                                                if state == 173:
                                                    return -0.332834393
                                                if state == 174:
                                                    return 0.152580172
                                        if state == 92:
                                            state = (
                                                123
                                                if x["col_last"] < -0.0683965683
                                                else 124
                                            )
                                            if state == 123:
                                                return -0.00310679642
                                            if state == 124:
                                                return -0.353047282
                                if state == 54:
                                    state = (
                                        73
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.0706553459)
                                        else 74
                                    )
                                    if state == 73:
                                        state = (
                                            93
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.4149437)
                                            else 94
                                        )
                                        if state == 93:
                                            state = (
                                                125
                                                if x["col_last"] < -0.112086296
                                                else 126
                                            )
                                            if state == 125:
                                                return -0.116277888
                                            if state == 126:
                                                state = (
                                                    175
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 21.7465)
                                                    else 176
                                                )
                                                if state == 175:
                                                    return -0.137601957
                                                if state == 176:
                                                    state = (
                                                        247
                                                        if x["sgscore1_med"]
                                                        < 0.00489583518
                                                        else 248
                                                    )
                                                    if state == 247:
                                                        return -0.00490454165
                                                    if state == 248:
                                                        return 0.246321306
                                        if state == 94:
                                            return -0.121519938
                                    if state == 74:
                                        return -0.131172389
                        if state == 18:
                            return -0.224084035
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.909599304)
                            else 20
                        )
                        if state == 19:
                            state = (
                                33
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 22.0825005)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    55
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.732857168)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        75
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < 0.150333881)
                                        else 76
                                    )
                                    if state == 75:
                                        state = (
                                            97
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.0322704)
                                            else 98
                                        )
                                        if state == 97:
                                            state = (
                                                129
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 1.02509975)
                                                else 130
                                            )
                                            if state == 129:
                                                state = (
                                                    177
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 21.0100002)
                                                    else 178
                                                )
                                                if state == 177:
                                                    state = (
                                                        249
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.178169504
                                                        )
                                                        else 250
                                                    )
                                                    if state == 249:
                                                        return 0.109975979
                                                    if state == 250:
                                                        state = (
                                                            327
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.193519115
                                                            )
                                                            else 328
                                                        )
                                                        if state == 327:
                                                            return -0.0734584481
                                                        if state == 328:
                                                            return 0.0141298193
                                                if state == 178:
                                                    state = (
                                                        251
                                                        if x["sgscore1_med"]
                                                        < 0.00354166492
                                                        else 252
                                                    )
                                                    if state == 251:
                                                        return 0.0278452206
                                                    if state == 252:
                                                        state = (
                                                            329
                                                            if x["col_last"]
                                                            < -0.15486002
                                                            else 330
                                                        )
                                                        if state == 329:
                                                            return -0.046063222
                                                        if state == 330:
                                                            return 0.252553135
                                            if state == 130:
                                                state = (
                                                    179
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.9125004)
                                                    else 180
                                                )
                                                if state == 179:
                                                    return 0.0145596294
                                                if state == 180:
                                                    return -0.163719594
                                        if state == 98:
                                            state = (
                                                131
                                                if x["col_last"] < 0.0233139992
                                                else 132
                                            )
                                            if state == 131:
                                                state = (
                                                    181
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 21.2504997)
                                                    else 182
                                                )
                                                if state == 181:
                                                    state = (
                                                        253
                                                        if x["sgscore1_med"]
                                                        < 0.00395833515
                                                        else 254
                                                    )
                                                    if state == 253:
                                                        state = (
                                                            331
                                                            if x["col_last"]
                                                            < -0.0955147743
                                                            else 332
                                                        )
                                                        if state == 331:
                                                            return 0.10389363
                                                        if state == 332:
                                                            return -0.122039206
                                                    if state == 254:
                                                        return -0.2357274
                                                if state == 182:
                                                    return 0.145794585
                                            if state == 132:
                                                state = (
                                                    183
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 17.5672493)
                                                    else 184
                                                )
                                                if state == 183:
                                                    state = (
                                                        257
                                                        if x["sgscore1_med"]
                                                        < 0.0293749999
                                                        else 258
                                                    )
                                                    if state == 257:
                                                        return -0.0081463689
                                                    if state == 258:
                                                        return -0.232538089
                                                if state == 184:
                                                    state = (
                                                        259
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.0466666967
                                                        )
                                                        else 260
                                                    )
                                                    if state == 259:
                                                        state = (
                                                            335
                                                            if x["col_last"]
                                                            < 0.102365494
                                                            else 336
                                                        )
                                                        if state == 335:
                                                            return 0.12712203
                                                        if state == 336:
                                                            return -0.0354745016
                                                    if state == 260:
                                                        state = (
                                                            337
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.474579811
                                                            )
                                                            else 338
                                                        )
                                                        if state == 337:
                                                            return 0.0522967689
                                                        if state == 338:
                                                            return -0.0358343795
                                    if state == 76:
                                        state = (
                                            99
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.5471916)
                                            else 100
                                        )
                                        if state == 99:
                                            state = (
                                                133
                                                if x["col_last"] < 0.647818089
                                                else 134
                                            )
                                            if state == 133:
                                                state = (
                                                    185
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 17.8095016)
                                                    else 186
                                                )
                                                if state == 185:
                                                    return -0.130354375
                                                if state == 186:
                                                    state = (
                                                        261
                                                        if x["sgscore1_med"]
                                                        < 0.595047951
                                                        else 262
                                                    )
                                                    if state == 261:
                                                        state = (
                                                            339
                                                            if x["col_last"]
                                                            < 0.253117085
                                                            else 340
                                                        )
                                                        if state == 339:
                                                            return -0.153302282
                                                        if state == 340:
                                                            return 0.127709523
                                                    if state == 262:
                                                        return 0.116492525
                                            if state == 134:
                                                state = (
                                                    187
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.3059998)
                                                    else 188
                                                )
                                                if state == 187:
                                                    state = (
                                                        263
                                                        if x["sgscore1_med"]
                                                        < 0.0282500014
                                                        else 264
                                                    )
                                                    if state == 263:
                                                        return 0.0165760145
                                                    if state == 264:
                                                        return -0.311979651
                                                if state == 188:
                                                    state = (
                                                        265
                                                        if x["sgscore1_med"]
                                                        < 0.595047951
                                                        else 266
                                                    )
                                                    if state == 265:
                                                        return -0.1254953
                                                    if state == 266:
                                                        return 0.14933306
                                        if state == 100:
                                            state = (
                                                135
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.399897099)
                                                else 136
                                            )
                                            if state == 135:
                                                state = (
                                                    189
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.050251)
                                                    else 190
                                                )
                                                if state == 189:
                                                    state = (
                                                        267
                                                        if x["sgscore1_med"]
                                                        < 0.175705001
                                                        else 268
                                                    )
                                                    if state == 267:
                                                        return 0.215612486
                                                    if state == 268:
                                                        return -0.129556358
                                                if state == 190:
                                                    state = (
                                                        269
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.00998512004
                                                        )
                                                        else 270
                                                    )
                                                    if state == 269:
                                                        return -0.199868336
                                                    if state == 270:
                                                        return -0.0295724496
                                            if state == 136:
                                                return 0.0952559337
                                if state == 56:
                                    state = 77 if x["col_peak"] < -0.134886742 else 78
                                    if state == 77:
                                        state = (
                                            101
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.5988312)
                                            else 102
                                        )
                                        if state == 101:
                                            return 0.249443009
                                        if state == 102:
                                            state = (
                                                137
                                                if x["col_last"] < 0.446294785
                                                else 138
                                            )
                                            if state == 137:
                                                return -0.0360144153
                                            if state == 138:
                                                state = (
                                                    193
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.5779991)
                                                    else 194
                                                )
                                                if state == 193:
                                                    state = (
                                                        273
                                                        if x["sgscore1_med"]
                                                        < 0.0486145504
                                                        else 274
                                                    )
                                                    if state == 273:
                                                        return 0.0805099234
                                                    if state == 274:
                                                        return -0.124913916
                                                if state == 194:
                                                    return 0.158873707
                                    if state == 78:
                                        state = (
                                            103
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.5389099)
                                            else 104
                                        )
                                        if state == 103:
                                            state = (
                                                139
                                                if x["col_last"] < -0.101027489
                                                else 140
                                            )
                                            if state == 139:
                                                return 0.0356476605
                                            if state == 140:
                                                state = (
                                                    197
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.191)
                                                    else 198
                                                )
                                                if state == 197:
                                                    state = (
                                                        279
                                                        if x["sgscore1_med"]
                                                        < 0.0296250004
                                                        else 280
                                                    )
                                                    if state == 279:
                                                        state = (
                                                            341
                                                            if x["col_last"]
                                                            < 2.27463627
                                                            else 342
                                                        )
                                                        if state == 341:
                                                            return 0.121538982
                                                        if state == 342:
                                                            return -0.107365347
                                                    if state == 280:
                                                        return 0.256106734
                                                if state == 198:
                                                    state = (
                                                        281
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.641104519
                                                        )
                                                        else 282
                                                    )
                                                    if state == 281:
                                                        return 0.287514567
                                                    if state == 282:
                                                        return -0.016433306
                                        if state == 104:
                                            state = (
                                                141
                                                if x["col_last"] < -0.0154485703
                                                else 142
                                            )
                                            if state == 141:
                                                state = (
                                                    199
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.1069984)
                                                    else 200
                                                )
                                                if state == 199:
                                                    state = (
                                                        283
                                                        if x["sgscore1_med"]
                                                        < 0.0084374994
                                                        else 284
                                                    )
                                                    if state == 283:
                                                        return 0.159665972
                                                    if state == 284:
                                                        return -0.109606586
                                                if state == 200:
                                                    return -0.290383786
                                            if state == 142:
                                                state = (
                                                    201
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 17.8614998)
                                                    else 202
                                                )
                                                if state == 201:
                                                    state = (
                                                        285
                                                        if x["sgscore1_med"]
                                                        < 0.149881005
                                                        else 286
                                                    )
                                                    if state == 285:
                                                        return 0.114800476
                                                    if state == 286:
                                                        return 0.288008541
                                                if state == 202:
                                                    state = (
                                                        287
                                                        if x["sgscore1_med"]
                                                        < 0.0121458499
                                                        else 288
                                                    )
                                                    if state == 287:
                                                        state = (
                                                            349
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.513084412
                                                            )
                                                            else 350
                                                        )
                                                        if state == 349:
                                                            return 0.0490129143
                                                        if state == 350:
                                                            return 0.202338308
                                                    if state == 288:
                                                        state = (
                                                            351
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.382620811
                                                            )
                                                            else 352
                                                        )
                                                        if state == 351:
                                                            return -0.0474393219
                                                        if state == 352:
                                                            return 0.0677742213
                            if state == 34:
                                state = (
                                    57
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.709285736)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        79
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.0797691345)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            105
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.7421608)
                                            else 106
                                        )
                                        if state == 105:
                                            state = (
                                                143
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < -0.0732955933)
                                                else 144
                                            )
                                            if state == 143:
                                                state = (
                                                    203
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 22.2159996)
                                                    else 204
                                                )
                                                if state == 203:
                                                    return -0.0497292057
                                                if state == 204:
                                                    state = (
                                                        289
                                                        if x["sgscore1_med"]
                                                        < 0.00643750001
                                                        else 290
                                                    )
                                                    if state == 289:
                                                        return -0.0781473443
                                                    if state == 290:
                                                        return 0.18652539
                                            if state == 144:
                                                state = (
                                                    205
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 22.1850014)
                                                    else 206
                                                )
                                                if state == 205:
                                                    return -0.156538099
                                                if state == 206:
                                                    state = (
                                                        291
                                                        if x["sgscore1_med"]
                                                        < 0.0106874853
                                                        else 292
                                                    )
                                                    if state == 291:
                                                        return -0.0843133107
                                                    if state == 292:
                                                        return 0.125619859
                                        if state == 106:
                                            state = (
                                                145
                                                if x["col_last"] < -0.0356359482
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    207
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 22.8570004)
                                                    else 208
                                                )
                                                if state == 207:
                                                    return -0.261372924
                                                if state == 208:
                                                    return 0.0248256158
                                            if state == 146:
                                                state = (
                                                    209
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 22.8455009)
                                                    else 210
                                                )
                                                if state == 209:
                                                    state = (
                                                        293
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.753303528
                                                        )
                                                        else 294
                                                    )
                                                    if state == 293:
                                                        return -0.296022713
                                                    if state == 294:
                                                        return 0.063819997
                                                if state == 210:
                                                    state = (
                                                        295
                                                        if x["sgscore1_med"]
                                                        < 0.359916985
                                                        else 296
                                                    )
                                                    if state == 295:
                                                        state = (
                                                            355
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.00169277191
                                                            )
                                                            else 356
                                                        )
                                                        if state == 355:
                                                            return 0.0939039364
                                                        if state == 356:
                                                            return -0.155151561
                                                    if state == 296:
                                                        return 0.204013363
                                    if state == 80:
                                        state = (
                                            107
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.3621483)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                147
                                                if x["col_last"] < 1.0531702
                                                else 148
                                            )
                                            if state == 147:
                                                return -0.238139197
                                            if state == 148:
                                                state = (
                                                    213
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 22.3297501)
                                                    else 214
                                                )
                                                if state == 213:
                                                    return 0.056978818
                                                if state == 214:
                                                    state = (
                                                        297
                                                        if x["sgscore1_med"]
                                                        < 0.480547488
                                                        else 298
                                                    )
                                                    if state == 297:
                                                        return -0.281640828
                                                    if state == 298:
                                                        return 0.0209856778
                                        if state == 108:
                                            return 0.0699927881
                                if state == 58:
                                    state = 81 if x["col_peak"] < -0.14703083 else 82
                                    if state == 81:
                                        return -0.143074214
                                    if state == 82:
                                        state = (
                                            109
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.124733)
                                            else 110
                                        )
                                        if state == 109:
                                            state = (
                                                149
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.100839615)
                                                else 150
                                            )
                                            if state == 149:
                                                return 0.236595139
                                            if state == 150:
                                                return -0.00143910514
                                        if state == 110:
                                            state = (
                                                151
                                                if x["col_last"] < -0.0703420043
                                                else 152
                                            )
                                            if state == 151:
                                                return 0.0315477885
                                            if state == 152:
                                                state = (
                                                    215
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 22.2919998)
                                                    else 216
                                                )
                                                if state == 215:
                                                    return 0.151180491
                                                if state == 216:
                                                    return -0.202045768
                        if state == 20:
                            return 0.248049185
            if state == 2:
                state = 5 if x["col_last"] < 0.575383186 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.49636626)
                        else 12
                    )
                    if state == 11:
                        state = 21 if x["col_peak"] < 0.184121132 else 22
                        if state == 21:
                            return -0.00152520172
                        if state == 22:
                            state = (
                                35
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.4977493)
                                else 36
                            )
                            if state == 35:
                                return -0.17698884
                            if state == 36:
                                return 0.0333655737
                    if state == 12:
                        state = 23 if x["col_peak"] < 0.252241611 else 24
                        if state == 23:
                            return -0.0124341799
                        if state == 24:
                            state = (
                                37
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.8347511)
                                else 38
                            )
                            if state == 37:
                                return 0.164695427
                            if state == 38:
                                return -0.0628141537
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.620831251)
                        else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.450921059)
                            else 26
                        )
                        if state == 25:
                            state = (
                                39
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.4459991)
                                else 40
                            )
                            if state == 39:
                                return -0.208318949
                            if state == 40:
                                return 0.0255047716
                        if state == 26:
                            return 0.0237589292
                    if state == 14:
                        state = 27 if x["col_peak"] < 0.633175969 else 28
                        if state == 27:
                            state = (
                                43
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.2659988)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    63
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.605833292)
                                    else 64
                                )
                                if state == 63:
                                    return -0.0272110272
                                if state == 64:
                                    return 0.221146956
                            if state == 44:
                                return -0.184127763
                        if state == 28:
                            state = (
                                45
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 16.9895)
                                else 46
                            )
                            if state == 45:
                                return -0.0838785544
                            if state == 46:
                                state = (
                                    65
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.938571453)
                                    else 66
                                )
                                if state == 65:
                                    return 0.253207922
                                if state == 66:
                                    return -0.0489422195
    elif num_booster == 24:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 18.6708908 else 2
            if state == 1:
                state = 3 if x["col_det"] < -0.197768211 else 4
                if state == 3:
                    state = 7 if x["mag_peak"] < 18.5166969 else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.86905098)
                            else 16
                        )
                        if state == 15:
                            return 0.152428687
                        if state == 16:
                            state = (
                                31
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.6578484)
                                else 32
                            )
                            if state == 31:
                                state = 59 if x["maggaia_med"] < 17.9146633 else 60
                                if state == 59:
                                    return 0.124045372
                                if state == 60:
                                    state = (
                                        111
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.4710007)
                                        else 112
                                    )
                                    if state == 111:
                                        return 0.00348156714
                                    if state == 112:
                                        return -0.254489154
                            if state == 32:
                                return -0.0196814258
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 6.91437531)
                            else 18
                        )
                        if state == 17:
                            state = (
                                33
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.1447544)
                                else 34
                            )
                            if state == 33:
                                state = 63 if x["maggaia_med"] < 18.6122723 else 64
                                if state == 63:
                                    return 0.252476692
                                if state == 64:
                                    state = (
                                        113
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.2565002)
                                        else 114
                                    )
                                    if state == 113:
                                        return -0.204777017
                                    if state == 114:
                                        state = (
                                            193
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.1414986)
                                            else 194
                                        )
                                        if state == 193:
                                            return -0.0314260125
                                        if state == 194:
                                            return 0.187293112
                            if state == 34:
                                state = 65 if x["maggaia_med"] < 16.3988266 else 66
                                if state == 65:
                                    return 0.1821367
                                if state == 66:
                                    state = (
                                        115
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.7329998)
                                        else 116
                                    )
                                    if state == 115:
                                        return 0.00752458302
                                    if state == 116:
                                        return -0.241507724
                        if state == 18:
                            state = (
                                35
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.7277031)
                                else 36
                            )
                            if state == 35:
                                return 0.033236485
                            if state == 36:
                                state = 67 if x["maggaia_med"] < 17.824255 else 68
                                if state == 67:
                                    return 0.359487355
                                if state == 68:
                                    state = (
                                        117
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 21.5380001)
                                        else 118
                                    )
                                    if state == 117:
                                        return -0.104550719
                                    if state == 118:
                                        return 0.0986500457
                if state == 4:
                    state = 9 if x["mag_peak"] < 18.9998703 else 10
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.98407984)
                            else 20
                        )
                        if state == 19:
                            state = (
                                37
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.9641056)
                                else 38
                            )
                            if state == 37:
                                state = 69 if x["maggaia_med"] < 19.5990334 else 70
                                if state == 69:
                                    state = (
                                        119
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 16.2540016)
                                        else 120
                                    )
                                    if state == 119:
                                        return -0.152225375
                                    if state == 120:
                                        state = (
                                            197
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.1592503)
                                            else 198
                                        )
                                        if state == 197:
                                            state = (
                                                273
                                                if x["mag_peak"] < 18.4580746
                                                else 274
                                            )
                                            if state == 273:
                                                return 0.214645892
                                            if state == 274:
                                                state = (
                                                    337
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.8818171)
                                                    else 338
                                                )
                                                if state == 337:
                                                    return -0.0688884705
                                                if state == 338:
                                                    return 0.101369374
                                        if state == 198:
                                            state = (
                                                275
                                                if x["mag_peak"] < 18.0527916
                                                else 276
                                            )
                                            if state == 275:
                                                return 0.137086108
                                            if state == 276:
                                                return -0.142356262
                                if state == 70:
                                    state = (
                                        121
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.868)
                                        else 122
                                    )
                                    if state == 121:
                                        return 0.146662563
                                    if state == 122:
                                        return -0.208817333
                            if state == 38:
                                state = 71 if x["maggaia_med"] < 17.8212318 else 72
                                if state == 71:
                                    state = (
                                        123
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.7210007)
                                        else 124
                                    )
                                    if state == 123:
                                        state = (
                                            199
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.5515499)
                                            else 200
                                        )
                                        if state == 199:
                                            state = (
                                                277
                                                if x["mag_peak"] < 18.6195049
                                                else 278
                                            )
                                            if state == 277:
                                                return 0.0769387335
                                            if state == 278:
                                                return -0.123545207
                                        if state == 200:
                                            state = (
                                                279
                                                if x["mag_peak"] < 18.441597
                                                else 280
                                            )
                                            if state == 279:
                                                state = (
                                                    339
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.93748856)
                                                    else 340
                                                )
                                                if state == 339:
                                                    return 0.0898021087
                                                if state == 340:
                                                    return -0.0884740129
                                            if state == 280:
                                                return -0.337653071
                                    if state == 124:
                                        state = (
                                            201
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.509201)
                                            else 202
                                        )
                                        if state == 201:
                                            return -0.146722913
                                        if state == 202:
                                            state = (
                                                281
                                                if x["mag_peak"] < 18.7353516
                                                else 282
                                            )
                                            if state == 281:
                                                return 0.28568837
                                            if state == 282:
                                                state = (
                                                    341
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.072291702)
                                                    else 342
                                                )
                                                if state == 341:
                                                    return -0.145266503
                                                if state == 342:
                                                    state = (
                                                        403
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 0.135034651
                                                        )
                                                        else 404
                                                    )
                                                    if state == 403:
                                                        return 0.126901478
                                                    if state == 404:
                                                        return -0.144128576
                                if state == 72:
                                    state = (
                                        125
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 16.8845005)
                                        else 126
                                    )
                                    if state == 125:
                                        return -0.147168368
                                    if state == 126:
                                        state = (
                                            203
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.7033005)
                                            else 204
                                        )
                                        if state == 203:
                                            state = (
                                                283
                                                if x["mag_peak"] < 17.7807064
                                                else 284
                                            )
                                            if state == 283:
                                                return 0.120792739
                                            if state == 284:
                                                return -0.160442486
                                        if state == 204:
                                            state = (
                                                285
                                                if x["mag_peak"] < 18.9316006
                                                else 286
                                            )
                                            if state == 285:
                                                state = (
                                                    343
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0200115498)
                                                    else 344
                                                )
                                                if state == 343:
                                                    return -0.18726328
                                                if state == 344:
                                                    state = (
                                                        405
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 1.54041088
                                                        )
                                                        else 406
                                                    )
                                                    if state == 405:
                                                        state = (
                                                            461
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.425533295
                                                            )
                                                            else 462
                                                        )
                                                        if state == 461:
                                                            return 0.218973592
                                                        if state == 462:
                                                            return 0.0107804658
                                                    if state == 406:
                                                        return 0.310997516
                                            if state == 286:
                                                state = (
                                                    345
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.93094897)
                                                    else 346
                                                )
                                                if state == 345:
                                                    state = (
                                                        407
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 0.0506539494
                                                        )
                                                        else 408
                                                    )
                                                    if state == 407:
                                                        return -0.161766768
                                                    if state == 408:
                                                        return 0.255855829
                                                if state == 346:
                                                    return -0.249164358
                        if state == 20:
                            state = (
                                39
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.0381813)
                                else 40
                            )
                            if state == 39:
                                state = 73 if x["maggaia_med"] < 19.4592896 else 74
                                if state == 73:
                                    state = (
                                        127
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 20.8125)
                                        else 128
                                    )
                                    if state == 127:
                                        state = (
                                            205
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.9366989)
                                            else 206
                                        )
                                        if state == 205:
                                            return -0.26088807
                                        if state == 206:
                                            state = (
                                                289
                                                if x["mag_peak"] < 18.3155537
                                                else 290
                                            )
                                            if state == 289:
                                                state = (
                                                    347
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.96407413)
                                                    else 348
                                                )
                                                if state == 347:
                                                    return 0.187527031
                                                if state == 348:
                                                    state = (
                                                        411
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 4.99424171
                                                        )
                                                        else 412
                                                    )
                                                    if state == 411:
                                                        return -0.249449685
                                                    if state == 412:
                                                        return 0.0745785236
                                            if state == 290:
                                                state = (
                                                    349
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.92894173)
                                                    else 350
                                                )
                                                if state == 349:
                                                    state = (
                                                        413
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 3.95511007
                                                        )
                                                        else 414
                                                    )
                                                    if state == 413:
                                                        return -0.0233997479
                                                    if state == 414:
                                                        state = (
                                                            467
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.0235357285
                                                            )
                                                            else 468
                                                        )
                                                        if state == 467:
                                                            return -0.220524475
                                                        if state == 468:
                                                            return 0.015714854
                                                if state == 350:
                                                    return 0.130901381
                                    if state == 128:
                                        state = (
                                            207
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.5393524)
                                            else 208
                                        )
                                        if state == 207:
                                            state = (
                                                291
                                                if x["mag_peak"] < 17.0365067
                                                else 292
                                            )
                                            if state == 291:
                                                state = (
                                                    351
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.00897598)
                                                    else 352
                                                )
                                                if state == 351:
                                                    return -0.18022801
                                                if state == 352:
                                                    return 0.0285995547
                                            if state == 292:
                                                state = (
                                                    353
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.97859383)
                                                    else 354
                                                )
                                                if state == 353:
                                                    return -0.0649092123
                                                if state == 354:
                                                    return 0.162338272
                                        if state == 208:
                                            state = (
                                                293
                                                if x["mag_peak"] < 18.0485115
                                                else 294
                                            )
                                            if state == 293:
                                                return 0.0370399132
                                            if state == 294:
                                                return -0.312263966
                                if state == 74:
                                    state = (
                                        129
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.0275002)
                                        else 130
                                    )
                                    if state == 129:
                                        return 0.147498414
                                    if state == 130:
                                        state = (
                                            209
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.5998993)
                                            else 210
                                        )
                                        if state == 209:
                                            state = (
                                                295
                                                if x["mag_peak"] < 17.9002743
                                                else 296
                                            )
                                            if state == 295:
                                                state = (
                                                    357
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.92329884)
                                                    else 358
                                                )
                                                if state == 357:
                                                    return -0.402998894
                                                if state == 358:
                                                    return 0.0988338515
                                            if state == 296:
                                                state = (
                                                    359
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.00887108)
                                                    else 360
                                                )
                                                if state == 359:
                                                    state = (
                                                        417
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 3.99714708
                                                        )
                                                        else 418
                                                    )
                                                    if state == 417:
                                                        return 0.0128329974
                                                    if state == 418:
                                                        return -0.212595522
                                                if state == 360:
                                                    return 0.126232341
                                        if state == 210:
                                            state = (
                                                297
                                                if x["mag_peak"] < 18.7402763
                                                else 298
                                            )
                                            if state == 297:
                                                return 0.174527273
                                            if state == 298:
                                                return -0.0933527499
                            if state == 40:
                                state = 75 if x["maggaia_med"] < 19.6917305 else 76
                                if state == 75:
                                    state = (
                                        131
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.5879993)
                                        else 132
                                    )
                                    if state == 131:
                                        state = (
                                            211
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.3409996)
                                            else 212
                                        )
                                        if state == 211:
                                            state = (
                                                299
                                                if x["mag_peak"] < 17.828804
                                                else 300
                                            )
                                            if state == 299:
                                                return 0.127008617
                                            if state == 300:
                                                state = (
                                                    361
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.99908638)
                                                    else 362
                                                )
                                                if state == 361:
                                                    state = (
                                                        419
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 7.94251156
                                                        )
                                                        else 420
                                                    )
                                                    if state == 419:
                                                        state = (
                                                            469
                                                            if x["col_last"]
                                                            < 1.02171516
                                                            else 470
                                                        )
                                                        if state == 469:
                                                            return 0.0504589938
                                                        if state == 470:
                                                            return -0.131812707
                                                    if state == 420:
                                                        return -0.338948071
                                                if state == 362:
                                                    state = (
                                                        421
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 9.95279503
                                                        )
                                                        else 422
                                                    )
                                                    if state == 421:
                                                        return 0.198420793
                                                    if state == 422:
                                                        return -0.134401336
                                        if state == 212:
                                            state = (
                                                301
                                                if x["mag_peak"] < 18.7476883
                                                else 302
                                            )
                                            if state == 301:
                                                state = (
                                                    363
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.09937477)
                                                    else 364
                                                )
                                                if state == 363:
                                                    return 0.270950288
                                                if state == 364:
                                                    state = (
                                                        423
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"] < 5.9893465
                                                        )
                                                        else 424
                                                    )
                                                    if state == 423:
                                                        return -0.279254884
                                                    if state == 424:
                                                        return 0.134356081
                                            if state == 302:
                                                state = (
                                                    365
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.02664375)
                                                    else 366
                                                )
                                                if state == 365:
                                                    state = (
                                                        425
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 3.11348391
                                                        )
                                                        else 426
                                                    )
                                                    if state == 425:
                                                        state = (
                                                            473
                                                            if x["col_last"]
                                                            < 0.173231125
                                                            else 474
                                                        )
                                                        if state == 473:
                                                            return -0.0718242973
                                                        if state == 474:
                                                            return 0.163697228
                                                    if state == 426:
                                                        return -0.299475789
                                                if state == 366:
                                                    return 0.304816216
                                    if state == 132:
                                        state = (
                                            213
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.8150749)
                                            else 214
                                        )
                                        if state == 213:
                                            state = (
                                                303
                                                if x["mag_peak"] < 18.515274
                                                else 304
                                            )
                                            if state == 303:
                                                state = (
                                                    367
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 7.02013302)
                                                    else 368
                                                )
                                                if state == 367:
                                                    state = (
                                                        427
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 4.99055576
                                                        )
                                                        else 428
                                                    )
                                                    if state == 427:
                                                        return -0.329763204
                                                    if state == 428:
                                                        state = (
                                                            475
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.0770149231
                                                            )
                                                            else 476
                                                        )
                                                        if state == 475:
                                                            return -0.105908118
                                                        if state == 476:
                                                            return 0.0850531533
                                                if state == 368:
                                                    return 0.21115686
                                            if state == 304:
                                                state = (
                                                    369
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.55007553)
                                                    else 370
                                                )
                                                if state == 369:
                                                    return -0.508601487
                                                if state == 370:
                                                    return -0.0399702676
                                        if state == 214:
                                            state = (
                                                305
                                                if x["mag_peak"] < 18.9844398
                                                else 306
                                            )
                                            if state == 305:
                                                state = (
                                                    371
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.95845509)
                                                    else 372
                                                )
                                                if state == 371:
                                                    return 0.0458964482
                                                if state == 372:
                                                    return 0.291177362
                                            if state == 306:
                                                return -0.181805253
                                if state == 76:
                                    state = (
                                        133
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 20.828249)
                                        else 134
                                    )
                                    if state == 133:
                                        state = (
                                            215
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.3620987)
                                            else 216
                                        )
                                        if state == 215:
                                            state = (
                                                307
                                                if x["mag_peak"] < 17.514864
                                                else 308
                                            )
                                            if state == 307:
                                                return -0.00162361283
                                            if state == 308:
                                                return 0.250363708
                                        if state == 216:
                                            state = (
                                                309
                                                if x["mag_peak"] < 18.1267548
                                                else 310
                                            )
                                            if state == 309:
                                                return 0.241334707
                                            if state == 310:
                                                state = (
                                                    373
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.48285294)
                                                    else 374
                                                )
                                                if state == 373:
                                                    return -0.286689073
                                                if state == 374:
                                                    state = (
                                                        433
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 5.99965858
                                                        )
                                                        else 434
                                                    )
                                                    if state == 433:
                                                        return 0.1092389
                                                    if state == 434:
                                                        return -0.234288037
                                    if state == 134:
                                        state = (
                                            217
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.7709503)
                                            else 218
                                        )
                                        if state == 217:
                                            return -0.0638450608
                                        if state == 218:
                                            return 0.301743984
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.9921298)
                            else 22
                        )
                        if state == 21:
                            state = (
                                41
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.0971909)
                                else 42
                            )
                            if state == 41:
                                state = 77 if x["maggaia_med"] < 18.1421242 else 78
                                if state == 77:
                                    state = (
                                        135
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 21.0112495)
                                        else 136
                                    )
                                    if state == 135:
                                        state = (
                                            219
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.0779495)
                                            else 220
                                        )
                                        if state == 219:
                                            return 0.0239946265
                                        if state == 220:
                                            return -0.124661565
                                    if state == 136:
                                        state = (
                                            221
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.5317497)
                                            else 222
                                        )
                                        if state == 221:
                                            return -0.308197975
                                        if state == 222:
                                            return 0.0726222992
                                if state == 78:
                                    state = (
                                        137
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.4264984)
                                        else 138
                                    )
                                    if state == 137:
                                        state = (
                                            223
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.9141502)
                                            else 224
                                        )
                                        if state == 223:
                                            return -0.0828082338
                                        if state == 224:
                                            return 0.15828833
                                    if state == 138:
                                        state = (
                                            225
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.9722004)
                                            else 226
                                        )
                                        if state == 225:
                                            return 0.0922314376
                                        if state == 226:
                                            return 0.302760541
                            if state == 42:
                                state = 79 if x["maggaia_med"] < 18.1641998 else 80
                                if state == 79:
                                    return -0.362061441
                                if state == 80:
                                    state = (
                                        139
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 22.0159988)
                                        else 140
                                    )
                                    if state == 139:
                                        state = (
                                            227
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.8027)
                                            else 228
                                        )
                                        if state == 227:
                                            state = (
                                                311
                                                if x["mag_peak"] < 19.0356541
                                                else 312
                                            )
                                            if state == 311:
                                                return 0.0158839617
                                            if state == 312:
                                                state = (
                                                    375
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.91038752)
                                                    else 376
                                                )
                                                if state == 375:
                                                    return -0.327893108
                                                if state == 376:
                                                    state = (
                                                        435
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.91072917
                                                        )
                                                        else 436
                                                    )
                                                    if state == 435:
                                                        return 0.331359684
                                                    if state == 436:
                                                        state = (
                                                            479
                                                            if x["col_last"]
                                                            < 0.00690603256
                                                            else 480
                                                        )
                                                        if state == 479:
                                                            return 0.0955910385
                                                        if state == 480:
                                                            return -0.33292529
                                        if state == 228:
                                            return 0.132470712
                                    if state == 140:
                                        state = (
                                            229
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.6473007)
                                            else 230
                                        )
                                        if state == 229:
                                            return 0.159473822
                                        if state == 230:
                                            return -0.138641044
                        if state == 22:
                            state = (
                                43
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.0979843)
                                else 44
                            )
                            if state == 43:
                                state = 81 if x["maggaia_med"] < 17.9611111 else 82
                                if state == 81:
                                    state = (
                                        141
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.4610004)
                                        else 142
                                    )
                                    if state == 141:
                                        state = (
                                            231
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.7997494)
                                            else 232
                                        )
                                        if state == 231:
                                            return -0.140632689
                                        if state == 232:
                                            return -0.431292415
                                    if state == 142:
                                        state = (
                                            233
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.7360497)
                                            else 234
                                        )
                                        if state == 233:
                                            return 0.0709039196
                                        if state == 234:
                                            return -0.155060992
                                if state == 82:
                                    state = (
                                        143
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.8837509)
                                        else 144
                                    )
                                    if state == 143:
                                        state = (
                                            235
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.1236)
                                            else 236
                                        )
                                        if state == 235:
                                            return -0.0741195306
                                        if state == 236:
                                            return -0.398384929
                                    if state == 144:
                                        state = (
                                            237
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.7695007)
                                            else 238
                                        )
                                        if state == 237:
                                            return -0.0680024028
                                        if state == 238:
                                            return 0.163653418
                            if state == 44:
                                state = 83 if x["maggaia_med"] < 15.4132843 else 84
                                if state == 83:
                                    state = (
                                        145
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 21.7420006)
                                        else 146
                                    )
                                    if state == 145:
                                        return -0.156502768
                                    if state == 146:
                                        return 0.177804232
                                if state == 84:
                                    return -0.384783983
            if state == 2:
                state = 5 if x["col_det"] < -0.209334373 else 6
                if state == 5:
                    state = 11 if x["mag_peak"] < 18.5847206 else 12
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 9.41513824)
                            else 24
                        )
                        if state == 23:
                            state = (
                                45
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.8212547)
                                else 46
                            )
                            if state == 45:
                                state = 85 if x["maggaia_med"] < 19.9534225 else 86
                                if state == 85:
                                    state = (
                                        147
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 21.6975002)
                                        else 148
                                    )
                                    if state == 147:
                                        return 0.279111326
                                    if state == 148:
                                        state = (
                                            239
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.5076485)
                                            else 240
                                        )
                                        if state == 239:
                                            return -0.132667527
                                        if state == 240:
                                            return 0.0442707986
                                if state == 86:
                                    state = (
                                        149
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 20.2384987)
                                        else 150
                                    )
                                    if state == 149:
                                        return 0.167321965
                                    if state == 150:
                                        return -0.19337827
                            if state == 46:
                                return 0.246141374
                        if state == 24:
                            return -0.17341809
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 4.89123821)
                            else 26
                        )
                        if state == 25:
                            state = (
                                47
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.3081818)
                                else 48
                            )
                            if state == 47:
                                state = (
                                    87
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 17.4042015)
                                    else 88
                                )
                                if state == 87:
                                    state = (
                                        151
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.6105003)
                                        else 152
                                    )
                                    if state == 151:
                                        return 0.147505075
                                    if state == 152:
                                        state = (
                                            241
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.6300507)
                                            else 242
                                        )
                                        if state == 241:
                                            return 0.00253151054
                                        if state == 242:
                                            return -0.277244061
                                if state == 88:
                                    state = (
                                        153
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.7024994)
                                        else 154
                                    )
                                    if state == 153:
                                        return 0.26427564
                                    if state == 154:
                                        return -0.00899240188
                            if state == 48:
                                state = (
                                    89
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.5687065)
                                    else 90
                                )
                                if state == 89:
                                    state = (
                                        155
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.6364994)
                                        else 156
                                    )
                                    if state == 155:
                                        return 0.0327749886
                                    if state == 156:
                                        return -0.317522645
                                if state == 90:
                                    state = (
                                        157
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 21.9830017)
                                        else 158
                                    )
                                    if state == 157:
                                        return -0.120385863
                                    if state == 158:
                                        return 0.0519494489
                        if state == 26:
                            state = (
                                49
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.8058319)
                                else 50
                            )
                            if state == 49:
                                state = (
                                    91
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.6196041)
                                    else 92
                                )
                                if state == 91:
                                    return 0.198416889
                                if state == 92:
                                    return -0.126778021
                            if state == 50:
                                state = 93 if x["maggaia_med"] < 17.1547127 else 94
                                if state == 93:
                                    state = (
                                        159
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 20.9769993)
                                        else 160
                                    )
                                    if state == 159:
                                        state = (
                                            245
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.6553497)
                                            else 246
                                        )
                                        if state == 245:
                                            state = (
                                                313
                                                if x["mag_peak"] < 19.0002174
                                                else 314
                                            )
                                            if state == 313:
                                                return 0.114236362
                                            if state == 314:
                                                return -0.1124347
                                        if state == 246:
                                            return 0.132028133
                                    if state == 160:
                                        return -0.150521189
                                if state == 94:
                                    state = (
                                        161
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 22.2775002)
                                        else 162
                                    )
                                    if state == 161:
                                        return -0.363502264
                                    if state == 162:
                                        return -0.0358907282
                if state == 6:
                    state = 13 if x["mag_peak"] < 18.3082199 else 14
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 8.95223999)
                            else 28
                        )
                        if state == 27:
                            state = (
                                51
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.4316597)
                                else 52
                            )
                            if state == 51:
                                state = (
                                    95
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 20.8378754)
                                    else 96
                                )
                                if state == 95:
                                    state = (
                                        163
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 17.137001)
                                        else 164
                                    )
                                    if state == 163:
                                        state = (
                                            247
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.1882305)
                                            else 248
                                        )
                                        if state == 247:
                                            return -0.0219786465
                                        if state == 248:
                                            state = (
                                                315
                                                if x["mag_peak"] < 17.6361332
                                                else 316
                                            )
                                            if state == 315:
                                                return 0.0509330854
                                            if state == 316:
                                                return -0.303964555
                                    if state == 164:
                                        state = (
                                            249
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.0276489)
                                            else 250
                                        )
                                        if state == 249:
                                            state = (
                                                317
                                                if x["mag_peak"] < 17.9389019
                                                else 318
                                            )
                                            if state == 317:
                                                state = (
                                                    377
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0548321977)
                                                    else 378
                                                )
                                                if state == 377:
                                                    return -0.0715393424
                                                if state == 378:
                                                    return 0.293619275
                                            if state == 318:
                                                state = (
                                                    379
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.86082172)
                                                    else 380
                                                )
                                                if state == 379:
                                                    return -0.351204067
                                                if state == 380:
                                                    state = (
                                                        437
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 3.03696775
                                                        )
                                                        else 438
                                                    )
                                                    if state == 437:
                                                        return 0.290497392
                                                    if state == 438:
                                                        state = (
                                                            481
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.946737289
                                                            )
                                                            else 482
                                                        )
                                                        if state == 481:
                                                            return 0.0666442886
                                                        if state == 482:
                                                            return -0.168480158
                                        if state == 250:
                                            return 0.310162932
                                if state == 96:
                                    return -0.210483462
                            if state == 52:
                                state = 97 if x["maggaia_med"] < 15.2518263 else 98
                                if state == 97:
                                    return 0.0415877961
                                if state == 98:
                                    state = (
                                        167
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 17.3484993)
                                        else 168
                                    )
                                    if state == 167:
                                        return -0.0504128784
                                    if state == 168:
                                        state = (
                                            251
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.0622501)
                                            else 252
                                        )
                                        if state == 251:
                                            return 0.0436475612
                                        if state == 252:
                                            return 0.336521089
                        if state == 28:
                            state = (
                                53
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.6598969)
                                else 54
                            )
                            if state == 53:
                                state = 99 if x["maggaia_med"] < 19.7853127 else 100
                                if state == 99:
                                    state = (
                                        169
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.081501)
                                        else 170
                                    )
                                    if state == 169:
                                        return 0.131808043
                                    if state == 170:
                                        return -0.322861791
                                if state == 100:
                                    state = (
                                        171
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.3355007)
                                        else 172
                                    )
                                    if state == 171:
                                        state = (
                                            253
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.1544495)
                                            else 254
                                        )
                                        if state == 253:
                                            state = (
                                                319
                                                if x["mag_peak"] < 17.7840576
                                                else 320
                                            )
                                            if state == 319:
                                                return -0.118275121
                                            if state == 320:
                                                return 0.119353816
                                        if state == 254:
                                            return -0.189525276
                                    if state == 172:
                                        return 0.215455279
                            if state == 54:
                                state = (
                                    101
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.463665)
                                    else 102
                                )
                                if state == 101:
                                    state = (
                                        173
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.1505013)
                                        else 174
                                    )
                                    if state == 173:
                                        return 0.171077296
                                    if state == 174:
                                        return -0.0371505208
                                if state == 102:
                                    return -0.0249684509
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 7.95737267)
                            else 30
                        )
                        if state == 29:
                            state = (
                                55
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.8317451)
                                else 56
                            )
                            if state == 55:
                                state = 103 if x["maggaia_med"] < 15.8731422 else 104
                                if state == 103:
                                    state = (
                                        175
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.3719997)
                                        else 176
                                    )
                                    if state == 175:
                                        state = (
                                            255
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.4920006)
                                            else 256
                                        )
                                        if state == 255:
                                            return -0.0725133792
                                        if state == 256:
                                            return 0.116704099
                                    if state == 176:
                                        state = (
                                            257
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.7938499)
                                            else 258
                                        )
                                        if state == 257:
                                            return -0.215199426
                                        if state == 258:
                                            return 0.0771462396
                                if state == 104:
                                    state = (
                                        177
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 20.7509995)
                                        else 178
                                    )
                                    if state == 177:
                                        state = (
                                            259
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.1316166)
                                            else 260
                                        )
                                        if state == 259:
                                            state = (
                                                321
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.4299145)
                                                else 322
                                            )
                                            if state == 321:
                                                state = (
                                                    381
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.9488945)
                                                    else 382
                                                )
                                                if state == 381:
                                                    state = (
                                                        439
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.90740156
                                                        )
                                                        else 440
                                                    )
                                                    if state == 439:
                                                        return -0.064793922
                                                    if state == 440:
                                                        return 0.184913769
                                                if state == 382:
                                                    state = (
                                                        441
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 4.96644115
                                                        )
                                                        else 442
                                                    )
                                                    if state == 441:
                                                        return -0.232788667
                                                    if state == 442:
                                                        return 0.0669846833
                                            if state == 322:
                                                return 0.0677505434
                                        if state == 260:
                                            state = (
                                                323
                                                if x["mag_peak"] < 18.5917053
                                                else 324
                                            )
                                            if state == 323:
                                                state = (
                                                    383
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0294444505)
                                                    else 384
                                                )
                                                if state == 383:
                                                    return -0.140695766
                                                if state == 384:
                                                    state = (
                                                        443
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.98227429
                                                        )
                                                        else 444
                                                    )
                                                    if state == 443:
                                                        return 0.162273854
                                                    if state == 444:
                                                        state = (
                                                            485
                                                            if x["col_last"]
                                                            < 0.562593937
                                                            else 486
                                                        )
                                                        if state == 485:
                                                            return 0.106804021
                                                        if state == 486:
                                                            return -0.100413494
                                            if state == 324:
                                                state = (
                                                    385
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0294444505)
                                                    else 386
                                                )
                                                if state == 385:
                                                    state = (
                                                        445
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 0.0198379494
                                                        )
                                                        else 446
                                                    )
                                                    if state == 445:
                                                        return 0.2036459
                                                    if state == 446:
                                                        return -0.0684302673
                                                if state == 386:
                                                    return 0.330783367
                                    if state == 178:
                                        state = (
                                            261
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.8280716)
                                            else 262
                                        )
                                        if state == 261:
                                            return -0.146458298
                                        if state == 262:
                                            return 0.154346585
                            if state == 56:
                                state = 105 if x["maggaia_med"] < 14.4506378 else 106
                                if state == 105:
                                    return -0.265962124
                                if state == 106:
                                    state = (
                                        181
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 21.1564999)
                                        else 182
                                    )
                                    if state == 181:
                                        state = (
                                            263
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.8930511)
                                            else 264
                                        )
                                        if state == 263:
                                            state = (
                                                325
                                                if x["mag_peak"] < 18.5428104
                                                else 326
                                            )
                                            if state == 325:
                                                state = (
                                                    387
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.98227429)
                                                    else 388
                                                )
                                                if state == 387:
                                                    return 0.292305827
                                                if state == 388:
                                                    state = (
                                                        447
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.99534726
                                                        )
                                                        else 448
                                                    )
                                                    if state == 447:
                                                        return -0.322093338
                                                    if state == 448:
                                                        state = (
                                                            487
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.796244025
                                                            )
                                                            else 488
                                                        )
                                                        if state == 487:
                                                            return 0.241268277
                                                        if state == 488:
                                                            return -0.0451243892
                                            if state == 326:
                                                state = (
                                                    389
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.02418423)
                                                    else 390
                                                )
                                                if state == 389:
                                                    state = (
                                                        449
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 4.02758694
                                                        )
                                                        else 450
                                                    )
                                                    if state == 449:
                                                        state = (
                                                            489
                                                            if x["col_last"]
                                                            < -0.028673172
                                                            else 490
                                                        )
                                                        if state == 489:
                                                            return -0.159993634
                                                        if state == 490:
                                                            return 0.0134680988
                                                    if state == 450:
                                                        state = (
                                                            491
                                                            if x["col_last"]
                                                            < 0.256256104
                                                            else 492
                                                        )
                                                        if state == 491:
                                                            return 0.0647112951
                                                        if state == 492:
                                                            return -0.216155708
                                                if state == 390:
                                                    state = (
                                                        451
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 7.01501751
                                                        )
                                                        else 452
                                                    )
                                                    if state == 451:
                                                        return 0.241712615
                                                    if state == 452:
                                                        return 0.0191764068
                                        if state == 264:
                                            return 0.315222651
                                    if state == 182:
                                        state = (
                                            265
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.8348007)
                                            else 266
                                        )
                                        if state == 265:
                                            state = (
                                                327
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.8759308)
                                                else 328
                                            )
                                            if state == 327:
                                                state = (
                                                    391
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.95855904)
                                                    else 392
                                                )
                                                if state == 391:
                                                    return 0.277416885
                                                if state == 392:
                                                    state = (
                                                        455
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"] < 5.8738308
                                                        )
                                                        else 456
                                                    )
                                                    if state == 455:
                                                        return -0.142664418
                                                    if state == 456:
                                                        return 0.14215897
                                            if state == 328:
                                                return -0.155441105
                                        if state == 266:
                                            state = (
                                                329
                                                if x["mag_peak"] < 18.8013458
                                                else 330
                                            )
                                            if state == 329:
                                                state = (
                                                    393
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.92812538)
                                                    else 394
                                                )
                                                if state == 393:
                                                    return 0.229960635
                                                if state == 394:
                                                    return -0.186919779
                                            if state == 330:
                                                state = (
                                                    395
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.91670132)
                                                    else 396
                                                )
                                                if state == 395:
                                                    state = (
                                                        457
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.90307856
                                                        )
                                                        else 458
                                                    )
                                                    if state == 457:
                                                        state = (
                                                            497
                                                            if x["col_last"]
                                                            < 0.0307192802
                                                            else 498
                                                        )
                                                        if state == 497:
                                                            return -0.0292754993
                                                        if state == 498:
                                                            return -0.26610738
                                                    if state == 458:
                                                        return 0.153684571
                                                if state == 396:
                                                    return -0.342264205
                        if state == 30:
                            state = (
                                57
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.8331413)
                                else 58
                            )
                            if state == 57:
                                state = 107 if x["maggaia_med"] < 20.442915 else 108
                                if state == 107:
                                    state = (
                                        183
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 20.9744987)
                                        else 184
                                    )
                                    if state == 183:
                                        return -0.470052034
                                    if state == 184:
                                        state = (
                                            267
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.3866005)
                                            else 268
                                        )
                                        if state == 267:
                                            return 0.230019286
                                        if state == 268:
                                            return -0.153589264
                                if state == 108:
                                    state = (
                                        185
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.6229992)
                                        else 186
                                    )
                                    if state == 185:
                                        return -0.222341359
                                    if state == 186:
                                        return 0.176608726
                            if state == 58:
                                state = 109 if x["maggaia_med"] < 18.8697243 else 110
                                if state == 109:
                                    state = (
                                        187
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.46875)
                                        else 188
                                    )
                                    if state == 187:
                                        return -0.296989411
                                    if state == 188:
                                        state = (
                                            269
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.7813835)
                                            else 270
                                        )
                                        if state == 269:
                                            state = (
                                                331
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.8921356)
                                                else 332
                                            )
                                            if state == 331:
                                                state = (
                                                    397
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.01493645)
                                                    else 398
                                                )
                                                if state == 397:
                                                    state = (
                                                        459
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 7.98285866
                                                        )
                                                        else 460
                                                    )
                                                    if state == 459:
                                                        return 0.0522699431
                                                    if state == 460:
                                                        return -0.197564393
                                                if state == 398:
                                                    return 0.318498611
                                            if state == 332:
                                                return -0.128395006
                                        if state == 270:
                                            state = (
                                                333
                                                if x["mag_peak"] < 18.6405468
                                                else 334
                                            )
                                            if state == 333:
                                                return -0.278670877
                                            if state == 334:
                                                state = (
                                                    399
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.98240185)
                                                    else 400
                                                )
                                                if state == 399:
                                                    return -0.259570211
                                                if state == 400:
                                                    return 0.240075141
                                if state == 110:
                                    state = (
                                        189
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 22.8999996)
                                        else 190
                                    )
                                    if state == 189:
                                        state = (
                                            271
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.7841988)
                                            else 272
                                        )
                                        if state == 271:
                                            return 0.184661597
                                        if state == 272:
                                            return -0.343687356
                                    if state == 190:
                                        return 0.205467328
    elif num_booster == 25:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["col_last"]) or (x["col_last"] < -0.244664669) else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3049507) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["col_last"]) or (x["col_last"] < -0.272703648)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.282299)
                            else 16
                        )
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.58174133)
                                else 28
                            )
                            if state == 27:
                                state = 49 if x["col_det"] < 0.155955315 else 50
                                if state == 49:
                                    state = 77 if x["mag_peak"] < 19.0372505 else 78
                                    if state == 77:
                                        state = (
                                            111
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 8.0101099)
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                153
                                                if x["sgscore1_med"] < 0.524385512
                                                else 154
                                            )
                                            if state == 153:
                                                state = (
                                                    209
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.155573845)
                                                    else 210
                                                )
                                                if state == 209:
                                                    state = (
                                                        269
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.193405569
                                                        )
                                                        else 270
                                                    )
                                                    if state == 269:
                                                        return 0.184734538
                                                    if state == 270:
                                                        state = (
                                                            339
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.572619081
                                                            )
                                                            else 340
                                                        )
                                                        if state == 339:
                                                            return 0.128291264
                                                        if state == 340:
                                                            return -0.033255253
                                                if state == 210:
                                                    return 0.323848665
                                            if state == 154:
                                                return 0.0190180298
                                        if state == 112:
                                            state = (
                                                155
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0523332991)
                                                else 156
                                            )
                                            if state == 155:
                                                state = (
                                                    213
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.0247235298)
                                                    else 214
                                                )
                                                if state == 213:
                                                    state = (
                                                        271
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.250765085
                                                        )
                                                        else 272
                                                    )
                                                    if state == 271:
                                                        return -0.20736441
                                                    if state == 272:
                                                        state = (
                                                            341
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.564285755
                                                            )
                                                            else 342
                                                        )
                                                        if state == 341:
                                                            return -0.0529029556
                                                        if state == 342:
                                                            return 0.178666577
                                                if state == 214:
                                                    state = (
                                                        273
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.30896938
                                                        )
                                                        else 274
                                                    )
                                                    if state == 273:
                                                        return -0.223480761
                                                    if state == 274:
                                                        return 0.0372303501
                                            if state == 156:
                                                state = (
                                                    215
                                                    if x["col_peak"] < -0.208384514
                                                    else 216
                                                )
                                                if state == 215:
                                                    return -0.129058912
                                                if state == 216:
                                                    state = (
                                                        275
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 0.82318604
                                                        )
                                                        else 276
                                                    )
                                                    if state == 275:
                                                        state = (
                                                            343
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.715000033
                                                            )
                                                            else 344
                                                        )
                                                        if state == 343:
                                                            return -0.0241629705
                                                        if state == 344:
                                                            return 0.131600976
                                                    if state == 276:
                                                        return 0.254878044
                                    if state == 78:
                                        state = (
                                            113
                                            if x["neargaia_med"] < 38.6304131
                                            else 114
                                        )
                                        if state == 113:
                                            state = (
                                                157
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0407291502)
                                                else 158
                                            )
                                            if state == 157:
                                                return -0.192644358
                                            if state == 158:
                                                return 0.00849679019
                                        if state == 114:
                                            state = (
                                                159
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0276458003)
                                                else 160
                                            )
                                            if state == 159:
                                                return -0.170750156
                                            if state == 160:
                                                return 0.13748695
                                if state == 50:
                                    state = (
                                        79
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 18.9997444)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            115
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 31.9215469)
                                            else 116
                                        )
                                        if state == 115:
                                            state = (
                                                161
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0525982492)
                                                else 162
                                            )
                                            if state == 161:
                                                state = (
                                                    217
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.414191246)
                                                    else 218
                                                )
                                                if state == 217:
                                                    state = (
                                                        277
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 0.26956737
                                                        )
                                                        else 278
                                                    )
                                                    if state == 277:
                                                        state = (
                                                            345
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.761904836
                                                            )
                                                            else 346
                                                        )
                                                        if state == 345:
                                                            return 0.12330813
                                                        if state == 346:
                                                            return -0.112389661
                                                    if state == 278:
                                                        state = (
                                                            347
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.325833499
                                                            )
                                                            else 348
                                                        )
                                                        if state == 347:
                                                            return -0.14031893
                                                        if state == 348:
                                                            return 0.149347901
                                                if state == 218:
                                                    state = (
                                                        279
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.236214653
                                                        )
                                                        else 280
                                                    )
                                                    if state == 279:
                                                        return -0.14818947
                                                    if state == 280:
                                                        return 0.048319146
                                            if state == 162:
                                                state = (
                                                    219
                                                    if x["col_peak"] < 0.101237059
                                                    else 220
                                                )
                                                if state == 219:
                                                    state = (
                                                        281
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.12121058
                                                        )
                                                        else 282
                                                    )
                                                    if state == 281:
                                                        state = (
                                                            349
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.770238161
                                                            )
                                                            else 350
                                                        )
                                                        if state == 349:
                                                            return -0.113443553
                                                        if state == 350:
                                                            return 0.0894926041
                                                    if state == 282:
                                                        return -0.23533909
                                                if state == 220:
                                                    state = (
                                                        283
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.726302505
                                                        )
                                                        else 284
                                                    )
                                                    if state == 283:
                                                        state = (
                                                            353
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"] < 0.50345248
                                                            )
                                                            else 354
                                                        )
                                                        if state == 353:
                                                            return 0.0450422987
                                                        if state == 354:
                                                            return -0.204383776
                                                    if state == 284:
                                                        state = (
                                                            355
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.559523821
                                                            )
                                                            else 356
                                                        )
                                                        if state == 355:
                                                            return -0.0615190268
                                                        if state == 356:
                                                            return 0.146734267
                                        if state == 116:
                                            state = (
                                                163
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00239583501)
                                                else 164
                                            )
                                            if state == 163:
                                                state = (
                                                    221
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.0736160278)
                                                    else 222
                                                )
                                                if state == 221:
                                                    state = (
                                                        285
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.298093379
                                                        )
                                                        else 286
                                                    )
                                                    if state == 285:
                                                        return 0.234644294
                                                    if state == 286:
                                                        state = (
                                                            357
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.626428485
                                                            )
                                                            else 358
                                                        )
                                                        if state == 357:
                                                            return -0.110955991
                                                        if state == 358:
                                                            return 0.0871441737
                                                if state == 222:
                                                    return -0.14783743
                                            if state == 164:
                                                state = (
                                                    223
                                                    if x["col_peak"] < 0.138772011
                                                    else 224
                                                )
                                                if state == 223:
                                                    state = (
                                                        287
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.824581146
                                                        )
                                                        else 288
                                                    )
                                                    if state == 287:
                                                        state = (
                                                            359
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.546666741
                                                            )
                                                            else 360
                                                        )
                                                        if state == 359:
                                                            return 0.110121027
                                                        if state == 360:
                                                            return -0.087504901
                                                    if state == 288:
                                                        state = (
                                                            361
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.724642873
                                                            )
                                                            else 362
                                                        )
                                                        if state == 361:
                                                            return -0.49503848
                                                        if state == 362:
                                                            return -0.0443552844
                                                if state == 224:
                                                    state = (
                                                        289
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.762813807
                                                        )
                                                        else 290
                                                    )
                                                    if state == 289:
                                                        return -0.179342821
                                                    if state == 290:
                                                        state = (
                                                            365
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.736666679
                                                            )
                                                            else 366
                                                        )
                                                        if state == 365:
                                                            return -0.148570076
                                                        if state == 366:
                                                            return 0.168910086
                                    if state == 80:
                                        return -0.319115043
                            if state == 28:
                                state = 51 if x["col_det"] < -0.19970417 else 52
                                if state == 51:
                                    state = 81 if x["mag_peak"] < 16.8419952 else 82
                                    if state == 81:
                                        return -0.199888423
                                    if state == 82:
                                        state = (
                                            117
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 49.0284195)
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                165
                                                if x["sgscore1_med"] < 0.00208333507
                                                else 166
                                            )
                                            if state == 165:
                                                return -0.215519965
                                            if state == 166:
                                                state = (
                                                    225
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.103421211)
                                                    else 226
                                                )
                                                if state == 225:
                                                    state = (
                                                        291
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 3.52481151
                                                        )
                                                        else 292
                                                    )
                                                    if state == 291:
                                                        state = (
                                                            367
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.600714326
                                                            )
                                                            else 368
                                                        )
                                                        if state == 367:
                                                            return -0.121129028
                                                        if state == 368:
                                                            return 0.180432707
                                                    if state == 292:
                                                        return 0.255905777
                                                if state == 226:
                                                    state = (
                                                        293
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 4.58409405
                                                        )
                                                        else 294
                                                    )
                                                    if state == 293:
                                                        return 0.111532241
                                                    if state == 294:
                                                        return -0.106561936
                                        if state == 118:
                                            state = (
                                                167
                                                if x["sgscore1_med"] < 0.298291653
                                                else 168
                                            )
                                            if state == 167:
                                                state = (
                                                    227
                                                    if x["col_peak"] < 0.240551993
                                                    else 228
                                                )
                                                if state == 227:
                                                    return -0.120634161
                                                if state == 228:
                                                    return 0.0973484814
                                            if state == 168:
                                                return -0.0954620987
                                if state == 52:
                                    state = 83 if x["mag_peak"] < 18.5600853 else 84
                                    if state == 83:
                                        state = (
                                            119
                                            if x["neargaia_med"] < 51.6211777
                                            else 120
                                        )
                                        if state == 119:
                                            state = (
                                                169
                                                if x["sgscore1_med"] < 0.0573899001
                                                else 170
                                            )
                                            if state == 169:
                                                state = (
                                                    229
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.265174866)
                                                    else 230
                                                )
                                                if state == 229:
                                                    state = (
                                                        295
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.82801008
                                                        )
                                                        else 296
                                                    )
                                                    if state == 295:
                                                        state = (
                                                            369
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.711785674
                                                            )
                                                            else 370
                                                        )
                                                        if state == 369:
                                                            return 0.121389404
                                                        if state == 370:
                                                            return -0.165731534
                                                    if state == 296:
                                                        state = (
                                                            371
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.516666651
                                                            )
                                                            else 372
                                                        )
                                                        if state == 371:
                                                            return 0.0109585794
                                                        if state == 372:
                                                            return 0.344949037
                                                if state == 230:
                                                    return -0.25035724
                                            if state == 170:
                                                state = (
                                                    231
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.486245155)
                                                    else 232
                                                )
                                                if state == 231:
                                                    state = (
                                                        297
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.81000793
                                                        )
                                                        else 298
                                                    )
                                                    if state == 297:
                                                        state = (
                                                            373
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.613095284
                                                            )
                                                            else 374
                                                        )
                                                        if state == 373:
                                                            return -0.169451162
                                                        if state == 374:
                                                            return 0.242128149
                                                    if state == 298:
                                                        state = (
                                                            375
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.936785698
                                                            )
                                                            else 376
                                                        )
                                                        if state == 375:
                                                            return -0.156848788
                                                        if state == 376:
                                                            return 0.0719984323
                                                if state == 232:
                                                    return 0.227935046
                                        if state == 120:
                                            state = (
                                                171
                                                if x["sgscore1_med"] < 0.0202708002
                                                else 172
                                            )
                                            if state == 171:
                                                state = (
                                                    233
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.14864397)
                                                    else 234
                                                )
                                                if state == 233:
                                                    return 0.18421708
                                                if state == 234:
                                                    return -0.210928172
                                            if state == 172:
                                                state = (
                                                    235
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.244843483)
                                                    else 236
                                                )
                                                if state == 235:
                                                    state = (
                                                        299
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 6.90332508
                                                        )
                                                        else 300
                                                    )
                                                    if state == 299:
                                                        return 0.323337317
                                                    if state == 300:
                                                        state = (
                                                            377
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.258333504
                                                            )
                                                            else 378
                                                        )
                                                        if state == 377:
                                                            return -0.141422004
                                                        if state == 378:
                                                            return 0.0521265082
                                                if state == 236:
                                                    return -0.115667902
                                    if state == 84:
                                        state = (
                                            121
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 18.25737)
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                173
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0481636524)
                                                else 174
                                            )
                                            if state == 173:
                                                state = (
                                                    237
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.115039825)
                                                    else 238
                                                )
                                                if state == 237:
                                                    state = (
                                                        301
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 6.02744579
                                                        )
                                                        else 302
                                                    )
                                                    if state == 301:
                                                        state = (
                                                            379
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.886428833
                                                            )
                                                            else 380
                                                        )
                                                        if state == 379:
                                                            return -0.50225693
                                                        if state == 380:
                                                            return -0.118084714
                                                    if state == 302:
                                                        return -0.0519371778
                                                if state == 238:
                                                    state = (
                                                        303
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 2.34545135
                                                        )
                                                        else 304
                                                    )
                                                    if state == 303:
                                                        return -0.313824117
                                                    if state == 304:
                                                        state = (
                                                            383
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.789880991
                                                            )
                                                            else 384
                                                        )
                                                        if state == 383:
                                                            return 0.227180451
                                                        if state == 384:
                                                            return -0.165554911
                                            if state == 174:
                                                state = (
                                                    239
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.293700218)
                                                    else 240
                                                )
                                                if state == 239:
                                                    state = (
                                                        305
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 3.91163588
                                                        )
                                                        else 306
                                                    )
                                                    if state == 305:
                                                        state = (
                                                            385
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.665238142
                                                            )
                                                            else 386
                                                        )
                                                        if state == 385:
                                                            return -0.145559922
                                                        if state == 386:
                                                            return 0.076823771
                                                    if state == 306:
                                                        state = (
                                                            387
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.919999957
                                                            )
                                                            else 388
                                                        )
                                                        if state == 387:
                                                            return -0.348383665
                                                        if state == 388:
                                                            return 0.095671393
                                                if state == 240:
                                                    state = (
                                                        307
                                                        if np.isnan(x["distnr_med"])
                                                        or (x["distnr_med"] < 2.9745667)
                                                        else 308
                                                    )
                                                    if state == 307:
                                                        return 0.173115149
                                                    if state == 308:
                                                        return -0.135353222
                                        if state == 122:
                                            state = (
                                                175
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0103124995)
                                                else 176
                                            )
                                            if state == 175:
                                                state = (
                                                    241
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.172480583)
                                                    else 242
                                                )
                                                if state == 241:
                                                    state = (
                                                        309
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.84686899
                                                        )
                                                        else 310
                                                    )
                                                    if state == 309:
                                                        return -0.338720679
                                                    if state == 310:
                                                        state = (
                                                            391
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.577499986
                                                            )
                                                            else 392
                                                        )
                                                        if state == 391:
                                                            return 0.0434456505
                                                        if state == 392:
                                                            return 0.230250314
                                                if state == 242:
                                                    return -0.102484174
                                            if state == 176:
                                                state = (
                                                    243
                                                    if x["col_peak"] < -0.0648732185
                                                    else 244
                                                )
                                                if state == 243:
                                                    state = (
                                                        311
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.85104573
                                                        )
                                                        else 312
                                                    )
                                                    if state == 311:
                                                        return 0.179825738
                                                    if state == 312:
                                                        state = (
                                                            393
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"] < 0.86178571
                                                            )
                                                            else 394
                                                        )
                                                        if state == 393:
                                                            return -0.432139248
                                                        if state == 394:
                                                            return -0.0226883925
                                                if state == 244:
                                                    state = (
                                                        313
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 2.01324964
                                                        )
                                                        else 314
                                                    )
                                                    if state == 313:
                                                        state = (
                                                            395
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.802857161
                                                            )
                                                            else 396
                                                        )
                                                        if state == 395:
                                                            return 0.26930359
                                                        if state == 396:
                                                            return -0.148156479
                                                    if state == 314:
                                                        state = (
                                                            397
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.618333459
                                                            )
                                                            else 398
                                                        )
                                                        if state == 397:
                                                            return 0.0242876336
                                                        if state == 398:
                                                            return -0.286103308
                        if state == 16:
                            return -0.283973575
                    if state == 8:
                        return -0.213464037
                if state == 4:
                    state = 9 if x["col_last"] < -0.251250267 else 10
                    if state == 9:
                        return -0.0554802306
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.6243515)
                            else 20
                        )
                        if state == 19:
                            state = (
                                33
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.02834272)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    53
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.344221115)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        85
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 18.7623463)
                                        else 86
                                    )
                                    if state == 85:
                                        state = (
                                            123
                                            if x["neargaia_med"] < 13.6196365
                                            else 124
                                        )
                                        if state == 123:
                                            state = (
                                                177
                                                if x["sgscore1_med"] < 0.00395833515
                                                else 178
                                            )
                                            if state == 177:
                                                return -0.0212174822
                                            if state == 178:
                                                state = (
                                                    245
                                                    if x["col_peak"] < 0.131124496
                                                    else 246
                                                )
                                                if state == 245:
                                                    return 0.105626158
                                                if state == 246:
                                                    return -0.348512709
                                        if state == 124:
                                            state = (
                                                179
                                                if x["sgscore1_med"] < 0.0124583505
                                                else 180
                                            )
                                            if state == 179:
                                                state = (
                                                    247
                                                    if x["col_peak"] < 1.76520252
                                                    else 248
                                                )
                                                if state == 247:
                                                    return 0.234866932
                                                if state == 248:
                                                    state = (
                                                        315
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.54620659
                                                        )
                                                        else 316
                                                    )
                                                    if state == 315:
                                                        state = (
                                                            399
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.539999843
                                                            )
                                                            else 400
                                                        )
                                                        if state == 399:
                                                            return -0.22913681
                                                        if state == 400:
                                                            return 0.223559454
                                                    if state == 316:
                                                        return -0.182012796
                                            if state == 180:
                                                state = (
                                                    249
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.0318113938)
                                                    else 250
                                                )
                                                if state == 249:
                                                    return -0.280653
                                                if state == 250:
                                                    return 0.108080968
                                    if state == 86:
                                        state = (
                                            125
                                            if x["neargaia_med"] < 24.9131432
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                181
                                                if x["sgscore1_med"] < 0.0117707998
                                                else 182
                                            )
                                            if state == 181:
                                                return 0.113647886
                                            if state == 182:
                                                return -0.0956384093
                                        if state == 126:
                                            state = (
                                                183
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00968750007)
                                                else 184
                                            )
                                            if state == 183:
                                                state = (
                                                    253
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.667106628)
                                                    else 254
                                                )
                                                if state == 253:
                                                    return -0.113634668
                                                if state == 254:
                                                    return 0.160532385
                                            if state == 184:
                                                return 0.301770329
                                if state == 54:
                                    state = (
                                        87
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 18.9449291)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            127
                                            if x["neargaia_med"] < 54.6585999
                                            else 128
                                        )
                                        if state == 127:
                                            state = (
                                                185
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.160160512)
                                                else 186
                                            )
                                            if state == 185:
                                                return 0.230996042
                                            if state == 186:
                                                return -0.0938157067
                                        if state == 128:
                                            return -0.0762468129
                                    if state == 88:
                                        return -0.130926222
                            if state == 34:
                                state = 55 if x["col_det"] < 0.511550426 else 56
                                if state == 55:
                                    state = (
                                        89
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 18.8133507)
                                        else 90
                                    )
                                    if state == 89:
                                        state = (
                                            131
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 29.7300339)
                                            else 132
                                        )
                                        if state == 131:
                                            state = (
                                                187
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.106901854)
                                                else 188
                                            )
                                            if state == 187:
                                                return -0.127269268
                                            if state == 188:
                                                return 0.127057284
                                        if state == 132:
                                            return 0.160500169
                                    if state == 90:
                                        return -0.141114488
                                if state == 56:
                                    state = 91 if x["mag_peak"] < 17.6903934 else 92
                                    if state == 91:
                                        return -0.0887596011
                                    if state == 92:
                                        state = (
                                            135
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 5.53036022)
                                            else 136
                                        )
                                        if state == 135:
                                            return 0.450543553
                                        if state == 136:
                                            state = (
                                                191
                                                if x["sgscore1_med"] < 0.659983516
                                                else 192
                                            )
                                            if state == 191:
                                                state = (
                                                    255
                                                    if x["col_peak"] < 0.531406403
                                                    else 256
                                                )
                                                if state == 255:
                                                    state = (
                                                        317
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 3.06848431
                                                        )
                                                        else 318
                                                    )
                                                    if state == 317:
                                                        return -0.183189988
                                                    if state == 318:
                                                        return 0.077142708
                                                if state == 256:
                                                    state = (
                                                        319
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 2.44249701
                                                        )
                                                        else 320
                                                    )
                                                    if state == 319:
                                                        return 0.0251606796
                                                    if state == 320:
                                                        state = (
                                                            405
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.949999928
                                                            )
                                                            else 406
                                                        )
                                                        if state == 405:
                                                            return 0.29639852
                                                        if state == 406:
                                                            return 0.0133891813
                                            if state == 192:
                                                return -0.133734986
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.458043516)
                                else 36
                            )
                            if state == 35:
                                return -0.237786621
                            if state == 36:
                                state = 57 if x["col_det"] < 0.0518260002 else 58
                                if state == 57:
                                    return -0.188425541
                                if state == 58:
                                    state = 95 if x["mag_peak"] < 18.7418442 else 96
                                    if state == 95:
                                        return 0.302754492
                                    if state == 96:
                                        state = (
                                            137
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 60.0373001)
                                            else 138
                                        )
                                        if state == 137:
                                            return -0.201300576
                                        if state == 138:
                                            return 0.152203292
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.4596996) else 6
                )
                if state == 5:
                    state = 11 if x["col_last"] < 1.27837467 else 12
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.5759506)
                            else 22
                        )
                        if state == 21:
                            state = (
                                37
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.777822852)
                                else 38
                            )
                            if state == 37:
                                return -0.16865164
                            if state == 38:
                                state = 59 if x["col_det"] < -0.242964745 else 60
                                if state == 59:
                                    return -0.0729161724
                                if state == 60:
                                    state = (
                                        97
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 17.2037506)
                                        else 98
                                    )
                                    if state == 97:
                                        return 0.183411598
                                    if state == 98:
                                        return -0.144153267
                        if state == 22:
                            state = (
                                39
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 3.15885401)
                                else 40
                            )
                            if state == 39:
                                state = 61 if x["col_det"] < -0.143974781 else 62
                                if state == 61:
                                    return 0.0910005048
                                if state == 62:
                                    return -0.285221159
                            if state == 40:
                                state = 63 if x["col_det"] < -0.0616402626 else 64
                                if state == 63:
                                    return -0.115967259
                                if state == 64:
                                    state = 99 if x["mag_peak"] < 17.4705582 else 100
                                    if state == 99:
                                        return 0.158193529
                                    if state == 100:
                                        return -0.0567271449
                    if state == 12:
                        return 0.00151305331
                if state == 6:
                    state = 13 if x["col_last"] < -0.163662583 else 14
                    if state == 13:
                        state = (
                            23
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1172504)
                            else 24
                        )
                        if state == 23:
                            state = (
                                41
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.48512578)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    65
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.19938755)
                                    else 66
                                )
                                if state == 65:
                                    return -0.162859082
                                if state == 66:
                                    return 0.0199295003
                            if state == 42:
                                state = 67 if x["col_det"] < -0.115961075 else 68
                                if state == 67:
                                    return -0.0448327735
                                if state == 68:
                                    return 0.174603671
                        if state == 24:
                            state = (
                                43
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 3.31760192)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    69
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.312478065)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        103
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 18.7612095)
                                        else 104
                                    )
                                    if state == 103:
                                        state = (
                                            141
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 13.9136)
                                            else 142
                                        )
                                        if state == 141:
                                            return -0.113774292
                                        if state == 142:
                                            state = (
                                                195
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00170833501)
                                                else 196
                                            )
                                            if state == 195:
                                                return -0.0757098943
                                            if state == 196:
                                                return 0.137652099
                                    if state == 104:
                                        return 0.170615077
                                if state == 70:
                                    return 0.287920922
                            if state == 44:
                                return -0.0598313436
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6627998)
                            else 26
                        )
                        if state == 25:
                            return 0.259452611
                        if state == 26:
                            state = (
                                47
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 7.30212021)
                                else 48
                            )
                            if state == 47:
                                state = 73 if x["col_det"] < 0.119942665 else 74
                                if state == 73:
                                    state = (
                                        105
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 19.0330086)
                                        else 106
                                    )
                                    if state == 105:
                                        state = (
                                            143
                                            if x["neargaia_med"] < 10.4679146
                                            else 144
                                        )
                                        if state == 143:
                                            state = (
                                                197
                                                if x["sgscore1_med"] < 0.209589005
                                                else 198
                                            )
                                            if state == 197:
                                                state = (
                                                    257
                                                    if x["col_peak"] < 0.17357254
                                                    else 258
                                                )
                                                if state == 257:
                                                    return -0.163867965
                                                if state == 258:
                                                    state = (
                                                        323
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 0.69662559
                                                        )
                                                        else 324
                                                    )
                                                    if state == 323:
                                                        return 0.157011762
                                                    if state == 324:
                                                        return -0.0656082332
                                            if state == 198:
                                                state = (
                                                    259
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.177290916)
                                                    else 260
                                                )
                                                if state == 259:
                                                    state = (
                                                        325
                                                        if np.isnan(x["distnr_med"])
                                                        or (x["distnr_med"] < 4.4342041)
                                                        else 326
                                                    )
                                                    if state == 325:
                                                        state = (
                                                            409
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.888571382
                                                            )
                                                            else 410
                                                        )
                                                        if state == 409:
                                                            return -0.175084174
                                                        if state == 410:
                                                            return 0.0376414247
                                                    if state == 326:
                                                        return 0.0328991897
                                                if state == 260:
                                                    return -0.290324986
                                        if state == 144:
                                            state = (
                                                199
                                                if x["sgscore1_med"] < 0.00204166491
                                                else 200
                                            )
                                            if state == 199:
                                                return 0.196069434
                                            if state == 200:
                                                state = (
                                                    261
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.0855808258)
                                                    else 262
                                                )
                                                if state == 261:
                                                    state = (
                                                        327
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.696392298
                                                        )
                                                        else 328
                                                    )
                                                    if state == 327:
                                                        state = (
                                                            411
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.736904502
                                                            )
                                                            else 412
                                                        )
                                                        if state == 411:
                                                            return -0.249022722
                                                        if state == 412:
                                                            return -0.0867437497
                                                    if state == 328:
                                                        state = (
                                                            413
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.457262099
                                                            )
                                                            else 414
                                                        )
                                                        if state == 413:
                                                            return 0.111709759
                                                        if state == 414:
                                                            return -0.0245582797
                                                if state == 262:
                                                    state = (
                                                        329
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.770270944
                                                        )
                                                        else 330
                                                    )
                                                    if state == 329:
                                                        return -0.172903121
                                                    if state == 330:
                                                        state = (
                                                            415
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.937857151
                                                            )
                                                            else 416
                                                        )
                                                        if state == 415:
                                                            return 0.170653954
                                                        if state == 416:
                                                            return -0.0941084847
                                    if state == 106:
                                        return -0.221581042
                                if state == 74:
                                    state = (
                                        107
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 18.9998856)
                                        else 108
                                    )
                                    if state == 107:
                                        state = (
                                            147
                                            if x["neargaia_med"] < 0.148225427
                                            else 148
                                        )
                                        if state == 147:
                                            state = (
                                                201
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00270833494)
                                                else 202
                                            )
                                            if state == 201:
                                                return 0.141399935
                                            if state == 202:
                                                return -0.25000146
                                        if state == 148:
                                            state = (
                                                203
                                                if x["sgscore1_med"] < 0.00348958513
                                                else 204
                                            )
                                            if state == 203:
                                                state = (
                                                    263
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < -0.0152955055)
                                                    else 264
                                                )
                                                if state == 263:
                                                    state = (
                                                        331
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.561656356
                                                        )
                                                        else 332
                                                    )
                                                    if state == 331:
                                                        state = (
                                                            417
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.647500157
                                                            )
                                                            else 418
                                                        )
                                                        if state == 417:
                                                            return -0.0644258261
                                                        if state == 418:
                                                            return 0.148125917
                                                    if state == 332:
                                                        state = (
                                                            419
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.751666665
                                                            )
                                                            else 420
                                                        )
                                                        if state == 419:
                                                            return -0.193711311
                                                        if state == 420:
                                                            return 0.0150266141
                                                if state == 264:
                                                    state = (
                                                        333
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.80337739
                                                        )
                                                        else 334
                                                    )
                                                    if state == 333:
                                                        return 0.15555647
                                                    if state == 334:
                                                        return -0.0273225512
                                            if state == 204:
                                                state = (
                                                    265
                                                    if x["col_peak"] < -0.171809196
                                                    else 266
                                                )
                                                if state == 265:
                                                    state = (
                                                        335
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 3.66478062
                                                        )
                                                        else 336
                                                    )
                                                    if state == 335:
                                                        state = (
                                                            421
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.577499866
                                                            )
                                                            else 422
                                                        )
                                                        if state == 421:
                                                            return 0.0641180947
                                                        if state == 422:
                                                            return -0.129332587
                                                    if state == 336:
                                                        return 0.11204116
                                                if state == 266:
                                                    state = (
                                                        337
                                                        if np.isnan(x["distnr_med"])
                                                        or (x["distnr_med"] < 1.3742826)
                                                        else 338
                                                    )
                                                    if state == 337:
                                                        state = (
                                                            423
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.519285619
                                                            )
                                                            else 424
                                                        )
                                                        if state == 423:
                                                            return 0.012177092
                                                        if state == 424:
                                                            return 0.132275283
                                                    if state == 338:
                                                        state = (
                                                            425
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.936071396
                                                            )
                                                            else 426
                                                        )
                                                        if state == 425:
                                                            return 0.0136539331
                                                        if state == 426:
                                                            return 0.212892801
                                    if state == 108:
                                        state = (
                                            149
                                            if x["neargaia_med"] < 39.2517166
                                            else 150
                                        )
                                        if state == 149:
                                            return -0.293512195
                                        if state == 150:
                                            state = (
                                                205
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00964583457)
                                                else 206
                                            )
                                            if state == 205:
                                                return -0.137033775
                                            if state == 206:
                                                state = (
                                                    267
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.430422783)
                                                    else 268
                                                )
                                                if state == 267:
                                                    return -0.152215973
                                                if state == 268:
                                                    return 0.206673011
                            if state == 48:
                                state = 75 if x["col_det"] < 0.320269108 else 76
                                if state == 75:
                                    return 0.232511342
                                if state == 76:
                                    state = 109 if x["mag_peak"] < 18.8270454 else 110
                                    if state == 109:
                                        return 0.119915232
                                    if state == 110:
                                        return -0.0694965944
    elif num_booster == 26:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 9.05241871) else 2
            if state == 1:
                state = 3 if x["maggaia_med"] < 15.7697001 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.27011037)
                        else 8
                    )
                    if state == 7:
                        return 0.0881940275
                    if state == 8:
                        return -0.209836274
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 4.63917255)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 19.753437)
                            else 18
                        )
                        if state == 17:
                            state = (
                                27
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.684667766)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    45
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.98320603)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        75
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.0070057)
                                        else 76
                                    )
                                    if state == 75:
                                        state = (
                                            123
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.3600025)
                                            else 124
                                        )
                                        if state == 123:
                                            return 0.151937097
                                        if state == 124:
                                            return -0.0385467596
                                    if state == 76:
                                        return -0.148416907
                                if state == 46:
                                    state = (
                                        77
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.7714005)
                                        else 78
                                    )
                                    if state == 77:
                                        return 0.0454438627
                                    if state == 78:
                                        return -0.205726832
                            if state == 28:
                                state = (
                                    47
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.49364567)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        79
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.3709488)
                                        else 80
                                    )
                                    if state == 79:
                                        return -0.0827833116
                                    if state == 80:
                                        state = (
                                            125
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.1825523)
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                191
                                                if x["col_last"] < 0.0794358253
                                                else 192
                                            )
                                            if state == 191:
                                                state = (
                                                    263
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.91496515)
                                                    else 264
                                                )
                                                if state == 263:
                                                    state = (
                                                        343
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980499983
                                                        )
                                                        else 344
                                                    )
                                                    if state == 343:
                                                        return -0.149371594
                                                    if state == 344:
                                                        return 0.0733101815
                                                if state == 264:
                                                    state = (
                                                        345
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.979749978
                                                        )
                                                        else 346
                                                    )
                                                    if state == 345:
                                                        return 0.237316653
                                                    if state == 346:
                                                        return -0.0528370626
                                            if state == 192:
                                                return 0.23718296
                                        if state == 126:
                                            return 0.359603792
                                if state == 48:
                                    state = (
                                        81
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.2281494)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            127
                                            if x["maggaia_med"] < 17.0281258
                                            else 128
                                        )
                                        if state == 127:
                                            return -0.0462496988
                                        if state == 128:
                                            return 0.134301811
                                    if state == 82:
                                        state = (
                                            129
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.1741543)
                                            else 130
                                        )
                                        if state == 129:
                                            state = (
                                                195
                                                if x["col_last"] < -0.0383486748
                                                else 196
                                            )
                                            if state == 195:
                                                return -0.049657438
                                            if state == 196:
                                                return 0.125276998
                                        if state == 130:
                                            state = (
                                                197
                                                if x["col_last"] < -0.144604206
                                                else 198
                                            )
                                            if state == 197:
                                                return 0.141212672
                                            if state == 198:
                                                return -0.178985268
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.39583015)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    49
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.98255777)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        83
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.0807495)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            131
                                            if x["maggaia_med"] < 20.5257721
                                            else 132
                                        )
                                        if state == 131:
                                            state = (
                                                199
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < -0.23488602)
                                                else 200
                                            )
                                            if state == 199:
                                                return -0.0562613271
                                            if state == 200:
                                                return 0.122945853
                                        if state == 132:
                                            return -0.0742548779
                                    if state == 84:
                                        state = (
                                            133
                                            if x["maggaia_med"] < 19.9933434
                                            else 134
                                        )
                                        if state == 133:
                                            return -0.0117596164
                                        if state == 134:
                                            return 0.198512331
                                if state == 50:
                                    return -0.157663211
                            if state == 30:
                                state = (
                                    51
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 1.4202199)
                                    else 52
                                )
                                if state == 51:
                                    return 0.0956892073
                                if state == 52:
                                    state = (
                                        85
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.1393509)
                                        else 86
                                    )
                                    if state == 85:
                                        return -0.236328378
                                    if state == 86:
                                        return 0.0240717344
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 19.8333244)
                            else 20
                        )
                        if state == 19:
                            return -0.178137332
                        if state == 20:
                            state = (
                                31
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 11.4198227)
                                else 32
                            )
                            if state == 31:
                                return -0.0664145499
                            if state == 32:
                                return 0.158588082
            if state == 2:
                state = 5 if x["maggaia_med"] < 15.7649202 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.174820632)
                        else 12
                    )
                    if state == 11:
                        return 0.202032119
                    if state == 12:
                        state = 21 if x["maggaia_med"] < 12.7760601 else 22
                        if state == 21:
                            state = (
                                33
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 3.65433288)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    53
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 7.3921299)
                                    else 54
                                )
                                if state == 53:
                                    return -0.148407668
                                if state == 54:
                                    return 0.0923731774
                            if state == 34:
                                return 0.147189498
                        if state == 22:
                            state = (
                                35
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 5.65758228)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    55
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 5.94086218)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        87
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.2536507)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            135
                                            if x["maggaia_med"] < 15.0108242
                                            else 136
                                        )
                                        if state == 135:
                                            return -0.168228239
                                        if state == 136:
                                            state = (
                                                201
                                                if x["col_last"] < 0.328485012
                                                else 202
                                            )
                                            if state == 201:
                                                return -0.043074131
                                            if state == 202:
                                                state = (
                                                    265
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.96241331)
                                                    else 266
                                                )
                                                if state == 265:
                                                    return 0.0075270473
                                                if state == 266:
                                                    state = (
                                                        347
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.982249975
                                                        )
                                                        else 348
                                                    )
                                                    if state == 347:
                                                        return 0.168486267
                                                    if state == 348:
                                                        return -0.0355528891
                                    if state == 88:
                                        state = (
                                            137
                                            if x["maggaia_med"] < 15.1687927
                                            else 138
                                        )
                                        if state == 137:
                                            state = (
                                                203
                                                if x["col_last"] < -0.117083549
                                                else 204
                                            )
                                            if state == 203:
                                                return 0.0552518219
                                            if state == 204:
                                                state = (
                                                    267
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0258622505)
                                                    else 268
                                                )
                                                if state == 267:
                                                    state = (
                                                        349
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.979249954
                                                        )
                                                        else 350
                                                    )
                                                    if state == 349:
                                                        return -0.107575469
                                                    if state == 350:
                                                        return 0.109009065
                                                if state == 268:
                                                    return -0.23380281
                                        if state == 138:
                                            return -0.425893635
                                if state == 56:
                                    state = (
                                        89
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.4612007)
                                        else 90
                                    )
                                    if state == 89:
                                        return -0.125725821
                                    if state == 90:
                                        state = (
                                            141
                                            if x["maggaia_med"] < 15.3497009
                                            else 142
                                        )
                                        if state == 141:
                                            return -0.0472787321
                                        if state == 142:
                                            return 0.254903525
                            if state == 36:
                                state = (
                                    57
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 1.56834483)
                                    else 58
                                )
                                if state == 57:
                                    return 0.152333573
                                if state == 58:
                                    state = (
                                        91
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.7287006)
                                        else 92
                                    )
                                    if state == 91:
                                        return -0.193933606
                                    if state == 92:
                                        return 0.0882028788
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.962787986)
                        else 14
                    )
                    if state == 13:
                        state = (
                            23
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 19.6930389)
                            else 24
                        )
                        if state == 23:
                            state = (
                                37
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.799340129)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    59
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 5.00068283)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        93
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.5408516)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            143
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.4889011)
                                            else 144
                                        )
                                        if state == 143:
                                            state = (
                                                205
                                                if x["col_last"] < 0.0334329605
                                                else 206
                                            )
                                            if state == 205:
                                                state = (
                                                    269
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.02541065)
                                                    else 270
                                                )
                                                if state == 269:
                                                    return -0.0712553859
                                                if state == 270:
                                                    return -0.312956363
                                            if state == 206:
                                                state = (
                                                    271
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.04970455)
                                                    else 272
                                                )
                                                if state == 271:
                                                    state = (
                                                        353
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.978249967
                                                        )
                                                        else 354
                                                    )
                                                    if state == 353:
                                                        state = (
                                                            437
                                                            if x["col_peak"]
                                                            < -0.0330791473
                                                            else 438
                                                        )
                                                        if state == 437:
                                                            return -0.00928279851
                                                        if state == 438:
                                                            return -0.122091584
                                                    if state == 354:
                                                        state = (
                                                            439
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.0590410233
                                                            )
                                                            else 440
                                                        )
                                                        if state == 439:
                                                            return 0.14620471
                                                        if state == 440:
                                                            return -0.0184682552
                                                if state == 272:
                                                    state = (
                                                        355
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.982749999
                                                        )
                                                        else 356
                                                    )
                                                    if state == 355:
                                                        return -0.364352643
                                                    if state == 356:
                                                        return 0.160393134
                                        if state == 144:
                                            return 0.27039364
                                    if state == 94:
                                        state = (
                                            145 if x["maggaia_med"] < 17.386507 else 146
                                        )
                                        if state == 145:
                                            return 0.123160385
                                        if state == 146:
                                            return -0.292274892
                                if state == 60:
                                    state = (
                                        95
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.0826492)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            147
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.70187)
                                            else 148
                                        )
                                        if state == 147:
                                            state = (
                                                209
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.516382217)
                                                else 210
                                            )
                                            if state == 209:
                                                state = (
                                                    273
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.9974308)
                                                    else 274
                                                )
                                                if state == 273:
                                                    return -0.235620916
                                                if state == 274:
                                                    state = (
                                                        357
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.978500009
                                                        )
                                                        else 358
                                                    )
                                                    if state == 357:
                                                        state = (
                                                            441
                                                            if x["col_peak"]
                                                            < 0.20870018
                                                            else 442
                                                        )
                                                        if state == 441:
                                                            return 0.0915238112
                                                        if state == 442:
                                                            return -0.107611217
                                                    if state == 358:
                                                        return -0.00353002572
                                            if state == 210:
                                                return -0.168262914
                                        if state == 148:
                                            state = (
                                                211
                                                if x["col_last"] < 0.190114975
                                                else 212
                                            )
                                            if state == 211:
                                                return -0.100652397
                                            if state == 212:
                                                state = (
                                                    275
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.41388321)
                                                    else 276
                                                )
                                                if state == 275:
                                                    return 0.240174145
                                                if state == 276:
                                                    state = (
                                                        359
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980749965
                                                        )
                                                        else 360
                                                    )
                                                    if state == 359:
                                                        return -0.124274984
                                                    if state == 360:
                                                        return 0.0566458926
                                    if state == 96:
                                        state = (
                                            149
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.5118141)
                                            else 150
                                        )
                                        if state == 149:
                                            state = (
                                                213
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.862461567)
                                                else 214
                                            )
                                            if state == 213:
                                                state = (
                                                    277
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.91915512)
                                                    else 278
                                                )
                                                if state == 277:
                                                    state = (
                                                        361
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.966750026
                                                        )
                                                        else 362
                                                    )
                                                    if state == 361:
                                                        return -0.23575905
                                                    if state == 362:
                                                        state = (
                                                            445
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < 0.0717916489
                                                            )
                                                            else 446
                                                        )
                                                        if state == 445:
                                                            return 0.190889657
                                                        if state == 446:
                                                            return -0.0108662266
                                                if state == 278:
                                                    state = (
                                                        363
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980250001
                                                        )
                                                        else 364
                                                    )
                                                    if state == 363:
                                                        state = (
                                                            447
                                                            if x["col_peak"]
                                                            < -0.162067413
                                                            else 448
                                                        )
                                                        if state == 447:
                                                            return -0.0304472428
                                                        if state == 448:
                                                            return -0.226391658
                                                    if state == 364:
                                                        state = (
                                                            449
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.0238895416
                                                            )
                                                            else 450
                                                        )
                                                        if state == 449:
                                                            return 0.105843082
                                                        if state == 450:
                                                            return -0.0489629842
                                            if state == 214:
                                                return 0.15022485
                                        if state == 150:
                                            state = (
                                                215
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.221874237)
                                                else 216
                                            )
                                            if state == 215:
                                                state = (
                                                    279
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.03965187)
                                                    else 280
                                                )
                                                if state == 279:
                                                    state = (
                                                        365
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.939749956
                                                        )
                                                        else 366
                                                    )
                                                    if state == 365:
                                                        return 0.0236342028
                                                    if state == 366:
                                                        return 0.322977006
                                                if state == 280:
                                                    state = (
                                                        367
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980250001
                                                        )
                                                        else 368
                                                    )
                                                    if state == 367:
                                                        return 0.083030805
                                                    if state == 368:
                                                        state = (
                                                            451
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.00198888779
                                                            )
                                                            else 452
                                                        )
                                                        if state == 451:
                                                            return -0.21119158
                                                        if state == 452:
                                                            return 0.00686163967
                                            if state == 216:
                                                state = (
                                                    281
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.8648262)
                                                    else 282
                                                )
                                                if state == 281:
                                                    return 0.116963252
                                                if state == 282:
                                                    state = (
                                                        371
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.975749969
                                                        )
                                                        else 372
                                                    )
                                                    if state == 371:
                                                        return 0.0537447184
                                                    if state == 372:
                                                        return -0.10894189
                            if state == 38:
                                state = (
                                    61
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.94793415)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        97
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.4081993)
                                        else 98
                                    )
                                    if state == 97:
                                        state = (
                                            151
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.2544518)
                                            else 152
                                        )
                                        if state == 151:
                                            return -0.216845691
                                        if state == 152:
                                            state = (
                                                219
                                                if x["col_last"] < 0.0664672852
                                                else 220
                                            )
                                            if state == 219:
                                                state = (
                                                    283
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.532795131)
                                                    else 284
                                                )
                                                if state == 283:
                                                    return 0.0394302532
                                                if state == 284:
                                                    return -0.145925894
                                            if state == 220:
                                                state = (
                                                    285
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0799942464)
                                                    else 286
                                                )
                                                if state == 285:
                                                    return 0.159192979
                                                if state == 286:
                                                    return -0.0822627321
                                    if state == 98:
                                        state = (
                                            153
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 17.526123)
                                            else 154
                                        )
                                        if state == 153:
                                            return 0.0460640453
                                        if state == 154:
                                            return -0.388810515
                                if state == 62:
                                    state = (
                                        99
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.4883995)
                                        else 100
                                    )
                                    if state == 99:
                                        state = (
                                            155
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.0317822)
                                            else 156
                                        )
                                        if state == 155:
                                            state = (
                                                221
                                                if x["col_last"] < 0.805970788
                                                else 222
                                            )
                                            if state == 221:
                                                state = (
                                                    287
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.99326372)
                                                    else 288
                                                )
                                                if state == 287:
                                                    return 0.0494354963
                                                if state == 288:
                                                    state = (
                                                        373
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.981750011
                                                        )
                                                        else 374
                                                    )
                                                    if state == 373:
                                                        return -0.244332701
                                                    if state == 374:
                                                        return 0.0342714228
                                            if state == 222:
                                                state = (
                                                    289
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.01550913)
                                                    else 290
                                                )
                                                if state == 289:
                                                    return 0.213538587
                                                if state == 290:
                                                    state = (
                                                        377
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.98150003
                                                        )
                                                        else 378
                                                    )
                                                    if state == 377:
                                                        return -0.222119749
                                                    if state == 378:
                                                        return 0.0491978712
                                        if state == 156:
                                            return 0.287203997
                                    if state == 100:
                                        return -0.28059718
                        if state == 24:
                            state = (
                                39
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.700089514)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    63
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 5.98134232)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        101
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.64925)
                                        else 102
                                    )
                                    if state == 101:
                                        state = (
                                            157 if x["maggaia_med"] < 20.399765 else 158
                                        )
                                        if state == 157:
                                            state = (
                                                223
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.0854215622)
                                                else 224
                                            )
                                            if state == 223:
                                                state = (
                                                    291
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 1.0319097)
                                                    else 292
                                                )
                                                if state == 291:
                                                    state = (
                                                        379
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.975749969
                                                        )
                                                        else 380
                                                    )
                                                    if state == 379:
                                                        return -0.103257306
                                                    if state == 380:
                                                        return 0.109358907
                                                if state == 292:
                                                    state = (
                                                        381
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.981250048
                                                        )
                                                        else 382
                                                    )
                                                    if state == 381:
                                                        return -0.241465554
                                                    if state == 382:
                                                        return 0.127564996
                                            if state == 224:
                                                state = (
                                                    293
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.99724531)
                                                    else 294
                                                )
                                                if state == 293:
                                                    return -0.176469505
                                                if state == 294:
                                                    return 0.0365677997
                                        if state == 158:
                                            state = (
                                                225
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.302585602)
                                                else 226
                                            )
                                            if state == 225:
                                                state = (
                                                    295
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.01156831)
                                                    else 296
                                                )
                                                if state == 295:
                                                    state = (
                                                        383
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.975250006
                                                        )
                                                        else 384
                                                    )
                                                    if state == 383:
                                                        return -0.0577220507
                                                    if state == 384:
                                                        return 0.181223944
                                                if state == 296:
                                                    return 0.236732602
                                            if state == 226:
                                                return 0.0148946736
                                    if state == 102:
                                        return -0.215189695
                                if state == 64:
                                    state = (
                                        103
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.287899)
                                        else 104
                                    )
                                    if state == 103:
                                        return 0.0184764974
                                    if state == 104:
                                        return -0.269962996
                            if state == 40:
                                state = (
                                    65
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.9605093)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        105
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.1244507)
                                        else 106
                                    )
                                    if state == 105:
                                        return 0.128571361
                                    if state == 106:
                                        return -0.0810102299
                                if state == 66:
                                    return -0.36341539
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 19.1166668)
                            else 26
                        )
                        if state == 25:
                            state = (
                                41
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.63685608)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    67
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.99085093)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        107
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.4500999)
                                        else 108
                                    )
                                    if state == 107:
                                        state = (
                                            161
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 17.6911774)
                                            else 162
                                        )
                                        if state == 161:
                                            state = (
                                                227
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.316147089)
                                                else 228
                                            )
                                            if state == 227:
                                                state = (
                                                    297
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0624537021)
                                                    else 298
                                                )
                                                if state == 297:
                                                    return -0.167805403
                                                if state == 298:
                                                    state = (
                                                        385
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.962499976
                                                        )
                                                        else 386
                                                    )
                                                    if state == 385:
                                                        return -0.0926754773
                                                    if state == 386:
                                                        state = (
                                                            459
                                                            if x["col_peak"]
                                                            < -0.198433876
                                                            else 460
                                                        )
                                                        if state == 459:
                                                            return -0.122957259
                                                        if state == 460:
                                                            return 0.282953501
                                            if state == 228:
                                                return -0.0804195851
                                        if state == 162:
                                            return 0.324464291
                                    if state == 108:
                                        state = (
                                            163
                                            if x["maggaia_med"] < 17.7666321
                                            else 164
                                        )
                                        if state == 163:
                                            return 0.28318885
                                        if state == 164:
                                            state = (
                                                229
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.0680146217)
                                                else 230
                                            )
                                            if state == 229:
                                                state = (
                                                    299
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.95964146)
                                                    else 300
                                                )
                                                if state == 299:
                                                    state = (
                                                        387
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.981249988
                                                        )
                                                        else 388
                                                    )
                                                    if state == 387:
                                                        return -0.239879981
                                                    if state == 388:
                                                        return 0.167077512
                                                if state == 300:
                                                    return 0.169772446
                                            if state == 230:
                                                return -0.17685248
                                if state == 68:
                                    state = (
                                        109
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.9538002)
                                        else 110
                                    )
                                    if state == 109:
                                        state = (
                                            165
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.9624443)
                                            else 166
                                        )
                                        if state == 165:
                                            state = (
                                                231
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.272740364)
                                                else 232
                                            )
                                            if state == 231:
                                                state = (
                                                    301
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.94120979)
                                                    else 302
                                                )
                                                if state == 301:
                                                    state = (
                                                        389
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980250001
                                                        )
                                                        else 390
                                                    )
                                                    if state == 389:
                                                        state = (
                                                            461
                                                            if x["col_peak"]
                                                            < 0.0185470581
                                                            else 462
                                                        )
                                                        if state == 461:
                                                            return 0.0780697167
                                                        if state == 462:
                                                            return -0.220485047
                                                    if state == 390:
                                                        state = (
                                                            463
                                                            if x["col_peak"]
                                                            < -0.0603895187
                                                            else 464
                                                        )
                                                        if state == 463:
                                                            return -0.102641277
                                                        if state == 464:
                                                            return 0.159861505
                                                if state == 302:
                                                    state = (
                                                        391
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.967499971
                                                        )
                                                        else 392
                                                    )
                                                    if state == 391:
                                                        return -0.165325448
                                                    if state == 392:
                                                        state = (
                                                            465
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < 0.181191444
                                                            )
                                                            else 466
                                                        )
                                                        if state == 465:
                                                            return 0.277630448
                                                        if state == 466:
                                                            return -0.112373374
                                            if state == 232:
                                                state = (
                                                    303
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.99397564)
                                                    else 304
                                                )
                                                if state == 303:
                                                    return 0.0682318658
                                                if state == 304:
                                                    state = (
                                                        395
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.974000037
                                                        )
                                                        else 396
                                                    )
                                                    if state == 395:
                                                        return -0.256329894
                                                    if state == 396:
                                                        state = (
                                                            467
                                                            if x["col_peak"]
                                                            < 0.804535925
                                                            else 468
                                                        )
                                                        if state == 467:
                                                            return 0.175134435
                                                        if state == 468:
                                                            return -0.15931879
                                        if state == 166:
                                            return -0.1940597
                                    if state == 110:
                                        state = (
                                            167
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.5494576)
                                            else 168
                                        )
                                        if state == 167:
                                            return 0.223708659
                                        if state == 168:
                                            return -0.134405583
                            if state == 42:
                                state = (
                                    69
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.94021988)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        111
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.6203003)
                                        else 112
                                    )
                                    if state == 111:
                                        state = (
                                            169
                                            if x["maggaia_med"] < 18.7055054
                                            else 170
                                        )
                                        if state == 169:
                                            state = (
                                                233
                                                if x["col_last"] < -0.0962238312
                                                else 234
                                            )
                                            if state == 233:
                                                return -0.161880985
                                            if state == 234:
                                                state = (
                                                    307
                                                    if np.isnan(x["t_predetect"])
                                                    or (
                                                        x["t_predetect"] < 0.00210645003
                                                    )
                                                    else 308
                                                )
                                                if state == 307:
                                                    return -0.179742277
                                                if state == 308:
                                                    state = (
                                                        397
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.97724998
                                                        )
                                                        else 398
                                                    )
                                                    if state == 397:
                                                        state = (
                                                            469
                                                            if x["col_peak"]
                                                            < -0.223805428
                                                            else 470
                                                        )
                                                        if state == 469:
                                                            return 0.0717999637
                                                        if state == 470:
                                                            return -0.129366025
                                                    if state == 398:
                                                        state = (
                                                            471
                                                            if x["col_peak"]
                                                            < -0.125795841
                                                            else 472
                                                        )
                                                        if state == 471:
                                                            return 0.103224933
                                                        if state == 472:
                                                            return 0.288072944
                                        if state == 170:
                                            state = (
                                                235
                                                if x["col_last"] < 0.247670174
                                                else 236
                                            )
                                            if state == 235:
                                                return 0.108059742
                                            if state == 236:
                                                state = (
                                                    309
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.91723967)
                                                    else 310
                                                )
                                                if state == 309:
                                                    return 0.328340501
                                                if state == 310:
                                                    return -0.0845783204
                                    if state == 112:
                                        state = (
                                            171
                                            if x["maggaia_med"] < 17.3650322
                                            else 172
                                        )
                                        if state == 171:
                                            state = (
                                                237
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.0433769226)
                                                else 238
                                            )
                                            if state == 237:
                                                state = (
                                                    311
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0271643009)
                                                    else 312
                                                )
                                                if state == 311:
                                                    return 0.304576337
                                                if state == 312:
                                                    return 0.0173000637
                                            if state == 238:
                                                return -0.0204808861
                                        if state == 172:
                                            return -0.229854003
                                if state == 70:
                                    state = (
                                        113
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.2345009)
                                        else 114
                                    )
                                    if state == 113:
                                        state = (
                                            173
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.640686)
                                            else 174
                                        )
                                        if state == 173:
                                            state = (
                                                239
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.811145782)
                                                else 240
                                            )
                                            if state == 239:
                                                state = (
                                                    313
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.96636581)
                                                    else 314
                                                )
                                                if state == 313:
                                                    state = (
                                                        403
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.966750026
                                                        )
                                                        else 404
                                                    )
                                                    if state == 403:
                                                        return -0.0559728257
                                                    if state == 404:
                                                        state = (
                                                            475
                                                            if x["col_peak"]
                                                            < -0.287260532
                                                            else 476
                                                        )
                                                        if state == 475:
                                                            return -0.11460989
                                                        if state == 476:
                                                            return 0.237383604
                                                if state == 314:
                                                    return -0.0920363069
                                            if state == 240:
                                                state = (
                                                    315
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.96636581)
                                                    else 316
                                                )
                                                if state == 315:
                                                    return 0.11401841
                                                if state == 316:
                                                    return -0.102718279
                                        if state == 174:
                                            return -0.288738489
                                    if state == 114:
                                        state = (
                                            175
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.829668)
                                            else 176
                                        )
                                        if state == 175:
                                            state = (
                                                243
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.158667564)
                                                else 244
                                            )
                                            if state == 243:
                                                state = (
                                                    317
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.00357628)
                                                    else 318
                                                )
                                                if state == 317:
                                                    state = (
                                                        405
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.980749965
                                                        )
                                                        else 406
                                                    )
                                                    if state == 405:
                                                        state = (
                                                            477
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.0815544128
                                                            )
                                                            else 478
                                                        )
                                                        if state == 477:
                                                            return -0.214904025
                                                        if state == 478:
                                                            return -0.0900277868
                                                    if state == 406:
                                                        state = (
                                                            479
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.0674242973
                                                            )
                                                            else 480
                                                        )
                                                        if state == 479:
                                                            return 0.136309445
                                                        if state == 480:
                                                            return -0.178094566
                                                if state == 318:
                                                    state = (
                                                        407
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.979249954
                                                        )
                                                        else 408
                                                    )
                                                    if state == 407:
                                                        return 0.0120354919
                                                    if state == 408:
                                                        return 0.27270624
                                            if state == 244:
                                                state = (
                                                    319
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.49248886)
                                                    else 320
                                                )
                                                if state == 319:
                                                    state = (
                                                        409
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.982249975
                                                        )
                                                        else 410
                                                    )
                                                    if state == 409:
                                                        return -0.212444887
                                                    if state == 410:
                                                        state = (
                                                            485
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.0674242973
                                                            )
                                                            else 486
                                                        )
                                                        if state == 485:
                                                            return 0.216330037
                                                        if state == 486:
                                                            return -0.186773539
                                                if state == 320:
                                                    return 0.0650283024
                                        if state == 176:
                                            state = (
                                                245
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.971386909)
                                                else 246
                                            )
                                            if state == 245:
                                                state = (
                                                    321
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.94449663)
                                                    else 322
                                                )
                                                if state == 321:
                                                    state = (
                                                        411
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.975750029
                                                        )
                                                        else 412
                                                    )
                                                    if state == 411:
                                                        return -0.021670565
                                                    if state == 412:
                                                        state = (
                                                            487
                                                            if x["col_peak"]
                                                            < -0.134196758
                                                            else 488
                                                        )
                                                        if state == 487:
                                                            return -0.0265643913
                                                        if state == 488:
                                                            return 0.286358297
                                                if state == 322:
                                                    state = (
                                                        413
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.961000025
                                                        )
                                                        else 414
                                                    )
                                                    if state == 413:
                                                        return -0.166949943
                                                    if state == 414:
                                                        state = (
                                                            489
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.0811281204
                                                            )
                                                            else 490
                                                        )
                                                        if state == 489:
                                                            return 0.276075393
                                                        if state == 490:
                                                            return -0.226401299
                                            if state == 246:
                                                return -0.119550243
                        if state == 26:
                            state = (
                                43
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.34934044)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    71
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 7.98383665)
                                    else 72
                                )
                                if state == 71:
                                    state = (
                                        115
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.8675499)
                                        else 116
                                    )
                                    if state == 115:
                                        state = (
                                            177
                                            if x["maggaia_med"] < 19.5018234
                                            else 178
                                        )
                                        if state == 177:
                                            state = (
                                                247
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.0907974243)
                                                else 248
                                            )
                                            if state == 247:
                                                state = (
                                                    323
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.01908016)
                                                    else 324
                                                )
                                                if state == 323:
                                                    return -0.132596537
                                                if state == 324:
                                                    return 0.167759195
                                            if state == 248:
                                                state = (
                                                    325
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.37306118)
                                                    else 326
                                                )
                                                if state == 325:
                                                    return -0.253080666
                                                if state == 326:
                                                    return 0.148573637
                                        if state == 178:
                                            state = (
                                                249
                                                if x["col_last"] < -0.102252007
                                                else 250
                                            )
                                            if state == 249:
                                                return 0.0223435517
                                            if state == 250:
                                                state = (
                                                    327
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0396123007)
                                                    else 328
                                                )
                                                if state == 327:
                                                    return -0.22954075
                                                if state == 328:
                                                    state = (
                                                        415
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.972500026
                                                        )
                                                        else 416
                                                    )
                                                    if state == 415:
                                                        state = (
                                                            491
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < 0.0871229172
                                                            )
                                                            else 492
                                                        )
                                                        if state == 491:
                                                            return 0.0433885306
                                                        if state == 492:
                                                            return -0.141438767
                                                    if state == 416:
                                                        return 0.323342085
                                    if state == 116:
                                        state = (
                                            179 if x["maggaia_med"] < 19.302845 else 180
                                        )
                                        if state == 179:
                                            state = (
                                                251
                                                if x["col_last"] < 0.239053249
                                                else 252
                                            )
                                            if state == 251:
                                                return 0.00244712643
                                            if state == 252:
                                                return -0.320068777
                                        if state == 180:
                                            state = (
                                                253
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.305167198)
                                                else 254
                                            )
                                            if state == 253:
                                                state = (
                                                    329
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.97014475)
                                                    else 330
                                                )
                                                if state == 329:
                                                    state = (
                                                        417
                                                        if np.isnan(x["classtar_med"])
                                                        or (x["classtar_med"] < 0.96875)
                                                        else 418
                                                    )
                                                    if state == 417:
                                                        return -0.208557755
                                                    if state == 418:
                                                        return 0.100053579
                                                if state == 330:
                                                    state = (
                                                        419
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.982249975
                                                        )
                                                        else 420
                                                    )
                                                    if state == 419:
                                                        state = (
                                                            495
                                                            if x["col_peak"]
                                                            < 0.145759583
                                                            else 496
                                                        )
                                                        if state == 495:
                                                            return 0.00999632291
                                                        if state == 496:
                                                            return -0.287172377
                                                    if state == 420:
                                                        return 0.0726360902
                                            if state == 254:
                                                return 0.158764899
                                if state == 72:
                                    state = (
                                        117
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.0356998)
                                        else 118
                                    )
                                    if state == 117:
                                        return 0.183589458
                                    if state == 118:
                                        state = (
                                            181
                                            if x["maggaia_med"] < 20.4225044
                                            else 182
                                        )
                                        if state == 181:
                                            return -0.383845717
                                        if state == 182:
                                            return 0.130488038
                            if state == 44:
                                state = (
                                    73
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 5.02609348)
                                    else 74
                                )
                                if state == 73:
                                    state = (
                                        119
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.97575)
                                        else 120
                                    )
                                    if state == 119:
                                        state = (
                                            183
                                            if x["maggaia_med"] < 19.3728123
                                            else 184
                                        )
                                        if state == 183:
                                            state = (
                                                255
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < -0.0131473541)
                                                else 256
                                            )
                                            if state == 255:
                                                state = (
                                                    331
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.95256948)
                                                    else 332
                                                )
                                                if state == 331:
                                                    return 0.212583199
                                                if state == 332:
                                                    state = (
                                                        421
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.981750011
                                                        )
                                                        else 422
                                                    )
                                                    if state == 421:
                                                        return -0.38068068
                                                    if state == 422:
                                                        return -0.0124891344
                                            if state == 256:
                                                state = (
                                                    333
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.45982647)
                                                    else 334
                                                )
                                                if state == 333:
                                                    return 0.097044453
                                                if state == 334:
                                                    return -0.328865349
                                        if state == 184:
                                            return -0.303442478
                                    if state == 120:
                                        state = (
                                            185
                                            if x["maggaia_med"] < 20.1878948
                                            else 186
                                        )
                                        if state == 185:
                                            state = (
                                                257
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.712607861)
                                                else 258
                                            )
                                            if state == 257:
                                                state = (
                                                    335
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.942685187)
                                                    else 336
                                                )
                                                if state == 335:
                                                    state = (
                                                        423
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.982249975
                                                        )
                                                        else 424
                                                    )
                                                    if state == 423:
                                                        state = (
                                                            497
                                                            if x["col_peak"]
                                                            < 0.629563391
                                                            else 498
                                                        )
                                                        if state == 497:
                                                            return -0.26464808
                                                        if state == 498:
                                                            return 0.0193648562
                                                    if state == 424:
                                                        return 0.149032936
                                                if state == 336:
                                                    state = (
                                                        425
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.979750037
                                                        )
                                                        else 426
                                                    )
                                                    if state == 425:
                                                        state = (
                                                            499
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.228504181
                                                            )
                                                            else 500
                                                        )
                                                        if state == 499:
                                                            return -0.0723570436
                                                        if state == 500:
                                                            return 0.211761147
                                                    if state == 426:
                                                        return 0.253664643
                                            if state == 258:
                                                return 0.258776724
                                        if state == 186:
                                            state = (
                                                259
                                                if x["col_last"] < 0.175806999
                                                else 260
                                            )
                                            if state == 259:
                                                return -0.254039258
                                            if state == 260:
                                                state = (
                                                    337
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.94311333)
                                                    else 338
                                                )
                                                if state == 337:
                                                    state = (
                                                        427
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.978500009
                                                        )
                                                        else 428
                                                    )
                                                    if state == 427:
                                                        return -0.0217948034
                                                    if state == 428:
                                                        return 0.160321131
                                                if state == 338:
                                                    return -0.123464346
                                if state == 74:
                                    state = (
                                        121
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.4447498)
                                        else 122
                                    )
                                    if state == 121:
                                        return 0.191092864
                                    if state == 122:
                                        state = (
                                            187
                                            if x["maggaia_med"] < 19.1240883
                                            else 188
                                        )
                                        if state == 187:
                                            return -0.310461134
                                        if state == 188:
                                            state = (
                                                261
                                                if x["col_last"] < 0.529909134
                                                else 262
                                            )
                                            if state == 261:
                                                state = (
                                                    339
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 7.00666094)
                                                    else 340
                                                )
                                                if state == 339:
                                                    return 0.231757879
                                                if state == 340:
                                                    state = (
                                                        431
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.976750016
                                                        )
                                                        else 432
                                                    )
                                                    if state == 431:
                                                        return -0.149600074
                                                    if state == 432:
                                                        return 0.112716839
                                            if state == 262:
                                                state = (
                                                    341
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.94525433)
                                                    else 342
                                                )
                                                if state == 341:
                                                    return 0.267110646
                                                if state == 342:
                                                    state = (
                                                        433
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.961749971
                                                        )
                                                        else 434
                                                    )
                                                    if state == 433:
                                                        return 0.0996617004
                                                    if state == 434:
                                                        state = (
                                                            501
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < 0.318408966
                                                            )
                                                            else 502
                                                        )
                                                        if state == 501:
                                                            return -0.251560599
                                                        if state == 502:
                                                            return 0.0917635709
    elif num_booster == 27:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 19.1144104) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 1.99822235)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 2.27831268)
                        else 8
                    )
                    if state == 7:
                        state = 13 if x["mag_peak"] < 18.7825451 else 14
                        if state == 13:
                            state = 23 if x["col_last"] < 0.0499629974 else 24
                            if state == 23:
                                state = (
                                    39
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.1290588)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        67
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.282449722)
                                        else 68
                                    )
                                    if state == 67:
                                        state = (
                                            115
                                            if np.isnan(x["distpsnr1_med"])
                                            or (x["distpsnr1_med"] < 0.845009327)
                                            else 116
                                        )
                                        if state == 115:
                                            return -0.276338398
                                        if state == 116:
                                            return -0.0163437631
                                    if state == 68:
                                        state = (
                                            117
                                            if x["distpsnr1_med"] < 0.182282239
                                            else 118
                                        )
                                        if state == 117:
                                            return -0.0713032186
                                        if state == 118:
                                            return 0.102958992
                                if state == 40:
                                    return 0.00203231233
                            if state == 24:
                                state = (
                                    41
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.0381813)
                                    else 42
                                )
                                if state == 41:
                                    state = (
                                        71
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.0198745728)
                                        else 72
                                    )
                                    if state == 71:
                                        state = (
                                            119
                                            if x["distpsnr1_med"] < 0.159471452
                                            else 120
                                        )
                                        if state == 119:
                                            return -0.25649929
                                        if state == 120:
                                            state = (
                                                187
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.983749986)
                                                else 188
                                            )
                                            if state == 187:
                                                state = (
                                                    269
                                                    if x["mag_peak"] < 18.08218
                                                    else 270
                                                )
                                                if state == 269:
                                                    state = (
                                                        347
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.06633)
                                                        else 348
                                                    )
                                                    if state == 347:
                                                        return 0.0787922889
                                                    if state == 348:
                                                        return -0.220441401
                                                if state == 270:
                                                    state = (
                                                        349
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9736557)
                                                        else 350
                                                    )
                                                    if state == 349:
                                                        state = (
                                                            423
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.135718346
                                                            )
                                                            else 424
                                                        )
                                                        if state == 423:
                                                            return -0.00517012971
                                                        if state == 424:
                                                            return 0.11069309
                                                    if state == 350:
                                                        return -0.168880105
                                            if state == 188:
                                                state = (
                                                    271
                                                    if x["mag_peak"] < 18.2194557
                                                    else 272
                                                )
                                                if state == 271:
                                                    return 0.112367079
                                                if state == 272:
                                                    return -0.0915033668
                                    if state == 72:
                                        state = (
                                            121
                                            if x["distpsnr1_med"] < 0.698203981
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                189
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.97874999)
                                                else 190
                                            )
                                            if state == 189:
                                                state = (
                                                    273
                                                    if x["mag_peak"] < 18.0958214
                                                    else 274
                                                )
                                                if state == 273:
                                                    state = (
                                                        353
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.6808319)
                                                        else 354
                                                    )
                                                    if state == 353:
                                                        return -0.532857835
                                                    if state == 354:
                                                        return 0.0850745961
                                                if state == 274:
                                                    return 0.0894835666
                                            if state == 190:
                                                state = (
                                                    275
                                                    if x["mag_peak"] < 17.9749718
                                                    else 276
                                                )
                                                if state == 275:
                                                    state = (
                                                        357
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.2115746)
                                                        else 358
                                                    )
                                                    if state == 357:
                                                        return -0.165552586
                                                    if state == 358:
                                                        return 0.114595011
                                                if state == 276:
                                                    return 0.117246777
                                        if state == 122:
                                            state = (
                                                191
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.980749965)
                                                else 192
                                            )
                                            if state == 191:
                                                state = (
                                                    277
                                                    if x["mag_peak"] < 18.5331516
                                                    else 278
                                                )
                                                if state == 277:
                                                    return 0.134301364
                                                if state == 278:
                                                    return -0.087417081
                                            if state == 192:
                                                state = (
                                                    279
                                                    if x["mag_peak"] < 18.6269951
                                                    else 280
                                                )
                                                if state == 279:
                                                    state = (
                                                        361
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.5217514)
                                                        else 362
                                                    )
                                                    if state == 361:
                                                        return -0.0271155033
                                                    if state == 362:
                                                        return 0.221848547
                                                if state == 280:
                                                    return -0.0407847874
                                if state == 42:
                                    state = 73 if x["col_det"] < 0.154354095 else 74
                                    if state == 73:
                                        state = (
                                            123
                                            if x["distpsnr1_med"] < 1.92136765
                                            else 124
                                        )
                                        if state == 123:
                                            state = (
                                                193
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982749999)
                                                else 194
                                            )
                                            if state == 193:
                                                state = (
                                                    281
                                                    if x["mag_peak"] < 18.7526398
                                                    else 282
                                                )
                                                if state == 281:
                                                    return 0.257941723
                                                if state == 282:
                                                    return 0.0366252251
                                            if state == 194:
                                                return 0.0189457778
                                        if state == 124:
                                            return -0.144627437
                                    if state == 74:
                                        state = (
                                            125
                                            if x["distpsnr1_med"] < 1.3878715
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                195
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.924000025)
                                                else 196
                                            )
                                            if state == 195:
                                                return -0.194288462
                                            if state == 196:
                                                state = (
                                                    285
                                                    if x["mag_peak"] < 18.74646
                                                    else 286
                                                )
                                                if state == 285:
                                                    state = (
                                                        367
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.5890732)
                                                        else 368
                                                    )
                                                    if state == 367:
                                                        state = (
                                                            429
                                                            if x["col_last"]
                                                            < 0.442555428
                                                            else 430
                                                        )
                                                        if state == 429:
                                                            return 0.0216584094
                                                        if state == 430:
                                                            return 0.151891425
                                                    if state == 368:
                                                        return 0.0487795472
                                                if state == 286:
                                                    state = (
                                                        369
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1897354)
                                                        else 370
                                                    )
                                                    if state == 369:
                                                        return 0.0226117913
                                                    if state == 370:
                                                        return 0.311311662
                                        if state == 126:
                                            state = (
                                                197
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.976000011)
                                                else 198
                                            )
                                            if state == 197:
                                                state = (
                                                    287
                                                    if x["mag_peak"] < 18.5114822
                                                    else 288
                                                )
                                                if state == 287:
                                                    return 0.198560432
                                                if state == 288:
                                                    return -0.0378747545
                                            if state == 198:
                                                state = (
                                                    289
                                                    if x["mag_peak"] < 18.0642624
                                                    else 290
                                                )
                                                if state == 289:
                                                    return -0.229058757
                                                if state == 290:
                                                    state = (
                                                        371
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.8303909)
                                                        else 372
                                                    )
                                                    if state == 371:
                                                        state = (
                                                            433
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.142861366
                                                            )
                                                            else 434
                                                        )
                                                        if state == 433:
                                                            return -0.0316728279
                                                        if state == 434:
                                                            return -0.193457693
                                                    if state == 372:
                                                        return 0.0986486375
                        if state == 14:
                            state = 25 if x["col_last"] < 0.0762724876 else 26
                            if state == 25:
                                state = (
                                    43
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.6265488)
                                    else 44
                                )
                                if state == 43:
                                    state = (
                                        75
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.09329319)
                                        else 76
                                    )
                                    if state == 75:
                                        state = (
                                            127
                                            if np.isnan(x["distpsnr1_med"])
                                            or (x["distpsnr1_med"] < 1.30654764)
                                            else 128
                                        )
                                        if state == 127:
                                            state = (
                                                199
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.976250052)
                                                else 200
                                            )
                                            if state == 199:
                                                state = (
                                                    291
                                                    if x["mag_peak"] < 38.2218094
                                                    else 292
                                                )
                                                if state == 291:
                                                    return 0.0207225177
                                                if state == 292:
                                                    return 0.224473074
                                            if state == 200:
                                                state = (
                                                    293
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.9150906)
                                                    else 294
                                                )
                                                if state == 293:
                                                    state = (
                                                        375
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1926422)
                                                        else 376
                                                    )
                                                    if state == 375:
                                                        state = (
                                                            437
                                                            if x["col_last"]
                                                            < -0.140212059
                                                            else 438
                                                        )
                                                        if state == 437:
                                                            return 0.0403985307
                                                        if state == 438:
                                                            return 0.173035786
                                                    if state == 376:
                                                        state = (
                                                            439
                                                            if x["col_last"]
                                                            < -0.103930786
                                                            else 440
                                                        )
                                                        if state == 439:
                                                            return 0.0400122404
                                                        if state == 440:
                                                            return -0.161709175
                                                if state == 294:
                                                    return 0.00573909422
                                        if state == 128:
                                            state = (
                                                201
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982749999)
                                                else 202
                                            )
                                            if state == 201:
                                                return 0.0403001793
                                            if state == 202:
                                                return -0.130658254
                                    if state == 76:
                                        state = (
                                            129
                                            if x["distpsnr1_med"] < 1.00462365
                                            else 130
                                        )
                                        if state == 129:
                                            return -0.205577165
                                        if state == 130:
                                            state = (
                                                203
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.975499988)
                                                else 204
                                            )
                                            if state == 203:
                                                return -0.093601808
                                            if state == 204:
                                                return 0.167456061
                                if state == 44:
                                    return -0.216066673
                            if state == 26:
                                state = (
                                    45
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.0353584)
                                    else 46
                                )
                                if state == 45:
                                    state = 77 if x["col_det"] < -0.101406097 else 78
                                    if state == 77:
                                        return 0.17931138
                                    if state == 78:
                                        state = (
                                            133
                                            if x["distpsnr1_med"] < 0.113736264
                                            else 134
                                        )
                                        if state == 133:
                                            return -0.216273233
                                        if state == 134:
                                            state = (
                                                207
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.978249967)
                                                else 208
                                            )
                                            if state == 207:
                                                return -0.0829195753
                                            if state == 208:
                                                state = (
                                                    295
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.8137283)
                                                    else 296
                                                )
                                                if state == 295:
                                                    state = (
                                                        377
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.6766434)
                                                        else 378
                                                    )
                                                    if state == 377:
                                                        state = (
                                                            441
                                                            if x["col_last"]
                                                            < 0.350072861
                                                            else 442
                                                        )
                                                        if state == 441:
                                                            return -0.153465599
                                                        if state == 442:
                                                            return 0.023420509
                                                    if state == 378:
                                                        return 0.0667538643
                                                if state == 296:
                                                    return 0.109751403
                                if state == 46:
                                    state = 79 if x["col_det"] < -0.0390267372 else 80
                                    if state == 79:
                                        state = (
                                            135
                                            if x["distpsnr1_med"] < 1.22268581
                                            else 136
                                        )
                                        if state == 135:
                                            state = (
                                                209
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.968500018)
                                                else 210
                                            )
                                            if state == 209:
                                                return -0.14778012
                                            if state == 210:
                                                state = (
                                                    297
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.843399)
                                                    else 298
                                                )
                                                if state == 297:
                                                    state = (
                                                        379
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1095295)
                                                        else 380
                                                    )
                                                    if state == 379:
                                                        state = (
                                                            445
                                                            if x["col_last"]
                                                            < 0.91023159
                                                            else 446
                                                        )
                                                        if state == 445:
                                                            return -0.0837723985
                                                        if state == 446:
                                                            return 0.140987217
                                                    if state == 380:
                                                        return -0.201136351
                                                if state == 298:
                                                    return 0.211127058
                                        if state == 136:
                                            state = (
                                                211
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.977499962)
                                                else 212
                                            )
                                            if state == 211:
                                                state = (
                                                    299
                                                    if x["mag_peak"] < 18.9609051
                                                    else 300
                                                )
                                                if state == 299:
                                                    return 0.00504596485
                                                if state == 300:
                                                    state = (
                                                        381
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.3234711)
                                                        else 382
                                                    )
                                                    if state == 381:
                                                        return 0.0372551531
                                                    if state == 382:
                                                        return -0.152155176
                                            if state == 212:
                                                return -0.273819566
                                    if state == 80:
                                        state = (
                                            137
                                            if np.isnan(x["distpsnr1_med"])
                                            or (x["distpsnr1_med"] < 1.49756885)
                                            else 138
                                        )
                                        if state == 137:
                                            state = (
                                                213
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.971500039)
                                                else 214
                                            )
                                            if state == 213:
                                                state = (
                                                    303
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.8589745)
                                                    else 304
                                                )
                                                if state == 303:
                                                    return -0.285704732
                                                if state == 304:
                                                    return -0.0299293734
                                            if state == 214:
                                                state = (
                                                    305
                                                    if x["mag_peak"] < 18.8765507
                                                    else 306
                                                )
                                                if state == 305:
                                                    return -0.222410262
                                                if state == 306:
                                                    state = (
                                                        385
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.4011497)
                                                        else 386
                                                    )
                                                    if state == 385:
                                                        state = (
                                                            449
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.216709137
                                                            )
                                                            else 450
                                                        )
                                                        if state == 449:
                                                            return -0.119476303
                                                        if state == 450:
                                                            return 0.17957449
                                                    if state == 386:
                                                        return 0.151664048
                                        if state == 138:
                                            state = (
                                                215
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.881999969)
                                                else 216
                                            )
                                            if state == 215:
                                                return 0.14016223
                                            if state == 216:
                                                return -0.343074352
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.4135685)
                            else 16
                        )
                        if state == 15:
                            state = 27 if x["col_last"] < -0.0603995323 else 28
                            if state == 27:
                                return -0.0512902327
                            if state == 28:
                                state = (
                                    47
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.6370583)
                                    else 48
                                )
                                if state == 47:
                                    return -0.121040151
                                if state == 48:
                                    state = 83 if x["col_det"] < -0.190948963 else 84
                                    if state == 83:
                                        return 0.0224423297
                                    if state == 84:
                                        state = (
                                            141
                                            if np.isnan(x["distpsnr1_med"])
                                            or (x["distpsnr1_med"] < 0.782145798)
                                            else 142
                                        )
                                        if state == 141:
                                            state = (
                                                217
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982249975)
                                                else 218
                                            )
                                            if state == 217:
                                                state = (
                                                    307
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.0478516)
                                                    else 308
                                                )
                                                if state == 307:
                                                    return -0.195998952
                                                if state == 308:
                                                    return 0.0320143737
                                            if state == 218:
                                                return 0.0414929651
                                        if state == 142:
                                            return -0.433012128
                        if state == 16:
                            state = (
                                29
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < -0.200263977)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    49
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.6947289)
                                    else 50
                                )
                                if state == 49:
                                    state = 85 if x["col_det"] < 0.0773210526 else 86
                                    if state == 85:
                                        return 0.0367153734
                                    if state == 86:
                                        return -0.327052087
                                if state == 50:
                                    state = 87 if x["col_det"] < 0.170300484 else 88
                                    if state == 87:
                                        return 0.140777513
                                    if state == 88:
                                        return -0.0719835535
                            if state == 30:
                                return 0.0498891622
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 2.542557)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["mag_peak"] < 18.6801491 else 18
                        if state == 17:
                            state = 31 if x["col_last"] < 0.176691383 else 32
                            if state == 31:
                                state = (
                                    51
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.3023453)
                                    else 52
                                )
                                if state == 51:
                                    return 0.0699311346
                                if state == 52:
                                    state = (
                                        89
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.432901382)
                                        else 90
                                    )
                                    if state == 89:
                                        return 0.151939511
                                    if state == 90:
                                        return -0.122153901
                            if state == 32:
                                state = (
                                    53
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.6098957)
                                    else 54
                                )
                                if state == 53:
                                    state = 91 if x["col_det"] < -0.120594025 else 92
                                    if state == 91:
                                        state = (
                                            143
                                            if x["distpsnr1_med"] < 2.11967468
                                            else 144
                                        )
                                        if state == 143:
                                            return -0.11483106
                                        if state == 144:
                                            state = (
                                                219
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.979250014)
                                                else 220
                                            )
                                            if state == 219:
                                                return 0.0930533186
                                            if state == 220:
                                                state = (
                                                    309
                                                    if x["mag_peak"] < 18.5565224
                                                    else 310
                                                )
                                                if state == 309:
                                                    state = (
                                                        387
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.6393967)
                                                        else 388
                                                    )
                                                    if state == 387:
                                                        return 0.0897845924
                                                    if state == 388:
                                                        return -0.0844131485
                                                if state == 310:
                                                    return 0.137559339
                                    if state == 92:
                                        state = (
                                            145
                                            if x["distpsnr1_med"] < 10.2363396
                                            else 146
                                        )
                                        if state == 145:
                                            return 0.283032894
                                        if state == 146:
                                            state = (
                                                223
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982249975)
                                                else 224
                                            )
                                            if state == 223:
                                                return -0.0677690357
                                            if state == 224:
                                                return 0.0966483206
                                if state == 54:
                                    state = 93 if x["col_det"] < -0.123331547 else 94
                                    if state == 93:
                                        return -0.0197998844
                                    if state == 94:
                                        state = (
                                            149
                                            if x["distpsnr1_med"] < 10.5195808
                                            else 150
                                        )
                                        if state == 149:
                                            state = (
                                                225
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.976750016)
                                                else 226
                                            )
                                            if state == 225:
                                                return -0.0543098859
                                            if state == 226:
                                                return 0.238013253
                                        if state == 150:
                                            return -0.0527870357
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.503203392)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    55
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.1048927)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        95
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.189738274)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            151
                                            if x["distpsnr1_med"] < 7.39682388
                                            else 152
                                        )
                                        if state == 151:
                                            return 0.329757214
                                        if state == 152:
                                            return 0.0226104651
                                    if state == 96:
                                        state = (
                                            153
                                            if x["distpsnr1_med"] < 2.14512157
                                            else 154
                                        )
                                        if state == 153:
                                            state = (
                                                233
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.962499976)
                                                else 234
                                            )
                                            if state == 233:
                                                return 0.0113388067
                                            if state == 234:
                                                return -0.300375521
                                        if state == 154:
                                            state = (
                                                235
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.982249975)
                                                else 236
                                            )
                                            if state == 235:
                                                state = (
                                                    315
                                                    if x["mag_peak"] < 18.8445988
                                                    else 316
                                                )
                                                if state == 315:
                                                    return -0.0922443047
                                                if state == 316:
                                                    state = (
                                                        389
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.8207054)
                                                        else 390
                                                    )
                                                    if state == 389:
                                                        return 0.173186243
                                                    if state == 390:
                                                        state = (
                                                            451
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.0960144997
                                                            )
                                                            else 452
                                                        )
                                                        if state == 451:
                                                            return 0.108122543
                                                        if state == 452:
                                                            return -0.0960566476
                                            if state == 236:
                                                return 0.220692396
                                if state == 56:
                                    state = (
                                        97
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.0519599915)
                                        else 98
                                    )
                                    if state == 97:
                                        state = (
                                            155
                                            if x["distpsnr1_med"] < 2.16185713
                                            else 156
                                        )
                                        if state == 155:
                                            state = (
                                                237
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.979249954)
                                                else 238
                                            )
                                            if state == 237:
                                                state = (
                                                    317
                                                    if x["mag_peak"] < 18.9883156
                                                    else 318
                                                )
                                                if state == 317:
                                                    return 0.290930301
                                                if state == 318:
                                                    state = (
                                                        391
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.287323)
                                                        else 392
                                                    )
                                                    if state == 391:
                                                        return 0.14715077
                                                    if state == 392:
                                                        return -0.0278299954
                                            if state == 238:
                                                return -0.180473402
                                        if state == 156:
                                            state = (
                                                239
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.964250028)
                                                else 240
                                            )
                                            if state == 239:
                                                state = (
                                                    319
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 19.0207863)
                                                    else 320
                                                )
                                                if state == 319:
                                                    state = (
                                                        393
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.0872917)
                                                        else 394
                                                    )
                                                    if state == 393:
                                                        state = (
                                                            453
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.317414761
                                                            )
                                                            else 454
                                                        )
                                                        if state == 453:
                                                            return -0.0569570139
                                                        if state == 454:
                                                            return 0.203742206
                                                    if state == 394:
                                                        return -0.14365381
                                                if state == 320:
                                                    return 0.355572581
                                            if state == 240:
                                                state = (
                                                    321
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.7695503)
                                                    else 322
                                                )
                                                if state == 321:
                                                    state = (
                                                        395
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.146286)
                                                        else 396
                                                    )
                                                    if state == 395:
                                                        return 0.0622623153
                                                    if state == 396:
                                                        return -0.348230094
                                                if state == 322:
                                                    state = (
                                                        397
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1851501)
                                                        else 398
                                                    )
                                                    if state == 397:
                                                        return -0.16226244
                                                    if state == 398:
                                                        return 0.178371519
                                    if state == 98:
                                        return -0.279878139
                            if state == 34:
                                state = (
                                    57
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.0672817)
                                    else 58
                                )
                                if state == 57:
                                    return 0.138728172
                                if state == 58:
                                    state = 99 if x["col_det"] < -0.137888908 else 100
                                    if state == 99:
                                        return -0.191703096
                                    if state == 100:
                                        state = (
                                            157
                                            if x["distpsnr1_med"] < 3.48609972
                                            else 158
                                        )
                                        if state == 157:
                                            state = (
                                                241
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.975750029)
                                                else 242
                                            )
                                            if state == 241:
                                                return -0.172120005
                                            if state == 242:
                                                state = (
                                                    323
                                                    if x["mag_peak"] < 18.8330879
                                                    else 324
                                                )
                                                if state == 323:
                                                    return 0.117956288
                                                if state == 324:
                                                    return -0.0513515398
                                        if state == 158:
                                            state = (
                                                243
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.972499967)
                                                else 244
                                            )
                                            if state == 243:
                                                return -0.0665989891
                                            if state == 244:
                                                return 0.182532728
                    if state == 10:
                        state = 19 if x["mag_peak"] < 18.5682812 else 20
                        if state == 19:
                            state = 35 if x["col_last"] < 0.150277615 else 36
                            if state == 35:
                                state = (
                                    59
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 17.9792671)
                                    else 60
                                )
                                if state == 59:
                                    return 0.0671067759
                                if state == 60:
                                    state = 101 if x["col_det"] < -0.0333652496 else 102
                                    if state == 101:
                                        return -0.0153235039
                                    if state == 102:
                                        state = (
                                            161
                                            if x["distpsnr1_med"] < 10.5096989
                                            else 162
                                        )
                                        if state == 161:
                                            return -0.215221569
                                        if state == 162:
                                            return 0.057664901
                            if state == 36:
                                state = (
                                    61
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.6890144)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        103
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.321150303)
                                        else 104
                                    )
                                    if state == 103:
                                        state = (
                                            163
                                            if x["distpsnr1_med"] < 3.03803682
                                            else 164
                                        )
                                        if state == 163:
                                            state = (
                                                245
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981750011)
                                                else 246
                                            )
                                            if state == 245:
                                                return 0.159817919
                                            if state == 246:
                                                state = (
                                                    325
                                                    if x["mag_peak"] < 18.2665005
                                                    else 326
                                                )
                                                if state == 325:
                                                    return -0.266850352
                                                if state == 326:
                                                    return 0.126330405
                                        if state == 164:
                                            state = (
                                                247
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.971750021)
                                                else 248
                                            )
                                            if state == 247:
                                                return -0.143829688
                                            if state == 248:
                                                state = (
                                                    327
                                                    if x["mag_peak"] < 17.8770866
                                                    else 328
                                                )
                                                if state == 327:
                                                    state = (
                                                        401
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.9890709)
                                                        else 402
                                                    )
                                                    if state == 401:
                                                        return 0.201267958
                                                    if state == 402:
                                                        state = (
                                                            463
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.649284363
                                                            )
                                                            else 464
                                                        )
                                                        if state == 463:
                                                            return -0.00696151331
                                                        if state == 464:
                                                            return 0.127724543
                                                if state == 328:
                                                    return 0.301211596
                                    if state == 104:
                                        state = (
                                            165
                                            if x["distpsnr1_med"] < 9.75690365
                                            else 166
                                        )
                                        if state == 165:
                                            state = (
                                                249
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981750011)
                                                else 250
                                            )
                                            if state == 249:
                                                state = (
                                                    329
                                                    if x["mag_peak"] < 18.3965397
                                                    else 330
                                                )
                                                if state == 329:
                                                    return -0.257063299
                                                if state == 330:
                                                    state = (
                                                        405
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.5277786)
                                                        else 406
                                                    )
                                                    if state == 405:
                                                        return 0.0850898698
                                                    if state == 406:
                                                        return -0.126311153
                                            if state == 250:
                                                state = (
                                                    331
                                                    if x["mag_peak"] < 17.7559853
                                                    else 332
                                                )
                                                if state == 331:
                                                    state = (
                                                        407
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 17.9857769)
                                                        else 408
                                                    )
                                                    if state == 407:
                                                        return 0.0819974765
                                                    if state == 408:
                                                        return -0.110736892
                                                if state == 332:
                                                    state = (
                                                        409
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.5386467)
                                                        else 410
                                                    )
                                                    if state == 409:
                                                        return 0.23107186
                                                    if state == 410:
                                                        return -0.0419040471
                                        if state == 166:
                                            return 0.170227498
                                if state == 62:
                                    state = 105 if x["col_det"] < -0.131129742 else 106
                                    if state == 105:
                                        return -0.0304070991
                                    if state == 106:
                                        state = (
                                            169
                                            if x["distpsnr1_med"] < 8.15991974
                                            else 170
                                        )
                                        if state == 169:
                                            state = (
                                                251
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.745499969)
                                                else 252
                                            )
                                            if state == 251:
                                                return 0.018976815
                                            if state == 252:
                                                return 0.314767569
                                        if state == 170:
                                            state = (
                                                253
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.976500034)
                                                else 254
                                            )
                                            if state == 253:
                                                return -0.116681419
                                            if state == 254:
                                                return 0.111220904
                        if state == 20:
                            state = 37 if x["col_last"] < 0.544618607 else 38
                            if state == 37:
                                state = (
                                    63
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.457901)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        107
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.0983225554)
                                        else 108
                                    )
                                    if state == 107:
                                        return 0.243502483
                                    if state == 108:
                                        return 0.0415580235
                                if state == 64:
                                    state = (
                                        109
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.123085499)
                                        else 110
                                    )
                                    if state == 109:
                                        state = (
                                            173
                                            if x["distpsnr1_med"] < 3.30002904
                                            else 174
                                        )
                                        if state == 173:
                                            state = (
                                                255
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.960749984)
                                                else 256
                                            )
                                            if state == 255:
                                                return -0.0174541119
                                            if state == 256:
                                                state = (
                                                    335
                                                    if x["mag_peak"] < 18.6246109
                                                    else 336
                                                )
                                                if state == 335:
                                                    return -0.143984318
                                                if state == 336:
                                                    state = (
                                                        411
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.8270359)
                                                        else 412
                                                    )
                                                    if state == 411:
                                                        state = (
                                                            467
                                                            if x["col_last"]
                                                            < 0.100343704
                                                            else 468
                                                        )
                                                        if state == 467:
                                                            return 0.0214994885
                                                        if state == 468:
                                                            return -0.163342565
                                                    if state == 412:
                                                        state = (
                                                            469
                                                            if x["col_last"]
                                                            < 0.296478271
                                                            else 470
                                                        )
                                                        if state == 469:
                                                            return 0.224162236
                                                        if state == 470:
                                                            return -0.0147510981
                                        if state == 174:
                                            state = (
                                                257
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.921000004)
                                                else 258
                                            )
                                            if state == 257:
                                                return 0.139964759
                                            if state == 258:
                                                state = (
                                                    337
                                                    if x["mag_peak"] < 18.8753738
                                                    else 338
                                                )
                                                if state == 337:
                                                    state = (
                                                        413
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2290726)
                                                        else 414
                                                    )
                                                    if state == 413:
                                                        state = (
                                                            471
                                                            if x["col_last"]
                                                            < 0.117478371
                                                            else 472
                                                        )
                                                        if state == 471:
                                                            return 0.0728358403
                                                        if state == 472:
                                                            return -0.102363691
                                                    if state == 414:
                                                        return 0.159666389
                                                if state == 338:
                                                    state = (
                                                        415
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1359119)
                                                        else 416
                                                    )
                                                    if state == 415:
                                                        state = (
                                                            473
                                                            if x["col_last"]
                                                            < -0.149234772
                                                            else 474
                                                        )
                                                        if state == 473:
                                                            return 0.133079275
                                                        if state == 474:
                                                            return -0.0972698033
                                                    if state == 416:
                                                        state = (
                                                            475
                                                            if x["col_last"]
                                                            < -0.202924103
                                                            else 476
                                                        )
                                                        if state == 475:
                                                            return -0.0126824789
                                                        if state == 476:
                                                            return -0.279281497
                                    if state == 110:
                                        state = (
                                            175
                                            if x["distpsnr1_med"] < 2.91038513
                                            else 176
                                        )
                                        if state == 175:
                                            return -0.118415765
                                        if state == 176:
                                            state = (
                                                259
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.967000008)
                                                else 260
                                            )
                                            if state == 259:
                                                return -0.0984257013
                                            if state == 260:
                                                return 0.265633613
                            if state == 38:
                                state = (
                                    65
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.1683502)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        111
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.0571918488)
                                        else 112
                                    )
                                    if state == 111:
                                        state = (
                                            177
                                            if x["distpsnr1_med"] < 4.52156639
                                            else 178
                                        )
                                        if state == 177:
                                            state = (
                                                261
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.981750011)
                                                else 262
                                            )
                                            if state == 261:
                                                state = (
                                                    339
                                                    if x["mag_peak"] < 18.672226
                                                    else 340
                                                )
                                                if state == 339:
                                                    return -0.140551597
                                                if state == 340:
                                                    state = (
                                                        417
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.8785076)
                                                        else 418
                                                    )
                                                    if state == 417:
                                                        return 0.135974377
                                                    if state == 418:
                                                        return -0.0384494737
                                            if state == 262:
                                                state = (
                                                    341
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.6954231)
                                                    else 342
                                                )
                                                if state == 341:
                                                    state = (
                                                        419
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.7031517)
                                                        else 420
                                                    )
                                                    if state == 419:
                                                        return 0.0504188612
                                                    if state == 420:
                                                        return -0.271600306
                                                if state == 342:
                                                    return -0.00440930948
                                        if state == 178:
                                            state = (
                                                263
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.976250052)
                                                else 264
                                            )
                                            if state == 263:
                                                return -0.0448965356
                                            if state == 264:
                                                state = (
                                                    343
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.5771523)
                                                    else 344
                                                )
                                                if state == 343:
                                                    state = (
                                                        421
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0605202)
                                                        else 422
                                                    )
                                                    if state == 421:
                                                        return 0.193627775
                                                    if state == 422:
                                                        return -0.179960415
                                                if state == 344:
                                                    return 0.228398591
                                    if state == 112:
                                        state = (
                                            179
                                            if x["distpsnr1_med"] < 3.02367711
                                            else 180
                                        )
                                        if state == 179:
                                            return -0.138450921
                                        if state == 180:
                                            return 0.209089503
                                if state == 66:
                                    state = 113 if x["col_det"] < -0.286783218 else 114
                                    if state == 113:
                                        state = (
                                            181
                                            if x["distpsnr1_med"] < 2.77290654
                                            else 182
                                        )
                                        if state == 181:
                                            return 0.199947998
                                        if state == 182:
                                            state = (
                                                265
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.980499983)
                                                else 266
                                            )
                                            if state == 265:
                                                return -0.0594519265
                                            if state == 266:
                                                return 0.138315037
                                    if state == 114:
                                        state = (
                                            183
                                            if x["distpsnr1_med"] < 11.4137154
                                            else 184
                                        )
                                        if state == 183:
                                            return -0.192765683
                                        if state == 184:
                                            state = (
                                                267
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.977500021)
                                                else 268
                                            )
                                            if state == 267:
                                                return -0.150499776
                                            if state == 268:
                                                return 0.162469223
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 3.65327835 else 6
                if state == 5:
                    return -0.336010635
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 2.35120058)
                        else 12
                    )
                    if state == 11:
                        state = 21 if x["mag_peak"] < 20.0382996 else 22
                        if state == 21:
                            return 0.00407333719
                        if state == 22:
                            return 0.338378727
                    if state == 12:
                        return -0.262263089
    elif num_booster == 28:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3143997) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["col_last"]) or (x["col_last"] < 0.14428091) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.869750023)
                        else 8
                    )
                    if state == 7:
                        return -0.286229551
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.2322998)
                            else 16
                        )
                        if state == 15:
                            state = 27 if x["col_last"] < -0.209165573 else 28
                            if state == 27:
                                state = (
                                    49
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 8.96140766)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        81
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.278260231)
                                        else 82
                                    )
                                    if state == 81:
                                        return -0.196997106
                                    if state == 82:
                                        return 0.0462343879
                                if state == 50:
                                    return 0.0380995311
                            if state == 28:
                                state = (
                                    51
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.243012458)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        83
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.154354095)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            115
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.974750042)
                                            else 116
                                        )
                                        if state == 115:
                                            return -0.252263367
                                        if state == 116:
                                            state = (
                                                157
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.208761871)
                                                else 158
                                            )
                                            if state == 157:
                                                state = (
                                                    205
                                                    if x["maggaia_med"] < 18.5768623
                                                    else 206
                                                )
                                                if state == 205:
                                                    return -0.1216584
                                                if state == 206:
                                                    state = (
                                                        255
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.672500134)
                                                        else 256
                                                    )
                                                    if state == 255:
                                                        return 0.23747839
                                                    if state == 256:
                                                        return 0.0125587769
                                            if state == 158:
                                                state = (
                                                    207
                                                    if x["maggaia_med"] < 19.5480995
                                                    else 208
                                                )
                                                if state == 207:
                                                    state = (
                                                        257
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.762023628)
                                                        else 258
                                                    )
                                                    if state == 257:
                                                        return 0.103460342
                                                    if state == 258:
                                                        return -0.100419171
                                                if state == 208:
                                                    return -0.212579593
                                    if state == 84:
                                        return -0.210892439
                                if state == 52:
                                    state = (
                                        85
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.115785599)
                                        else 86
                                    )
                                    if state == 85:
                                        state = (
                                            117
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.971249998)
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                159
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.357905656)
                                                else 160
                                            )
                                            if state == 159:
                                                state = (
                                                    209
                                                    if x["maggaia_med"] < 19.2611752
                                                    else 210
                                                )
                                                if state == 209:
                                                    return 0.136687875
                                                if state == 210:
                                                    return -0.13880226
                                            if state == 160:
                                                state = (
                                                    211
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 19.2723465)
                                                    else 212
                                                )
                                                if state == 211:
                                                    return -0.253217876
                                                if state == 212:
                                                    state = (
                                                        261
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.558452487)
                                                        else 262
                                                    )
                                                    if state == 261:
                                                        return 0.157242164
                                                    if state == 262:
                                                        return -0.117666818
                                        if state == 118:
                                            state = (
                                                161
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 4.29941559)
                                                else 162
                                            )
                                            if state == 161:
                                                state = (
                                                    213
                                                    if x["maggaia_med"] < 18.9656487
                                                    else 214
                                                )
                                                if state == 213:
                                                    state = (
                                                        263
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.751428723)
                                                        else 264
                                                    )
                                                    if state == 263:
                                                        state = (
                                                            313
                                                            if x["col_last"]
                                                            < -0.11401701
                                                            else 314
                                                        )
                                                        if state == 313:
                                                            return 0.237375334
                                                        if state == 314:
                                                            return 0.00879365858
                                                    if state == 264:
                                                        return 0.169675812
                                                if state == 214:
                                                    state = (
                                                        265
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.517500043)
                                                        else 266
                                                    )
                                                    if state == 265:
                                                        return 0.0275290683
                                                    if state == 266:
                                                        state = (
                                                            317
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.0609426498
                                                            )
                                                            else 318
                                                        )
                                                        if state == 317:
                                                            return -0.0973939449
                                                        if state == 318:
                                                            return -0.291909009
                                            if state == 162:
                                                state = (
                                                    215
                                                    if x["maggaia_med"] < 17.07201
                                                    else 216
                                                )
                                                if state == 215:
                                                    state = (
                                                        267
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.431666672)
                                                        else 268
                                                    )
                                                    if state == 267:
                                                        return 0.0912581459
                                                    if state == 268:
                                                        state = (
                                                            319
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.120948315
                                                            )
                                                            else 320
                                                        )
                                                        if state == 319:
                                                            return -0.223519936
                                                        if state == 320:
                                                            return 0.0487187654
                                                if state == 216:
                                                    state = (
                                                        269
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.300833166)
                                                        else 270
                                                    )
                                                    if state == 269:
                                                        return -0.0805198103
                                                    if state == 270:
                                                        state = (
                                                            321
                                                            if x["col_last"]
                                                            < -0.0969028473
                                                            else 322
                                                        )
                                                        if state == 321:
                                                            return -0.0468701534
                                                        if state == 322:
                                                            return 0.121282861
                                    if state == 86:
                                        state = (
                                            119
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.913249969)
                                            else 120
                                        )
                                        if state == 119:
                                            return 0.213525817
                                        if state == 120:
                                            state = (
                                                165
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.704973459)
                                                else 166
                                            )
                                            if state == 165:
                                                state = (
                                                    217
                                                    if x["maggaia_med"] < 17.9289284
                                                    else 218
                                                )
                                                if state == 217:
                                                    return -0.0943310186
                                                if state == 218:
                                                    state = (
                                                        273
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.512500048)
                                                        else 274
                                                    )
                                                    if state == 273:
                                                        return 0.00874585938
                                                    if state == 274:
                                                        state = (
                                                            323
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.0494318008
                                                            )
                                                            else 324
                                                        )
                                                        if state == 323:
                                                            return 0.155026987
                                                        if state == 324:
                                                            return -0.0743604675
                                            if state == 166:
                                                state = (
                                                    219
                                                    if x["maggaia_med"] < 19.809166
                                                    else 220
                                                )
                                                if state == 219:
                                                    state = (
                                                        275
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.498333395)
                                                        else 276
                                                    )
                                                    if state == 275:
                                                        return 0.101565741
                                                    if state == 276:
                                                        state = (
                                                            325
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.0984306335
                                                            )
                                                            else 326
                                                        )
                                                        if state == 325:
                                                            return -0.0354387723
                                                        if state == 326:
                                                            return -0.130382776
                                                if state == 220:
                                                    state = (
                                                        277
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.225833505)
                                                        else 278
                                                    )
                                                    if state == 277:
                                                        return -0.110295087
                                                    if state == 278:
                                                        return 0.140542105
                        if state == 16:
                            state = 29 if x["col_last"] < -0.20762676 else 30
                            if state == 29:
                                return 0.0153533937
                            if state == 30:
                                state = (
                                    53
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.135199964)
                                    else 54
                                )
                                if state == 53:
                                    return 0.138389796
                                if state == 54:
                                    state = 87 if x["col_det"] < -0.225799084 else 88
                                    if state == 87:
                                        state = (
                                            121
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.979750037)
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                167
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.70191717)
                                                else 168
                                            )
                                            if state == 167:
                                                return 0.0958894789
                                            if state == 168:
                                                return -0.12482316
                                        if state == 122:
                                            return 0.042661123
                                    if state == 88:
                                        state = (
                                            123
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.87650001)
                                            else 124
                                        )
                                        if state == 123:
                                            return 0.0897678062
                                        if state == 124:
                                            state = (
                                                171
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.78888106)
                                                else 172
                                            )
                                            if state == 171:
                                                return -0.363698035
                                            if state == 172:
                                                state = (
                                                    221
                                                    if x["maggaia_med"] < 17.0152416
                                                    else 222
                                                )
                                                if state == 221:
                                                    state = (
                                                        279
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.670238078)
                                                        else 280
                                                    )
                                                    if state == 279:
                                                        return -0.114759363
                                                    if state == 280:
                                                        return 0.224503577
                                                if state == 222:
                                                    return -0.235517666
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.982249975)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.8391037)
                            else 18
                        )
                        if state == 17:
                            return -0.269366175
                        if state == 18:
                            state = 31 if x["col_last"] < 0.154932976 else 32
                            if state == 31:
                                return 0.139823496
                            if state == 32:
                                state = (
                                    57
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 4.31920624)
                                    else 58
                                )
                                if state == 57:
                                    state = 91 if x["col_det"] < -0.166069031 else 92
                                    if state == 91:
                                        state = (
                                            125
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.980749965)
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                173
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.09642887)
                                                else 174
                                            )
                                            if state == 173:
                                                return -0.295735896
                                            if state == 174:
                                                return 0.0721309111
                                        if state == 126:
                                            state = (
                                                175
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.53285003)
                                                else 176
                                            )
                                            if state == 175:
                                                return -0.106460333
                                            if state == 176:
                                                return 0.114749752
                                    if state == 92:
                                        state = (
                                            127
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.966500044)
                                            else 128
                                        )
                                        if state == 127:
                                            state = (
                                                177
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.349426508)
                                                else 178
                                            )
                                            if state == 177:
                                                return -0.0373960398
                                            if state == 178:
                                                state = (
                                                    227
                                                    if x["maggaia_med"] < 17.1332321
                                                    else 228
                                                )
                                                if state == 227:
                                                    return 0.0281838849
                                                if state == 228:
                                                    return -0.203357324
                                        if state == 128:
                                            state = (
                                                179
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.731927872)
                                                else 180
                                            )
                                            if state == 179:
                                                state = (
                                                    229
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 19.6511898)
                                                    else 230
                                                )
                                                if state == 229:
                                                    state = (
                                                        283
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.778928518)
                                                        else 284
                                                    )
                                                    if state == 283:
                                                        state = (
                                                            327
                                                            if x["col_last"]
                                                            < 0.256591797
                                                            else 328
                                                        )
                                                        if state == 327:
                                                            return -0.00719348527
                                                        if state == 328:
                                                            return 0.225576282
                                                    if state == 284:
                                                        return 0.0145078776
                                                if state == 230:
                                                    return -0.140636384
                                            if state == 180:
                                                state = (
                                                    231
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 14.4461384)
                                                    else 232
                                                )
                                                if state == 231:
                                                    return -0.241533786
                                                if state == 232:
                                                    state = (
                                                        285
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.564643025)
                                                        else 286
                                                    )
                                                    if state == 285:
                                                        return 0.277830631
                                                    if state == 286:
                                                        state = (
                                                            331
                                                            if x["col_last"]
                                                            < 0.278614998
                                                            else 332
                                                        )
                                                        if state == 331:
                                                            return 0.055062104
                                                        if state == 332:
                                                            return -0.0763656124
                                if state == 58:
                                    state = (
                                        93
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.301250458)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            129
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.97724998)
                                            else 130
                                        )
                                        if state == 129:
                                            return -0.214374945
                                        if state == 130:
                                            return 0.0247828756
                                    if state == 94:
                                        state = (
                                            131
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.980749965)
                                            else 132
                                        )
                                        if state == 131:
                                            return 0.257952183
                                        if state == 132:
                                            return -0.0526019819
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.2080498)
                            else 20
                        )
                        if state == 19:
                            state = 33 if x["col_last"] < 0.491827965 else 34
                            if state == 33:
                                return -0.0828169733
                            if state == 34:
                                state = (
                                    61
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.32486308)
                                    else 62
                                )
                                if state == 61:
                                    return -0.0718476996
                                if state == 62:
                                    return 0.105480656
                        if state == 20:
                            state = 35 if x["col_last"] < 0.158889294 else 36
                            if state == 35:
                                return -0.00744247623
                            if state == 36:
                                state = (
                                    65
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 2.82327676)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        95
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.460550308)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            133
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.985249996)
                                            else 134
                                        )
                                        if state == 133:
                                            state = (
                                                183
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.16763252)
                                                else 184
                                            )
                                            if state == 183:
                                                return 0.016500961
                                            if state == 184:
                                                state = (
                                                    233
                                                    if x["maggaia_med"] < 17.0951042
                                                    else 234
                                                )
                                                if state == 233:
                                                    state = (
                                                        287
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.636785746)
                                                        else 288
                                                    )
                                                    if state == 287:
                                                        return -0.105192646
                                                    if state == 288:
                                                        return 0.118053406
                                                if state == 234:
                                                    return 0.315407842
                                        if state == 134:
                                            return -0.0665197372
                                    if state == 96:
                                        state = (
                                            135
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.984250009)
                                            else 136
                                        )
                                        if state == 135:
                                            return 0.0562645644
                                        if state == 136:
                                            return -0.137328595
                                if state == 66:
                                    state = (
                                        97
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.022649765)
                                        else 98
                                    )
                                    if state == 97:
                                        state = (
                                            137
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982749999)
                                            else 138
                                        )
                                        if state == 137:
                                            return 0.12422616
                                        if state == 138:
                                            state = (
                                                185
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.60762239)
                                                else 186
                                            )
                                            if state == 185:
                                                return 0.111056916
                                            if state == 186:
                                                state = (
                                                    235
                                                    if x["maggaia_med"] < 17.5840816
                                                    else 236
                                                )
                                                if state == 235:
                                                    return -0.174111828
                                                if state == 236:
                                                    return 0.0801832974
                                    if state == 98:
                                        return -0.0691524968
            if state == 2:
                state = (
                    5 if np.isnan(x["col_last"]) or (x["col_last"] < 0.292408943) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.982249975)
                        else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4853001)
                            else 22
                        )
                        if state == 21:
                            state = 37 if x["col_last"] < -0.137669563 else 38
                            if state == 37:
                                state = (
                                    67
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.822583795)
                                    else 68
                                )
                                if state == 67:
                                    return 0.0508091152
                                if state == 68:
                                    return -0.122707918
                            if state == 38:
                                state = (
                                    69
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.586440921)
                                    else 70
                                )
                                if state == 69:
                                    state = 101 if x["col_det"] < 0.117350578 else 102
                                    if state == 101:
                                        return 0.0633875802
                                    if state == 102:
                                        state = (
                                            139
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.940500021)
                                            else 140
                                        )
                                        if state == 139:
                                            return 0.0756529868
                                        if state == 140:
                                            return -0.165231898
                                if state == 70:
                                    state = 103 if x["col_det"] < -0.344749451 else 104
                                    if state == 103:
                                        return -0.180024579
                                    if state == 104:
                                        state = (
                                            141
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.82675004)
                                            else 142
                                        )
                                        if state == 141:
                                            return -0.141037166
                                        if state == 142:
                                            state = (
                                                187
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.767082512)
                                                else 188
                                            )
                                            if state == 187:
                                                return 0.301869571
                                            if state == 188:
                                                state = (
                                                    237
                                                    if x["maggaia_med"] < 18.0397949
                                                    else 238
                                                )
                                                if state == 237:
                                                    return 0.228638157
                                                if state == 238:
                                                    state = (
                                                        295
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.561428785)
                                                        else 296
                                                    )
                                                    if state == 295:
                                                        state = (
                                                            337
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.0725989342
                                                            )
                                                            else 338
                                                        )
                                                        if state == 337:
                                                            return 0.197467566
                                                        if state == 338:
                                                            return -0.00428394554
                                                    if state == 296:
                                                        state = (
                                                            339
                                                            if x["col_last"]
                                                            < -0.0609874725
                                                            else 340
                                                        )
                                                        if state == 339:
                                                            return 0.142923787
                                                        if state == 340:
                                                            return -0.0529488623
                        if state == 22:
                            state = (
                                39
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < -0.0479059219)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    71
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 2.12909985)
                                    else 72
                                )
                                if state == 71:
                                    state = (
                                        105
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.145400047)
                                        else 106
                                    )
                                    if state == 105:
                                        state = (
                                            143
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.981750011)
                                            else 144
                                        )
                                        if state == 143:
                                            state = (
                                                189
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.10328555)
                                                else 190
                                            )
                                            if state == 189:
                                                state = (
                                                    239
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 17.2296543)
                                                    else 240
                                                )
                                                if state == 239:
                                                    return -0.118948936
                                                if state == 240:
                                                    return 0.0527801514
                                            if state == 190:
                                                state = (
                                                    241
                                                    if x["maggaia_med"] < 17.3445168
                                                    else 242
                                                )
                                                if state == 241:
                                                    state = (
                                                        299
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.726071358)
                                                        else 300
                                                    )
                                                    if state == 299:
                                                        return -0.0116438922
                                                    if state == 300:
                                                        return 0.216753095
                                                if state == 242:
                                                    state = (
                                                        301
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.892499983)
                                                        else 302
                                                    )
                                                    if state == 301:
                                                        return -0.304691344
                                                    if state == 302:
                                                        return 0.0995110497
                                        if state == 144:
                                            state = (
                                                191
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.03442192)
                                                else 192
                                            )
                                            if state == 191:
                                                return -0.0915805399
                                            if state == 192:
                                                return 0.254066378
                                    if state == 106:
                                        return -0.268074244
                                if state == 72:
                                    state = (
                                        107 if x["col_det"] < -0.000249862671 else 108
                                    )
                                    if state == 107:
                                        return -0.190315917
                                    if state == 108:
                                        state = (
                                            147
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.980749965)
                                            else 148
                                        )
                                        if state == 147:
                                            state = (
                                                193
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 2.94492912)
                                                else 194
                                            )
                                            if state == 193:
                                                state = (
                                                    245
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 19.3661919)
                                                    else 246
                                                )
                                                if state == 245:
                                                    state = (
                                                        303
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.698571444)
                                                        else 304
                                                    )
                                                    if state == 303:
                                                        return 0.339269102
                                                    if state == 304:
                                                        return 0.00332700391
                                                if state == 246:
                                                    return -0.0186712183
                                            if state == 194:
                                                state = (
                                                    247
                                                    if x["maggaia_med"] < 18.6519127
                                                    else 248
                                                )
                                                if state == 247:
                                                    return -0.199836791
                                                if state == 248:
                                                    state = (
                                                        305
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.795356929)
                                                        else 306
                                                    )
                                                    if state == 305:
                                                        return 0.132750854
                                                    if state == 306:
                                                        return -0.113138221
                                        if state == 148:
                                            state = (
                                                195
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.13299227)
                                                else 196
                                            )
                                            if state == 195:
                                                return 0.211034223
                                            if state == 196:
                                                state = (
                                                    249
                                                    if x["maggaia_med"] < 15.9373856
                                                    else 250
                                                )
                                                if state == 249:
                                                    return 0.00897330791
                                                if state == 250:
                                                    state = (
                                                        307
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.481190324)
                                                        else 308
                                                    )
                                                    if state == 307:
                                                        return 0.0512601435
                                                    if state == 308:
                                                        return -0.295698553
                            if state == 40:
                                state = (
                                    73
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 11.8579254)
                                    else 74
                                )
                                if state == 73:
                                    return -0.203679264
                                if state == 74:
                                    return 0.138431013
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.33745)
                            else 24
                        )
                        if state == 23:
                            return 0.0492133833
                        if state == 24:
                            state = (
                                43
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.157406807)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    75
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.330715448)
                                    else 76
                                )
                                if state == 75:
                                    return 0.00790196657
                                if state == 76:
                                    return 0.303216726
                            if state == 44:
                                return 0.0319562294
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.919749975)
                        else 14
                    )
                    if state == 13:
                        return -0.158575967
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3462486)
                            else 26
                        )
                        if state == 25:
                            state = 45 if x["col_last"] < 0.683042526 else 46
                            if state == 45:
                                return -0.10313528
                            if state == 46:
                                return 0.0621807501
                        if state == 26:
                            state = 47 if x["col_last"] < 0.334629059 else 48
                            if state == 47:
                                state = (
                                    77
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 4.00925064)
                                    else 78
                                )
                                if state == 77:
                                    return 0.303933233
                                if state == 78:
                                    return -0.0869457871
                            if state == 48:
                                state = (
                                    79
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 3.12920713)
                                    else 80
                                )
                                if state == 79:
                                    state = 109 if x["col_det"] < 1.60949802 else 110
                                    if state == 109:
                                        return -0.0554059856
                                    if state == 110:
                                        state = (
                                            151
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.963250041)
                                            else 152
                                        )
                                        if state == 151:
                                            return 0.292223781
                                        if state == 152:
                                            state = (
                                                201
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.261674434)
                                                else 202
                                            )
                                            if state == 201:
                                                return -0.0830681622
                                            if state == 202:
                                                state = (
                                                    251
                                                    if x["maggaia_med"] < 18.8767624
                                                    else 252
                                                )
                                                if state == 251:
                                                    state = (
                                                        309
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.717619002)
                                                        else 310
                                                    )
                                                    if state == 309:
                                                        state = (
                                                            343
                                                            if x["col_last"]
                                                            < 0.717288494
                                                            else 344
                                                        )
                                                        if state == 343:
                                                            return 0.0351307839
                                                        if state == 344:
                                                            return -0.155443504
                                                    if state == 310:
                                                        return 0.118808188
                                                if state == 252:
                                                    return 0.224323407
                                if state == 80:
                                    state = 111 if x["col_det"] < 0.291193008 else 112
                                    if state == 111:
                                        return 0.107790895
                                    if state == 112:
                                        state = (
                                            153
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.98150003)
                                            else 154
                                        )
                                        if state == 153:
                                            return -0.14645493
                                        if state == 154:
                                            return 0.0610792041
    elif num_booster == 29:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 19.0851231) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.4975681) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.99402761)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.2540016)
                            else 16
                        )
                        if state == 15:
                            return -0.160379156
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.692857087)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    39
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.299119473)
                                    else 40
                                )
                                if state == 39:
                                    state = 67 if x["col_det"] < -0.230606556 else 68
                                    if state == 67:
                                        return 0.00634383596
                                    if state == 68:
                                        state = (
                                            113
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.2087498)
                                            else 114
                                        )
                                        if state == 113:
                                            state = (
                                                169
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 28.5089798)
                                                else 170
                                            )
                                            if state == 169:
                                                state = (
                                                    247
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0360127017)
                                                    else 248
                                                )
                                                if state == 247:
                                                    return -0.0586066879
                                                if state == 248:
                                                    state = (
                                                        325
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.1603794)
                                                        else 326
                                                    )
                                                    if state == 325:
                                                        return 0.258002907
                                                    if state == 326:
                                                        return -0.0252704117
                                            if state == 170:
                                                state = (
                                                    249
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.97889471)
                                                    else 250
                                                )
                                                if state == 249:
                                                    return 0.16782172
                                                if state == 250:
                                                    return -0.141941011
                                        if state == 114:
                                            return 0.287253618
                                if state == 40:
                                    return -0.071339108
                            if state == 26:
                                state = (
                                    41
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.285926342)
                                    else 42
                                )
                                if state == 41:
                                    state = (
                                        69
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.570916176)
                                        else 70
                                    )
                                    if state == 69:
                                        state = (
                                            115
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.2753773)
                                            else 116
                                        )
                                        if state == 115:
                                            state = (
                                                173
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 42.949791)
                                                else 174
                                            )
                                            if state == 173:
                                                state = (
                                                    251
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0427083485)
                                                    else 252
                                                )
                                                if state == 251:
                                                    return -0.0298608169
                                                if state == 252:
                                                    return 0.230399892
                                            if state == 174:
                                                return -0.0719284415
                                        if state == 116:
                                            state = (
                                                175
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 12.4887323)
                                                else 176
                                            )
                                            if state == 175:
                                                return 0.0457900651
                                            if state == 176:
                                                state = (
                                                    253
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.02148151)
                                                    else 254
                                                )
                                                if state == 253:
                                                    return -0.216290012
                                                if state == 254:
                                                    return 0.140596852
                                    if state == 70:
                                        return -0.0755641311
                                if state == 42:
                                    return 0.200254142
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.5304985)
                            else 18
                        )
                        if state == 17:
                            state = (
                                27
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.752857208)
                                else 28
                            )
                            if state == 27:
                                state = 43 if x["col_det"] < -0.209820747 else 44
                                if state == 43:
                                    return 0.0676406398
                                if state == 44:
                                    state = (
                                        73
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.138638973)
                                        else 74
                                    )
                                    if state == 73:
                                        state = (
                                            119
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 17.8767357)
                                            else 120
                                        )
                                        if state == 119:
                                            return -0.0314082913
                                        if state == 120:
                                            return -0.248870894
                                    if state == 74:
                                        state = (
                                            121
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 17.1519279)
                                            else 122
                                        )
                                        if state == 121:
                                            return 0.111536004
                                        if state == 122:
                                            state = (
                                                179
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 5.99787045)
                                                else 180
                                            )
                                            if state == 179:
                                                return -0.226442397
                                            if state == 180:
                                                return 0.0362559184
                            if state == 28:
                                state = (
                                    45
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.232652664)
                                    else 46
                                )
                                if state == 45:
                                    state = 75 if x["col_det"] < 0.0152244568 else 76
                                    if state == 75:
                                        return -0.152262047
                                    if state == 76:
                                        state = (
                                            123
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.0760727)
                                            else 124
                                        )
                                        if state == 123:
                                            state = (
                                                181
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 14.4510126)
                                                else 182
                                            )
                                            if state == 181:
                                                return 0.00994999614
                                            if state == 182:
                                                return -0.154596433
                                        if state == 124:
                                            return 0.193323448
                                if state == 46:
                                    return -0.171965554
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.626904964)
                                else 30
                            )
                            if state == 29:
                                return 0.221175998
                            if state == 30:
                                state = (
                                    49
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.175686836)
                                    else 50
                                )
                                if state == 49:
                                    state = 79 if x["col_det"] < 0.000001 else 80
                                    if state == 79:
                                        return 0.153979421
                                    if state == 80:
                                        state = (
                                            125
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.3060188)
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                185
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 11.0074129)
                                                else 186
                                            )
                                            if state == 185:
                                                return -0.0243442543
                                            if state == 186:
                                                state = (
                                                    257
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.98141766)
                                                    else 258
                                                )
                                                if state == 257:
                                                    return 0.216499805
                                                if state == 258:
                                                    return -0.0389121063
                                        if state == 126:
                                            state = (
                                                187
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 15.9178762)
                                                else 188
                                            )
                                            if state == 187:
                                                return -0.127160788
                                            if state == 188:
                                                state = (
                                                    261
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.97634888)
                                                    else 262
                                                )
                                                if state == 261:
                                                    return 0.136347562
                                                if state == 262:
                                                    return -0.0819442123
                                if state == 50:
                                    state = 81 if x["col_det"] < 0.112420723 else 82
                                    if state == 81:
                                        state = (
                                            127
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.0873184)
                                            else 128
                                        )
                                        if state == 127:
                                            return 0.0978154466
                                        if state == 128:
                                            return -0.200645924
                                    if state == 82:
                                        state = (
                                            129
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.0295601)
                                            else 130
                                        )
                                        if state == 129:
                                            return 0.191079974
                                        if state == 130:
                                            return -0.0424233042
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.9644618)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.40275)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.692261815)
                                else 32
                            )
                            if state == 31:
                                state = 51 if x["col_det"] < 0.574210167 else 52
                                if state == 51:
                                    state = 83 if x["col_det"] < -0.0225172043 else 84
                                    if state == 83:
                                        return 0.114546426
                                    if state == 84:
                                        state = (
                                            131
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.3901939)
                                            else 132
                                        )
                                        if state == 131:
                                            state = (
                                                191
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 26.9848843)
                                                else 192
                                            )
                                            if state == 191:
                                                state = (
                                                    263
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.91845489)
                                                    else 264
                                                )
                                                if state == 263:
                                                    return 0.104828656
                                                if state == 264:
                                                    return -0.188721657
                                            if state == 192:
                                                state = (
                                                    265
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.94679976)
                                                    else 266
                                                )
                                                if state == 265:
                                                    return -0.00772591401
                                                if state == 266:
                                                    return 0.266995668
                                        if state == 132:
                                            return -0.120239139
                                if state == 52:
                                    return -0.283074528
                            if state == 32:
                                state = 53 if x["col_det"] < 0.0735651702 else 54
                                if state == 53:
                                    state = 85 if x["col_det"] < -0.0312614441 else 86
                                    if state == 85:
                                        state = (
                                            133
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.5088615)
                                            else 134
                                        )
                                        if state == 133:
                                            state = (
                                                195
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 19.4931068)
                                                else 196
                                            )
                                            if state == 195:
                                                return 0.115736321
                                            if state == 196:
                                                return -0.0928933844
                                        if state == 134:
                                            return 0.138702288
                                    if state == 86:
                                        state = (
                                            135
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.6183701)
                                            else 136
                                        )
                                        if state == 135:
                                            return 0.130076572
                                        if state == 136:
                                            state = (
                                                197
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 9.06896973)
                                                else 198
                                            )
                                            if state == 197:
                                                return 0.0205113124
                                            if state == 198:
                                                return -0.235051483
                                if state == 54:
                                    state = 87 if x["col_det"] < 0.161623955 else 88
                                    if state == 87:
                                        return 0.263213754
                                    if state == 88:
                                        state = (
                                            137
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.7393742)
                                            else 138
                                        )
                                        if state == 137:
                                            state = (
                                                199
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 39.8787994)
                                                else 200
                                            )
                                            if state == 199:
                                                state = (
                                                    267
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.10508108)
                                                    else 268
                                                )
                                                if state == 267:
                                                    state = (
                                                        331
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.8932495)
                                                        else 332
                                                    )
                                                    if state == 331:
                                                        state = (
                                                            391
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 22.0540047)
                                                            else 392
                                                        )
                                                        if state == 391:
                                                            return 0.116338752
                                                        if state == 392:
                                                            return -0.176292896
                                                    if state == 332:
                                                        state = (
                                                            393
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 11.0147514)
                                                            else 394
                                                        )
                                                        if state == 393:
                                                            return -0.0857536942
                                                        if state == 394:
                                                            return 0.196108967
                                                if state == 268:
                                                    return -0.16162166
                                            if state == 200:
                                                return -0.158689007
                                        if state == 138:
                                            state = (
                                                201
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 54.9239655)
                                                else 202
                                            )
                                            if state == 201:
                                                state = (
                                                    269
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.88876152)
                                                    else 270
                                                )
                                                if state == 269:
                                                    return -0.11832235
                                                if state == 270:
                                                    return 0.0777513608
                                            if state == 202:
                                                return -0.139461651
                        if state == 20:
                            state = (
                                33
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.710000098)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    55
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.279000282)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        89
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.108854294)
                                        else 90
                                    )
                                    if state == 89:
                                        state = (
                                            139
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.6776772)
                                            else 140
                                        )
                                        if state == 139:
                                            state = (
                                                203
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 25.9778023)
                                                else 204
                                            )
                                            if state == 203:
                                                state = (
                                                    273
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0856249481)
                                                    else 274
                                                )
                                                if state == 273:
                                                    state = (
                                                        335
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9405003)
                                                        else 336
                                                    )
                                                    if state == 335:
                                                        state = (
                                                            395
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 14.4780445)
                                                            else 396
                                                        )
                                                        if state == 395:
                                                            return 0.13935113
                                                        if state == 396:
                                                            return -0.162284374
                                                    if state == 336:
                                                        state = (
                                                            397
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 13.0088825)
                                                            else 398
                                                        )
                                                        if state == 397:
                                                            return -0.268469602
                                                        if state == 398:
                                                            return -0.0777481124
                                                if state == 274:
                                                    state = (
                                                        337
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0090065)
                                                        else 338
                                                    )
                                                    if state == 337:
                                                        return 0.188073918
                                                    if state == 338:
                                                        state = (
                                                            401
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 14.4581537)
                                                            else 402
                                                        )
                                                        if state == 401:
                                                            return 0.168198094
                                                        if state == 402:
                                                            return -0.000210275248
                                            if state == 204:
                                                state = (
                                                    275
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0856249481)
                                                    else 276
                                                )
                                                if state == 275:
                                                    state = (
                                                        339
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0255566)
                                                        else 340
                                                    )
                                                    if state == 339:
                                                        return 0.0815893561
                                                    if state == 340:
                                                        return -0.125488758
                                                if state == 276:
                                                    state = (
                                                        341
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.6039505)
                                                        else 342
                                                    )
                                                    if state == 341:
                                                        state = (
                                                            405
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 86.2431641)
                                                            else 406
                                                        )
                                                        if state == 405:
                                                            return 0.200591579
                                                        if state == 406:
                                                            return -0.042732887
                                                    if state == 342:
                                                        return 0.0547657646
                                        if state == 140:
                                            state = (
                                                205
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 40.8439789)
                                                else 206
                                            )
                                            if state == 205:
                                                state = (
                                                    277
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.03966999)
                                                    else 278
                                                )
                                                if state == 277:
                                                    return -0.207135156
                                                if state == 278:
                                                    state = (
                                                        345
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.1923275)
                                                        else 346
                                                    )
                                                    if state == 345:
                                                        return -0.097779803
                                                    if state == 346:
                                                        return 0.14695169
                                            if state == 206:
                                                state = (
                                                    279
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.06831598)
                                                    else 280
                                                )
                                                if state == 279:
                                                    state = (
                                                        347
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.1419601)
                                                        else 348
                                                    )
                                                    if state == 347:
                                                        return 0.0959228277
                                                    if state == 348:
                                                        return 0.252299309
                                                if state == 280:
                                                    return -0.0698084235
                                    if state == 90:
                                        state = (
                                            141
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.0035019)
                                            else 142
                                        )
                                        if state == 141:
                                            return 0.212970003
                                        if state == 142:
                                            state = (
                                                207
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 34.9396744)
                                                else 208
                                            )
                                            if state == 207:
                                                return -0.123288423
                                            if state == 208:
                                                return 0.158897668
                                if state == 56:
                                    state = 91 if x["col_det"] < 0.357438087 else 92
                                    if state == 91:
                                        return -0.266507506
                                    if state == 92:
                                        state = (
                                            143
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.8769035)
                                            else 144
                                        )
                                        if state == 143:
                                            return 0.118538387
                                        if state == 144:
                                            state = (
                                                209
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 39.4283905)
                                                else 210
                                            )
                                            if state == 209:
                                                state = (
                                                    283
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.91499996)
                                                    else 284
                                                )
                                                if state == 283:
                                                    return -0.206064552
                                                if state == 284:
                                                    return 0.00939689111
                                            if state == 210:
                                                return 0.153362066
                            if state == 34:
                                state = 57 if x["col_det"] < -0.127769947 else 58
                                if state == 57:
                                    state = 93 if x["col_det"] < -0.180157661 else 94
                                    if state == 93:
                                        state = (
                                            145
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.0017929)
                                            else 146
                                        )
                                        if state == 145:
                                            state = (
                                                211
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 13.050209)
                                                else 212
                                            )
                                            if state == 211:
                                                return -0.0328347459
                                            if state == 212:
                                                return 0.166112244
                                        if state == 146:
                                            state = (
                                                213
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 31.5178127)
                                                else 214
                                            )
                                            if state == 213:
                                                state = (
                                                    287
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 1.4524132)
                                                    else 288
                                                )
                                                if state == 287:
                                                    return 0.117100298
                                                if state == 288:
                                                    return -0.233903497
                                            if state == 214:
                                                return 0.111338504
                                    if state == 94:
                                        return 0.294906557
                                if state == 58:
                                    state = 95 if x["col_det"] < 0.0970244408 else 96
                                    if state == 95:
                                        state = (
                                            147
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.7466431)
                                            else 148
                                        )
                                        if state == 147:
                                            return 0.110679291
                                        if state == 148:
                                            state = (
                                                215
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 37.4590759)
                                                else 216
                                            )
                                            if state == 215:
                                                return -0.264351964
                                            if state == 216:
                                                return 0.0975429937
                                    if state == 96:
                                        state = (
                                            149
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.0986462)
                                            else 150
                                        )
                                        if state == 149:
                                            state = (
                                                217
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 16.0760193)
                                                else 218
                                            )
                                            if state == 217:
                                                state = (
                                                    291
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.00023746)
                                                    else 292
                                                )
                                                if state == 291:
                                                    state = (
                                                        353
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0484524)
                                                        else 354
                                                    )
                                                    if state == 353:
                                                        state = (
                                                            413
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 15.9808044)
                                                            else 414
                                                        )
                                                        if state == 413:
                                                            return -0.034938626
                                                        if state == 414:
                                                            return -0.225474894
                                                    if state == 354:
                                                        return 0.0775845274
                                                if state == 292:
                                                    return 0.177511767
                                            if state == 218:
                                                state = (
                                                    293
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 1.94153357)
                                                    else 294
                                                )
                                                if state == 293:
                                                    state = (
                                                        355
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0275688)
                                                        else 356
                                                    )
                                                    if state == 355:
                                                        state = (
                                                            415
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 30.9519043)
                                                            else 416
                                                        )
                                                        if state == 415:
                                                            return 0.0984821841
                                                        if state == 416:
                                                            return -0.141128629
                                                    if state == 356:
                                                        return 0.0655097291
                                                if state == 294:
                                                    state = (
                                                        357
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.8840637)
                                                        else 358
                                                    )
                                                    if state == 357:
                                                        state = (
                                                            417
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 21.0006886)
                                                            else 418
                                                        )
                                                        if state == 417:
                                                            return -0.0678422153
                                                        if state == 418:
                                                            return 0.126328692
                                                    if state == 358:
                                                        return 0.182097986
                                        if state == 150:
                                            state = (
                                                219
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 7.95342588)
                                                else 220
                                            )
                                            if state == 219:
                                                return 0.161639616
                                            if state == 220:
                                                state = (
                                                    295
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.95501757)
                                                    else 296
                                                )
                                                if state == 295:
                                                    state = (
                                                        359
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 20.0484428)
                                                        else 360
                                                    )
                                                    if state == 359:
                                                        state = (
                                                            419
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 13.1319733)
                                                            else 420
                                                        )
                                                        if state == 419:
                                                            return -0.23543103
                                                        if state == 420:
                                                            return -0.0804566666
                                                    if state == 360:
                                                        state = (
                                                            421
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 26.0314713)
                                                            else 422
                                                        )
                                                        if state == 421:
                                                            return -0.109097205
                                                        if state == 422:
                                                            return 0.110518336
                                                if state == 296:
                                                    return 0.238513052
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.675499)
                            else 22
                        )
                        if state == 21:
                            state = (
                                35
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.81285727)
                                else 36
                            )
                            if state == 35:
                                state = 59 if x["col_det"] < -0.330803871 else 60
                                if state == 59:
                                    return -0.293222129
                                if state == 60:
                                    state = 97 if x["col_det"] < -0.288079262 else 98
                                    if state == 97:
                                        return 0.301684439
                                    if state == 98:
                                        state = (
                                            151
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.6581001)
                                            else 152
                                        )
                                        if state == 151:
                                            state = (
                                                221
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 25.9113369)
                                                else 222
                                            )
                                            if state == 221:
                                                state = (
                                                    297
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.00067711)
                                                    else 298
                                                )
                                                if state == 297:
                                                    return -0.320098579
                                                if state == 298:
                                                    state = (
                                                        361
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0980701)
                                                        else 362
                                                    )
                                                    if state == 361:
                                                        state = (
                                                            423
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 19.9828949)
                                                            else 424
                                                        )
                                                        if state == 423:
                                                            return 0.0757795349
                                                        if state == 424:
                                                            return -0.182466194
                                                    if state == 362:
                                                        state = (
                                                            425
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 17.9480495)
                                                            else 426
                                                        )
                                                        if state == 425:
                                                            return -0.166195735
                                                        if state == 426:
                                                            return -0.0290279705
                                            if state == 222:
                                                state = (
                                                    299
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.09169579)
                                                    else 300
                                                )
                                                if state == 299:
                                                    state = (
                                                        363
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1752224)
                                                        else 364
                                                    )
                                                    if state == 363:
                                                        state = (
                                                            427
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 44.8210373)
                                                            else 428
                                                        )
                                                        if state == 427:
                                                            return 0.185916871
                                                        if state == 428:
                                                            return -0.0246283747
                                                    if state == 364:
                                                        state = (
                                                            429
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 30.9575634)
                                                            else 430
                                                        )
                                                        if state == 429:
                                                            return 0.0325950682
                                                        if state == 430:
                                                            return -0.150760666
                                                if state == 300:
                                                    return -0.244062796
                                        if state == 152:
                                            state = (
                                                223
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 64.9031219)
                                                else 224
                                            )
                                            if state == 223:
                                                state = (
                                                    301
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 7.87876701)
                                                    else 302
                                                )
                                                if state == 301:
                                                    state = (
                                                        365
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.7534065)
                                                        else 366
                                                    )
                                                    if state == 365:
                                                        return 0.0100718113
                                                    if state == 366:
                                                        return 0.13613309
                                                if state == 302:
                                                    state = (
                                                        367
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.9960747)
                                                        else 368
                                                    )
                                                    if state == 367:
                                                        state = (
                                                            435
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 27.0005379)
                                                            else 436
                                                        )
                                                        if state == 435:
                                                            return -0.0984421
                                                        if state == 436:
                                                            return 0.0765124187
                                                    if state == 368:
                                                        state = (
                                                            437
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 54.3472595)
                                                            else 438
                                                        )
                                                        if state == 437:
                                                            return -0.124609232
                                                        if state == 438:
                                                            return 0.105907321
                                            if state == 224:
                                                return -0.107198492
                            if state == 36:
                                state = 61 if x["col_det"] < -0.192783356 else 62
                                if state == 61:
                                    state = 99 if x["col_det"] < -0.488599777 else 100
                                    if state == 99:
                                        return 0.0997976214
                                    if state == 100:
                                        state = (
                                            153
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.8035374)
                                            else 154
                                        )
                                        if state == 153:
                                            return -0.0151588796
                                        if state == 154:
                                            state = (
                                                225
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 20.9903946)
                                                else 226
                                            )
                                            if state == 225:
                                                return -0.252654672
                                            if state == 226:
                                                return 0.00317059131
                                if state == 62:
                                    state = 101 if x["col_det"] < 0.292550087 else 102
                                    if state == 101:
                                        state = (
                                            155
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.5462265)
                                            else 156
                                        )
                                        if state == 155:
                                            return 0.252845913
                                        if state == 156:
                                            return 0.0477541499
                                    if state == 102:
                                        state = (
                                            157
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.8601761)
                                            else 158
                                        )
                                        if state == 157:
                                            state = (
                                                229
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 14.4859486)
                                                else 230
                                            )
                                            if state == 229:
                                                return -0.199143723
                                            if state == 230:
                                                return 0.0630470291
                                        if state == 158:
                                            state = (
                                                231
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 26.0022163)
                                                else 232
                                            )
                                            if state == 231:
                                                state = (
                                                    307
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.41596031)
                                                    else 308
                                                )
                                                if state == 307:
                                                    return 0.0524219833
                                                if state == 308:
                                                    return -0.179375887
                                            if state == 232:
                                                return 0.218845755
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.597499967)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    63
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.0348577499)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        103
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.0376234055)
                                        else 104
                                    )
                                    if state == 103:
                                        state = (
                                            159
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.7807159)
                                            else 160
                                        )
                                        if state == 159:
                                            return 0.192213193
                                        if state == 160:
                                            state = (
                                                235
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 51.9390564)
                                                else 236
                                            )
                                            if state == 235:
                                                state = (
                                                    311
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.87460041)
                                                    else 312
                                                )
                                                if state == 311:
                                                    return -0.300039113
                                                if state == 312:
                                                    state = (
                                                        375
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1566429)
                                                        else 376
                                                    )
                                                    if state == 375:
                                                        return 0.136327282
                                                    if state == 376:
                                                        state = (
                                                            447
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 32.9726372)
                                                            else 448
                                                        )
                                                        if state == 447:
                                                            return -0.141163379
                                                        if state == 448:
                                                            return 0.124220796
                                            if state == 236:
                                                state = (
                                                    313
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.93646431)
                                                    else 314
                                                )
                                                if state == 313:
                                                    return 0.138054222
                                                if state == 314:
                                                    return -0.111769669
                                    if state == 104:
                                        return 0.184550047
                                if state == 64:
                                    state = 105 if x["col_det"] < 0.173799515 else 106
                                    if state == 105:
                                        return -0.260591209
                                    if state == 106:
                                        state = (
                                            161
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.4373283)
                                            else 162
                                        )
                                        if state == 161:
                                            return -0.183524981
                                        if state == 162:
                                            return 0.0962131992
                            if state == 38:
                                state = 65 if x["col_det"] < -0.109480858 else 66
                                if state == 65:
                                    state = 107 if x["col_det"] < -0.265649796 else 108
                                    if state == 107:
                                        state = (
                                            163
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.0739231)
                                            else 164
                                        )
                                        if state == 163:
                                            return -0.171211869
                                        if state == 164:
                                            state = (
                                                237
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 22.0215263)
                                                else 238
                                            )
                                            if state == 237:
                                                state = (
                                                    315
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.00431061)
                                                    else 316
                                                )
                                                if state == 315:
                                                    return -0.114005141
                                                if state == 316:
                                                    return 0.0819801912
                                            if state == 238:
                                                return 0.112900265
                                    if state == 108:
                                        state = (
                                            165
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.2180843)
                                            else 166
                                        )
                                        if state == 165:
                                            state = (
                                                239
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 23.9383049)
                                                else 240
                                            )
                                            if state == 239:
                                                return 0.271285176
                                            if state == 240:
                                                state = (
                                                    317
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.90156269)
                                                    else 318
                                                )
                                                if state == 317:
                                                    return -0.0729208812
                                                if state == 318:
                                                    return 0.136745676
                                        if state == 166:
                                            state = (
                                                241
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 18.0262566)
                                                else 242
                                            )
                                            if state == 241:
                                                return -0.159426108
                                            if state == 242:
                                                state = (
                                                    319
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.90156269)
                                                    else 320
                                                )
                                                if state == 319:
                                                    state = (
                                                        379
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.6476326)
                                                        else 380
                                                    )
                                                    if state == 379:
                                                        return 0.0782949999
                                                    if state == 380:
                                                        return -0.115451463
                                                if state == 320:
                                                    return 0.146738514
                                if state == 66:
                                    state = 109 if x["col_det"] < -0.0663461685 else 110
                                    if state == 109:
                                        return -0.306867421
                                    if state == 110:
                                        state = (
                                            167
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.6539516)
                                            else 168
                                        )
                                        if state == 167:
                                            state = (
                                                243
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 19.0036697)
                                                else 244
                                            )
                                            if state == 243:
                                                return -0.318142623
                                            if state == 244:
                                                return -0.0327975415
                                        if state == 168:
                                            state = (
                                                245
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 23.0167542)
                                                else 246
                                            )
                                            if state == 245:
                                                state = (
                                                    321
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.0222683)
                                                    else 322
                                                )
                                                if state == 321:
                                                    state = (
                                                        381
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.6900196)
                                                        else 382
                                                    )
                                                    if state == 381:
                                                        return 0.0776022524
                                                    if state == 382:
                                                        return -0.287007362
                                                if state == 322:
                                                    state = (
                                                        383
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1807823)
                                                        else 384
                                                    )
                                                    if state == 383:
                                                        return 0.18719247
                                                    if state == 384:
                                                        return -0.0538693741
                                            if state == 246:
                                                state = (
                                                    323
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.94186878)
                                                    else 324
                                                )
                                                if state == 323:
                                                    state = (
                                                        385
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.5272675)
                                                        else 386
                                                    )
                                                    if state == 385:
                                                        return 0.0349038616
                                                    if state == 386:
                                                        state = (
                                                            453
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 46.4244995)
                                                            else 454
                                                        )
                                                        if state == 453:
                                                            return -0.368335634
                                                        if state == 454:
                                                            return -0.055008851
                                                if state == 324:
                                                    return 0.23297818
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.4475403) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 6.9973321)
                        else 12
                    )
                    if state == 11:
                        return -0.260273337
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.9305)
                            else 24
                        )
                        if state == 23:
                            return 0.0568844266
                        if state == 24:
                            return -0.169003829
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["t_predetect"])
                        or (x["t_predetect"] < 0.0204918496)
                        else 14
                    )
                    if state == 13:
                        return 0.254135281
                    if state == 14:
                        return -0.17468214
    elif num_booster == 30:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 0.109919474 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.984250009)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.962249994)
                        else 8
                    )
                    if state == 7:
                        return -0.0367729701
                    if state == 8:
                        state = (
                            11
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.8829002)
                            else 12
                        )
                        if state == 11:
                            return -0.243928626
                        if state == 12:
                            return 0.101221427
                if state == 4:
                    return 0.0854237825
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.859750032)
                    else 6
                )
                if state == 5:
                    return -0.230304882
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.981250048)
                        else 10
                    )
                    if state == 9:
                        state = (
                            13
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 19.1144104)
                            else 14
                        )
                        if state == 13:
                            state = 19 if x["mag_peak"] < 18.9933681 else 20
                            if state == 19:
                                state = (
                                    23
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.744999886)
                                    else 24
                                )
                                if state == 23:
                                    state = 31 if x["col_last"] < -0.0591103211 else 32
                                    if state == 31:
                                        return 0.193459779
                                    if state == 32:
                                        state = (
                                            47
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 15.962841)
                                            else 48
                                        )
                                        if state == 47:
                                            state = (
                                                77 if x["mag_peak"] < 18.5068817 else 78
                                            )
                                            if state == 77:
                                                return -0.0286906231
                                            if state == 78:
                                                return 0.201198965
                                        if state == 48:
                                            state = (
                                                79 if x["mag_peak"] < 18.263546 else 80
                                            )
                                            if state == 79:
                                                state = (
                                                    119
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.729285717)
                                                    else 120
                                                )
                                                if state == 119:
                                                    state = (
                                                        163
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.145505756)
                                                        else 164
                                                    )
                                                    if state == 163:
                                                        state = (
                                                            207
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.948500037
                                                            )
                                                            else 208
                                                        )
                                                        if state == 207:
                                                            return -0.0504384711
                                                        if state == 208:
                                                            return 0.194285661
                                                    if state == 164:
                                                        state = (
                                                            209
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.972499967
                                                            )
                                                            else 210
                                                        )
                                                        if state == 209:
                                                            return 0.00890756026
                                                        if state == 210:
                                                            return -0.190713122
                                                if state == 120:
                                                    state = (
                                                        165
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"] < -0.151770592
                                                        )
                                                        else 166
                                                    )
                                                    if state == 165:
                                                        return -0.138838306
                                                    if state == 166:
                                                        return -0.00450304057
                                            if state == 80:
                                                state = (
                                                    121
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.728452444)
                                                    else 122
                                                )
                                                if state == 121:
                                                    state = (
                                                        167
                                                        if x["col_peak"] < 1.03013039
                                                        else 168
                                                    )
                                                    if state == 167:
                                                        state = (
                                                            211
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.979750037
                                                            )
                                                            else 212
                                                        )
                                                        if state == 211:
                                                            return -0.0428881049
                                                        if state == 212:
                                                            return -0.109211549
                                                    if state == 168:
                                                        return 0.100870296
                                                if state == 122:
                                                    state = (
                                                        169
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.22144413)
                                                        else 170
                                                    )
                                                    if state == 169:
                                                        state = (
                                                            215
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.939499974
                                                            )
                                                            else 216
                                                        )
                                                        if state == 215:
                                                            return 0.0565092005
                                                        if state == 216:
                                                            return -0.098481901
                                                    if state == 170:
                                                        return -0.227822974
                                if state == 24:
                                    state = 33 if x["col_last"] < 0.175702095 else 34
                                    if state == 33:
                                        state = (
                                            49
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 21.9677715)
                                            else 50
                                        )
                                        if state == 49:
                                            return -0.116846368
                                        if state == 50:
                                            state = (
                                                83 if x["mag_peak"] < 18.633049 else 84
                                            )
                                            if state == 83:
                                                return -0.141336501
                                            if state == 84:
                                                return 0.124020249
                                    if state == 34:
                                        state = (
                                            51
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 27.9504509)
                                            else 52
                                        )
                                        if state == 51:
                                            state = (
                                                85 if x["mag_peak"] < 18.8515854 else 86
                                            )
                                            if state == 85:
                                                return 0.200411633
                                            if state == 86:
                                                state = (
                                                    123
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.960714281)
                                                    else 124
                                                )
                                                if state == 123:
                                                    state = (
                                                        171
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"]
                                                            < -0.0791025162
                                                        )
                                                        else 172
                                                    )
                                                    if state == 171:
                                                        state = (
                                                            217
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.978249967
                                                            )
                                                            else 218
                                                        )
                                                        if state == 217:
                                                            return 0.084996134
                                                        if state == 218:
                                                            return -0.103342138
                                                    if state == 172:
                                                        return 0.151002765
                                                if state == 124:
                                                    return -0.151008651
                                        if state == 52:
                                            state = (
                                                87 if x["mag_peak"] < 18.7498741 else 88
                                            )
                                            if state == 87:
                                                state = (
                                                    125
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.90500015)
                                                    else 126
                                                )
                                                if state == 125:
                                                    state = (
                                                        173
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.433734894)
                                                        else 174
                                                    )
                                                    if state == 173:
                                                        return 0.168337524
                                                    if state == 174:
                                                        return -0.0921092704
                                                if state == 126:
                                                    state = (
                                                        175
                                                        if x["col_peak"] < 0.348198891
                                                        else 176
                                                    )
                                                    if state == 175:
                                                        return -0.152347833
                                                    if state == 176:
                                                        return 0.111444488
                                            if state == 88:
                                                state = (
                                                    127
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.803214192)
                                                    else 128
                                                )
                                                if state == 127:
                                                    return 0.0928467438
                                                if state == 128:
                                                    state = (
                                                        179
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"]
                                                            < -0.0701203346
                                                        )
                                                        else 180
                                                    )
                                                    if state == 179:
                                                        state = (
                                                            227
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.976500034
                                                            )
                                                            else 228
                                                        )
                                                        if state == 227:
                                                            return 0.0372149311
                                                        if state == 228:
                                                            return -0.252674401
                                                    if state == 180:
                                                        return 0.0280291028
                            if state == 20:
                                state = (
                                    25
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.573333442)
                                    else 26
                                )
                                if state == 25:
                                    state = (
                                        35
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < -0.0750179291)
                                        else 36
                                    )
                                    if state == 35:
                                        state = (
                                            53
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 10.0218172)
                                            else 54
                                        )
                                        if state == 53:
                                            return 0.131690219
                                        if state == 54:
                                            state = (
                                                89 if x["mag_peak"] < 19.0332069 else 90
                                            )
                                            if state == 89:
                                                return 0.0471439809
                                            if state == 90:
                                                state = (
                                                    129
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.533333302)
                                                    else 130
                                                )
                                                if state == 129:
                                                    return -0.175349936
                                                if state == 130:
                                                    return 0.0358505733
                                    if state == 36:
                                        state = (
                                            55
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 6.06008101)
                                            else 56
                                        )
                                        if state == 55:
                                            return 0.207526758
                                        if state == 56:
                                            return 0.0764932856
                                if state == 26:
                                    state = (
                                        37
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.386411667)
                                        else 38
                                    )
                                    if state == 37:
                                        state = (
                                            57
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 15.0027142)
                                            else 58
                                        )
                                        if state == 57:
                                            state = (
                                                91
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 19.0732231)
                                                else 92
                                            )
                                            if state == 91:
                                                state = (
                                                    131
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.747738123)
                                                    else 132
                                                )
                                                if state == 131:
                                                    return -0.0328519419
                                                if state == 132:
                                                    return 0.0453277826
                                            if state == 92:
                                                return 0.166925088
                                        if state == 58:
                                            state = (
                                                93
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 19.0326004)
                                                else 94
                                            )
                                            if state == 93:
                                                state = (
                                                    133
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.942857087)
                                                    else 134
                                                )
                                                if state == 133:
                                                    state = (
                                                        181
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.135022163)
                                                        else 182
                                                    )
                                                    if state == 181:
                                                        state = (
                                                            231
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.977500021
                                                            )
                                                            else 232
                                                        )
                                                        if state == 231:
                                                            return -0.212947026
                                                        if state == 232:
                                                            return -0.104579911
                                                    if state == 182:
                                                        return 0.00357736414
                                                if state == 134:
                                                    return 0.0859431922
                                            if state == 94:
                                                state = (
                                                    135
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.711666644)
                                                    else 136
                                                )
                                                if state == 135:
                                                    state = (
                                                        183
                                                        if x["col_peak"] < 0.255036354
                                                        else 184
                                                    )
                                                    if state == 183:
                                                        return 0.168213814
                                                    if state == 184:
                                                        return -0.0876734257
                                                if state == 136:
                                                    return -0.178463861
                                    if state == 38:
                                        state = (
                                            59
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 14.9799252)
                                            else 60
                                        )
                                        if state == 59:
                                            return 0.23316592
                                        if state == 60:
                                            state = (
                                                95 if x["mag_peak"] < 38.2224808 else 96
                                            )
                                            if state == 95:
                                                return -0.100945562
                                            if state == 96:
                                                state = (
                                                    137
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.923928738)
                                                    else 138
                                                )
                                                if state == 137:
                                                    return -0.0679913759
                                                if state == 138:
                                                    return 0.159201801
                        if state == 14:
                            return -0.286702633
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 19.0049686)
                            else 16
                        )
                        if state == 15:
                            state = 21 if x["mag_peak"] < 18.3418159 else 22
                            if state == 21:
                                state = (
                                    27
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.633095086)
                                    else 28
                                )
                                if state == 27:
                                    state = 39 if x["col_last"] < -0.0033493042 else 40
                                    if state == 39:
                                        return -0.0388685986
                                    if state == 40:
                                        state = (
                                            63
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 31.0059948)
                                            else 64
                                        )
                                        if state == 63:
                                            state = (
                                                97 if x["mag_peak"] < 16.4545383 else 98
                                            )
                                            if state == 97:
                                                return -0.0829814449
                                            if state == 98:
                                                state = (
                                                    139
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.589285731)
                                                    else 140
                                                )
                                                if state == 139:
                                                    state = (
                                                        185
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.128613472)
                                                        else 186
                                                    )
                                                    if state == 185:
                                                        return 0.174648002
                                                    if state == 186:
                                                        return -0.229309231
                                                if state == 140:
                                                    return 0.164701641
                                        if state == 64:
                                            return 0.190952942
                                if state == 28:
                                    state = (
                                        41
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.807132363)
                                        else 42
                                    )
                                    if state == 41:
                                        state = (
                                            65
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 18.8593979)
                                            else 66
                                        )
                                        if state == 65:
                                            state = (
                                                99 if x["mag_peak"] < 17.752285 else 100
                                            )
                                            if state == 99:
                                                return -0.264777035
                                            if state == 100:
                                                state = (
                                                    141
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.674166739)
                                                    else 142
                                                )
                                                if state == 141:
                                                    return -0.0858214647
                                                if state == 142:
                                                    state = (
                                                        187
                                                        if x["col_peak"] < 0.1513381
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        return 0.141631514
                                                    if state == 188:
                                                        return -0.0317480005
                                        if state == 66:
                                            state = (
                                                101
                                                if x["mag_peak"] < 18.1379395
                                                else 102
                                            )
                                            if state == 101:
                                                state = (
                                                    143
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.755714357)
                                                    else 144
                                                )
                                                if state == 143:
                                                    state = (
                                                        189
                                                        if x["col_peak"] < 0.084731102
                                                        else 190
                                                    )
                                                    if state == 189:
                                                        state = (
                                                            237
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.98300004
                                                            )
                                                            else 238
                                                        )
                                                        if state == 237:
                                                            return -0.140924841
                                                        if state == 238:
                                                            return 0.106583841
                                                    if state == 190:
                                                        state = (
                                                            239
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.982749999
                                                            )
                                                            else 240
                                                        )
                                                        if state == 239:
                                                            return 0.00884973351
                                                        if state == 240:
                                                            return 0.130084381
                                                if state == 144:
                                                    state = (
                                                        191
                                                        if x["col_peak"] < -0.287279606
                                                        else 192
                                                    )
                                                    if state == 191:
                                                        return -0.0829351693
                                                    if state == 192:
                                                        return 0.211661994
                                            if state == 102:
                                                return 0.214199513
                                    if state == 42:
                                        state = (
                                            67
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 55.9695816)
                                            else 68
                                        )
                                        if state == 67:
                                            return 0.184193075
                                        if state == 68:
                                            return -0.0400342382
                            if state == 22:
                                state = (
                                    29
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.94107151)
                                    else 30
                                )
                                if state == 29:
                                    state = (
                                        43
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.318917274)
                                        else 44
                                    )
                                    if state == 43:
                                        state = (
                                            69
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 10.1535301)
                                            else 70
                                        )
                                        if state == 69:
                                            state = (
                                                105
                                                if x["mag_peak"] < 18.6286507
                                                else 106
                                            )
                                            if state == 105:
                                                return -0.0150880916
                                            if state == 106:
                                                state = (
                                                    147
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.627619028)
                                                    else 148
                                                )
                                                if state == 147:
                                                    return 0.224492475
                                                if state == 148:
                                                    return 0.0633469597
                                        if state == 70:
                                            state = (
                                                107
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.6382427)
                                                else 108
                                            )
                                            if state == 107:
                                                state = (
                                                    149
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.6511904)
                                                    else 150
                                                )
                                                if state == 149:
                                                    state = (
                                                        195
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"] < -0.208757401
                                                        )
                                                        else 196
                                                    )
                                                    if state == 195:
                                                        return -0.0618666522
                                                    if state == 196:
                                                        return -0.196685731
                                                if state == 150:
                                                    state = (
                                                        197
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"]
                                                            < -0.0626482964
                                                        )
                                                        else 198
                                                    )
                                                    if state == 197:
                                                        return 0.00304878294
                                                    if state == 198:
                                                        return 0.138657108
                                            if state == 108:
                                                state = (
                                                    151
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.343333334)
                                                    else 152
                                                )
                                                if state == 151:
                                                    return -0.223083526
                                                if state == 152:
                                                    state = (
                                                        199
                                                        if np.isnan(x["col_peak"])
                                                        or (
                                                            x["col_peak"] < -0.177043915
                                                        )
                                                        else 200
                                                    )
                                                    if state == 199:
                                                        state = (
                                                            249
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.982749999
                                                            )
                                                            else 250
                                                        )
                                                        if state == 249:
                                                            return 0.0550098158
                                                        if state == 250:
                                                            return -0.0848336071
                                                    if state == 200:
                                                        return 0.239628673
                                    if state == 44:
                                        state = (
                                            71
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 25.9998093)
                                            else 72
                                        )
                                        if state == 71:
                                            state = (
                                                109
                                                if x["mag_peak"] < 18.4356365
                                                else 110
                                            )
                                            if state == 109:
                                                return -0.0775444433
                                            if state == 110:
                                                state = (
                                                    153
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.573333323)
                                                    else 154
                                                )
                                                if state == 153:
                                                    return -0.0508791916
                                                if state == 154:
                                                    state = (
                                                        201
                                                        if x["col_peak"] < 0.0344266891
                                                        else 202
                                                    )
                                                    if state == 201:
                                                        return 0.0202000905
                                                    if state == 202:
                                                        state = (
                                                            251
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.983749986
                                                            )
                                                            else 252
                                                        )
                                                        if state == 251:
                                                            return 0.317021072
                                                        if state == 252:
                                                            return 0.0159350168
                                        if state == 72:
                                            state = (
                                                111
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.3711624)
                                                else 112
                                            )
                                            if state == 111:
                                                return -0.105776608
                                            if state == 112:
                                                state = (
                                                    155
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.815000176)
                                                    else 156
                                                )
                                                if state == 155:
                                                    state = (
                                                        203
                                                        if x["col_peak"] < -0.072324276
                                                        else 204
                                                    )
                                                    if state == 203:
                                                        return 0.0698586479
                                                    if state == 204:
                                                        return -0.0702376068
                                                if state == 156:
                                                    return 0.178898707
                                if state == 30:
                                    state = 45 if x["col_last"] < 0.0939216614 else 46
                                    if state == 45:
                                        return 0.106988505
                                    if state == 46:
                                        state = (
                                            75
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 25.0205669)
                                            else 76
                                        )
                                        if state == 75:
                                            state = (
                                                113
                                                if x["mag_peak"] < 18.5753326
                                                else 114
                                            )
                                            if state == 113:
                                                return 0.0972814709
                                            if state == 114:
                                                state = (
                                                    157
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.96035713)
                                                    else 158
                                                )
                                                if state == 157:
                                                    state = (
                                                        205
                                                        if x["col_peak"] < 0.31923008
                                                        else 206
                                                    )
                                                    if state == 205:
                                                        return -0.258471102
                                                    if state == 206:
                                                        state = (
                                                            255
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.982249975
                                                            )
                                                            else 256
                                                        )
                                                        if state == 255:
                                                            return -0.183773518
                                                        if state == 256:
                                                            return 0.0470601879
                                                if state == 158:
                                                    return -0.0116131837
                                        if state == 76:
                                            state = (
                                                115
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.6368332)
                                                else 116
                                            )
                                            if state == 115:
                                                return 0.136704549
                                            if state == 116:
                                                state = (
                                                    159
                                                    if np.isnan(x["rb_med"])
                                                    or (x["rb_med"] < 0.948928535)
                                                    else 160
                                                )
                                                if state == 159:
                                                    return -0.113220818
                                                if state == 160:
                                                    return 0.0480081812
                        if state == 16:
                            return -0.209658891
    elif num_booster == 31:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.980749965)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.2992496)
                    else 4
                )
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 3.06795144) else 8
                    if state == 7:
                        return 0.184108868
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 4.25833082)
                            else 16
                        )
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.6424999)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    51
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.573333144)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        83
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 0.444895297)
                                        else 84
                                    )
                                    if state == 83:
                                        return -0.0626841784
                                    if state == 84:
                                        state = (
                                            131
                                            if x["neargaia_med"] < 30.4143486
                                            else 132
                                        )
                                        if state == 131:
                                            state = (
                                                191
                                                if x["col_det"] < -0.303711414
                                                else 192
                                            )
                                            if state == 191:
                                                return -0.0195128191
                                            if state == 192:
                                                return -0.364688277
                                        if state == 132:
                                            return 0.0152088869
                                if state == 52:
                                    state = (
                                        85 if x["neargaia_med"] < 0.184811682 else 86
                                    )
                                    if state == 85:
                                        state = (
                                            133
                                            if x["neargaia_med"] < 0.114794329
                                            else 134
                                        )
                                        if state == 133:
                                            return -0.128442198
                                        if state == 134:
                                            state = (
                                                193
                                                if x["col_det"] < 0.730124474
                                                else 194
                                            )
                                            if state == 193:
                                                return 0.163185999
                                            if state == 194:
                                                state = (
                                                    259
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.244682312)
                                                    else 260
                                                )
                                                if state == 259:
                                                    return -0.155359462
                                                if state == 260:
                                                    return 0.188016817
                                    if state == 86:
                                        state = (
                                            135
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 0.907149434)
                                            else 136
                                        )
                                        if state == 135:
                                            state = (
                                                195
                                                if x["col_det"] < 0.077735588
                                                else 196
                                            )
                                            if state == 195:
                                                state = (
                                                    261
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.07460356)
                                                    else 262
                                                )
                                                if state == 261:
                                                    state = (
                                                        341
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 0.511227548
                                                        )
                                                        else 342
                                                    )
                                                    if state == 341:
                                                        state = (
                                                            417
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.587777138
                                                            )
                                                            else 418
                                                        )
                                                        if state == 417:
                                                            return -0.0649419352
                                                        if state == 418:
                                                            return 0.111856617
                                                    if state == 342:
                                                        return -0.139231294
                                                if state == 262:
                                                    return 0.176475734
                                            if state == 196:
                                                state = (
                                                    263
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.549306631)
                                                    else 264
                                                )
                                                if state == 263:
                                                    state = (
                                                        343
                                                        if x["neargaia_med"]
                                                        < 0.283123255
                                                        else 344
                                                    )
                                                    if state == 343:
                                                        state = (
                                                            419
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.266569078
                                                            )
                                                            else 420
                                                        )
                                                        if state == 419:
                                                            return -0.179286689
                                                        if state == 420:
                                                            return 0.00543073239
                                                    if state == 344:
                                                        state = (
                                                            421
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.184377
                                                            )
                                                            else 422
                                                        )
                                                        if state == 421:
                                                            return 0.00017404354
                                                        if state == 422:
                                                            return -0.234264553
                                                if state == 264:
                                                    state = (
                                                        345
                                                        if x["neargaia_med"]
                                                        < 0.61923039
                                                        else 346
                                                    )
                                                    if state == 345:
                                                        return 0.164366022
                                                    if state == 346:
                                                        state = (
                                                            423
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.583520532
                                                            )
                                                            else 424
                                                        )
                                                        if state == 423:
                                                            return 0.115760937
                                                        if state == 424:
                                                            return -0.0910989195
                                        if state == 136:
                                            state = (
                                                197
                                                if x["col_det"] < 0.10766983
                                                else 198
                                            )
                                            if state == 197:
                                                state = (
                                                    265
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.40309334)
                                                    else 266
                                                )
                                                if state == 265:
                                                    state = (
                                                        347
                                                        if x["neargaia_med"]
                                                        < 35.2115364
                                                        else 348
                                                    )
                                                    if state == 347:
                                                        state = (
                                                            425
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.589949369
                                                            )
                                                            else 426
                                                        )
                                                        if state == 425:
                                                            return -0.0939095765
                                                        if state == 426:
                                                            return 0.0902099088
                                                    if state == 348:
                                                        return -0.149145633
                                                if state == 266:
                                                    state = (
                                                        349
                                                        if x["neargaia_med"]
                                                        < 46.7485237
                                                        else 350
                                                    )
                                                    if state == 349:
                                                        return -0.288088411
                                                    if state == 350:
                                                        return 0.191632301
                                            if state == 198:
                                                state = (
                                                    267
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.270053416)
                                                    else 268
                                                )
                                                if state == 267:
                                                    return -0.157691777
                                                if state == 268:
                                                    state = (
                                                        351
                                                        if x["neargaia_med"]
                                                        < 44.0852051
                                                        else 352
                                                    )
                                                    if state == 351:
                                                        state = (
                                                            427
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.75370169
                                                            )
                                                            else 428
                                                        )
                                                        if state == 427:
                                                            return 0.0819702446
                                                        if state == 428:
                                                            return -0.130495787
                                                    if state == 352:
                                                        state = (
                                                            429
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.371353745
                                                            )
                                                            else 430
                                                        )
                                                        if state == 429:
                                                            return 0.132408485
                                                        if state == 430:
                                                            return -0.132468358
                            if state == 30:
                                state = (
                                    53
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.381667018)
                                    else 54
                                )
                                if state == 53:
                                    return 0.150763795
                                if state == 54:
                                    state = 87 if x["neargaia_med"] < 12.1749363 else 88
                                    if state == 87:
                                        state = (
                                            137
                                            if x["neargaia_med"] < 11.1396065
                                            else 138
                                        )
                                        if state == 137:
                                            state = (
                                                199
                                                if x["col_det"] < 0.470748901
                                                else 200
                                            )
                                            if state == 199:
                                                return -0.184986785
                                            if state == 200:
                                                state = (
                                                    271
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.03799248)
                                                    else 272
                                                )
                                                if state == 271:
                                                    state = (
                                                        353
                                                        if x["neargaia_med"]
                                                        < 0.576908886
                                                        else 354
                                                    )
                                                    if state == 353:
                                                        return -0.0679745674
                                                    if state == 354:
                                                        state = (
                                                            433
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.724896133
                                                            )
                                                            else 434
                                                        )
                                                        if state == 433:
                                                            return -0.103825025
                                                        if state == 434:
                                                            return 0.199393362
                                                if state == 272:
                                                    return -0.152581826
                                        if state == 138:
                                            return 0.169758111
                                    if state == 88:
                                        state = (
                                            139
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 19.6242218)
                                            else 140
                                        )
                                        if state == 139:
                                            state = (
                                                201
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.0425491333)
                                                else 202
                                            )
                                            if state == 201:
                                                state = (
                                                    273
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.160274804)
                                                    else 274
                                                )
                                                if state == 273:
                                                    return 0.092226699
                                                if state == 274:
                                                    return -0.349490821
                                            if state == 202:
                                                state = (
                                                    275
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.32628012)
                                                    else 276
                                                )
                                                if state == 275:
                                                    return 0.101449668
                                                if state == 276:
                                                    return -0.111773834
                                        if state == 140:
                                            state = (
                                                203
                                                if x["col_det"] < -0.0454711914
                                                else 204
                                            )
                                            if state == 203:
                                                state = (
                                                    277
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.28293753)
                                                    else 278
                                                )
                                                if state == 277:
                                                    state = (
                                                        357
                                                        if x["neargaia_med"]
                                                        < 20.6797676
                                                        else 358
                                                    )
                                                    if state == 357:
                                                        return 0.151623249
                                                    if state == 358:
                                                        return -0.159371212
                                                if state == 278:
                                                    return 0.161340803
                                            if state == 204:
                                                state = (
                                                    279
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.271749526)
                                                    else 280
                                                )
                                                if state == 279:
                                                    return 0.103427649
                                                if state == 280:
                                                    state = (
                                                        363
                                                        if x["neargaia_med"]
                                                        < 19.8451481
                                                        else 364
                                                    )
                                                    if state == 363:
                                                        return -0.00721383886
                                                    if state == 364:
                                                        return -0.251626611
                        if state == 16:
                            state = (
                                31
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.5349998)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    55
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.442857146)
                                    else 56
                                )
                                if state == 55:
                                    return 0.119755454
                                if state == 56:
                                    return -0.115664572
                            if state == 32:
                                state = (
                                    57
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.628571451)
                                    else 58
                                )
                                if state == 57:
                                    return -0.0766932592
                                if state == 58:
                                    state = 93 if x["neargaia_med"] < 31.0687637 else 94
                                    if state == 93:
                                        state = (
                                            141
                                            if x["neargaia_med"] < 12.744422
                                            else 142
                                        )
                                        if state == 141:
                                            return 0.0180258714
                                        if state == 142:
                                            state = (
                                                205
                                                if x["col_det"] < 0.188986778
                                                else 206
                                            )
                                            if state == 205:
                                                return 0.305396527
                                            if state == 206:
                                                return -0.023971023
                                    if state == 94:
                                        return 0.0142237088
                if state == 4:
                    state = 9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 7.04712391) else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 4.64067268)
                            else 18
                        )
                        if state == 17:
                            return 0.175806001
                        if state == 18:
                            return -0.0748962611
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 3.1340766)
                            else 20
                        )
                        if state == 19:
                            state = (
                                33
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 20.9619999)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    59
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.666666687)
                                    else 60
                                )
                                if state == 59:
                                    state = 95 if x["neargaia_med"] < 4.08155441 else 96
                                    if state == 95:
                                        return -0.150486946
                                    if state == 96:
                                        state = (
                                            143
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 72.7956848)
                                            else 144
                                        )
                                        if state == 143:
                                            state = (
                                                207
                                                if x["col_det"] < -0.217721939
                                                else 208
                                            )
                                            if state == 207:
                                                state = (
                                                    281
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.24893808)
                                                    else 282
                                                )
                                                if state == 281:
                                                    state = (
                                                        365
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 41.6411591
                                                        )
                                                        else 366
                                                    )
                                                    if state == 365:
                                                        return -0.04442624
                                                    if state == 366:
                                                        return 0.159695104
                                                if state == 282:
                                                    return -0.173717171
                                            if state == 208:
                                                state = (
                                                    283
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.12268829)
                                                    else 284
                                                )
                                                if state == 283:
                                                    state = (
                                                        367
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 54.1910515
                                                        )
                                                        else 368
                                                    )
                                                    if state == 367:
                                                        state = (
                                                            437
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.33976686
                                                            )
                                                            else 438
                                                        )
                                                        if state == 437:
                                                            return 0.250394493
                                                        if state == 438:
                                                            return 0.0375592262
                                                    if state == 368:
                                                        return 0.282561123
                                                if state == 284:
                                                    state = (
                                                        369
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 23.5400829
                                                        )
                                                        else 370
                                                    )
                                                    if state == 369:
                                                        state = (
                                                            439
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.01346254
                                                            )
                                                            else 440
                                                        )
                                                        if state == 439:
                                                            return 0.301551193
                                                        if state == 440:
                                                            return 0.0223534349
                                                    if state == 370:
                                                        state = (
                                                            441
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.71423864
                                                            )
                                                            else 442
                                                        )
                                                        if state == 441:
                                                            return -0.107254937
                                                        if state == 442:
                                                            return 0.0407460593
                                        if state == 144:
                                            return -0.163981318
                                if state == 60:
                                    state = (
                                        97
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 43.4401283)
                                        else 98
                                    )
                                    if state == 97:
                                        state = (
                                            145
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 39.4782028)
                                            else 146
                                        )
                                        if state == 145:
                                            state = (
                                                209
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.291570663)
                                                else 210
                                            )
                                            if state == 209:
                                                state = (
                                                    285
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.82965732)
                                                    else 286
                                                )
                                                if state == 285:
                                                    state = (
                                                        371
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 36.3686371
                                                        )
                                                        else 372
                                                    )
                                                    if state == 371:
                                                        state = (
                                                            443
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.2570481
                                                            )
                                                            else 444
                                                        )
                                                        if state == 443:
                                                            return -0.22043407
                                                        if state == 444:
                                                            return -0.0537434779
                                                    if state == 372:
                                                        return 0.0989532545
                                                if state == 286:
                                                    state = (
                                                        373
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 24.8721466
                                                        )
                                                        else 374
                                                    )
                                                    if state == 373:
                                                        return 0.301824242
                                                    if state == 374:
                                                        return -0.115748517
                                            if state == 210:
                                                return -0.300889045
                                        if state == 146:
                                            return 0.297048151
                                    if state == 98:
                                        state = (
                                            147
                                            if x["neargaia_med"] < 53.6693573
                                            else 148
                                        )
                                        if state == 147:
                                            return -0.255066633
                                        if state == 148:
                                            state = (
                                                213
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.372898102)
                                                else 214
                                            )
                                            if state == 213:
                                                return 0.0517108738
                                            if state == 214:
                                                return -0.154022217
                            if state == 34:
                                state = (
                                    61
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.814999998)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        99
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 12.4830599)
                                        else 100
                                    )
                                    if state == 99:
                                        state = (
                                            149
                                            if x["neargaia_med"] < 10.6096535
                                            else 150
                                        )
                                        if state == 149:
                                            state = (
                                                215
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.0428600311)
                                                else 216
                                            )
                                            if state == 215:
                                                state = (
                                                    289
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.05437005)
                                                    else 290
                                                )
                                                if state == 289:
                                                    return 0.0466783345
                                                if state == 290:
                                                    return -0.148566455
                                            if state == 216:
                                                return 0.186987743
                                        if state == 150:
                                            return -0.35898304
                                    if state == 100:
                                        state = (
                                            151
                                            if x["neargaia_med"] < 16.033062
                                            else 152
                                        )
                                        if state == 151:
                                            state = (
                                                217
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.341268063)
                                                else 218
                                            )
                                            if state == 217:
                                                return 0.199848145
                                            if state == 218:
                                                state = (
                                                    291
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.769049287)
                                                    else 292
                                                )
                                                if state == 291:
                                                    return 0.0750629455
                                                if state == 292:
                                                    return -0.153233081
                                        if state == 152:
                                            state = (
                                                219
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.0171508789)
                                                else 220
                                            )
                                            if state == 219:
                                                state = (
                                                    293
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.54213572)
                                                    else 294
                                                )
                                                if state == 293:
                                                    state = (
                                                        375
                                                        if x["neargaia_med"]
                                                        < 55.0748596
                                                        else 376
                                                    )
                                                    if state == 375:
                                                        state = (
                                                            445
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.773862481
                                                            )
                                                            else 446
                                                        )
                                                        if state == 445:
                                                            return -0.0748416036
                                                        if state == 446:
                                                            return -0.252845585
                                                    if state == 376:
                                                        state = (
                                                            447
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.30260491
                                                            )
                                                            else 448
                                                        )
                                                        if state == 447:
                                                            return -0.0538835563
                                                        if state == 448:
                                                            return 0.0930222943
                                                if state == 294:
                                                    return 0.113107353
                                            if state == 220:
                                                state = (
                                                    295
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.03880751)
                                                    else 296
                                                )
                                                if state == 295:
                                                    return -0.0551788658
                                                if state == 296:
                                                    return 0.127772599
                                if state == 62:
                                    state = (
                                        101 if x["neargaia_med"] < 19.2427959 else 102
                                    )
                                    if state == 101:
                                        return 0.236845627
                                    if state == 102:
                                        return 0.0248876885
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.3425007)
                                else 36
                            )
                            if state == 35:
                                return 0.214520991
                            if state == 36:
                                state = (
                                    63
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.587499976)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        103 if x["neargaia_med"] < 43.0381317 else 104
                                    )
                                    if state == 103:
                                        state = (
                                            155
                                            if x["neargaia_med"] < 17.2115593
                                            else 156
                                        )
                                        if state == 155:
                                            state = (
                                                221
                                                if x["col_det"] < -0.340205669
                                                else 222
                                            )
                                            if state == 221:
                                                return 0.0576935373
                                            if state == 222:
                                                return -0.202731133
                                        if state == 156:
                                            state = (
                                                223
                                                if x["col_det"] < 0.301169872
                                                else 224
                                            )
                                            if state == 223:
                                                return 0.226337165
                                            if state == 224:
                                                state = (
                                                    299
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 5.91815376)
                                                    else 300
                                                )
                                                if state == 299:
                                                    state = (
                                                        381
                                                        if x["neargaia_med"]
                                                        < 34.8550758
                                                        else 382
                                                    )
                                                    if state == 381:
                                                        return 0.152032286
                                                    if state == 382:
                                                        state = (
                                                            451
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 5.12775803
                                                            )
                                                            else 452
                                                        )
                                                        if state == 451:
                                                            return -0.156864941
                                                        if state == 452:
                                                            return 0.116920635
                                                if state == 300:
                                                    return -0.239513189
                                    if state == 104:
                                        return -0.265089184
                                if state == 64:
                                    state = (
                                        105
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 72.9343872)
                                        else 106
                                    )
                                    if state == 105:
                                        state = (
                                            157
                                            if x["neargaia_med"] < 34.7279968
                                            else 158
                                        )
                                        if state == 157:
                                            state = (
                                                225
                                                if x["col_det"] < -0.179254055
                                                else 226
                                            )
                                            if state == 225:
                                                return 0.0664068237
                                            if state == 226:
                                                state = (
                                                    303
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 4.37117004)
                                                    else 304
                                                )
                                                if state == 303:
                                                    return -0.0331299715
                                                if state == 304:
                                                    state = (
                                                        385
                                                        if x["neargaia_med"] < 14.219326
                                                        else 386
                                                    )
                                                    if state == 385:
                                                        return -0.251056552
                                                    if state == 386:
                                                        return -0.0234464426
                                        if state == 158:
                                            return -0.293918312
                                    if state == 106:
                                        return 0.0855926275
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.8950005)
                    else 6
                )
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 28.9734726) else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.223553985)
                            else 22
                        )
                        if state == 21:
                            return 0.0952553228
                        if state == 22:
                            state = (
                                39
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 16.5294991)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    65
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.609166563)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        107 if x["neargaia_med"] < 25.7340298 else 108
                                    )
                                    if state == 107:
                                        return -0.144806206
                                    if state == 108:
                                        return 0.0516643897
                                if state == 66:
                                    return 0.0928815827
                            if state == 40:
                                state = (
                                    67
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.713571429)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        109 if x["neargaia_med"] < 1.56128836 else 110
                                    )
                                    if state == 109:
                                        return -0.271059781
                                    if state == 110:
                                        state = (
                                            159
                                            if x["neargaia_med"] < 21.7613926
                                            else 160
                                        )
                                        if state == 159:
                                            return 0.0327556357
                                        if state == 160:
                                            return -0.172248319
                                if state == 68:
                                    return 0.0640733987
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 1.37473965)
                            else 24
                        )
                        if state == 23:
                            return -0.244971097
                        if state == 24:
                            state = (
                                41
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 16.0950012)
                                else 42
                            )
                            if state == 41:
                                return -0.0959509015
                            if state == 42:
                                return 0.107680865
                if state == 6:
                    state = (
                        13 if np.isnan(x["t_lc"]) or (x["t_lc"] < 36.9405899) else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 2.77378988)
                            else 26
                        )
                        if state == 25:
                            state = (
                                43
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.8064995)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    69
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.91785717)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        111
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 32.3512878)
                                        else 112
                                    )
                                    if state == 111:
                                        state = (
                                            161
                                            if x["neargaia_med"] < 0.893558025
                                            else 162
                                        )
                                        if state == 161:
                                            state = (
                                                227
                                                if x["col_det"] < 0.298853874
                                                else 228
                                            )
                                            if state == 227:
                                                return -0.296539366
                                            if state == 228:
                                                state = (
                                                    305
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.205948502)
                                                    else 306
                                                )
                                                if state == 305:
                                                    state = (
                                                        387
                                                        if x["neargaia_med"]
                                                        < 0.142818958
                                                        else 388
                                                    )
                                                    if state == 387:
                                                        return 0.0416317321
                                                    if state == 388:
                                                        return -0.139330119
                                                if state == 306:
                                                    return 0.186604321
                                        if state == 162:
                                            state = (
                                                229
                                                if x["col_det"] < -0.340829849
                                                else 230
                                            )
                                            if state == 229:
                                                return -0.140268147
                                            if state == 230:
                                                state = (
                                                    307
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.46962392)
                                                    else 308
                                                )
                                                if state == 307:
                                                    state = (
                                                        391
                                                        if x["neargaia_med"]
                                                        < 13.6864109
                                                        else 392
                                                    )
                                                    if state == 391:
                                                        state = (
                                                            459
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.179351509
                                                            )
                                                            else 460
                                                        )
                                                        if state == 459:
                                                            return -0.104234502
                                                        if state == 460:
                                                            return 0.139054656
                                                    if state == 392:
                                                        state = (
                                                            461
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.23438412
                                                            )
                                                            else 462
                                                        )
                                                        if state == 461:
                                                            return 0.0472490564
                                                        if state == 462:
                                                            return 0.231869891
                                                if state == 308:
                                                    state = (
                                                        393
                                                        if x["neargaia_med"]
                                                        < 11.8986511
                                                        else 394
                                                    )
                                                    if state == 393:
                                                        return 0.260547161
                                                    if state == 394:
                                                        state = (
                                                            463
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.60829496
                                                            )
                                                            else 464
                                                        )
                                                        if state == 463:
                                                            return -0.152448148
                                                        if state == 464:
                                                            return 0.0926376134
                                    if state == 112:
                                        state = (
                                            163
                                            if x["neargaia_med"] < 44.5813255
                                            else 164
                                        )
                                        if state == 163:
                                            state = (
                                                231
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.149958611)
                                                else 232
                                            )
                                            if state == 231:
                                                state = (
                                                    309
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.49849963)
                                                    else 310
                                                )
                                                if state == 309:
                                                    state = (
                                                        395
                                                        if x["neargaia_med"]
                                                        < 36.8613777
                                                        else 396
                                                    )
                                                    if state == 395:
                                                        return 0.0934259892
                                                    if state == 396:
                                                        return -0.359070688
                                                if state == 310:
                                                    state = (
                                                        397
                                                        if x["neargaia_med"]
                                                        < 34.8555756
                                                        else 398
                                                    )
                                                    if state == 397:
                                                        return -0.160503104
                                                    if state == 398:
                                                        state = (
                                                            465
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.05681992
                                                            )
                                                            else 466
                                                        )
                                                        if state == 465:
                                                            return 0.173699856
                                                        if state == 466:
                                                            return -0.0553403161
                                            if state == 232:
                                                state = (
                                                    311
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.45444107)
                                                    else 312
                                                )
                                                if state == 311:
                                                    return 0.178539798
                                                if state == 312:
                                                    return -0.120431215
                                        if state == 164:
                                            state = (
                                                233
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.210500717)
                                                else 234
                                            )
                                            if state == 233:
                                                state = (
                                                    313
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.88252139)
                                                    else 314
                                                )
                                                if state == 313:
                                                    state = (
                                                        401
                                                        if x["neargaia_med"]
                                                        < 45.8750763
                                                        else 402
                                                    )
                                                    if state == 401:
                                                        return 0.128727421
                                                    if state == 402:
                                                        state = (
                                                            467
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.746502042
                                                            )
                                                            else 468
                                                        )
                                                        if state == 467:
                                                            return 0.149394587
                                                        if state == 468:
                                                            return -0.103320733
                                                if state == 314:
                                                    return 0.234528169
                                            if state == 234:
                                                state = (
                                                    315
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.40160513)
                                                    else 316
                                                )
                                                if state == 315:
                                                    return -0.129134193
                                                if state == 316:
                                                    return 0.100179039
                                if state == 70:
                                    state = (
                                        113 if x["neargaia_med"] < 16.389637 else 114
                                    )
                                    if state == 113:
                                        state = (
                                            165
                                            if x["neargaia_med"] < 1.57060599
                                            else 166
                                        )
                                        if state == 165:
                                            return 0.133012116
                                        if state == 166:
                                            state = (
                                                235
                                                if x["col_det"] < -0.0317316055
                                                else 236
                                            )
                                            if state == 235:
                                                return -0.0406383872
                                            if state == 236:
                                                state = (
                                                    317
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.36439872)
                                                    else 318
                                                )
                                                if state == 317:
                                                    return 0.0401270613
                                                if state == 318:
                                                    return -0.314561754
                                    if state == 114:
                                        state = (
                                            167
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 43.3996658)
                                            else 168
                                        )
                                        if state == 167:
                                            return 0.223747522
                                        if state == 168:
                                            state = (
                                                237
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.265805721)
                                                else 238
                                            )
                                            if state == 237:
                                                return -0.24870488
                                            if state == 238:
                                                state = (
                                                    319
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.17287993)
                                                    else 320
                                                )
                                                if state == 319:
                                                    return -0.180471539
                                                if state == 320:
                                                    return 0.150842264
                            if state == 44:
                                state = (
                                    71
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.476071417)
                                    else 72
                                )
                                if state == 71:
                                    return 0.000675898104
                                if state == 72:
                                    state = (
                                        115 if x["neargaia_med"] < 26.0511608 else 116
                                    )
                                    if state == 115:
                                        return -0.251159489
                                    if state == 116:
                                        state = (
                                            169
                                            if x["neargaia_med"] < 39.2693367
                                            else 170
                                        )
                                        if state == 169:
                                            return 0.147519335
                                        if state == 170:
                                            return -0.0358891152
                        if state == 26:
                            state = (
                                45
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.0439987)
                                else 46
                            )
                            if state == 45:
                                state = (
                                    73
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.635357261)
                                    else 74
                                )
                                if state == 73:
                                    state = (
                                        117 if x["neargaia_med"] < 6.8999815 else 118
                                    )
                                    if state == 117:
                                        state = (
                                            171
                                            if x["neargaia_med"] < 5.25289631
                                            else 172
                                        )
                                        if state == 171:
                                            state = (
                                                241
                                                if x["col_det"] < 0.0665459633
                                                else 242
                                            )
                                            if state == 241:
                                                return -0.121268988
                                            if state == 242:
                                                return 0.0503015444
                                        if state == 172:
                                            return -0.202680498
                                    if state == 118:
                                        state = (
                                            173
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 18.3785591)
                                            else 174
                                        )
                                        if state == 173:
                                            state = (
                                                243
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.248883247)
                                                else 244
                                            )
                                            if state == 243:
                                                state = (
                                                    321
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.05921388)
                                                    else 322
                                                )
                                                if state == 321:
                                                    return 0.00151449023
                                                if state == 322:
                                                    return 0.290476233
                                            if state == 244:
                                                return -0.0992094576
                                        if state == 174:
                                            state = (
                                                245
                                                if x["col_det"] < 0.0458504371
                                                else 246
                                            )
                                            if state == 245:
                                                return 0.136279762
                                            if state == 246:
                                                state = (
                                                    323
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.3314395)
                                                    else 324
                                                )
                                                if state == 323:
                                                    return -0.283990771
                                                if state == 324:
                                                    return 0.186234564
                                if state == 74:
                                    state = (
                                        119 if x["neargaia_med"] < 22.3934612 else 120
                                    )
                                    if state == 119:
                                        state = (
                                            175
                                            if x["neargaia_med"] < 13.0591621
                                            else 176
                                        )
                                        if state == 175:
                                            state = (
                                                247
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.0276193619)
                                                else 248
                                            )
                                            if state == 247:
                                                state = (
                                                    325
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.28691006)
                                                    else 326
                                                )
                                                if state == 325:
                                                    return 0.0433280021
                                                if state == 326:
                                                    state = (
                                                        405
                                                        if x["neargaia_med"]
                                                        < 8.95381737
                                                        else 406
                                                    )
                                                    if state == 405:
                                                        return -0.271416515
                                                    if state == 406:
                                                        return 0.110979259
                                            if state == 248:
                                                return 0.0674526095
                                        if state == 176:
                                            return -0.279456198
                                    if state == 120:
                                        state = (
                                            177
                                            if x["neargaia_med"] < 33.9036407
                                            else 178
                                        )
                                        if state == 177:
                                            return 0.141072303
                                        if state == 178:
                                            state = (
                                                249
                                                if x["col_det"] < 0.228963852
                                                else 250
                                            )
                                            if state == 249:
                                                state = (
                                                    327
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.93560433)
                                                    else 328
                                                )
                                                if state == 327:
                                                    return -0.103561945
                                                if state == 328:
                                                    return 0.161363706
                                            if state == 250:
                                                state = (
                                                    329
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.5049839)
                                                    else 330
                                                )
                                                if state == 329:
                                                    state = (
                                                        409
                                                        if x["neargaia_med"]
                                                        < 61.5095673
                                                        else 410
                                                    )
                                                    if state == 409:
                                                        return 0.143374145
                                                    if state == 410:
                                                        return -0.222014382
                                                if state == 330:
                                                    return -0.256063193
                            if state == 46:
                                state = (
                                    75
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.648333311)
                                    else 76
                                )
                                if state == 75:
                                    return 0.203327656
                                if state == 76:
                                    state = (
                                        121 if x["neargaia_med"] < 26.0486145 else 122
                                    )
                                    if state == 121:
                                        state = (
                                            179
                                            if x["neargaia_med"] < 14.9077921
                                            else 180
                                        )
                                        if state == 179:
                                            state = (
                                                251
                                                if x["col_det"] < 0.0385503769
                                                else 252
                                            )
                                            if state == 251:
                                                return -0.105582528
                                            if state == 252:
                                                state = (
                                                    333
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 5.62578678)
                                                    else 334
                                                )
                                                if state == 333:
                                                    return 0.134590566
                                                if state == 334:
                                                    return -0.0495445617
                                        if state == 180:
                                            return -0.194323778
                                    if state == 122:
                                        return 0.105465166
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.249977291)
                            else 28
                        )
                        if state == 27:
                            state = (
                                47
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 20.4055004)
                                else 48
                            )
                            if state == 47:
                                return -0.191525832
                            if state == 48:
                                return 0.0265511721
                        if state == 28:
                            state = (
                                49
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.0907497)
                                else 50
                            )
                            if state == 49:
                                state = (
                                    79
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.638571382)
                                    else 80
                                )
                                if state == 79:
                                    state = (
                                        125
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 14.434433)
                                        else 126
                                    )
                                    if state == 125:
                                        return 0.161172658
                                    if state == 126:
                                        return -0.0627384633
                                if state == 80:
                                    state = (
                                        127 if x["neargaia_med"] < 16.4956627 else 128
                                    )
                                    if state == 127:
                                        state = (
                                            185
                                            if x["neargaia_med"] < 13.0921259
                                            else 186
                                        )
                                        if state == 185:
                                            return 0.0496215187
                                        if state == 186:
                                            return -0.253816158
                                    if state == 128:
                                        return 0.156853884
                            if state == 50:
                                state = (
                                    81
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.284166753)
                                    else 82
                                )
                                if state == 81:
                                    return -0.0990430117
                                if state == 82:
                                    state = (
                                        129 if x["neargaia_med"] < 8.28699493 else 130
                                    )
                                    if state == 129:
                                        state = (
                                            187
                                            if x["neargaia_med"] < 5.81316853
                                            else 188
                                        )
                                        if state == 187:
                                            return 0.216800198
                                        if state == 188:
                                            state = (
                                                255
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.310898781)
                                                else 256
                                            )
                                            if state == 255:
                                                state = (
                                                    335
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.51443434)
                                                    else 336
                                                )
                                                if state == 335:
                                                    return 0.151706874
                                                if state == 336:
                                                    return -0.12256024
                                            if state == 256:
                                                return -0.124926992
                                    if state == 130:
                                        state = (
                                            189
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 38.4405327)
                                            else 190
                                        )
                                        if state == 189:
                                            return 0.231287777
                                        if state == 190:
                                            state = (
                                                257
                                                if x["col_det"] < -0.273994446
                                                else 258
                                            )
                                            if state == 257:
                                                return -0.0519343279
                                            if state == 258:
                                                state = (
                                                    337
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.46125579)
                                                    else 338
                                                )
                                                if state == 337:
                                                    state = (
                                                        413
                                                        if x["neargaia_med"]
                                                        < 38.6394043
                                                        else 414
                                                    )
                                                    if state == 413:
                                                        return -0.204348847
                                                    if state == 414:
                                                        return 0.212451354
                                                if state == 338:
                                                    return 0.217000902
    elif num_booster == 32:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < 0.295680046) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.504097998)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3772621)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["sgscore1_med"] < 0.0151875 else 16
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.30541992)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    53
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.42035818)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        85
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 18.7143593)
                                        else 86
                                    )
                                    if state == 85:
                                        state = (
                                            127 if x["col_last"] < 0.123503208 else 128
                                        )
                                        if state == 127:
                                            return 0.176055193
                                        if state == 128:
                                            state = (
                                                167
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 23.9589882)
                                                else 168
                                            )
                                            if state == 167:
                                                state = (
                                                    229
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.02617133)
                                                    else 230
                                                )
                                                if state == 229:
                                                    state = (
                                                        289
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 21.0138359)
                                                        else 290
                                                    )
                                                    if state == 289:
                                                        state = (
                                                            327
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.699166656
                                                            )
                                                            else 328
                                                        )
                                                        if state == 327:
                                                            return -0.0975793079
                                                        if state == 328:
                                                            return 0.0433802567
                                                    if state == 290:
                                                        return -0.184774667
                                                if state == 230:
                                                    return 0.10763555
                                            if state == 168:
                                                state = (
                                                    231
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.227983385)
                                                    else 232
                                                )
                                                if state == 231:
                                                    return -0.0191224739
                                                if state == 232:
                                                    state = (
                                                        293
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 53.8408928)
                                                        else 294
                                                    )
                                                    if state == 293:
                                                        state = (
                                                            331
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.570714295
                                                            )
                                                            else 332
                                                        )
                                                        if state == 331:
                                                            return -0.0513015389
                                                        if state == 332:
                                                            return 0.199306577
                                                    if state == 294:
                                                        return -0.0305115376
                                    if state == 86:
                                        state = (
                                            129 if x["col_last"] < 0.455464363 else 130
                                        )
                                        if state == 129:
                                            state = (
                                                169
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 24.9065971)
                                                else 170
                                            )
                                            if state == 169:
                                                state = (
                                                    233
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.309745818)
                                                    else 234
                                                )
                                                if state == 233:
                                                    return -0.0141562559
                                                if state == 234:
                                                    return -0.271559447
                                            if state == 170:
                                                return -0.0224350374
                                        if state == 130:
                                            state = (
                                                171
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 14.0493584)
                                                else 172
                                            )
                                            if state == 171:
                                                return -0.21478498
                                            if state == 172:
                                                state = (
                                                    237
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.522333264)
                                                    else 238
                                                )
                                                if state == 237:
                                                    state = (
                                                        297
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 35.0187454)
                                                        else 298
                                                    )
                                                    if state == 297:
                                                        state = (
                                                            335
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.714166641
                                                            )
                                                            else 336
                                                        )
                                                        if state == 335:
                                                            return -0.128356352
                                                        if state == 336:
                                                            return 0.143352792
                                                    if state == 298:
                                                        return -0.0835869014
                                                if state == 238:
                                                    state = (
                                                        299
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 17.9219913)
                                                        else 300
                                                    )
                                                    if state == 299:
                                                        return 0.015080343
                                                    if state == 300:
                                                        state = (
                                                            341
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.607857168
                                                            )
                                                            else 342
                                                        )
                                                        if state == 341:
                                                            return 0.0566084646
                                                        if state == 342:
                                                            return -0.237499878
                                if state == 54:
                                    state = 87 if x["maggaia_med"] < 16.553936 else 88
                                    if state == 87:
                                        state = (
                                            131
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < -0.0326910019)
                                            else 132
                                        )
                                        if state == 131:
                                            return -0.0347615071
                                        if state == 132:
                                            return 0.130266652
                                    if state == 88:
                                        state = (
                                            133
                                            if x["col_last"] < -0.0496311188
                                            else 134
                                        )
                                        if state == 133:
                                            return -0.0631165951
                                        if state == 134:
                                            state = (
                                                179
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 66.8084106)
                                                else 180
                                            )
                                            if state == 179:
                                                return -0.336391747
                                            if state == 180:
                                                return 0.0192793049
                            if state == 30:
                                state = (
                                    55
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 3.15873051)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        89
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 17.785862)
                                        else 90
                                    )
                                    if state == 89:
                                        return -0.119324408
                                    if state == 90:
                                        state = (
                                            135
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.193267822)
                                            else 136
                                        )
                                        if state == 135:
                                            return 0.214870095
                                        if state == 136:
                                            state = (
                                                181
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 27.4647388)
                                                else 182
                                            )
                                            if state == 181:
                                                return -0.152721807
                                            if state == 182:
                                                return 0.110292971
                                if state == 56:
                                    state = (
                                        91
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 17.7880173)
                                        else 92
                                    )
                                    if state == 91:
                                        state = (
                                            137
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.351893425)
                                            else 138
                                        )
                                        if state == 137:
                                            state = (
                                                183
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 22.0632744)
                                                else 184
                                            )
                                            if state == 183:
                                                state = (
                                                    245
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 5.90492153)
                                                    else 246
                                                )
                                                if state == 245:
                                                    state = (
                                                        301
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 22.0212269)
                                                        else 302
                                                    )
                                                    if state == 301:
                                                        state = (
                                                            343
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"] < 0.65500015
                                                            )
                                                            else 344
                                                        )
                                                        if state == 343:
                                                            return 0.102191932
                                                        if state == 344:
                                                            return -0.10990867
                                                    if state == 302:
                                                        return 0.0939501077
                                                if state == 246:
                                                    return -0.108438067
                                            if state == 184:
                                                return -0.201486751
                                        if state == 138:
                                            state = (
                                                185
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 25.5224304)
                                                else 186
                                            )
                                            if state == 185:
                                                return 0.175574183
                                            if state == 186:
                                                return -0.196248204
                                    if state == 92:
                                        state = (
                                            139
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < -0.0459089279)
                                            else 140
                                        )
                                        if state == 139:
                                            state = (
                                                187
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 10.9864817)
                                                else 188
                                            )
                                            if state == 187:
                                                return 0.0188438371
                                            if state == 188:
                                                state = (
                                                    249
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 7.53305626)
                                                    else 250
                                                )
                                                if state == 249:
                                                    return 0.189213768
                                                if state == 250:
                                                    return -0.0266411025
                                        if state == 140:
                                            return -0.0336816534
                        if state == 16:
                            state = (
                                31
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.21160936)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    57
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.297016501)
                                    else 58
                                )
                                if state == 57:
                                    state = 93 if x["maggaia_med"] < 17.4279366 else 94
                                    if state == 93:
                                        state = (
                                            141 if x["col_last"] < 0.885963917 else 142
                                        )
                                        if state == 141:
                                            return -0.00928152446
                                        if state == 142:
                                            state = (
                                                193
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 42.9653015)
                                                else 194
                                            )
                                            if state == 193:
                                                return 0.17035915
                                            if state == 194:
                                                state = (
                                                    253
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.160983384)
                                                    else 254
                                                )
                                                if state == 253:
                                                    return 0.0700284615
                                                if state == 254:
                                                    return -0.127736166
                                    if state == 94:
                                        return -0.137899801
                                if state == 58:
                                    state = 95 if x["maggaia_med"] < 14.33218 else 96
                                    if state == 95:
                                        return -0.202362284
                                    if state == 96:
                                        state = (
                                            143 if x["col_last"] < -0.126117706 else 144
                                        )
                                        if state == 143:
                                            state = (
                                                195
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 16.0496597)
                                                else 196
                                            )
                                            if state == 195:
                                                return 0.184555873
                                            if state == 196:
                                                return -0.0475443602
                                        if state == 144:
                                            state = (
                                                197
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 17.0376797)
                                                else 198
                                            )
                                            if state == 197:
                                                state = (
                                                    255
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.94255114)
                                                    else 256
                                                )
                                                if state == 255:
                                                    state = (
                                                        303
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 15.9438772)
                                                        else 304
                                                    )
                                                    if state == 303:
                                                        state = (
                                                            345
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.941785693
                                                            )
                                                            else 346
                                                        )
                                                        if state == 345:
                                                            return 0.0639153197
                                                        if state == 346:
                                                            return -0.14625819
                                                    if state == 304:
                                                        return -0.155933619
                                                if state == 256:
                                                    state = (
                                                        305
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 13.0188713)
                                                        else 306
                                                    )
                                                    if state == 305:
                                                        state = (
                                                            347
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"] < 0.54595238
                                                            )
                                                            else 348
                                                        )
                                                        if state == 347:
                                                            return 0.202395469
                                                        if state == 348:
                                                            return -0.0735503584
                                                    if state == 306:
                                                        return 0.201988608
                                            if state == 198:
                                                state = (
                                                    257
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.58117163)
                                                    else 258
                                                )
                                                if state == 257:
                                                    state = (
                                                        307
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 57.9255219)
                                                        else 308
                                                    )
                                                    if state == 307:
                                                        state = (
                                                            349
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.624999881
                                                            )
                                                            else 350
                                                        )
                                                        if state == 349:
                                                            return -0.00210957858
                                                        if state == 350:
                                                            return 0.15340738
                                                    if state == 308:
                                                        state = (
                                                            351
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.664285719
                                                            )
                                                            else 352
                                                        )
                                                        if state == 351:
                                                            return 0.168534935
                                                        if state == 352:
                                                            return -0.0936839879
                                                if state == 258:
                                                    state = (
                                                        309
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 27.0245934)
                                                        else 310
                                                    )
                                                    if state == 309:
                                                        state = (
                                                            353
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.908214271
                                                            )
                                                            else 354
                                                        )
                                                        if state == 353:
                                                            return 0.142522037
                                                        if state == 354:
                                                            return -0.152112663
                                                    if state == 310:
                                                        state = (
                                                            355
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.597738147
                                                            )
                                                            else 356
                                                        )
                                                        if state == 355:
                                                            return -0.196584046
                                                        if state == 356:
                                                            return 0.0418688729
                            if state == 32:
                                state = (
                                    59
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 5.49455547)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        97
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 19.3642769)
                                        else 98
                                    )
                                    if state == 97:
                                        state = (
                                            145
                                            if x["col_last"] < -0.00296735764
                                            else 146
                                        )
                                        if state == 145:
                                            state = (
                                                199
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 6.02244186)
                                                else 200
                                            )
                                            if state == 199:
                                                return 0.00111036608
                                            if state == 200:
                                                state = (
                                                    259
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.71980047)
                                                    else 260
                                                )
                                                if state == 259:
                                                    return 0.0496949255
                                                if state == 260:
                                                    return -0.191012487
                                        if state == 146:
                                            state = (
                                                201
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 14.0195885)
                                                else 202
                                            )
                                            if state == 201:
                                                state = (
                                                    261
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.92239618)
                                                    else 262
                                                )
                                                if state == 261:
                                                    state = (
                                                        311
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 13.0945368)
                                                        else 312
                                                    )
                                                    if state == 311:
                                                        state = (
                                                            357
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.682023942
                                                            )
                                                            else 358
                                                        )
                                                        if state == 357:
                                                            return -0.215578452
                                                        if state == 358:
                                                            return 0.170552984
                                                    if state == 312:
                                                        return -0.162237853
                                                if state == 262:
                                                    return -0.263902158
                                            if state == 202:
                                                state = (
                                                    263
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.79466224)
                                                    else 264
                                                )
                                                if state == 263:
                                                    state = (
                                                        313
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 15.9267654)
                                                        else 314
                                                    )
                                                    if state == 313:
                                                        return 0.199018776
                                                    if state == 314:
                                                        state = (
                                                            359
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.585000038
                                                            )
                                                            else 360
                                                        )
                                                        if state == 359:
                                                            return -0.20663701
                                                        if state == 360:
                                                            return 0.0811461434
                                                if state == 264:
                                                    state = (
                                                        315
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 20.50214)
                                                        else 316
                                                    )
                                                    if state == 315:
                                                        state = (
                                                            361
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.495833337
                                                            )
                                                            else 362
                                                        )
                                                        if state == 361:
                                                            return -0.139479667
                                                        if state == 362:
                                                            return 0.00127491332
                                                    if state == 316:
                                                        state = (
                                                            363
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.504642844
                                                            )
                                                            else 364
                                                        )
                                                        if state == 363:
                                                            return -0.138735846
                                                        if state == 364:
                                                            return 0.174088895
                                    if state == 98:
                                        state = (
                                            147
                                            if x["col_last"] < -0.0574398041
                                            else 148
                                        )
                                        if state == 147:
                                            return -0.0123759871
                                        if state == 148:
                                            state = (
                                                205
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 48.4749146)
                                                else 206
                                            )
                                            if state == 205:
                                                state = (
                                                    265
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 4.859272)
                                                    else 266
                                                )
                                                if state == 265:
                                                    return -0.256747544
                                                if state == 266:
                                                    state = (
                                                        317
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 43.8582611)
                                                        else 318
                                                    )
                                                    if state == 317:
                                                        return 0.14105247
                                                    if state == 318:
                                                        return -0.103240617
                                            if state == 206:
                                                state = (
                                                    267
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.6054163)
                                                    else 268
                                                )
                                                if state == 267:
                                                    return 0.0990292504
                                                if state == 268:
                                                    return -0.149191454
                                if state == 60:
                                    state = (
                                        99
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 17.8655186)
                                        else 100
                                    )
                                    if state == 99:
                                        state = (
                                            149 if x["col_last"] < -0.096786499 else 150
                                        )
                                        if state == 149:
                                            return -0.0414115898
                                        if state == 150:
                                            return 0.216886282
                                    if state == 100:
                                        state = (
                                            151
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.0821208954)
                                            else 152
                                        )
                                        if state == 151:
                                            state = (
                                                209
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 55.0156555)
                                                else 210
                                            )
                                            if state == 209:
                                                state = (
                                                    271
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 5.69994068)
                                                    else 272
                                                )
                                                if state == 271:
                                                    return 0.133853287
                                                if state == 272:
                                                    state = (
                                                        319
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 18.8341084)
                                                        else 320
                                                    )
                                                    if state == 319:
                                                        return -0.0594697781
                                                    if state == 320:
                                                        state = (
                                                            367
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.495833337
                                                            )
                                                            else 368
                                                        )
                                                        if state == 367:
                                                            return 0.0304845236
                                                        if state == 368:
                                                            return -0.19253768
                                            if state == 210:
                                                return 0.0302031077
                                        if state == 152:
                                            return 0.00369903725
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0016369049)
                            else 18
                        )
                        if state == 17:
                            state = (
                                33
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.62117505)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    61
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.437463999)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        101 if x["maggaia_med"] < 18.8823242 else 102
                                    )
                                    if state == 101:
                                        return 0.0784066319
                                    if state == 102:
                                        return -0.136788294
                                if state == 62:
                                    state = (
                                        103
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 19.3252449)
                                        else 104
                                    )
                                    if state == 103:
                                        return -0.290518969
                                    if state == 104:
                                        return -0.100040793
                            if state == 34:
                                state = (
                                    63
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 5.72735882)
                                    else 64
                                )
                                if state == 63:
                                    return 0.137949601
                                if state == 64:
                                    return -0.0365015343
                        if state == 18:
                            state = (
                                35
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 3.12832308)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    65
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.86151874)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        105
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 17.3445168)
                                        else 106
                                    )
                                    if state == 105:
                                        state = (
                                            155 if x["col_last"] < -0.135569572 else 156
                                        )
                                        if state == 155:
                                            return 0.00155947125
                                        if state == 156:
                                            state = (
                                                213
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 32.4583168)
                                                else 214
                                            )
                                            if state == 213:
                                                state = (
                                                    275
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.583134055)
                                                    else 276
                                                )
                                                if state == 275:
                                                    return -0.0641768798
                                                if state == 276:
                                                    return 0.276812822
                                            if state == 214:
                                                state = (
                                                    277
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.662274599)
                                                    else 278
                                                )
                                                if state == 277:
                                                    return -0.111370832
                                                if state == 278:
                                                    return 0.112751283
                                    if state == 106:
                                        state = (
                                            157
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.707157135)
                                            else 158
                                        )
                                        if state == 157:
                                            state = (
                                                215
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 10.0274076)
                                                else 216
                                            )
                                            if state == 215:
                                                return -0.0941378102
                                            if state == 216:
                                                state = (
                                                    281
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.67796659)
                                                    else 282
                                                )
                                                if state == 281:
                                                    state = (
                                                        323
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 16.0546188)
                                                        else 324
                                                    )
                                                    if state == 323:
                                                        return 0.117560044
                                                    if state == 324:
                                                        state = (
                                                            373
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"] < 0.65154779
                                                            )
                                                            else 374
                                                        )
                                                        if state == 373:
                                                            return -0.0614829771
                                                        if state == 374:
                                                            return 0.106808856
                                                if state == 282:
                                                    return -0.14386034
                                        if state == 158:
                                            return -0.114302568
                                if state == 66:
                                    state = (
                                        107
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 19.8679047)
                                        else 108
                                    )
                                    if state == 107:
                                        return 0.267212927
                                    if state == 108:
                                        return -0.139153972
                            if state == 36:
                                state = (
                                    67
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 3.27475595)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        109
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 16.7288723)
                                        else 110
                                    )
                                    if state == 109:
                                        return 0.123574212
                                    if state == 110:
                                        return -0.32190302
                                if state == 68:
                                    state = (
                                        111 if x["maggaia_med"] < 20.2392921 else 112
                                    )
                                    if state == 111:
                                        state = (
                                            159
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.150309563)
                                            else 160
                                        )
                                        if state == 159:
                                            state = (
                                                219
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 27.9780388)
                                                else 220
                                            )
                                            if state == 219:
                                                state = (
                                                    283
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 4.0701437)
                                                    else 284
                                                )
                                                if state == 283:
                                                    return 0.144693911
                                                if state == 284:
                                                    state = (
                                                        325
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 12.0075932)
                                                        else 326
                                                    )
                                                    if state == 325:
                                                        return 0.0748341829
                                                    if state == 326:
                                                        return -0.132586971
                                            if state == 220:
                                                return 0.152504906
                                        if state == 160:
                                            return 0.203355342
                                    if state == 112:
                                        return -0.149755463
                if state == 4:
                    state = (
                        9 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.59445) else 10
                    )
                    if state == 9:
                        state = 19 if x["sgscore1_med"] < 0.970270991 else 20
                        if state == 19:
                            state = (
                                37
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 3.61642051)
                                else 38
                            )
                            if state == 37:
                                return -0.287493318
                            if state == 38:
                                state = (
                                    69
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 8.09486103)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        113 if x["maggaia_med"] < 19.0177345 else 114
                                    )
                                    if state == 113:
                                        return -0.0983863622
                                    if state == 114:
                                        return 0.127370924
                                if state == 70:
                                    return -0.19744122
                        if state == 20:
                            state = (
                                39
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 5.16412354)
                                else 40
                            )
                            if state == 39:
                                return -0.121532969
                            if state == 40:
                                state = (
                                    73
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 6.1096158)
                                    else 74
                                )
                                if state == 73:
                                    return 0.098371841
                                if state == 74:
                                    return -0.0700393245
                    if state == 10:
                        state = 21 if x["sgscore1_med"] < 0.600973487 else 22
                        if state == 21:
                            return -0.138081521
                        if state == 22:
                            state = (
                                41
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.911501229)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    75
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.258901298)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        117
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 16.713131)
                                        else 118
                                    )
                                    if state == 117:
                                        return 0.111002333
                                    if state == 118:
                                        return -0.0978798717
                                if state == 76:
                                    return -0.148348257
                            if state == 42:
                                state = (
                                    77
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.45520854)
                                    else 78
                                )
                                if state == 77:
                                    return 0.192826629
                                if state == 78:
                                    state = (
                                        121
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 19.47258)
                                        else 122
                                    )
                                    if state == 121:
                                        state = (
                                            163
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < -0.0793619156)
                                            else 164
                                        )
                                        if state == 163:
                                            state = (
                                                223
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 16.0731716)
                                                else 224
                                            )
                                            if state == 223:
                                                return -0.0218411814
                                            if state == 224:
                                                state = (
                                                    287
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 4.51341724)
                                                    else 288
                                                )
                                                if state == 287:
                                                    return -0.0607532039
                                                if state == 288:
                                                    return 0.158340558
                                        if state == 164:
                                            return 0.00589936506
                                    if state == 122:
                                        return -0.154564217
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.0268125013 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.0722008)
                        else 12
                    )
                    if state == 11:
                        state = 23 if x["sgscore1_med"] < 0.0122231999 else 24
                        if state == 23:
                            state = (
                                43
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 2.12756562)
                                else 44
                            )
                            if state == 43:
                                return 0.0586240329
                            if state == 44:
                                return -0.155508205
                        if state == 24:
                            return 0.25052309
                    if state == 12:
                        return -0.110632271
                if state == 6:
                    state = (
                        13 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.6966) else 14
                    )
                    if state == 13:
                        state = 25 if x["sgscore1_med"] < 0.0675892979 else 26
                        if state == 25:
                            return -0.035171479
                        if state == 26:
                            state = (
                                47
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.42504406)
                                else 48
                            )
                            if state == 47:
                                return -0.297809035
                            if state == 48:
                                state = (
                                    79
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.80631995)
                                    else 80
                                )
                                if state == 79:
                                    return 0.0924687684
                                if state == 80:
                                    return -0.133855611
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.17533949)
                            else 28
                        )
                        if state == 27:
                            state = (
                                49
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.42867327)
                                else 50
                            )
                            if state == 49:
                                return -0.0762533844
                            if state == 50:
                                state = (
                                    83
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 3.03194666)
                                    else 84
                                )
                                if state == 83:
                                    state = (
                                        125
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 18.2501698)
                                        else 126
                                    )
                                    if state == 125:
                                        return -0.0310650673
                                    if state == 126:
                                        return 0.178918466
                                if state == 84:
                                    return -0.0664357543
                        if state == 28:
                            state = (
                                51
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.89116216)
                                else 52
                            )
                            if state == 51:
                                return 0.072634913
                            if state == 52:
                                return -0.260399848
    elif num_booster == 33:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 0.926187694 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 6.02027225)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.6802483)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["maggaia_med"] < 18.9767303 else 16
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1577492)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    49
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 30.9950104)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        77
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.1708317)
                                        else 78
                                    )
                                    if state == 77:
                                        return 0.0153795481
                                    if state == 78:
                                        state = (
                                            125
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 1.89245951)
                                            else 126
                                        )
                                        if state == 125:
                                            return -0.226956636
                                        if state == 126:
                                            state = (
                                                171
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0971071497)
                                                else 172
                                            )
                                            if state == 171:
                                                state = (
                                                    225
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.5166435)
                                                    else 226
                                                )
                                                if state == 225:
                                                    return -0.217006922
                                                if state == 226:
                                                    return -0.0164148025
                                            if state == 172:
                                                return 0.121319562
                                if state == 50:
                                    state = (
                                        79
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.7902851)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            127
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.95865154)
                                            else 128
                                        )
                                        if state == 127:
                                            return -0.315135509
                                        if state == 128:
                                            return -0.120646857
                                    if state == 80:
                                        return 0.0274900626
                            if state == 30:
                                state = (
                                    51
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 18.06143)
                                    else 52
                                )
                                if state == 51:
                                    return 0.197747707
                                if state == 52:
                                    return -0.167753652
                        if state == 16:
                            return 0.198307484
                    if state == 8:
                        return -0.209917679
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.4982491)
                        else 10
                    )
                    if state == 9:
                        return -0.162938938
                    if state == 10:
                        state = 19 if x["maggaia_med"] < 19.3261929 else 20
                        if state == 19:
                            state = (
                                33
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.4011993)
                                else 34
                            )
                            if state == 33:
                                return 0.244810998
                            if state == 34:
                                return 0.00550836371
                        if state == 20:
                            return 0.00240995083
            if state == 2:
                state = (
                    5
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.13833332)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 21.467001)
                        else 12
                    )
                    if state == 11:
                        state = 21 if x["maggaia_med"] < 18.8987217 else 22
                        if state == 21:
                            state = (
                                35
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1568985)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    53
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 18.9563599)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        83
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.5852184)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            129
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.98169565)
                                            else 130
                                        )
                                        if state == 129:
                                            state = (
                                                173
                                                if x["sgscore1_med"] < 0.0667292029
                                                else 174
                                            )
                                            if state == 173:
                                                return 0.236260697
                                            if state == 174:
                                                state = (
                                                    229
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.8942642)
                                                    else 230
                                                )
                                                if state == 229:
                                                    state = (
                                                        297
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.1174507)
                                                        else 298
                                                    )
                                                    if state == 297:
                                                        return -0.0195494331
                                                    if state == 298:
                                                        return 0.230319887
                                                if state == 230:
                                                    state = (
                                                        299
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.6970634)
                                                        else 300
                                                    )
                                                    if state == 299:
                                                        state = (
                                                            365
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.03381944
                                                            )
                                                            else 366
                                                        )
                                                        if state == 365:
                                                            return 0.193122119
                                                        if state == 366:
                                                            return -0.0560117811
                                                    if state == 300:
                                                        return -0.232934669
                                        if state == 130:
                                            state = (
                                                175
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0781131014)
                                                else 176
                                            )
                                            if state == 175:
                                                state = (
                                                    231
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.1581917)
                                                    else 232
                                                )
                                                if state == 231:
                                                    state = (
                                                        301
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.3203011)
                                                        else 302
                                                    )
                                                    if state == 301:
                                                        return -0.0216211136
                                                    if state == 302:
                                                        return 0.206028953
                                                if state == 232:
                                                    return -0.0714978352
                                            if state == 176:
                                                state = (
                                                    233
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.9535141)
                                                    else 234
                                                )
                                                if state == 233:
                                                    return 0.0605080687
                                                if state == 234:
                                                    state = (
                                                        305
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.5550995)
                                                        else 306
                                                    )
                                                    if state == 305:
                                                        return -0.227460369
                                                    if state == 306:
                                                        return 0.00967945531
                                    if state == 84:
                                        return -0.149162948
                                if state == 54:
                                    state = (
                                        85
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.3572369)
                                        else 86
                                    )
                                    if state == 85:
                                        return 0.247247785
                                    if state == 86:
                                        state = (
                                            131
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.9962616)
                                            else 132
                                        )
                                        if state == 131:
                                            state = (
                                                177
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0550565496)
                                                else 178
                                            )
                                            if state == 177:
                                                state = (
                                                    235
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.5960999)
                                                    else 236
                                                )
                                                if state == 235:
                                                    state = (
                                                        307
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.9859009)
                                                        else 308
                                                    )
                                                    if state == 307:
                                                        return -0.0539343208
                                                    if state == 308:
                                                        return 0.108995818
                                                if state == 236:
                                                    return 0.197415382
                                            if state == 178:
                                                state = (
                                                    237
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.453846)
                                                    else 238
                                                )
                                                if state == 237:
                                                    return 0.092283994
                                                if state == 238:
                                                    state = (
                                                        309
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.1921616)
                                                        else 310
                                                    )
                                                    if state == 309:
                                                        return -0.0905375034
                                                    if state == 310:
                                                        state = (
                                                            371
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.86390042
                                                            )
                                                            else 372
                                                        )
                                                        if state == 371:
                                                            return -0.0312731639
                                                        if state == 372:
                                                            return 0.0996675491
                                        if state == 132:
                                            return 0.203272
                            if state == 36:
                                state = (
                                    55
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 44.8635941)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        87
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.2706871)
                                        else 88
                                    )
                                    if state == 87:
                                        return 0.181578815
                                    if state == 88:
                                        state = (
                                            133
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.971626163)
                                            else 134
                                        )
                                        if state == 133:
                                            state = (
                                                179
                                                if x["sgscore1_med"] < 0.181949005
                                                else 180
                                            )
                                            if state == 179:
                                                state = (
                                                    239
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.2421532)
                                                    else 240
                                                )
                                                if state == 239:
                                                    state = (
                                                        311
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.5562496)
                                                        else 312
                                                    )
                                                    if state == 311:
                                                        state = (
                                                            373
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 0.0396643505
                                                            )
                                                            else 374
                                                        )
                                                        if state == 373:
                                                            return 0.000516712025
                                                        if state == 374:
                                                            return 0.222710073
                                                    if state == 312:
                                                        return -0.125315651
                                                if state == 240:
                                                    return 0.197126493
                                            if state == 180:
                                                return -0.234942034
                                        if state == 134:
                                            state = (
                                                181
                                                if x["sgscore1_med"] < 0.198163494
                                                else 182
                                            )
                                            if state == 181:
                                                state = (
                                                    243
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.1197834)
                                                    else 244
                                                )
                                                if state == 243:
                                                    return 0.150178492
                                                if state == 244:
                                                    state = (
                                                        313
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.8865013)
                                                        else 314
                                                    )
                                                    if state == 313:
                                                        state = (
                                                            375
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 3.02195597
                                                            )
                                                            else 376
                                                        )
                                                        if state == 375:
                                                            return -0.12886861
                                                        if state == 376:
                                                            return 0.0444654971
                                                    if state == 314:
                                                        return 0.0897452459
                                            if state == 182:
                                                state = (
                                                    245
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.1500359)
                                                    else 246
                                                )
                                                if state == 245:
                                                    return -0.25817588
                                                if state == 246:
                                                    state = (
                                                        315
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.7206001)
                                                        else 316
                                                    )
                                                    if state == 315:
                                                        return -0.265330076
                                                    if state == 316:
                                                        return 0.140268117
                                if state == 56:
                                    return 0.160567477
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.426651)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    57
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 15.0546064)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        89
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.1377506)
                                        else 90
                                    )
                                    if state == 89:
                                        state = (
                                            135
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.97865152)
                                            else 136
                                        )
                                        if state == 135:
                                            state = (
                                                183
                                                if x["sgscore1_med"] < 0.544526994
                                                else 184
                                            )
                                            if state == 183:
                                                state = (
                                                    247
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.913063)
                                                    else 248
                                                )
                                                if state == 247:
                                                    return 0.281468242
                                                if state == 248:
                                                    state = (
                                                        317
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.5494499)
                                                        else 318
                                                    )
                                                    if state == 317:
                                                        return -0.0817266405
                                                    if state == 318:
                                                        state = (
                                                            377
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.92198491
                                                            )
                                                            else 378
                                                        )
                                                        if state == 377:
                                                            return -0.0117708026
                                                        if state == 378:
                                                            return 0.246829912
                                            if state == 184:
                                                return -0.106397167
                                        if state == 136:
                                            state = (
                                                185
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00270833494)
                                                else 186
                                            )
                                            if state == 185:
                                                return 0.165838689
                                            if state == 186:
                                                state = (
                                                    251
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.7577858)
                                                    else 252
                                                )
                                                if state == 251:
                                                    return 0.0968288034
                                                if state == 252:
                                                    state = (
                                                        319
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.8880005)
                                                        else 320
                                                    )
                                                    if state == 319:
                                                        return 0.062669754
                                                    if state == 320:
                                                        return -0.219384879
                                    if state == 90:
                                        state = (
                                            137
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 3.02734947)
                                            else 138
                                        )
                                        if state == 137:
                                            state = (
                                                187
                                                if x["sgscore1_med"] < 0.00204166491
                                                else 188
                                            )
                                            if state == 187:
                                                return 0.105347954
                                            if state == 188:
                                                return -0.245419905
                                        if state == 138:
                                            return 0.0250710361
                                if state == 58:
                                    state = (
                                        91
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.042408)
                                        else 92
                                    )
                                    if state == 91:
                                        state = (
                                            139
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.90409708)
                                            else 140
                                        )
                                        if state == 139:
                                            state = (
                                                189
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00392857008)
                                                else 190
                                            )
                                            if state == 189:
                                                return -0.303458989
                                            if state == 190:
                                                state = (
                                                    253
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.6446724)
                                                    else 254
                                                )
                                                if state == 253:
                                                    return -0.0951482281
                                                if state == 254:
                                                    state = (
                                                        323
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.6172943)
                                                        else 324
                                                    )
                                                    if state == 323:
                                                        return -0.0464146771
                                                    if state == 324:
                                                        return 0.186500713
                                        if state == 140:
                                            state = (
                                                191
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.328113019)
                                                else 192
                                            )
                                            if state == 191:
                                                return 0.197655216
                                            if state == 192:
                                                state = (
                                                    255
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.3737259)
                                                    else 256
                                                )
                                                if state == 255:
                                                    return -0.181584746
                                                if state == 256:
                                                    state = (
                                                        325
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.6090012)
                                                        else 326
                                                    )
                                                    if state == 325:
                                                        return -0.0494004041
                                                    if state == 326:
                                                        return 0.155516982
                                    if state == 92:
                                        state = (
                                            141
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 3.02623844)
                                            else 142
                                        )
                                        if state == 141:
                                            state = (
                                                193
                                                if x["sgscore1_med"] < 0.00395833515
                                                else 194
                                            )
                                            if state == 193:
                                                state = (
                                                    257
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.5198097)
                                                    else 258
                                                )
                                                if state == 257:
                                                    state = (
                                                        327
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.5133495)
                                                        else 328
                                                    )
                                                    if state == 327:
                                                        return 0.130176678
                                                    if state == 328:
                                                        return -0.110358186
                                                if state == 258:
                                                    state = (
                                                        329
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.1273994)
                                                        else 330
                                                    )
                                                    if state == 329:
                                                        state = (
                                                            381
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.90600109
                                                            )
                                                            else 382
                                                        )
                                                        if state == 381:
                                                            return -0.105391763
                                                        if state == 382:
                                                            return 0.217118934
                                                    if state == 330:
                                                        return -0.106744938
                                            if state == 194:
                                                state = (
                                                    259
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 20.1921329)
                                                    else 260
                                                )
                                                if state == 259:
                                                    state = (
                                                        331
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.9263)
                                                        else 332
                                                    )
                                                    if state == 331:
                                                        state = (
                                                            383
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 2.91129041
                                                            )
                                                            else 384
                                                        )
                                                        if state == 383:
                                                            return -0.17731379
                                                        if state == 384:
                                                            return 0.000564400863
                                                    if state == 332:
                                                        return -0.304580271
                                                if state == 260:
                                                    state = (
                                                        333
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.7267971)
                                                        else 334
                                                    )
                                                    if state == 333:
                                                        return -0.124212854
                                                    if state == 334:
                                                        return 0.0847982466
                                        if state == 142:
                                            return 0.169086844
                            if state == 38:
                                state = (
                                    59
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 14.9387093)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        93
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.6264)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            143
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.86420727)
                                            else 144
                                        )
                                        if state == 143:
                                            return 0.239275753
                                        if state == 144:
                                            return -0.0504150465
                                    if state == 94:
                                        return -0.132237002
                                if state == 60:
                                    state = (
                                        95
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.853941)
                                        else 96
                                    )
                                    if state == 95:
                                        return 0.23884964
                                    if state == 96:
                                        state = (
                                            145
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.91072893)
                                            else 146
                                        )
                                        if state == 145:
                                            state = (
                                                201
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.131026998)
                                                else 202
                                            )
                                            if state == 201:
                                                state = (
                                                    265
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 20.2723007)
                                                    else 266
                                                )
                                                if state == 265:
                                                    state = (
                                                        335
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 21.1796989)
                                                        else 336
                                                    )
                                                    if state == 335:
                                                        return -0.213534489
                                                    if state == 336:
                                                        return 0.00129590824
                                                if state == 266:
                                                    return 0.0445175767
                                            if state == 202:
                                                state = (
                                                    267
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.2234783)
                                                    else 268
                                                )
                                                if state == 267:
                                                    state = (
                                                        337
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.7962494)
                                                        else 338
                                                    )
                                                    if state == 337:
                                                        return -0.0633320734
                                                    if state == 338:
                                                        return 0.1033426
                                                if state == 268:
                                                    state = (
                                                        339
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 21.0667992)
                                                        else 340
                                                    )
                                                    if state == 339:
                                                        return 0.270833164
                                                    if state == 340:
                                                        return -0.038716834
                                        if state == 146:
                                            state = (
                                                203
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0126101002)
                                                else 204
                                            )
                                            if state == 203:
                                                return -0.265486807
                                            if state == 204:
                                                return -0.0231315754
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 19.3104744)
                            else 24
                        )
                        if state == 23:
                            state = (
                                39
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3691502)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    61
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 21.0160179)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        97
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.5312958)
                                        else 98
                                    )
                                    if state == 97:
                                        state = (
                                            147
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.51784724)
                                            else 148
                                        )
                                        if state == 147:
                                            return -0.138096392
                                        if state == 148:
                                            return 0.07356821
                                    if state == 98:
                                        return -0.290860415
                                if state == 62:
                                    state = (
                                        99
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.3080997)
                                        else 100
                                    )
                                    if state == 99:
                                        return 0.11255683
                                    if state == 100:
                                        state = (
                                            149
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.97587395)
                                            else 150
                                        )
                                        if state == 149:
                                            return -0.166970477
                                        if state == 150:
                                            return 0.127555221
                            if state == 40:
                                state = (
                                    63
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 21.9035931)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        101
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.9381866)
                                        else 102
                                    )
                                    if state == 101:
                                        return 0.0907056853
                                    if state == 102:
                                        return -0.118841574
                                if state == 64:
                                    return 0.0549422391
                        if state == 24:
                            state = (
                                41
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.6734009)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    65
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 39.9957962)
                                    else 66
                                )
                                if state == 65:
                                    return -0.218076944
                                if state == 66:
                                    return 0.00780668808
                            if state == 42:
                                return 0.155578315
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.4817505)
                        else 14
                    )
                    if state == 13:
                        state = 25 if x["maggaia_med"] < 19.1350517 else 26
                        if state == 25:
                            state = (
                                43
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9914036)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    67
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 53.9850235)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        105
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.392355)
                                        else 106
                                    )
                                    if state == 105:
                                        state = (
                                            151
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 5.93446732)
                                            else 152
                                        )
                                        if state == 151:
                                            return -0.128932402
                                        if state == 152:
                                            return 0.088077262
                                    if state == 106:
                                        return -0.247906178
                                if state == 68:
                                    return -0.0137673356
                            if state == 44:
                                state = (
                                    69
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 22.4810123)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        109
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.0385094)
                                        else 110
                                    )
                                    if state == 109:
                                        return -0.104569323
                                    if state == 110:
                                        return 0.141736671
                                if state == 70:
                                    return -0.134782806
                        if state == 26:
                            state = (
                                45
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.2961006)
                                else 46
                            )
                            if state == 45:
                                return -0.128226206
                            if state == 46:
                                state = (
                                    71
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 13.9313145)
                                    else 72
                                )
                                if state == 71:
                                    state = (
                                        111
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.69631)
                                        else 112
                                    )
                                    if state == 111:
                                        return 0.104278542
                                    if state == 112:
                                        return -0.205367565
                                if state == 72:
                                    state = (
                                        113
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.3466148)
                                        else 114
                                    )
                                    if state == 113:
                                        state = (
                                            153
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 9.45798016)
                                            else 154
                                        )
                                        if state == 153:
                                            state = (
                                                205
                                                if x["sgscore1_med"] < 0.00991666503
                                                else 206
                                            )
                                            if state == 205:
                                                return -0.0413066261
                                            if state == 206:
                                                state = (
                                                    273
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.0982056)
                                                    else 274
                                                )
                                                if state == 273:
                                                    state = (
                                                        341
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.4242001)
                                                        else 342
                                                    )
                                                    if state == 341:
                                                        return 0.212203473
                                                    if state == 342:
                                                        return -0.0302157048
                                                if state == 274:
                                                    return 0.0201377701
                                        if state == 154:
                                            return -0.185730785
                                    if state == 114:
                                        state = (
                                            155
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 7.96081018)
                                            else 156
                                        )
                                        if state == 155:
                                            return 0.225425601
                                        if state == 156:
                                            return -0.128223941
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 20.5690384)
                            else 28
                        )
                        if state == 27:
                            state = (
                                47
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.2406006)
                                else 48
                            )
                            if state == 47:
                                state = (
                                    73
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 11.0729275)
                                    else 74
                                )
                                if state == 73:
                                    state = (
                                        115
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.3023605)
                                        else 116
                                    )
                                    if state == 115:
                                        return 0.0404262021
                                    if state == 116:
                                        return -0.205424652
                                if state == 74:
                                    state = (
                                        117
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.2416401)
                                        else 118
                                    )
                                    if state == 117:
                                        state = (
                                            159
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 9.92728615)
                                            else 160
                                        )
                                        if state == 159:
                                            state = (
                                                207
                                                if x["sgscore1_med"] < 0.00499999989
                                                else 208
                                            )
                                            if state == 207:
                                                return -0.0368347131
                                            if state == 208:
                                                return 0.21103625
                                        if state == 160:
                                            return -0.0872022137
                                    if state == 118:
                                        state = (
                                            161
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 6.06523705)
                                            else 162
                                        )
                                        if state == 161:
                                            state = (
                                                211
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.411931515)
                                                else 212
                                            )
                                            if state == 211:
                                                state = (
                                                    275
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.4032421)
                                                    else 276
                                                )
                                                if state == 275:
                                                    return -0.000589636096
                                                if state == 276:
                                                    state = (
                                                        345
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.9552002)
                                                        else 346
                                                    )
                                                    if state == 345:
                                                        return 0.147107273
                                                    if state == 346:
                                                        state = (
                                                            385
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 4.9246645
                                                            )
                                                            else 386
                                                        )
                                                        if state == 385:
                                                            return 0.140069276
                                                        if state == 386:
                                                            return -0.114804476
                                            if state == 212:
                                                return -0.179117858
                                        if state == 162:
                                            state = (
                                                213
                                                if x["sgscore1_med"] < 0.052779749
                                                else 214
                                            )
                                            if state == 213:
                                                state = (
                                                    277
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.3727951)
                                                    else 278
                                                )
                                                if state == 277:
                                                    return -0.178766534
                                                if state == 278:
                                                    return 0.0663201734
                                            if state == 214:
                                                return 0.228073031
                            if state == 48:
                                state = (
                                    75
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 39.046669)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        119
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.9931602)
                                        else 120
                                    )
                                    if state == 119:
                                        state = (
                                            163
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 9.4071703)
                                            else 164
                                        )
                                        if state == 163:
                                            state = (
                                                215
                                                if x["sgscore1_med"] < 0.838283539
                                                else 216
                                            )
                                            if state == 215:
                                                state = (
                                                    279
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.4887314)
                                                    else 280
                                                )
                                                if state == 279:
                                                    state = (
                                                        347
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.9159508)
                                                        else 348
                                                    )
                                                    if state == 347:
                                                        state = (
                                                            387
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 8.98141766
                                                            )
                                                            else 388
                                                        )
                                                        if state == 387:
                                                            return 0.0704247504
                                                        if state == 388:
                                                            return -0.216788501
                                                    if state == 348:
                                                        return 0.204778209
                                                if state == 280:
                                                    state = (
                                                        349
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.1290493)
                                                        else 350
                                                    )
                                                    if state == 349:
                                                        state = (
                                                            389
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 8.03011513
                                                            )
                                                            else 390
                                                        )
                                                        if state == 389:
                                                            return -0.152705908
                                                        if state == 390:
                                                            return 0.00705476059
                                                    if state == 350:
                                                        state = (
                                                            391
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 9.07336807
                                                            )
                                                            else 392
                                                        )
                                                        if state == 391:
                                                            return 0.143858135
                                                        if state == 392:
                                                            return -0.107422881
                                            if state == 216:
                                                return 0.221372485
                                        if state == 164:
                                            return 0.232805282
                                    if state == 120:
                                        state = (
                                            165
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 9.00357628)
                                            else 166
                                        )
                                        if state == 165:
                                            state = (
                                                217
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.42198801)
                                                else 218
                                            )
                                            if state == 217:
                                                state = (
                                                    281
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 20.6072693)
                                                    else 282
                                                )
                                                if state == 281:
                                                    state = (
                                                        351
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.83255)
                                                        else 352
                                                    )
                                                    if state == 351:
                                                        state = (
                                                            393
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 5.90215302
                                                            )
                                                            else 394
                                                        )
                                                        if state == 393:
                                                            return -0.159206912
                                                        if state == 394:
                                                            return -0.347947717
                                                    if state == 352:
                                                        state = (
                                                            395
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 5.99343777
                                                            )
                                                            else 396
                                                        )
                                                        if state == 395:
                                                            return 0.0380320586
                                                        if state == 396:
                                                            return -0.158370078
                                                if state == 282:
                                                    return 0.0725685656
                                            if state == 218:
                                                state = (
                                                    283
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.1833515)
                                                    else 284
                                                )
                                                if state == 283:
                                                    return -0.212148249
                                                if state == 284:
                                                    state = (
                                                        353
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.9655495)
                                                        else 354
                                                    )
                                                    if state == 353:
                                                        state = (
                                                            397
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 8.43314171
                                                            )
                                                            else 398
                                                        )
                                                        if state == 397:
                                                            return 0.198961273
                                                        if state == 398:
                                                            return -0.0836374015
                                                    if state == 354:
                                                        return -0.160641715
                                        if state == 166:
                                            state = (
                                                219
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.01491665)
                                                else 220
                                            )
                                            if state == 219:
                                                return 0.19178322
                                            if state == 220:
                                                return -0.0608524233
                                if state == 76:
                                    state = (
                                        121
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.295845)
                                        else 122
                                    )
                                    if state == 121:
                                        state = (
                                            167
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 9.93366337)
                                            else 168
                                        )
                                        if state == 167:
                                            return 0.266879886
                                        if state == 168:
                                            return -0.0427914038
                                    if state == 122:
                                        state = (
                                            169
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 5.02683449)
                                            else 170
                                        )
                                        if state == 169:
                                            state = (
                                                221
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0472083502)
                                                else 222
                                            )
                                            if state == 221:
                                                state = (
                                                    287
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.921032)
                                                    else 288
                                                )
                                                if state == 287:
                                                    return 0.0930131301
                                                if state == 288:
                                                    return -0.0841078386
                                            if state == 222:
                                                return -0.235076889
                                        if state == 170:
                                            state = (
                                                223
                                                if x["sgscore1_med"] < 0.00597917009
                                                else 224
                                            )
                                            if state == 223:
                                                state = (
                                                    289
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.7804832)
                                                    else 290
                                                )
                                                if state == 289:
                                                    return -0.128492743
                                                if state == 290:
                                                    return 0.0452184789
                                            if state == 224:
                                                state = (
                                                    291
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.6620674)
                                                    else 292
                                                )
                                                if state == 291:
                                                    return -0.0290587898
                                                if state == 292:
                                                    state = (
                                                        361
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.6120415)
                                                        else 362
                                                    )
                                                    if state == 361:
                                                        return -0.0710001439
                                                    if state == 362:
                                                        return 0.197038963
                        if state == 28:
                            return -0.245918646
    elif num_booster == 34:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 0.255751789 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.0243124999)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.167916074)
                        else 8
                    )
                    if state == 7:
                        return -0.157043621
                    if state == 8:
                        state = 15 if x["sgscore1_med"] < 0.00808333512 else 16
                        if state == 15:
                            return -0.0694446415
                        if state == 16:
                            state = 27 if x["col_det"] < 0.245006561 else 28
                            if state == 27:
                                return -0.0430396758
                            if state == 28:
                                return 0.218711212
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.155263394)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["sgscore1_med"] < 0.196862996 else 18
                        if state == 17:
                            return -0.104181863
                        if state == 18:
                            return 0.102746688
                    if state == 10:
                        state = 19 if x["sgscore1_med"] < 0.0411666483 else 20
                        if state == 19:
                            state = 29 if x["col_det"] < 0.0511837006 else 30
                            if state == 29:
                                return 0.11172881
                            if state == 30:
                                return -0.162048355
                        if state == 20:
                            return -0.302808017
            if state == 2:
                state = (
                    5
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.504097998)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.115753241)
                        else 12
                    )
                    if state == 11:
                        return 0.234805226
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0143541507)
                            else 22
                        )
                        if state == 21:
                            state = 31 if x["col_det"] < 0.00654983521 else 32
                            if state == 31:
                                state = (
                                    43
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.4356499)
                                    else 44
                                )
                                if state == 43:
                                    state = (
                                        59
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.211903095)
                                        else 60
                                    )
                                    if state == 59:
                                        state = (
                                            79
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 45.9233208)
                                            else 80
                                        )
                                        if state == 79:
                                            state = (
                                                107
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 19.0477695)
                                                else 108
                                            )
                                            if state == 107:
                                                state = (
                                                    145
                                                    if x["neargaia_med"] < 19.8198967
                                                    else 146
                                                )
                                                if state == 145:
                                                    state = (
                                                        181
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.850529552
                                                        )
                                                        else 182
                                                    )
                                                    if state == 181:
                                                        return -0.0840463415
                                                    if state == 182:
                                                        state = (
                                                            223
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.14394426
                                                            )
                                                            else 224
                                                        )
                                                        if state == 223:
                                                            return 0.213044897
                                                        if state == 224:
                                                            return -0.0360431448
                                                if state == 146:
                                                    state = (
                                                        183
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.278782904
                                                        )
                                                        else 184
                                                    )
                                                    if state == 183:
                                                        return -0.1743166
                                                    if state == 184:
                                                        return 0.220081791
                                            if state == 108:
                                                return -0.10939201
                                        if state == 80:
                                            state = (
                                                109
                                                if x["mag_peak"] < 18.409935
                                                else 110
                                            )
                                            if state == 109:
                                                return 0.114212126
                                            if state == 110:
                                                state = (
                                                    147
                                                    if x["neargaia_med"] < 64.2927933
                                                    else 148
                                                )
                                                if state == 147:
                                                    return -0.239256114
                                                if state == 148:
                                                    return 0.0900702402
                                    if state == 60:
                                        state = (
                                            81
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 45.935463)
                                            else 82
                                        )
                                        if state == 81:
                                            state = (
                                                111
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.5166969)
                                                else 112
                                            )
                                            if state == 111:
                                                state = (
                                                    149
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 17.0327339)
                                                    else 150
                                                )
                                                if state == 149:
                                                    state = (
                                                        185
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.840819359
                                                        )
                                                        else 186
                                                    )
                                                    if state == 185:
                                                        return -0.181599334
                                                    if state == 186:
                                                        return 0.0758891329
                                                if state == 150:
                                                    return 0.032245405
                                            if state == 112:
                                                return 0.0837587491
                                        if state == 82:
                                            return -0.118467048
                                if state == 44:
                                    return -0.245157361
                            if state == 32:
                                state = (
                                    45
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.5160484)
                                    else 46
                                )
                                if state == 45:
                                    state = 61 if x["col_last"] < 0.0411691666 else 62
                                    if state == 61:
                                        return -0.124572963
                                    if state == 62:
                                        state = (
                                            83 if x["neargaia_med"] < 29.6155815 else 84
                                        )
                                        if state == 83:
                                            state = (
                                                113
                                                if x["mag_peak"] < 18.3018456
                                                else 114
                                            )
                                            if state == 113:
                                                return 0.12799421
                                            if state == 114:
                                                state = (
                                                    155
                                                    if x["neargaia_med"] < 16.9242496
                                                    else 156
                                                )
                                                if state == 155:
                                                    state = (
                                                        187
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.832683921
                                                        )
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        state = (
                                                            227
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.487698257
                                                            )
                                                            else 228
                                                        )
                                                        if state == 227:
                                                            return 0.0788783729
                                                        if state == 228:
                                                            return -0.210320115
                                                    if state == 188:
                                                        return 0.108252168
                                                if state == 156:
                                                    state = (
                                                        189
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.935156584
                                                        )
                                                        else 190
                                                    )
                                                    if state == 189:
                                                        return -0.266848683
                                                    if state == 190:
                                                        return 0.138873905
                                        if state == 84:
                                            state = (
                                                115
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.8215885)
                                                else 116
                                            )
                                            if state == 115:
                                                return 0.212435335
                                            if state == 116:
                                                return -0.0878332704
                                if state == 46:
                                    state = 63 if x["col_last"] < 0.0564517975 else 64
                                    if state == 63:
                                        state = (
                                            85 if x["neargaia_med"] < 53.5508423 else 86
                                        )
                                        if state == 85:
                                            state = (
                                                117
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.8187771)
                                                else 118
                                            )
                                            if state == 117:
                                                state = (
                                                    157
                                                    if x["neargaia_med"] < 38.3942032
                                                    else 158
                                                )
                                                if state == 157:
                                                    state = (
                                                        191
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.290111005
                                                        )
                                                        else 192
                                                    )
                                                    if state == 191:
                                                        return 0.160501972
                                                    if state == 192:
                                                        state = (
                                                            231
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.907636523
                                                            )
                                                            else 232
                                                        )
                                                        if state == 231:
                                                            return -0.101849221
                                                        if state == 232:
                                                            return 0.0820808485
                                                if state == 158:
                                                    return -0.127971679
                                            if state == 118:
                                                return -0.0964435488
                                        if state == 86:
                                            return 0.0837431699
                                    if state == 64:
                                        state = (
                                            87
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 53.6193047)
                                            else 88
                                        )
                                        if state == 87:
                                            state = (
                                                119
                                                if x["mag_peak"] < 18.3412762
                                                else 120
                                            )
                                            if state == 119:
                                                state = (
                                                    159
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 37.5544434)
                                                    else 160
                                                )
                                                if state == 159:
                                                    return 0.298430443
                                                if state == 160:
                                                    return -0.214568838
                                            if state == 120:
                                                state = (
                                                    161
                                                    if x["neargaia_med"] < 11.361248
                                                    else 162
                                                )
                                                if state == 161:
                                                    state = (
                                                        195
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 0.66897738
                                                        )
                                                        else 196
                                                    )
                                                    if state == 195:
                                                        return -0.200715408
                                                    if state == 196:
                                                        state = (
                                                            233
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.29764652
                                                            )
                                                            else 234
                                                        )
                                                        if state == 233:
                                                            return 0.125953883
                                                        if state == 234:
                                                            return -0.0338058211
                                                if state == 162:
                                                    state = (
                                                        197
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 3.81465721
                                                        )
                                                        else 198
                                                    )
                                                    if state == 197:
                                                        state = (
                                                            235
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.5127033
                                                            )
                                                            else 236
                                                        )
                                                        if state == 235:
                                                            return -0.0192459673
                                                        if state == 236:
                                                            return -0.242045388
                                                    if state == 198:
                                                        state = (
                                                            237
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 5.24333572
                                                            )
                                                            else 238
                                                        )
                                                        if state == 237:
                                                            return 0.176531821
                                                        if state == 238:
                                                            return -0.131722644
                                        if state == 88:
                                            state = (
                                                121
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.3410339)
                                                else 122
                                            )
                                            if state == 121:
                                                state = (
                                                    163
                                                    if x["neargaia_med"] < 61.4370422
                                                    else 164
                                                )
                                                if state == 163:
                                                    return 0.257752448
                                                if state == 164:
                                                    state = (
                                                        199
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.288492948
                                                        )
                                                        else 200
                                                    )
                                                    if state == 199:
                                                        return 0.116578497
                                                    if state == 200:
                                                        return -0.170443133
                                            if state == 122:
                                                state = (
                                                    165
                                                    if x["neargaia_med"] < 58.7469788
                                                    else 166
                                                )
                                                if state == 165:
                                                    return 0.147455081
                                                if state == 166:
                                                    return -0.134740904
                        if state == 22:
                            state = 33 if x["col_det"] < -0.200027466 else 34
                            if state == 33:
                                state = (
                                    47
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.1268005)
                                    else 48
                                )
                                if state == 47:
                                    state = 65 if x["col_last"] < -0.145664692 else 66
                                    if state == 65:
                                        return 0.000752245774
                                    if state == 66:
                                        state = (
                                            89 if x["neargaia_med"] < 79.3729553 else 90
                                        )
                                        if state == 89:
                                            state = (
                                                123
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.9413338)
                                                else 124
                                            )
                                            if state == 123:
                                                return 0.239861175
                                            if state == 124:
                                                return -0.0269612093
                                        if state == 90:
                                            return -0.0908314735
                                if state == 48:
                                    state = 67 if x["col_last"] < -0.121732235 else 68
                                    if state == 67:
                                        return 0.151353776
                                    if state == 68:
                                        state = (
                                            91 if x["neargaia_med"] < 12.9020882 else 92
                                        )
                                        if state == 91:
                                            return 0.0872904286
                                        if state == 92:
                                            return -0.214658424
                            if state == 34:
                                state = (
                                    49
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 18.312912)
                                    else 50
                                )
                                if state == 49:
                                    state = 69 if x["col_last"] < 0.379258156 else 70
                                    if state == 69:
                                        state = (
                                            93 if x["neargaia_med"] < 15.5754147 else 94
                                        )
                                        if state == 93:
                                            return -0.210715875
                                        if state == 94:
                                            return 0.0121400123
                                    if state == 70:
                                        state = (
                                            95
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 14.4686403)
                                            else 96
                                        )
                                        if state == 95:
                                            state = (
                                                127
                                                if x["mag_peak"] < 17.8278561
                                                else 128
                                            )
                                            if state == 127:
                                                state = (
                                                    167
                                                    if x["neargaia_med"] < 10.9030275
                                                    else 168
                                                )
                                                if state == 167:
                                                    return -0.122782685
                                                if state == 168:
                                                    return 0.0313863046
                                            if state == 128:
                                                return -0.20828034
                                        if state == 96:
                                            return 0.192057237
                                if state == 50:
                                    state = (
                                        71
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.943062782)
                                        else 72
                                    )
                                    if state == 71:
                                        state = (
                                            97
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 44.3937111)
                                            else 98
                                        )
                                        if state == 97:
                                            state = (
                                                131
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.9921303)
                                                else 132
                                            )
                                            if state == 131:
                                                state = (
                                                    169
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 36.3821182)
                                                    else 170
                                                )
                                                if state == 169:
                                                    state = (
                                                        207
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 2.52321053
                                                        )
                                                        else 208
                                                    )
                                                    if state == 207:
                                                        state = (
                                                            239
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.421563148
                                                            )
                                                            else 240
                                                        )
                                                        if state == 239:
                                                            return -0.00986836385
                                                        if state == 240:
                                                            return 0.0802050456
                                                    if state == 208:
                                                        state = (
                                                            241
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.15293241
                                                            )
                                                            else 242
                                                        )
                                                        if state == 241:
                                                            return -0.076205641
                                                        if state == 242:
                                                            return 0.0272214282
                                                if state == 170:
                                                    state = (
                                                        209
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 2.01350188
                                                        )
                                                        else 210
                                                    )
                                                    if state == 209:
                                                        state = (
                                                            243
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.756559074
                                                            )
                                                            else 244
                                                        )
                                                        if state == 243:
                                                            return 0.0155107528
                                                        if state == 244:
                                                            return 0.248860344
                                                    if state == 210:
                                                        state = (
                                                            245
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.41186166
                                                            )
                                                            else 246
                                                        )
                                                        if state == 245:
                                                            return -0.206919581
                                                        if state == 246:
                                                            return 0.137938857
                                            if state == 132:
                                                state = (
                                                    171
                                                    if x["neargaia_med"] < 43.91996
                                                    else 172
                                                )
                                                if state == 171:
                                                    return -0.299132198
                                                if state == 172:
                                                    state = (
                                                        211
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.66027761
                                                        )
                                                        else 212
                                                    )
                                                    if state == 211:
                                                        return -0.114246204
                                                    if state == 212:
                                                        return 0.128588051
                                        if state == 98:
                                            state = (
                                                133
                                                if x["mag_peak"] < 17.9111977
                                                else 134
                                            )
                                            if state == 133:
                                                return 0.176673278
                                            if state == 134:
                                                state = (
                                                    173
                                                    if x["neargaia_med"] < 72.2097397
                                                    else 174
                                                )
                                                if state == 173:
                                                    state = (
                                                        213
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 3.98116589
                                                        )
                                                        else 214
                                                    )
                                                    if state == 213:
                                                        state = (
                                                            247
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.05280137
                                                            )
                                                            else 248
                                                        )
                                                        if state == 247:
                                                            return -0.189835861
                                                        if state == 248:
                                                            return 0.0289443433
                                                    if state == 214:
                                                        state = (
                                                            249
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 6.72203732
                                                            )
                                                            else 250
                                                        )
                                                        if state == 249:
                                                            return -0.294201612
                                                        if state == 250:
                                                            return 0.0357190482
                                                if state == 174:
                                                    state = (
                                                        215
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.15071833
                                                        )
                                                        else 216
                                                    )
                                                    if state == 215:
                                                        return -0.174276814
                                                    if state == 216:
                                                        return 0.185143068
                                    if state == 72:
                                        state = (
                                            99
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 10.1080723)
                                            else 100
                                        )
                                        if state == 99:
                                            state = (
                                                135
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.5477524)
                                                else 136
                                            )
                                            if state == 135:
                                                return 0.0189164467
                                            if state == 136:
                                                return -0.306031913
                                        if state == 100:
                                            state = (
                                                137
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.9410439)
                                                else 138
                                            )
                                            if state == 137:
                                                return 0.130383208
                                            if state == 138:
                                                return -0.0561975688
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 14.1642752)
                        else 14
                    )
                    if state == 13:
                        state = 23 if x["sgscore1_med"] < 0.701501727 else 24
                        if state == 23:
                            state = 35 if x["col_det"] < 0.342365265 else 36
                            if state == 35:
                                return -0.16682303
                            if state == 36:
                                state = (
                                    51
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 21.1058502)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        73
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.02754879)
                                        else 74
                                    )
                                    if state == 73:
                                        state = (
                                            101
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 33.7386169)
                                            else 102
                                        )
                                        if state == 101:
                                            state = (
                                                139
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 17.5497646)
                                                else 140
                                            )
                                            if state == 139:
                                                return -0.0621055365
                                            if state == 140:
                                                return 0.109445326
                                        if state == 102:
                                            return -0.140600055
                                    if state == 74:
                                        return 0.0654058382
                                if state == 52:
                                    return 0.120349474
                        if state == 24:
                            state = (
                                37
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < -0.434876442)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    53
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 18.7768497)
                                    else 54
                                )
                                if state == 53:
                                    return -0.198610067
                                if state == 54:
                                    state = 75 if x["col_last"] < 0.474549294 else 76
                                    if state == 75:
                                        return 0.0459500663
                                    if state == 76:
                                        state = (
                                            105
                                            if x["neargaia_med"] < 10.9592228
                                            else 106
                                        )
                                        if state == 105:
                                            return 0.0943673179
                                        if state == 106:
                                            state = (
                                                143
                                                if x["mag_peak"] < 18.7860775
                                                else 144
                                            )
                                            if state == 143:
                                                return 0.0449655689
                                            if state == 144:
                                                return -0.183841303
                            if state == 38:
                                return -0.223601684
                    if state == 14:
                        return 0.172898859
    elif num_booster == 35:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.599546432) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["col_last"]) or (x["col_last"] < 0.335721016) else 4
                )
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 20.898756) else 8
                    if state == 7:
                        state = 13 if x["col_peak"] < -0.274420261 else 14
                        if state == 13:
                            return -0.160710052
                        if state == 14:
                            state = 19 if x["mag_peak"] < 18.0918999 else 20
                            if state == 19:
                                state = 29 if x["col_peak"] < 0.27562952 else 30
                                if state == 29:
                                    state = 47 if x["col_peak"] < -0.215229988 else 48
                                    if state == 47:
                                        return 0.0627215356
                                    if state == 48:
                                        state = (
                                            65
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.466541886)
                                            else 66
                                        )
                                        if state == 65:
                                            return 0.0547642671
                                        if state == 66:
                                            state = (
                                                89
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 20.7832489)
                                                else 90
                                            )
                                            if state == 89:
                                                state = (
                                                    125
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.84317303)
                                                    else 126
                                                )
                                                if state == 125:
                                                    return -0.0848927572
                                                if state == 126:
                                                    return 0.0908200443
                                            if state == 90:
                                                return -0.143725976
                                if state == 30:
                                    return -0.263791263
                            if state == 20:
                                state = (
                                    31
                                    if np.isnan(x["col_peak"])
                                    or (x["col_peak"] < 0.383778572)
                                    else 32
                                )
                                if state == 31:
                                    state = (
                                        49
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < 0.261850357)
                                        else 50
                                    )
                                    if state == 49:
                                        state = (
                                            67
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.741522431)
                                            else 68
                                        )
                                        if state == 67:
                                            state = (
                                                91
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.7895012)
                                                else 92
                                            )
                                            if state == 91:
                                                state = (
                                                    127
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.412781894)
                                                    else 128
                                                )
                                                if state == 127:
                                                    state = (
                                                        173
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.763809562)
                                                        else 174
                                                    )
                                                    if state == 173:
                                                        state = (
                                                            223
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.363566816
                                                            )
                                                            else 224
                                                        )
                                                        if state == 223:
                                                            return 0.14625673
                                                        if state == 224:
                                                            return -0.0725809187
                                                    if state == 174:
                                                        state = (
                                                            225
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.20866625
                                                            )
                                                            else 226
                                                        )
                                                        if state == 225:
                                                            return 0.0888064206
                                                        if state == 226:
                                                            return -0.156328514
                                                if state == 128:
                                                    return 0.181167156
                                            if state == 92:
                                                state = (
                                                    129
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.379196584)
                                                    else 130
                                                )
                                                if state == 129:
                                                    state = (
                                                        175
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.684642792)
                                                        else 176
                                                    )
                                                    if state == 175:
                                                        state = (
                                                            227
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.243013322
                                                            )
                                                            else 228
                                                        )
                                                        if state == 227:
                                                            return 0.125770316
                                                        if state == 228:
                                                            return -0.0905198827
                                                    if state == 176:
                                                        return -0.0931939706
                                                if state == 130:
                                                    state = (
                                                        177
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.636547685)
                                                        else 178
                                                    )
                                                    if state == 177:
                                                        return -0.136405706
                                                    if state == 178:
                                                        return 0.0845955685
                                        if state == 68:
                                            state = (
                                                93
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.512001)
                                                else 94
                                            )
                                            if state == 93:
                                                state = (
                                                    131
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 4.52662754)
                                                    else 132
                                                )
                                                if state == 131:
                                                    state = (
                                                        179
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.698333144)
                                                        else 180
                                                    )
                                                    if state == 179:
                                                        state = (
                                                            233
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.55471098
                                                            )
                                                            else 234
                                                        )
                                                        if state == 233:
                                                            return -0.052168902
                                                        if state == 234:
                                                            return -0.241149172
                                                    if state == 180:
                                                        state = (
                                                            235
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.95721066
                                                            )
                                                            else 236
                                                        )
                                                        if state == 235:
                                                            return -0.0465776585
                                                        if state == 236:
                                                            return 0.0608057939
                                                if state == 132:
                                                    return 0.0967540592
                                            if state == 94:
                                                state = (
                                                    133
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.937862813)
                                                    else 134
                                                )
                                                if state == 133:
                                                    state = (
                                                        183
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.734285831)
                                                        else 184
                                                    )
                                                    if state == 183:
                                                        state = (
                                                            237
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.796646893
                                                            )
                                                            else 238
                                                        )
                                                        if state == 237:
                                                            return 0.0428799838
                                                        if state == 238:
                                                            return -0.260824174
                                                    if state == 184:
                                                        state = (
                                                            239
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.870308995
                                                            )
                                                            else 240
                                                        )
                                                        if state == 239:
                                                            return -0.129602045
                                                        if state == 240:
                                                            return 0.0628771484
                                                if state == 134:
                                                    state = (
                                                        185
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.58845216)
                                                        else 186
                                                    )
                                                    if state == 185:
                                                        state = (
                                                            241
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 4.05399323
                                                            )
                                                            else 242
                                                        )
                                                        if state == 241:
                                                            return 0.0925351232
                                                        if state == 242:
                                                            return -0.0543135256
                                                    if state == 186:
                                                        state = (
                                                            243
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.27939367
                                                            )
                                                            else 244
                                                        )
                                                        if state == 243:
                                                            return 0.0897490531
                                                        if state == 244:
                                                            return -0.0487665348
                                    if state == 50:
                                        return -0.13346535
                                if state == 32:
                                    state = 51 if x["col_peak"] < 0.444479942 else 52
                                    if state == 51:
                                        return 0.150705308
                                    if state == 52:
                                        return -0.0207109805
                    if state == 8:
                        state = 15 if x["col_peak"] < 0.150078773 else 16
                        if state == 15:
                            state = 21 if x["mag_peak"] < 18.5429649 else 22
                            if state == 21:
                                state = 33 if x["col_peak"] < -0.336855888 else 34
                                if state == 33:
                                    return -0.114334352
                                if state == 34:
                                    state = 53 if x["col_peak"] < 0.0459666252 else 54
                                    if state == 53:
                                        state = (
                                            69
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 6.54354954)
                                            else 70
                                        )
                                        if state == 69:
                                            state = (
                                                95
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.2754993)
                                                else 96
                                            )
                                            if state == 95:
                                                state = (
                                                    135
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.64169693)
                                                    else 136
                                                )
                                                if state == 135:
                                                    state = (
                                                        187
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.756190419)
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        state = (
                                                            245
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.4296751
                                                            )
                                                            else 246
                                                        )
                                                        if state == 245:
                                                            return -0.0234500729
                                                        if state == 246:
                                                            return 0.10663747
                                                    if state == 188:
                                                        return 0.182190523
                                                if state == 136:
                                                    state = (
                                                        189
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.799999952)
                                                        else 190
                                                    )
                                                    if state == 189:
                                                        state = (
                                                            249
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.09112406
                                                            )
                                                            else 250
                                                        )
                                                        if state == 249:
                                                            return -0.157689616
                                                        if state == 250:
                                                            return 0.0428844877
                                                    if state == 190:
                                                        return 0.0988209546
                                            if state == 96:
                                                return 0.207572356
                                        if state == 70:
                                            state = (
                                                97
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 22.7625008)
                                                else 98
                                            )
                                            if state == 97:
                                                return 0.11585062
                                            if state == 98:
                                                return -0.0877263919
                                    if state == 54:
                                        state = (
                                            71
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 4.09785938)
                                            else 72
                                        )
                                        if state == 71:
                                            state = (
                                                99
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.1394997)
                                                else 100
                                            )
                                            if state == 99:
                                                return -0.0801047087
                                            if state == 100:
                                                return 0.159278527
                                        if state == 72:
                                            return -0.0972493887
                            if state == 22:
                                state = 35 if x["col_peak"] < 0.12549305 else 36
                                if state == 35:
                                    state = 55 if x["col_peak"] < -0.142198563 else 56
                                    if state == 55:
                                        state = (
                                            73
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.642098904)
                                            else 74
                                        )
                                        if state == 73:
                                            state = (
                                                101
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.4365005)
                                                else 102
                                            )
                                            if state == 101:
                                                return -0.05290718
                                            if state == 102:
                                                return 0.108538434
                                        if state == 74:
                                            state = (
                                                103
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.5704994)
                                                else 104
                                            )
                                            if state == 103:
                                                state = (
                                                    145
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.21486092)
                                                    else 146
                                                )
                                                if state == 145:
                                                    state = (
                                                        193
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.695833206)
                                                        else 194
                                                    )
                                                    if state == 193:
                                                        return -0.0262856018
                                                    if state == 194:
                                                        return 0.150641665
                                                if state == 146:
                                                    return -0.109652348
                                            if state == 104:
                                                return -0.281375349
                                    if state == 56:
                                        state = (
                                            75
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 1.24759829)
                                            else 76
                                        )
                                        if state == 75:
                                            state = (
                                                105
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.1274986)
                                                else 106
                                            )
                                            if state == 105:
                                                return -0.0716152862
                                            if state == 106:
                                                state = (
                                                    149
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.03384304)
                                                    else 150
                                                )
                                                if state == 149:
                                                    state = (
                                                        195
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.595000029)
                                                        else 196
                                                    )
                                                    if state == 195:
                                                        return -0.145391673
                                                    if state == 196:
                                                        return 0.0720264316
                                                if state == 150:
                                                    return 0.169156343
                                        if state == 76:
                                            state = (
                                                107
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.6965008)
                                                else 108
                                            )
                                            if state == 107:
                                                state = (
                                                    151
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 4.95206738)
                                                    else 152
                                                )
                                                if state == 151:
                                                    return -0.183262721
                                                if state == 152:
                                                    return 0.0474279225
                                            if state == 108:
                                                state = (
                                                    153
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.73241663)
                                                    else 154
                                                )
                                                if state == 153:
                                                    return -0.113743454
                                                if state == 154:
                                                    return 0.114004351
                                if state == 36:
                                    return 0.196589023
                        if state == 16:
                            state = 23 if x["mag_peak"] < 18.9518013 else 24
                            if state == 23:
                                state = 37 if x["col_peak"] < 0.153181076 else 38
                                if state == 37:
                                    return -0.190360755
                                if state == 38:
                                    state = (
                                        57
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < 0.180814743)
                                        else 58
                                    )
                                    if state == 57:
                                        state = (
                                            77
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.959147811)
                                            else 78
                                        )
                                        if state == 77:
                                            state = (
                                                109
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.5965004)
                                                else 110
                                            )
                                            if state == 109:
                                                state = (
                                                    155
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.222148001)
                                                    else 156
                                                )
                                                if state == 155:
                                                    state = (
                                                        201
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.750833333)
                                                        else 202
                                                    )
                                                    if state == 201:
                                                        return 0.14469853
                                                    if state == 202:
                                                        return -0.021701362
                                                if state == 156:
                                                    return -0.188828275
                                            if state == 110:
                                                state = (
                                                    157
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.780220032)
                                                    else 158
                                                )
                                                if state == 157:
                                                    state = (
                                                        203
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.847857118)
                                                        else 204
                                                    )
                                                    if state == 203:
                                                        state = (
                                                            261
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.247551858
                                                            )
                                                            else 262
                                                        )
                                                        if state == 261:
                                                            return -0.0466732681
                                                        if state == 262:
                                                            return 0.193377614
                                                    if state == 204:
                                                        return 0.0120218378
                                                if state == 158:
                                                    return -0.156556934
                                        if state == 78:
                                            state = (
                                                111
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.9729996)
                                                else 112
                                            )
                                            if state == 111:
                                                state = (
                                                    159
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.57055557)
                                                    else 160
                                                )
                                                if state == 159:
                                                    state = (
                                                        207
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.597976446)
                                                        else 208
                                                    )
                                                    if state == 207:
                                                        return 0.0488017276
                                                    if state == 208:
                                                        return 0.292610645
                                                if state == 160:
                                                    state = (
                                                        209
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.528928518)
                                                        else 210
                                                    )
                                                    if state == 209:
                                                        state = (
                                                            265
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.16959596
                                                            )
                                                            else 266
                                                        )
                                                        if state == 265:
                                                            return -0.201951295
                                                        if state == 266:
                                                            return 0.0523147881
                                                    if state == 210:
                                                        state = (
                                                            267
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.63798881
                                                            )
                                                            else 268
                                                        )
                                                        if state == 267:
                                                            return -0.160204172
                                                        if state == 268:
                                                            return 0.156679049
                                            if state == 112:
                                                state = (
                                                    161
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.95948744)
                                                    else 162
                                                )
                                                if state == 161:
                                                    return 0.246940836
                                                if state == 162:
                                                    state = (
                                                        211
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.49071449)
                                                        else 212
                                                    )
                                                    if state == 211:
                                                        state = (
                                                            269
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.79287338
                                                            )
                                                            else 270
                                                        )
                                                        if state == 269:
                                                            return -0.0249378495
                                                        if state == 270:
                                                            return 0.241453782
                                                    if state == 212:
                                                        state = (
                                                            271
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.59357691
                                                            )
                                                            else 272
                                                        )
                                                        if state == 271:
                                                            return -0.0557586923
                                                        if state == 272:
                                                            return -0.195772588
                                    if state == 58:
                                        state = (
                                            79
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 1.26743841)
                                            else 80
                                        )
                                        if state == 79:
                                            state = (
                                                113
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 16.8840008)
                                                else 114
                                            )
                                            if state == 113:
                                                state = (
                                                    163
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.718070269)
                                                    else 164
                                                )
                                                if state == 163:
                                                    state = (
                                                        213
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.732500017)
                                                        else 214
                                                    )
                                                    if state == 213:
                                                        return 0.0792831928
                                                    if state == 214:
                                                        state = (
                                                            273
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.715226054
                                                            )
                                                            else 274
                                                        )
                                                        if state == 273:
                                                            return -0.0779047757
                                                        if state == 274:
                                                            return 0.0813085735
                                                if state == 164:
                                                    state = (
                                                        215
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.755000234)
                                                        else 216
                                                    )
                                                    if state == 215:
                                                        return -0.0405846797
                                                    if state == 216:
                                                        state = (
                                                            277
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.738005161
                                                            )
                                                            else 278
                                                        )
                                                        if state == 277:
                                                            return -0.221432462
                                                        if state == 278:
                                                            return 0.0226263124
                                            if state == 114:
                                                state = (
                                                    165
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.229842216)
                                                    else 166
                                                )
                                                if state == 165:
                                                    return -0.0883211866
                                                if state == 166:
                                                    return 0.154180661
                                        if state == 80:
                                            state = (
                                                115
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.6790009)
                                                else 116
                                            )
                                            if state == 115:
                                                state = (
                                                    167
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.59152722)
                                                    else 168
                                                )
                                                if state == 167:
                                                    return -0.24157095
                                                if state == 168:
                                                    return 0.0446632095
                                            if state == 116:
                                                state = (
                                                    169
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.50263453)
                                                    else 170
                                                )
                                                if state == 169:
                                                    return -0.134999827
                                                if state == 170:
                                                    return 0.067928791
                            if state == 24:
                                return -0.0825580284
                if state == 4:
                    state = 9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 56.854496) else 10
                    if state == 9:
                        state = 17 if x["col_peak"] < 0.453103542 else 18
                        if state == 17:
                            state = 25 if x["mag_peak"] < 18.3554153 else 26
                            if state == 25:
                                state = 41 if x["col_peak"] < 0.147835732 else 42
                                if state == 41:
                                    state = 59 if x["col_peak"] < -0.129828453 else 60
                                    if state == 59:
                                        state = (
                                            81
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 1.8329308)
                                            else 82
                                        )
                                        if state == 81:
                                            state = (
                                                117
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 20.066)
                                                else 118
                                            )
                                            if state == 117:
                                                return -0.105219215
                                            if state == 118:
                                                return 0.10452643
                                        if state == 82:
                                            return 0.0650823936
                                    if state == 60:
                                        return 0.151593879
                                if state == 42:
                                    return -0.0263195299
                            if state == 26:
                                state = 43 if x["col_peak"] < 0.381382465 else 44
                                if state == 43:
                                    state = 63 if x["col_peak"] < 0.0695309639 else 64
                                    if state == 63:
                                        state = (
                                            85
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.279782236)
                                            else 86
                                        )
                                        if state == 85:
                                            return 0.0832291096
                                        if state == 86:
                                            state = (
                                                119
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 20.4235001)
                                                else 120
                                            )
                                            if state == 119:
                                                return -0.146445274
                                            if state == 120:
                                                state = (
                                                    171
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.09292269)
                                                    else 172
                                                )
                                                if state == 171:
                                                    return -0.111995831
                                                if state == 172:
                                                    return 0.0541763604
                                    if state == 64:
                                        state = (
                                            87
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.97317481)
                                            else 88
                                        )
                                        if state == 87:
                                            return -0.08940918
                                        if state == 88:
                                            state = (
                                                123
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.6835003)
                                                else 124
                                            )
                                            if state == 123:
                                                return -0.123849526
                                            if state == 124:
                                                return 0.142628983
                                if state == 44:
                                    return 0.131567508
                        if state == 18:
                            state = 27 if x["mag_peak"] < 17.9402885 else 28
                            if state == 27:
                                return 0.0891657174
                            if state == 28:
                                return -0.105647974
                    if state == 10:
                        return 0.109934971
            if state == 2:
                return 0.149115011
    elif num_booster == 36:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < 0.400482178) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.779677033)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.982249975)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.107795455)
                            else 14
                        )
                        if state == 13:
                            return 0.164851069
                        if state == 14:
                            state = (
                                21
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0823994)
                                else 22
                            )
                            if state == 21:
                                state = 27 if x["col_peak"] < 0.351959229 else 28
                                if state == 27:
                                    state = (
                                        37
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 18.3562584)
                                        else 38
                                    )
                                    if state == 37:
                                        state = (
                                            55
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.725663304)
                                            else 56
                                        )
                                        if state == 55:
                                            state = (
                                                79
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 17.3009987)
                                                else 80
                                            )
                                            if state == 79:
                                                return 0.0336104445
                                            if state == 80:
                                                return -0.153053284
                                        if state == 56:
                                            state = (
                                                81
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.4109993)
                                                else 82
                                            )
                                            if state == 81:
                                                return -0.144929633
                                            if state == 82:
                                                state = (
                                                    107
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.9990005)
                                                    else 108
                                                )
                                                if state == 107:
                                                    return 0.134615883
                                                if state == 108:
                                                    state = (
                                                        135
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.929781)
                                                        else 136
                                                    )
                                                    if state == 135:
                                                        return 0.0325988457
                                                    if state == 136:
                                                        return -0.159735188
                                    if state == 38:
                                        state = (
                                            57
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 3.18335152)
                                            else 58
                                        )
                                        if state == 57:
                                            return 0.0975366011
                                        if state == 58:
                                            return -0.0898884311
                                if state == 28:
                                    state = 39 if x["maggaia_med"] < 15.0142012 else 40
                                    if state == 39:
                                        return 0.00510532456
                                    if state == 40:
                                        state = (
                                            59
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.192884877)
                                            else 60
                                        )
                                        if state == 59:
                                            state = (
                                                83
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 17.7605)
                                                else 84
                                            )
                                            if state == 83:
                                                return 0.0819485262
                                            if state == 84:
                                                return -0.0873861983
                                        if state == 60:
                                            state = (
                                                85
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 17.8260002)
                                                else 86
                                            )
                                            if state == 85:
                                                return -0.258723795
                                            if state == 86:
                                                state = (
                                                    109
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.5105)
                                                    else 110
                                                )
                                                if state == 109:
                                                    return 0.0650240555
                                                if state == 110:
                                                    state = (
                                                        137
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.8292999)
                                                        else 138
                                                    )
                                                    if state == 137:
                                                        return -0.214071304
                                                    if state == 138:
                                                        state = (
                                                            181
                                                            if np.isnan(x["mag_peak"])
                                                            or (
                                                                x["mag_peak"]
                                                                < 18.813633
                                                            )
                                                            else 182
                                                        )
                                                        if state == 181:
                                                            return 0.0579985715
                                                        if state == 182:
                                                            return -0.184961021
                            if state == 22:
                                state = 29 if x["col_peak"] < -0.178159386 else 30
                                if state == 29:
                                    state = (
                                        41
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 19.1126995)
                                        else 42
                                    )
                                    if state == 41:
                                        state = (
                                            61
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 3.64731407)
                                            else 62
                                        )
                                        if state == 61:
                                            state = (
                                                87
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 17.9654999)
                                                else 88
                                            )
                                            if state == 87:
                                                state = (
                                                    111
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 17.8510017)
                                                    else 112
                                                )
                                                if state == 111:
                                                    return -0.0865258127
                                                if state == 112:
                                                    return 0.142039359
                                            if state == 88:
                                                state = (
                                                    113
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 21.0125008)
                                                    else 114
                                                )
                                                if state == 113:
                                                    state = (
                                                        139
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.5056992)
                                                        else 140
                                                    )
                                                    if state == 139:
                                                        return 0.108911693
                                                    if state == 140:
                                                        return -0.315056205
                                                if state == 114:
                                                    return 0.00248135207
                                        if state == 62:
                                            return 0.0782858059
                                    if state == 42:
                                        state = (
                                            63
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.767890751)
                                            else 64
                                        )
                                        if state == 63:
                                            return 0.149134517
                                        if state == 64:
                                            return -0.0820740312
                                if state == 30:
                                    state = 43 if x["maggaia_med"] < 14.1784706 else 44
                                    if state == 43:
                                        state = (
                                            65
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 5.69133997)
                                            else 66
                                        )
                                        if state == 65:
                                            return -0.257714123
                                        if state == 66:
                                            return 0.00763385417
                                    if state == 44:
                                        state = (
                                            67
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 1.38019848)
                                            else 68
                                        )
                                        if state == 67:
                                            state = (
                                                91
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.7084999)
                                                else 92
                                            )
                                            if state == 91:
                                                state = (
                                                    115
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.809)
                                                    else 116
                                                )
                                                if state == 115:
                                                    state = (
                                                        143
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.4717999)
                                                        else 144
                                                    )
                                                    if state == 143:
                                                        state = (
                                                            185
                                                            if x["mag_peak"]
                                                            < 18.3840752
                                                            else 186
                                                        )
                                                        if state == 185:
                                                            return 0.194897369
                                                        if state == 186:
                                                            return 0.0566246919
                                                    if state == 144:
                                                        state = (
                                                            187
                                                            if np.isnan(x["mag_peak"])
                                                            or (
                                                                x["mag_peak"]
                                                                < 18.6370735
                                                            )
                                                            else 188
                                                        )
                                                        if state == 187:
                                                            return -0.0557355918
                                                        if state == 188:
                                                            return 0.075674668
                                                if state == 116:
                                                    state = (
                                                        145
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.5195999)
                                                        else 146
                                                    )
                                                    if state == 145:
                                                        state = (
                                                            189
                                                            if x["mag_peak"]
                                                            < 18.6802197
                                                            else 190
                                                        )
                                                        if state == 189:
                                                            return 0.172038004
                                                        if state == 190:
                                                            return -0.0644356832
                                                    if state == 146:
                                                        state = (
                                                            191
                                                            if x["mag_peak"]
                                                            < 18.7255096
                                                            else 192
                                                        )
                                                        if state == 191:
                                                            return 0.0562664159
                                                        if state == 192:
                                                            return -0.235280439
                                            if state == 92:
                                                state = (
                                                    117
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 20.6912498)
                                                    else 118
                                                )
                                                if state == 117:
                                                    state = (
                                                        147
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.4696884)
                                                        else 148
                                                    )
                                                    if state == 147:
                                                        state = (
                                                            193
                                                            if x["mag_peak"]
                                                            < 18.8578339
                                                            else 194
                                                        )
                                                        if state == 193:
                                                            return 0.0443993583
                                                        if state == 194:
                                                            return -0.142612845
                                                    if state == 148:
                                                        state = (
                                                            195
                                                            if x["mag_peak"]
                                                            < 19.0010834
                                                            else 196
                                                        )
                                                        if state == 195:
                                                            return 0.265447795
                                                        if state == 196:
                                                            return 0.093355976
                                                if state == 118:
                                                    state = (
                                                        149
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.4853001)
                                                        else 150
                                                    )
                                                    if state == 149:
                                                        state = (
                                                            197
                                                            if x["mag_peak"]
                                                            < 18.8508339
                                                            else 198
                                                        )
                                                        if state == 197:
                                                            return 0.156428576
                                                        if state == 198:
                                                            return -0.0232518204
                                                    if state == 150:
                                                        state = (
                                                            199
                                                            if np.isnan(x["mag_peak"])
                                                            or (
                                                                x["mag_peak"]
                                                                < 18.107296
                                                            )
                                                            else 200
                                                        )
                                                        if state == 199:
                                                            return -0.0192625541
                                                        if state == 200:
                                                            return -0.169374943
                                        if state == 68:
                                            state = (
                                                93
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.4872513)
                                                else 94
                                            )
                                            if state == 93:
                                                state = (
                                                    119
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 17.4350014)
                                                    else 120
                                                )
                                                if state == 119:
                                                    state = (
                                                        151
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.006649)
                                                        else 152
                                                    )
                                                    if state == 151:
                                                        state = (
                                                            201
                                                            if x["mag_peak"]
                                                            < 18.6659431
                                                            else 202
                                                        )
                                                        if state == 201:
                                                            return -0.0447643809
                                                        if state == 202:
                                                            return 0.166968182
                                                    if state == 152:
                                                        return -0.0351846889
                                                if state == 120:
                                                    state = (
                                                        153
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.2694511)
                                                        else 154
                                                    )
                                                    if state == 153:
                                                        state = (
                                                            205
                                                            if x["mag_peak"]
                                                            < 18.5555267
                                                            else 206
                                                        )
                                                        if state == 205:
                                                            return 0.0334830508
                                                        if state == 206:
                                                            return -0.304947764
                                                    if state == 154:
                                                        state = (
                                                            207
                                                            if x["mag_peak"]
                                                            < 19.1113243
                                                            else 208
                                                        )
                                                        if state == 207:
                                                            return 0.102166109
                                                        if state == 208:
                                                            return -0.0352334864
                                            if state == 94:
                                                state = (
                                                    121
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 20.3414993)
                                                    else 122
                                                )
                                                if state == 121:
                                                    state = (
                                                        155
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.6770515)
                                                        else 156
                                                    )
                                                    if state == 155:
                                                        state = (
                                                            209
                                                            if np.isnan(x["mag_peak"])
                                                            or (
                                                                x["mag_peak"]
                                                                < 18.9870949
                                                            )
                                                            else 210
                                                        )
                                                        if state == 209:
                                                            return 0.178900599
                                                        if state == 210:
                                                            return -0.071819663
                                                    if state == 156:
                                                        state = (
                                                            211
                                                            if np.isnan(x["mag_peak"])
                                                            or (
                                                                x["mag_peak"]
                                                                < 17.9599934
                                                            )
                                                            else 212
                                                        )
                                                        if state == 211:
                                                            return -0.0683805868
                                                        if state == 212:
                                                            return 0.1232467
                                                if state == 122:
                                                    state = (
                                                        157
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.8171768)
                                                        else 158
                                                    )
                                                    if state == 157:
                                                        state = (
                                                            213
                                                            if x["mag_peak"]
                                                            < 18.0843906
                                                            else 214
                                                        )
                                                        if state == 213:
                                                            return 0.1094184
                                                        if state == 214:
                                                            return -0.115629055
                                                    if state == 158:
                                                        state = (
                                                            215
                                                            if x["mag_peak"]
                                                            < 18.8089867
                                                            else 216
                                                        )
                                                        if state == 215:
                                                            return 0.133497477
                                                        if state == 216:
                                                            return -0.036609862
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 5.31099796)
                            else 16
                        )
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.5962486)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    31
                                    if np.isnan(x["col_peak"])
                                    or (x["col_peak"] < 0.183917999)
                                    else 32
                                )
                                if state == 31:
                                    state = 45 if x["maggaia_med"] < 19.4595947 else 46
                                    if state == 45:
                                        state = (
                                            69
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 1.50592852)
                                            else 70
                                        )
                                        if state == 69:
                                            state = (
                                                95
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 17.0354996)
                                                else 96
                                            )
                                            if state == 95:
                                                state = (
                                                    123
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 16.4220009)
                                                    else 124
                                                )
                                                if state == 123:
                                                    state = (
                                                        159
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.0264053)
                                                        else 160
                                                    )
                                                    if state == 159:
                                                        return -0.030347148
                                                    if state == 160:
                                                        return 0.144102946
                                                if state == 124:
                                                    return -0.202802211
                                            if state == 96:
                                                state = (
                                                    125
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.4689999)
                                                    else 126
                                                )
                                                if state == 125:
                                                    state = (
                                                        163
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.4659729)
                                                        else 164
                                                    )
                                                    if state == 163:
                                                        return 0.266791016
                                                    if state == 164:
                                                        return -0.0146860015
                                                if state == 126:
                                                    state = (
                                                        165
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.4038391)
                                                        else 166
                                                    )
                                                    if state == 165:
                                                        state = (
                                                            217
                                                            if x["mag_peak"]
                                                            < 18.1313095
                                                            else 218
                                                        )
                                                        if state == 217:
                                                            return -0.0826120079
                                                        if state == 218:
                                                            return 0.100825645
                                                    if state == 166:
                                                        return -0.150623575
                                        if state == 70:
                                            state = (
                                                97
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 16.4314995)
                                                else 98
                                            )
                                            if state == 97:
                                                return -0.116911694
                                            if state == 98:
                                                state = (
                                                    127
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.1835003)
                                                    else 128
                                                )
                                                if state == 127:
                                                    return 0.231010318
                                                if state == 128:
                                                    state = (
                                                        167
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.5576515)
                                                        else 168
                                                    )
                                                    if state == 167:
                                                        return 0.159940869
                                                    if state == 168:
                                                        return -0.217247948
                                    if state == 46:
                                        state = (
                                            71
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 4.08486319)
                                            else 72
                                        )
                                        if state == 71:
                                            state = (
                                                99
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.8400002)
                                                else 100
                                            )
                                            if state == 99:
                                                state = (
                                                    129
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.1009998)
                                                    else 130
                                                )
                                                if state == 129:
                                                    state = (
                                                        169
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.396801)
                                                        else 170
                                                    )
                                                    if state == 169:
                                                        return -0.238768846
                                                    if state == 170:
                                                        state = (
                                                            221
                                                            if np.isnan(x["mag_peak"])
                                                            or (
                                                                x["mag_peak"]
                                                                < 18.1250401
                                                            )
                                                            else 222
                                                        )
                                                        if state == 221:
                                                            return 0.112205654
                                                        if state == 222:
                                                            return -0.0757352784
                                                if state == 130:
                                                    state = (
                                                        171
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 18.6988487)
                                                        else 172
                                                    )
                                                    if state == 171:
                                                        state = (
                                                            223
                                                            if x["mag_peak"]
                                                            < 18.5243015
                                                            else 224
                                                        )
                                                        if state == 223:
                                                            return 0.142611116
                                                        if state == 224:
                                                            return -0.167639092
                                                    if state == 172:
                                                        state = (
                                                            225
                                                            if np.isnan(x["mag_peak"])
                                                            or (
                                                                x["mag_peak"]
                                                                < 18.530674
                                                            )
                                                            else 226
                                                        )
                                                        if state == 225:
                                                            return 0.205159023
                                                        if state == 226:
                                                            return -0.0524198934
                                            if state == 100:
                                                state = (
                                                    131
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 20.0634995)
                                                    else 132
                                                )
                                                if state == 131:
                                                    state = (
                                                        173
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.3450508)
                                                        else 174
                                                    )
                                                    if state == 173:
                                                        return -0.012537295
                                                    if state == 174:
                                                        return -0.456864357
                                                if state == 132:
                                                    state = (
                                                        175
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.0499992)
                                                        else 176
                                                    )
                                                    if state == 175:
                                                        state = (
                                                            227
                                                            if x["mag_peak"]
                                                            < 17.6023636
                                                            else 228
                                                        )
                                                        if state == 227:
                                                            return -0.0712365136
                                                        if state == 228:
                                                            return 0.162731186
                                                    if state == 176:
                                                        return -0.184048608
                                        if state == 72:
                                            return 0.104456112
                                if state == 32:
                                    state = (
                                        47
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 16.4228497)
                                        else 48
                                    )
                                    if state == 47:
                                        return -0.0213329997
                                    if state == 48:
                                        return 0.202008456
                            if state == 24:
                                state = 33 if x["col_peak"] < -0.159108162 else 34
                                if state == 33:
                                    state = (
                                        49
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 18.7707748)
                                        else 50
                                    )
                                    if state == 49:
                                        return 0.121406518
                                    if state == 50:
                                        state = (
                                            73
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 1.55632734)
                                            else 74
                                        )
                                        if state == 73:
                                            return -0.208995163
                                        if state == 74:
                                            state = (
                                                101
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 21.1660004)
                                                else 102
                                            )
                                            if state == 101:
                                                return 0.116601527
                                            if state == 102:
                                                return -0.0897456333
                                if state == 34:
                                    state = (
                                        51
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 19.4309845)
                                        else 52
                                    )
                                    if state == 51:
                                        return 0.257443428
                                    if state == 52:
                                        state = (
                                            75
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 1.65842378)
                                            else 76
                                        )
                                        if state == 75:
                                            return -0.0669734254
                                        if state == 76:
                                            return 0.238671854
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.8702087)
                                else 26
                            )
                            if state == 25:
                                return -0.231748998
                            if state == 26:
                                state = 35 if x["col_peak"] < -0.114146233 else 36
                                if state == 35:
                                    return -0.0357918926
                                if state == 36:
                                    state = 53 if x["maggaia_med"] < 15.8538351 else 54
                                    if state == 53:
                                        return -0.112823054
                                    if state == 54:
                                        return 0.163914919
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.983749986)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 14.4805918)
                            else 18
                        )
                        if state == 17:
                            return -0.183002084
                        if state == 18:
                            return 0.14454262
                    if state == 10:
                        return -0.0108946133
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.254539996 else 6
                if state == 5:
                    return 0.155242711
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.981750011)
                        else 12
                    )
                    if state == 11:
                        return -0.150547147
                    if state == 12:
                        return 0.1354395
    elif num_booster == 37:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 14.4506378 else 2
            if state == 1:
                return -0.162065595
            if state == 2:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 9.0520134) else 4
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.5494499)
                        else 6
                    )
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 6.00721073)
                            else 10
                        )
                        if state == 9:
                            return -0.0994416699
                        if state == 10:
                            state = (
                                19
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 17.7108765)
                                else 20
                            )
                            if state == 19:
                                return 0.153653696
                            if state == 20:
                                return -0.0960383639
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 5.05189228)
                            else 12
                        )
                        if state == 11:
                            state = 21 if x["maggaia_med"] < 18.3315849 else 22
                            if state == 21:
                                return 0.00374065083
                            if state == 22:
                                return 0.146880627
                        if state == 12:
                            return -0.0636702254
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.9275513)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0804224983)
                            else 14
                        )
                        if state == 13:
                            return 0.0914299116
                        if state == 14:
                            state = (
                                25
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 20.1909523)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    31
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 15.7441006)
                                    else 32
                                )
                                if state == 31:
                                    return 0.0265258197
                                if state == 32:
                                    return -0.244126365
                            if state == 26:
                                return 0.0971599966
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 3.13833332)
                            else 16
                        )
                        if state == 15:
                            state = 27 if x["maggaia_med"] < 19.3656216 else 28
                            if state == 27:
                                state = 33 if x["mag_peak"] < 18.9061813 else 34
                                if state == 33:
                                    state = (
                                        41
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 3.00217605)
                                        else 42
                                    )
                                    if state == 41:
                                        state = (
                                            57
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.031642437)
                                            else 58
                                        )
                                        if state == 57:
                                            state = (
                                                81
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.0264053)
                                                else 82
                                            )
                                            if state == 81:
                                                state = (
                                                    115
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.92903948)
                                                    else 116
                                                )
                                                if state == 115:
                                                    return 0.0345629007
                                                if state == 116:
                                                    return -0.155343398
                                            if state == 82:
                                                state = (
                                                    117
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.99386001)
                                                    else 118
                                                )
                                                if state == 117:
                                                    state = (
                                                        161
                                                        if x["neargaia_med"]
                                                        < 1.85329735
                                                        else 162
                                                    )
                                                    if state == 161:
                                                        state = (
                                                            223
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.0000496
                                                            )
                                                            else 224
                                                        )
                                                        if state == 223:
                                                            return 0.0843061805
                                                        if state == 224:
                                                            return -0.11546994
                                                    if state == 162:
                                                        state = (
                                                            225
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.9621506
                                                            )
                                                            else 226
                                                        )
                                                        if state == 225:
                                                            return 0.307727635
                                                        if state == 226:
                                                            return 0.141281173
                                                if state == 118:
                                                    return -0.0401454568
                                        if state == 58:
                                            state = (
                                                83
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.2437)
                                                else 84
                                            )
                                            if state == 83:
                                                return 0.141762033
                                            if state == 84:
                                                state = (
                                                    121
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.91072917)
                                                    else 122
                                                )
                                                if state == 121:
                                                    state = (
                                                        167
                                                        if x["neargaia_med"]
                                                        < 2.58334303
                                                        else 168
                                                    )
                                                    if state == 167:
                                                        state = (
                                                            229
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.1532497
                                                            )
                                                            else 230
                                                        )
                                                        if state == 229:
                                                            return -0.131120548
                                                        if state == 230:
                                                            return 0.110604063
                                                    if state == 168:
                                                        state = (
                                                            231
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.5020008
                                                            )
                                                            else 232
                                                        )
                                                        if state == 231:
                                                            return 0.180740356
                                                        if state == 232:
                                                            return -0.0985256582
                                                if state == 122:
                                                    state = (
                                                        169
                                                        if x["neargaia_med"]
                                                        < 43.5898743
                                                        else 170
                                                    )
                                                    if state == 169:
                                                        state = (
                                                            233
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.5671997
                                                            )
                                                            else 234
                                                        )
                                                        if state == 233:
                                                            return -0.0978750214
                                                        if state == 234:
                                                            return 0.0521222018
                                                    if state == 170:
                                                        return -0.304375172
                                    if state == 42:
                                        return 0.26207158
                                if state == 34:
                                    state = (
                                        43
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 0.0204050504)
                                        else 44
                                    )
                                    if state == 43:
                                        return 0.142503187
                                    if state == 44:
                                        state = 59 if x["col_peak"] < 1.00815773 else 60
                                        if state == 59:
                                            state = (
                                                85
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.8927994)
                                                else 86
                                            )
                                            if state == 85:
                                                state = (
                                                    123
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.064427048)
                                                    else 124
                                                )
                                                if state == 123:
                                                    return 0.0924441665
                                                if state == 124:
                                                    state = (
                                                        171
                                                        if x["neargaia_med"]
                                                        < 55.2161179
                                                        else 172
                                                    )
                                                    if state == 171:
                                                        return -0.228794798
                                                    if state == 172:
                                                        return 0.0364260972
                                            if state == 86:
                                                return 0.0853438452
                                        if state == 60:
                                            state = (
                                                87
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.1863003)
                                                else 88
                                            )
                                            if state == 87:
                                                state = (
                                                    125
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.99858785)
                                                    else 126
                                                )
                                                if state == 125:
                                                    state = (
                                                        173
                                                        if x["neargaia_med"]
                                                        < 0.649827957
                                                        else 174
                                                    )
                                                    if state == 173:
                                                        state = (
                                                            235
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.1577492
                                                            )
                                                            else 236
                                                        )
                                                        if state == 235:
                                                            return -0.169280648
                                                        if state == 236:
                                                            return 0.118654363
                                                    if state == 174:
                                                        state = (
                                                            237
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.5880013
                                                            )
                                                            else 238
                                                        )
                                                        if state == 237:
                                                            return 0.21353893
                                                        if state == 238:
                                                            return -0.0152453426
                                                if state == 126:
                                                    state = (
                                                        175
                                                        if x["neargaia_med"]
                                                        < 27.8287506
                                                        else 176
                                                    )
                                                    if state == 175:
                                                        state = (
                                                            239
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.5897484
                                                            )
                                                            else 240
                                                        )
                                                        if state == 239:
                                                            return -0.0404039323
                                                        if state == 240:
                                                            return 0.26293394
                                                    if state == 176:
                                                        return -0.018545907
                                            if state == 88:
                                                state = (
                                                    127
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0491145998)
                                                    else 128
                                                )
                                                if state == 127:
                                                    return 0.00840732642
                                                if state == 128:
                                                    state = (
                                                        179
                                                        if x["neargaia_med"]
                                                        < 53.5943909
                                                        else 180
                                                    )
                                                    if state == 179:
                                                        return -0.149865314
                                                    if state == 180:
                                                        return 0.106434345
                            if state == 28:
                                state = 35 if x["mag_peak"] < 18.08218 else 36
                                if state == 35:
                                    state = (
                                        45
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 2.93402767)
                                        else 46
                                    )
                                    if state == 45:
                                        state = 61 if x["col_peak"] < 0.03245195 else 62
                                        if state == 61:
                                            return -0.00831399206
                                        if state == 62:
                                            return -0.243183002
                                    if state == 46:
                                        state = (
                                            63
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.174326897)
                                            else 64
                                        )
                                        if state == 63:
                                            state = (
                                                89
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.6319504)
                                                else 90
                                            )
                                            if state == 89:
                                                return -0.132740766
                                            if state == 90:
                                                return 0.125864387
                                        if state == 64:
                                            return 0.0148276584
                                if state == 36:
                                    state = (
                                        47
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 0.0453703478)
                                        else 48
                                    )
                                    if state == 47:
                                        state = (
                                            65
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < 0.0812664032)
                                            else 66
                                        )
                                        if state == 65:
                                            state = (
                                                91
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.3454514)
                                                else 92
                                            )
                                            if state == 91:
                                                state = (
                                                    129
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0416667014)
                                                    else 130
                                                )
                                                if state == 129:
                                                    state = (
                                                        181
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 3.04782248
                                                        )
                                                        else 182
                                                    )
                                                    if state == 181:
                                                        state = (
                                                            247
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.6331005
                                                            )
                                                            else 248
                                                        )
                                                        if state == 247:
                                                            return -0.161177516
                                                        if state == 248:
                                                            return 0.0297485199
                                                    if state == 182:
                                                        return -0.343928307
                                                if state == 130:
                                                    return -0.0164921768
                                            if state == 92:
                                                state = (
                                                    131
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0316030011)
                                                    else 132
                                                )
                                                if state == 131:
                                                    state = (
                                                        183
                                                        if x["neargaia_med"]
                                                        < 9.33505726
                                                        else 184
                                                    )
                                                    if state == 183:
                                                        return 0.172835171
                                                    if state == 184:
                                                        state = (
                                                            249
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"] < 20.610199
                                                            )
                                                            else 250
                                                        )
                                                        if state == 249:
                                                            return 0.0606571771
                                                        if state == 250:
                                                            return -0.155852944
                                                if state == 132:
                                                    return -0.161630005
                                        if state == 66:
                                            return 0.0692587495
                                    if state == 48:
                                        state = (
                                            67
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.0870957375)
                                            else 68
                                        )
                                        if state == 67:
                                            state = (
                                                93
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.4091988)
                                                else 94
                                            )
                                            if state == 93:
                                                state = (
                                                    133
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.00873852)
                                                    else 134
                                                )
                                                if state == 133:
                                                    state = (
                                                        185
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 37.965023
                                                        )
                                                        else 186
                                                    )
                                                    if state == 185:
                                                        state = (
                                                            251
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.9201012
                                                            )
                                                            else 252
                                                        )
                                                        if state == 251:
                                                            return -0.0246120598
                                                        if state == 252:
                                                            return -0.2515001
                                                    if state == 186:
                                                        state = (
                                                            253
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.9527493
                                                            )
                                                            else 254
                                                        )
                                                        if state == 253:
                                                            return 0.2336189
                                                        if state == 254:
                                                            return -0.0147254374
                                                if state == 134:
                                                    state = (
                                                        187
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 0.0696462989
                                                        )
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        state = (
                                                            255
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.2685013
                                                            )
                                                            else 256
                                                        )
                                                        if state == 255:
                                                            return -0.109952681
                                                        if state == 256:
                                                            return 0.0708040744
                                                    if state == 188:
                                                        state = (
                                                            257
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.0890713
                                                            )
                                                            else 258
                                                        )
                                                        if state == 257:
                                                            return 0.215900868
                                                        if state == 258:
                                                            return -0.00474561797
                                            if state == 94:
                                                state = (
                                                    135
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.91072893)
                                                    else 136
                                                )
                                                if state == 135:
                                                    state = (
                                                        189
                                                        if x["neargaia_med"]
                                                        < 159.757843
                                                        else 190
                                                    )
                                                    if state == 189:
                                                        state = (
                                                            259
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.5439491
                                                            )
                                                            else 260
                                                        )
                                                        if state == 259:
                                                            return 0.110017419
                                                        if state == 260:
                                                            return -0.0869427547
                                                    if state == 190:
                                                        return 0.262223214
                                                if state == 136:
                                                    state = (
                                                        191
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 0.568039715
                                                        )
                                                        else 192
                                                    )
                                                    if state == 191:
                                                        return -0.174571276
                                                    if state == 192:
                                                        state = (
                                                            261
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.6204491
                                                            )
                                                            else 262
                                                        )
                                                        if state == 261:
                                                            return -0.0364794396
                                                        if state == 262:
                                                            return 0.104535401
                                        if state == 68:
                                            state = (
                                                95
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.4668999)
                                                else 96
                                            )
                                            if state == 95:
                                                return -0.0191726852
                                            if state == 96:
                                                return 0.196260676
                        if state == 16:
                            state = 29 if x["maggaia_med"] < 16.9567528 else 30
                            if state == 29:
                                state = 37 if x["mag_peak"] < 18.7199974 else 38
                                if state == 37:
                                    state = (
                                        49
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 4.95333338)
                                        else 50
                                    )
                                    if state == 49:
                                        return 0.00196333695
                                    if state == 50:
                                        state = (
                                            69 if x["col_peak"] < -0.284540176 else 70
                                        )
                                        if state == 69:
                                            return -0.0570756458
                                        if state == 70:
                                            return 0.250527561
                                if state == 38:
                                    state = (
                                        51
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 3.96566558)
                                        else 52
                                    )
                                    if state == 51:
                                        return 0.158795938
                                    if state == 52:
                                        state = (
                                            71 if x["col_peak"] < 0.113194466 else 72
                                        )
                                        if state == 71:
                                            return -0.155929208
                                        if state == 72:
                                            state = (
                                                97
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.6594009)
                                                else 98
                                            )
                                            if state == 97:
                                                return -0.0882344097
                                            if state == 98:
                                                state = (
                                                    141
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.96007538)
                                                    else 142
                                                )
                                                if state == 141:
                                                    return -0.139665976
                                                if state == 142:
                                                    state = (
                                                        195
                                                        if x["neargaia_med"]
                                                        < 27.3192863
                                                        else 196
                                                    )
                                                    if state == 195:
                                                        return 0.218462914
                                                    if state == 196:
                                                        return -0.0567034371
                            if state == 30:
                                state = 39 if x["mag_peak"] < 18.2655869 else 40
                                if state == 39:
                                    state = (
                                        53
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 6.0189352)
                                        else 54
                                    )
                                    if state == 53:
                                        state = (
                                            73 if x["col_peak"] < 0.0438399315 else 74
                                        )
                                        if state == 73:
                                            return 0.177931264
                                        if state == 74:
                                            state = (
                                                101
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.0785484)
                                                else 102
                                            )
                                            if state == 101:
                                                state = (
                                                    143
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.93126154)
                                                    else 144
                                                )
                                                if state == 143:
                                                    state = (
                                                        197
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 15.5910826
                                                        )
                                                        else 198
                                                    )
                                                    if state == 197:
                                                        state = (
                                                            267
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.6266022
                                                            )
                                                            else 268
                                                        )
                                                        if state == 267:
                                                            return -0.245854527
                                                        if state == 268:
                                                            return -0.0405040905
                                                    if state == 198:
                                                        return 0.0837515816
                                                if state == 144:
                                                    state = (
                                                        199
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 0.64962709
                                                        )
                                                        else 200
                                                    )
                                                    if state == 199:
                                                        return 0.0935930461
                                                    if state == 200:
                                                        return -0.0250104759
                                            if state == 102:
                                                return 0.117927819
                                    if state == 54:
                                        state = (
                                            75
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < 0.157283306)
                                            else 76
                                        )
                                        if state == 75:
                                            state = (
                                                103
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.4111004)
                                                else 104
                                            )
                                            if state == 103:
                                                return 0.274835348
                                            if state == 104:
                                                state = (
                                                    145
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.97445011)
                                                    else 146
                                                )
                                                if state == 145:
                                                    state = (
                                                        201
                                                        if x["neargaia_med"]
                                                        < 5.35970831
                                                        else 202
                                                    )
                                                    if state == 201:
                                                        return -0.0429313034
                                                    if state == 202:
                                                        return 0.207814813
                                                if state == 146:
                                                    return -0.135570377
                                        if state == 76:
                                            state = (
                                                105
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 18.9428482)
                                                else 106
                                            )
                                            if state == 105:
                                                return -0.156551704
                                            if state == 106:
                                                return 0.109944493
                                if state == 40:
                                    state = (
                                        55
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 4.99861717)
                                        else 56
                                    )
                                    if state == 55:
                                        state = (
                                            77
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.0963125229)
                                            else 78
                                        )
                                        if state == 77:
                                            state = (
                                                107
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.601799)
                                                else 108
                                            )
                                            if state == 107:
                                                state = (
                                                    149
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.89367485)
                                                    else 150
                                                )
                                                if state == 149:
                                                    state = (
                                                        203
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 34.9356194
                                                        )
                                                        else 204
                                                    )
                                                    if state == 203:
                                                        state = (
                                                            271
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 18.7142582
                                                            )
                                                            else 272
                                                        )
                                                        if state == 271:
                                                            return -0.0446399823
                                                        if state == 272:
                                                            return 0.212661564
                                                    if state == 204:
                                                        return -0.123519845
                                                if state == 150:
                                                    state = (
                                                        205
                                                        if x["neargaia_med"]
                                                        < 35.0804825
                                                        else 206
                                                    )
                                                    if state == 205:
                                                        return -0.178690344
                                                    if state == 206:
                                                        return 0.148207366
                                            if state == 108:
                                                state = (
                                                    151
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.96383095)
                                                    else 152
                                                )
                                                if state == 151:
                                                    state = (
                                                        207
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 15.8229485
                                                        )
                                                        else 208
                                                    )
                                                    if state == 207:
                                                        return -0.289772272
                                                    if state == 208:
                                                        state = (
                                                            273
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.7965508
                                                            )
                                                            else 274
                                                        )
                                                        if state == 273:
                                                            return -0.24248828
                                                        if state == 274:
                                                            return -0.0338003971
                                                if state == 152:
                                                    state = (
                                                        209
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 14.8884964
                                                        )
                                                        else 210
                                                    )
                                                    if state == 209:
                                                        return -0.209317312
                                                    if state == 210:
                                                        return 0.15411298
                                        if state == 78:
                                            state = (
                                                109
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.8312988)
                                                else 110
                                            )
                                            if state == 109:
                                                return -0.31849131
                                            if state == 110:
                                                state = (
                                                    153
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.97017956)
                                                    else 154
                                                )
                                                if state == 153:
                                                    return 0.145811781
                                                if state == 154:
                                                    return -0.0942793787
                                    if state == 56:
                                        state = (
                                            79 if x["col_peak"] < -0.194995403 else 80
                                        )
                                        if state == 79:
                                            return 0.171817467
                                        if state == 80:
                                            state = (
                                                113
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.7529984)
                                                else 114
                                            )
                                            if state == 113:
                                                state = (
                                                    157
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 5.92255211)
                                                    else 158
                                                )
                                                if state == 157:
                                                    state = (
                                                        215
                                                        if x["neargaia_med"]
                                                        < 13.1777525
                                                        else 216
                                                    )
                                                    if state == 215:
                                                        return -0.182717279
                                                    if state == 216:
                                                        return 0.243553117
                                                if state == 158:
                                                    state = (
                                                        217
                                                        if x["neargaia_med"]
                                                        < 0.447695374
                                                        else 218
                                                    )
                                                    if state == 217:
                                                        return 0.11839202
                                                    if state == 218:
                                                        state = (
                                                            277
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.4071503
                                                            )
                                                            else 278
                                                        )
                                                        if state == 277:
                                                            return -0.0976592973
                                                        if state == 278:
                                                            return -0.194810763
                                            if state == 114:
                                                state = (
                                                    159
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 7.97646999)
                                                    else 160
                                                )
                                                if state == 159:
                                                    state = (
                                                        219
                                                        if x["neargaia_med"]
                                                        < 40.1621475
                                                        else 220
                                                    )
                                                    if state == 219:
                                                        state = (
                                                            279
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.4180984
                                                            )
                                                            else 280
                                                        )
                                                        if state == 279:
                                                            return 0.150684103
                                                        if state == 280:
                                                            return -0.0816737935
                                                    if state == 220:
                                                        return -0.167787701
                                                if state == 160:
                                                    state = (
                                                        221
                                                        if x["neargaia_med"]
                                                        < 64.1447296
                                                        else 222
                                                    )
                                                    if state == 221:
                                                        state = (
                                                            281
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.5641003
                                                            )
                                                            else 282
                                                        )
                                                        if state == 281:
                                                            return -0.232059017
                                                        if state == 282:
                                                            return 0.00842730701
                                                    if state == 222:
                                                        return 0.136807084
    elif num_booster == 38:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.6531525)
                else 2
            )
            if state == 1:
                state = 3 if x["mag_peak"] < 18.6978874 else 4
                if state == 3:
                    state = 5 if x["maggaia_med"] < 17.3634071 else 6
                    if state == 5:
                        state = (
                            9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 57.8929634) else 10
                        )
                        if state == 9:
                            state = 17 if x["neargaia_med"] < 0.664475739 else 18
                            if state == 17:
                                return -0.206947654
                            if state == 18:
                                state = (
                                    33
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.7868996)
                                    else 34
                                )
                                if state == 33:
                                    state = 55 if x["neargaia_med"] < 62.6368866 else 56
                                    if state == 55:
                                        state = 81 if x["mag_peak"] < 18.6115799 else 82
                                        if state == 81:
                                            state = (
                                                105
                                                if x["neargaia_med"] < 35.8097
                                                else 106
                                            )
                                            if state == 105:
                                                state = (
                                                    133
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.50253487)
                                                    else 134
                                                )
                                                if state == 133:
                                                    state = (
                                                        157
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 17.9360008)
                                                        else 158
                                                    )
                                                    if state == 157:
                                                        return -0.103088915
                                                    if state == 158:
                                                        state = (
                                                            189
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.101827502
                                                            )
                                                            else 190
                                                        )
                                                        if state == 189:
                                                            return -0.0467206761
                                                        if state == 190:
                                                            return 0.151663706
                                                if state == 134:
                                                    return -0.172895059
                                            if state == 106:
                                                return 0.0587643012
                                        if state == 82:
                                            return 0.125055954
                                    if state == 56:
                                        return -0.195261568
                                if state == 34:
                                    state = 57 if x["neargaia_med"] < 12.3417416 else 58
                                    if state == 57:
                                        return -0.0566313937
                                    if state == 58:
                                        state = 83 if x["mag_peak"] < 18.429493 else 84
                                        if state == 83:
                                            return 0.225695267
                                        if state == 84:
                                            state = (
                                                107
                                                if x["neargaia_med"] < 17.314949
                                                else 108
                                            )
                                            if state == 107:
                                                return 0.146207467
                                            if state == 108:
                                                return -0.182935447
                        if state == 10:
                            state = 19 if x["neargaia_med"] < 0.631879449 else 20
                            if state == 19:
                                return -0.115822405
                            if state == 20:
                                return 0.0933717787
                    if state == 6:
                        state = (
                            11
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 13.0225172)
                            else 12
                        )
                        if state == 11:
                            state = 21 if x["neargaia_med"] < 34.318821 else 22
                            if state == 21:
                                return -0.172275051
                            if state == 22:
                                return 0.0284592845
                        if state == 12:
                            state = 23 if x["neargaia_med"] < 0.236477241 else 24
                            if state == 23:
                                state = (
                                    37
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.0690918)
                                    else 38
                                )
                                if state == 37:
                                    return -0.0124449339
                                if state == 38:
                                    state = (
                                        61 if x["neargaia_med"] < 0.143116072 else 62
                                    )
                                    if state == 61:
                                        return -0.00202896632
                                    if state == 62:
                                        return -0.161944762
                            if state == 24:
                                state = (
                                    39
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.544651)
                                    else 40
                                )
                                if state == 39:
                                    state = 63 if x["neargaia_med"] < 1.30571175 else 64
                                    if state == 63:
                                        return 0.174801275
                                    if state == 64:
                                        state = 87 if x["mag_peak"] < 18.6743507 else 88
                                        if state == 87:
                                            state = (
                                                111
                                                if x["neargaia_med"] < 1.84045637
                                                else 112
                                            )
                                            if state == 111:
                                                return -0.191895694
                                            if state == 112:
                                                state = (
                                                    137
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 0.0427083485)
                                                    else 138
                                                )
                                                if state == 137:
                                                    state = (
                                                        161
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.3893509)
                                                        else 162
                                                    )
                                                    if state == 161:
                                                        return 0.132388383
                                                    if state == 162:
                                                        state = (
                                                            193
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.0515832976
                                                            )
                                                            else 194
                                                        )
                                                        if state == 193:
                                                            return -0.233061403
                                                        if state == 194:
                                                            return 0.0323153473
                                                if state == 138:
                                                    state = (
                                                        163
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.8433495)
                                                        else 164
                                                    )
                                                    if state == 163:
                                                        state = (
                                                            195
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.0972082987
                                                            )
                                                            else 196
                                                        )
                                                        if state == 195:
                                                            return 0.100117348
                                                        if state == 196:
                                                            return -0.0462078266
                                                    if state == 164:
                                                        state = (
                                                            197
                                                            if x["sgscore1_med"]
                                                            < 0.0128541999
                                                            else 198
                                                        )
                                                        if state == 197:
                                                            return 0.225860551
                                                        if state == 198:
                                                            return 0.102803625
                                        if state == 88:
                                            return 0.187915638
                                if state == 40:
                                    state = 65 if x["neargaia_med"] < 158.705048 else 66
                                    if state == 65:
                                        return 0.254343837
                                    if state == 66:
                                        return -0.0174193121
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.3846226)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 30.9952965)
                            else 14
                        )
                        if state == 13:
                            state = (
                                25
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 60.7572937)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    41
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.8931007)
                                    else 42
                                )
                                if state == 41:
                                    state = 67 if x["neargaia_med"] < 18.0725937 else 68
                                    if state == 67:
                                        state = (
                                            89
                                            if np.isnan(x["mag_peak"])
                                            or (x["mag_peak"] < 18.9997444)
                                            else 90
                                        )
                                        if state == 89:
                                            state = (
                                                115
                                                if x["neargaia_med"] < 11.7806931
                                                else 116
                                            )
                                            if state == 115:
                                                state = (
                                                    139
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 4.00838566)
                                                    else 140
                                                )
                                                if state == 139:
                                                    state = (
                                                        165
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.625351)
                                                        else 166
                                                    )
                                                    if state == 165:
                                                        state = (
                                                            199
                                                            if x["sgscore1_med"]
                                                            < 0.0340208001
                                                            else 200
                                                        )
                                                        if state == 199:
                                                            return 0.156494439
                                                        if state == 200:
                                                            return 0.0521801002
                                                    if state == 166:
                                                        return -0.111639015
                                                if state == 140:
                                                    state = (
                                                        167
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.2256508)
                                                        else 168
                                                    )
                                                    if state == 167:
                                                        state = (
                                                            203
                                                            if x["sgscore1_med"]
                                                            < 0.995968997
                                                            else 204
                                                        )
                                                        if state == 203:
                                                            return -0.128794119
                                                        if state == 204:
                                                            return 0.100888468
                                                    if state == 168:
                                                        return 0.167882204
                                            if state == 116:
                                                state = (
                                                    141
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.85813093)
                                                    else 142
                                                )
                                                if state == 141:
                                                    state = (
                                                        169
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.5233002)
                                                        else 170
                                                    )
                                                    if state == 169:
                                                        state = (
                                                            207
                                                            if x["sgscore1_med"]
                                                            < 0.313687503
                                                            else 208
                                                        )
                                                        if state == 207:
                                                            return 0.0840328112
                                                        if state == 208:
                                                            return -0.153934091
                                                    if state == 170:
                                                        return 0.169438437
                                                if state == 142:
                                                    state = (
                                                        171
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.8250275)
                                                        else 172
                                                    )
                                                    if state == 171:
                                                        state = (
                                                            209
                                                            if x["sgscore1_med"]
                                                            < 0.405842483
                                                            else 210
                                                        )
                                                        if state == 209:
                                                            return -0.15188399
                                                        if state == 210:
                                                            return 0.0954509079
                                                    if state == 172:
                                                        state = (
                                                            211
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.132842004
                                                            )
                                                            else 212
                                                        )
                                                        if state == 211:
                                                            return -0.312431902
                                                        if state == 212:
                                                            return -0.0916006044
                                        if state == 90:
                                            state = (
                                                117
                                                if x["neargaia_med"] < 12.7232323
                                                else 118
                                            )
                                            if state == 117:
                                                return -0.181449503
                                            if state == 118:
                                                return 0.0218508467
                                    if state == 68:
                                        state = 91 if x["mag_peak"] < 18.8715935 else 92
                                        if state == 91:
                                            state = (
                                                119
                                                if x["neargaia_med"] < 51.6489487
                                                else 120
                                            )
                                            if state == 119:
                                                state = (
                                                    143
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.90192127)
                                                    else 144
                                                )
                                                if state == 143:
                                                    state = (
                                                        173
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.7349014)
                                                        else 174
                                                    )
                                                    if state == 173:
                                                        return 0.136156633
                                                    if state == 174:
                                                        return -0.103666782
                                                if state == 144:
                                                    return 0.199819013
                                            if state == 120:
                                                return -0.13058725
                                        if state == 92:
                                            state = (
                                                121
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 54.9205933)
                                                else 122
                                            )
                                            if state == 121:
                                                state = (
                                                    147
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.95925331)
                                                    else 148
                                                )
                                                if state == 147:
                                                    state = (
                                                        175
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.624649)
                                                        else 176
                                                    )
                                                    if state == 175:
                                                        state = (
                                                            213
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.00188988005
                                                            )
                                                            else 214
                                                        )
                                                        if state == 213:
                                                            return -0.121649556
                                                        if state == 214:
                                                            return 0.12529996
                                                    if state == 176:
                                                        return -0.269017071
                                                if state == 148:
                                                    state = (
                                                        177
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.3950996)
                                                        else 178
                                                    )
                                                    if state == 177:
                                                        state = (
                                                            215
                                                            if x["sgscore1_med"]
                                                            < 0.318681508
                                                            else 216
                                                        )
                                                        if state == 215:
                                                            return -0.111087792
                                                        if state == 216:
                                                            return -0.00717103621
                                                    if state == 178:
                                                        return 0.0773086101
                                            if state == 122:
                                                return 0.154880166
                                if state == 42:
                                    state = 69 if x["neargaia_med"] < 34.352829 else 70
                                    if state == 69:
                                        state = 93 if x["mag_peak"] < 18.9906158 else 94
                                        if state == 93:
                                            return 0.0191891585
                                        if state == 94:
                                            state = (
                                                123
                                                if x["neargaia_med"] < 21.6599426
                                                else 124
                                            )
                                            if state == 123:
                                                return 0.0232282933
                                            if state == 124:
                                                return -0.113533042
                                    if state == 70:
                                        return 0.253821462
                            if state == 26:
                                state = (
                                    43
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.6184998)
                                    else 44
                                )
                                if state == 43:
                                    return -0.17758733
                                if state == 44:
                                    state = 71 if x["neargaia_med"] < 65.5865479 else 72
                                    if state == 71:
                                        return -0.201444596
                                    if state == 72:
                                        state = 95 if x["mag_peak"] < 18.9995842 else 96
                                        if state == 95:
                                            return 0.141748011
                                        if state == 96:
                                            state = (
                                                125
                                                if x["neargaia_med"] < 68.2880859
                                                else 126
                                            )
                                            if state == 125:
                                                return 0.0889028087
                                            if state == 126:
                                                return -0.0701359585
                        if state == 14:
                            state = (
                                27
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 54.5547676)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    45
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.2796001)
                                    else 46
                                )
                                if state == 45:
                                    state = 73 if x["neargaia_med"] < 20.8457088 else 74
                                    if state == 73:
                                        state = (
                                            97
                                            if np.isnan(x["mag_peak"])
                                            or (x["mag_peak"] < 18.9828377)
                                            else 98
                                        )
                                        if state == 97:
                                            return -0.167346969
                                        if state == 98:
                                            return 0.0288721975
                                    if state == 74:
                                        return 0.048365768
                                if state == 46:
                                    state = 75 if x["neargaia_med"] < 41.7758598 else 76
                                    if state == 75:
                                        state = (
                                            101 if x["mag_peak"] < 19.0216026 else 102
                                        )
                                        if state == 101:
                                            state = (
                                                129
                                                if x["neargaia_med"] < 14.3916988
                                                else 130
                                            )
                                            if state == 129:
                                                state = (
                                                    151
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.11348391)
                                                    else 152
                                                )
                                                if state == 151:
                                                    state = (
                                                        181
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 19.861599)
                                                        else 182
                                                    )
                                                    if state == 181:
                                                        return -0.00508178677
                                                    if state == 182:
                                                        state = (
                                                            219
                                                            if x["sgscore1_med"]
                                                            < 0.087729156
                                                            else 220
                                                        )
                                                        if state == 219:
                                                            return 0.144528493
                                                        if state == 220:
                                                            return -0.0476508178
                                                if state == 152:
                                                    return -0.0414535478
                                            if state == 130:
                                                state = (
                                                    153
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 6.50247097)
                                                    else 154
                                                )
                                                if state == 153:
                                                    state = (
                                                        185
                                                        if np.isnan(x["mag_det"])
                                                        or (x["mag_det"] < 20.2966995)
                                                        else 186
                                                    )
                                                    if state == 185:
                                                        state = (
                                                            223
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.0139062498
                                                            )
                                                            else 224
                                                        )
                                                        if state == 223:
                                                            return -0.181887224
                                                        if state == 224:
                                                            return 0.0108541166
                                                    if state == 186:
                                                        return -0.0337485522
                                                if state == 154:
                                                    return 0.0901966989
                                        if state == 102:
                                            state = (
                                                131
                                                if x["neargaia_med"] < 12.7178879
                                                else 132
                                            )
                                            if state == 131:
                                                return -0.269479781
                                            if state == 132:
                                                state = (
                                                    155
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.95720482)
                                                    else 156
                                                )
                                                if state == 155:
                                                    return -0.197032437
                                                if state == 156:
                                                    return 0.0200116709
                                    if state == 76:
                                        state = (
                                            103
                                            if np.isnan(x["mag_peak"])
                                            or (x["mag_peak"] < 19.0283928)
                                            else 104
                                        )
                                        if state == 103:
                                            return -0.331366122
                                        if state == 104:
                                            return -0.00520911999
                            if state == 28:
                                state = (
                                    47
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.4400997)
                                    else 48
                                )
                                if state == 47:
                                    state = 77 if x["neargaia_med"] < 66.1199646 else 78
                                    if state == 77:
                                        return 0.0790132284
                                    if state == 78:
                                        return -0.138253868
                                if state == 48:
                                    return 0.114998467
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 14.0495663)
                            else 16
                        )
                        if state == 15:
                            state = 29 if x["neargaia_med"] < 18.6217098 else 30
                            if state == 29:
                                return 0.0633530915
                            if state == 30:
                                state = (
                                    51
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.3742504)
                                    else 52
                                )
                                if state == 51:
                                    return -0.108365819
                                if state == 52:
                                    return 0.0809123591
                        if state == 16:
                            state = 31 if x["neargaia_med"] < 43.9889488 else 32
                            if state == 31:
                                state = (
                                    53
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.2360992)
                                    else 54
                                )
                                if state == 53:
                                    return 0.192011952
                                if state == 54:
                                    return -0.0673226863
                            if state == 32:
                                return -0.0203876086
            if state == 2:
                return -0.142394155
    elif num_booster == 39:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.928571522) else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 7.04469919) else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.2248497)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 2.98904514)
                            else 16
                        )
                        if state == 15:
                            return 0.112222128
                        if state == 16:
                            state = (
                                31
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.5804996)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    53
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 4.90430546)
                                    else 54
                                )
                                if state == 53:
                                    return 0.0913295299
                                if state == 54:
                                    return -0.067887567
                            if state == 32:
                                state = (
                                    55
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 4.95151615)
                                    else 56
                                )
                                if state == 55:
                                    return -0.105986863
                                if state == 56:
                                    return 0.0241760891
                    if state == 8:
                        return 0.0955699757
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4223499)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19 if np.isnan(x["t_lc"]) or (x["t_lc"] < 8.9757061) else 20
                        )
                        if state == 19:
                            state = (
                                35
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.4500008)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    59
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.03563643)
                                    else 60
                                )
                                if state == 59:
                                    return -0.0162338093
                                if state == 60:
                                    return -0.342290938
                            if state == 36:
                                return -0.0126427282
                        if state == 20:
                            state = (
                                37
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.9700012)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    63
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 5.94157982)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        91
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.994709969)
                                        else 92
                                    )
                                    if state == 91:
                                        state = (
                                            113
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4180984)
                                            else 114
                                        )
                                        if state == 113:
                                            state = (
                                                135
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 12.0048084)
                                                else 136
                                            )
                                            if state == 135:
                                                state = (
                                                    157
                                                    if x["col_last"] < 0.383244514
                                                    else 158
                                                )
                                                if state == 157:
                                                    state = (
                                                        187
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.26030302)
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        state = (
                                                            209
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 16.1391869
                                                            )
                                                            else 210
                                                        )
                                                        if state == 209:
                                                            return -0.0630704388
                                                        if state == 210:
                                                            return 0.10853979
                                                    if state == 188:
                                                        return -0.0976489261
                                                if state == 158:
                                                    state = (
                                                        189
                                                        if x["col_det"] < -0.182192326
                                                        else 190
                                                    )
                                                    if state == 189:
                                                        return -0.0462688878
                                                    if state == 190:
                                                        state = (
                                                            215
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 20.4244499
                                                            )
                                                            else 216
                                                        )
                                                        if state == 215:
                                                            return 0.15425247
                                                        if state == 216:
                                                            return -0.101273574
                                            if state == 136:
                                                state = (
                                                    159
                                                    if x["col_last"] < 0.121179581
                                                    else 160
                                                )
                                                if state == 159:
                                                    state = (
                                                        191
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.0989522934)
                                                        else 192
                                                    )
                                                    if state == 191:
                                                        state = (
                                                            217
                                                            if x["maggaia_med"]
                                                            < 19.3323441
                                                            else 218
                                                        )
                                                        if state == 217:
                                                            return 0.0962697491
                                                        if state == 218:
                                                            return -0.011599523
                                                    if state == 192:
                                                        return -0.0666883513
                                                if state == 160:
                                                    state = (
                                                        193
                                                        if x["col_det"] < -0.143614769
                                                        else 194
                                                    )
                                                    if state == 193:
                                                        state = (
                                                            219
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 18.2990303
                                                            )
                                                            else 220
                                                        )
                                                        if state == 219:
                                                            return -0.186384007
                                                        if state == 220:
                                                            return -0.00849862676
                                                    if state == 194:
                                                        state = (
                                                            221
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 14.1903896
                                                            )
                                                            else 222
                                                        )
                                                        if state == 221:
                                                            return -0.125734076
                                                        if state == 222:
                                                            return -0.0300650038
                                        if state == 114:
                                            return -0.164535314
                                    if state == 92:
                                        state = (
                                            115
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.2378502)
                                            else 116
                                        )
                                        if state == 115:
                                            return -0.057871826
                                        if state == 116:
                                            state = (
                                                137
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 19.4790459)
                                                else 138
                                            )
                                            if state == 137:
                                                return -0.0116487965
                                            if state == 138:
                                                return 0.21536766
                                if state == 64:
                                    state = (
                                        93
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.478464127)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            117
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.1264992)
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                139
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 23.0107918)
                                                else 140
                                            )
                                            if state == 139:
                                                state = (
                                                    163
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.259144783)
                                                    else 164
                                                )
                                                if state == 163:
                                                    state = (
                                                        197
                                                        if x["col_det"] < 0.0113191605
                                                        else 198
                                                    )
                                                    if state == 197:
                                                        return 0.0248969588
                                                    if state == 198:
                                                        return 0.233813331
                                                if state == 164:
                                                    return 0.016386088
                                            if state == 140:
                                                state = (
                                                    165
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < -0.0383281708)
                                                    else 166
                                                )
                                                if state == 165:
                                                    state = (
                                                        199
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.190657943)
                                                        else 200
                                                    )
                                                    if state == 199:
                                                        state = (
                                                            227
                                                            if x["maggaia_med"]
                                                            < 17.4192924
                                                            else 228
                                                        )
                                                        if state == 227:
                                                            return -0.105760992
                                                        if state == 228:
                                                            return 0.13569209
                                                    if state == 200:
                                                        return -0.0206989162
                                                if state == 166:
                                                    return -0.00599772111
                                        if state == 118:
                                            state = (
                                                141
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 14.0055094)
                                                else 142
                                            )
                                            if state == 141:
                                                state = (
                                                    167
                                                    if x["col_last"] < 0.250669479
                                                    else 168
                                                )
                                                if state == 167:
                                                    state = (
                                                        201
                                                        if x["col_det"] < -0.258872986
                                                        else 202
                                                    )
                                                    if state == 201:
                                                        return 0.0825089961
                                                    if state == 202:
                                                        return -0.127155915
                                                if state == 168:
                                                    return -0.219589591
                                            if state == 142:
                                                state = (
                                                    169
                                                    if x["col_last"] < 0.0336084366
                                                    else 170
                                                )
                                                if state == 169:
                                                    state = (
                                                        203
                                                        if x["col_det"] < -0.0671687126
                                                        else 204
                                                    )
                                                    if state == 203:
                                                        return -0.0399697646
                                                    if state == 204:
                                                        return 0.172590747
                                                if state == 170:
                                                    state = (
                                                        205
                                                        if x["col_det"] < 0.145645142
                                                        else 206
                                                    )
                                                    if state == 205:
                                                        state = (
                                                            235
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 19.7483368
                                                            )
                                                            else 236
                                                        )
                                                        if state == 235:
                                                            return 0.138247922
                                                        if state == 236:
                                                            return -0.144781217
                                                    if state == 206:
                                                        state = (
                                                            237
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 20.0017815
                                                            )
                                                            else 238
                                                        )
                                                        if state == 237:
                                                            return -0.0928549021
                                                        if state == 238:
                                                            return 0.117986284
                                    if state == 94:
                                        state = (
                                            119
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.08255)
                                            else 120
                                        )
                                        if state == 119:
                                            state = (
                                                143
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 31.9263134)
                                                else 144
                                            )
                                            if state == 143:
                                                return -0.120742418
                                            if state == 144:
                                                return 0.0564519726
                                        if state == 120:
                                            return 0.13999778
                            if state == 38:
                                state = (
                                    65
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 6.00809622)
                                    else 66
                                )
                                if state == 65:
                                    return -0.128957152
                                if state == 66:
                                    state = (
                                        95
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.370903969)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            121
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 17.9351006)
                                            else 122
                                        )
                                        if state == 121:
                                            return -0.0540830977
                                        if state == 122:
                                            state = (
                                                147
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 26.8944206)
                                                else 148
                                            )
                                            if state == 147:
                                                return 0.13697052
                                            if state == 148:
                                                return -0.0162584577
                                    if state == 96:
                                        return -0.0285077766
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 24.0391159)
                            else 22
                        )
                        if state == 21:
                            state = (
                                39
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 22.3535004)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    67
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.9936285)
                                    else 68
                                )
                                if state == 67:
                                    state = 97 if x["col_last"] < 0.152232647 else 98
                                    if state == 97:
                                        state = (
                                            123
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4857502)
                                            else 124
                                        )
                                        if state == 123:
                                            return 0.087056227
                                        if state == 124:
                                            state = (
                                                151
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 12.1173725)
                                                else 152
                                            )
                                            if state == 151:
                                                state = (
                                                    179
                                                    if x["col_last"] < -0.179911613
                                                    else 180
                                                )
                                                if state == 179:
                                                    return 0.0829420909
                                                if state == 180:
                                                    return -0.162918776
                                            if state == 152:
                                                state = (
                                                    181
                                                    if x["col_last"] < -0.105034828
                                                    else 182
                                                )
                                                if state == 181:
                                                    return 0.0953210369
                                                if state == 182:
                                                    return -0.0876734108
                                    if state == 98:
                                        state = (
                                            125
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4857502)
                                            else 126
                                        )
                                        if state == 125:
                                            return 0.216552585
                                        if state == 126:
                                            state = (
                                                153
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 15.9989471)
                                                else 154
                                            )
                                            if state == 153:
                                                state = (
                                                    183
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.199832916)
                                                    else 184
                                                )
                                                if state == 183:
                                                    state = (
                                                        207
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < 0.0576076508)
                                                        else 208
                                                    )
                                                    if state == 207:
                                                        state = (
                                                            239
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 17.7494583
                                                            )
                                                            else 240
                                                        )
                                                        if state == 239:
                                                            return 0.180799708
                                                        if state == 240:
                                                            return 0.00735270744
                                                    if state == 208:
                                                        return -0.0123160761
                                                if state == 184:
                                                    return -0.022973232
                                            if state == 154:
                                                return -0.0936300159
                                if state == 68:
                                    state = 99 if x["col_last"] < -0.123177528 else 100
                                    if state == 99:
                                        return 0.0893134102
                                    if state == 100:
                                        return -0.120936334
                            if state == 40:
                                return -0.16437538
                        if state == 22:
                            state = (
                                41
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.4262505)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    69
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.971221089)
                                    else 70
                                )
                                if state == 69:
                                    return 0.094242394
                                if state == 70:
                                    state = (
                                        101
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.584115982)
                                        else 102
                                    )
                                    if state == 101:
                                        state = (
                                            129
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4462509)
                                            else 130
                                        )
                                        if state == 129:
                                            return 0.0215808917
                                        if state == 130:
                                            return -0.173891231
                                    if state == 102:
                                        return -0.0197379477
                            if state == 42:
                                state = (
                                    71
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.940596104)
                                    else 72
                                )
                                if state == 71:
                                    state = 103 if x["col_last"] < 0.510352135 else 104
                                    if state == 103:
                                        return -0.0491872616
                                    if state == 104:
                                        state = (
                                            131
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.7080994)
                                            else 132
                                        )
                                        if state == 131:
                                            return -0.0499039926
                                        if state == 132:
                                            return 0.0992526039
                                if state == 72:
                                    return 0.134921148
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 13.9840736) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.9188499)
                        else 12
                    )
                    if state == 11:
                        return -0.0263202004
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 11.9736691)
                            else 26
                        )
                        if state == 25:
                            return 0.0253607649
                        if state == 26:
                            return 0.192548901
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.1220512)
                        else 14
                    )
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 16.0712433)
                            else 28
                        )
                        if state == 27:
                            return -0.099947311
                        if state == 28:
                            state = (
                                47
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.5655003)
                                else 48
                            )
                            if state == 47:
                                return 0.187037215
                            if state == 48:
                                return 0.0260779411
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 24.9808331)
                            else 30
                        )
                        if state == 29:
                            state = (
                                49
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.1860008)
                                else 50
                            )
                            if state == 49:
                                return -0.16932717
                            if state == 50:
                                return 0.103978589
                        if state == 30:
                            state = (
                                51
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.1860008)
                                else 52
                            )
                            if state == 51:
                                return -0.0927369446
                            if state == 52:
                                return 0.100871503
    elif num_booster == 40:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.403333247) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.0207707994)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.181200981)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 15.9932156)
                            else 16
                        )
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8311996)
                                else 30
                            )
                            if state == 29:
                                return -0.0395862684
                            if state == 30:
                                return 0.129405513
                        if state == 16:
                            return -0.0080841044
                    if state == 8:
                        return -0.069466576
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.108242512)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["maggaia_med"] < 41.8742523 else 18
                        if state == 17:
                            return -0.232271016
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.85075)
                                else 34
                            )
                            if state == 33:
                                return -0.117315598
                            if state == 34:
                                return 0.0631145462
                    if state == 10:
                        state = 19 if x["maggaia_med"] < 41.8742523 else 20
                        if state == 19:
                            return -0.0247195866
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.7943497)
                                else 36
                            )
                            if state == 35:
                                return 0.101949379
                            if state == 36:
                                return -0.0799796507
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.0138541497 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.145097256)
                        else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 19.34235)
                            else 22
                        )
                        if state == 21:
                            state = (
                                37
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.41395)
                                else 38
                            )
                            if state == 37:
                                state = 51 if x["maggaia_med"] < 17.0025768 else 52
                                if state == 51:
                                    return 0.182624981
                                if state == 52:
                                    state = (
                                        69
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.705833137)
                                        else 70
                                    )
                                    if state == 69:
                                        return -0.280341625
                                    if state == 70:
                                        return -0.0421679839
                            if state == 38:
                                state = 53 if x["maggaia_med"] < 18.6114006 else 54
                                if state == 53:
                                    state = (
                                        71
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.673333287)
                                        else 72
                                    )
                                    if state == 71:
                                        state = (
                                            93
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.654285729)
                                            else 94
                                        )
                                        if state == 93:
                                            state = (
                                                127
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.625357151)
                                                else 128
                                            )
                                            if state == 127:
                                                state = (
                                                    155
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 27.0074539)
                                                    else 156
                                                )
                                                if state == 155:
                                                    state = (
                                                        187
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4423256)
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        state = (
                                                            227
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.433216095
                                                            )
                                                            else 228
                                                        )
                                                        if state == 227:
                                                            return -0.103211358
                                                        if state == 228:
                                                            return 0.109264664
                                                    if state == 188:
                                                        return -0.153449163
                                                if state == 156:
                                                    state = (
                                                        189
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.5357761)
                                                        else 190
                                                    )
                                                    if state == 189:
                                                        return 0.150558472
                                                    if state == 190:
                                                        return -0.0550286099
                                            if state == 128:
                                                return -0.109426938
                                        if state == 94:
                                            return 0.117647566
                                    if state == 72:
                                        state = (
                                            95
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.751904845)
                                            else 96
                                        )
                                        if state == 95:
                                            return -0.168488443
                                        if state == 96:
                                            state = (
                                                129
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.776785851)
                                                else 130
                                            )
                                            if state == 129:
                                                return 0.125116423
                                            if state == 130:
                                                state = (
                                                    159
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 14.9892597)
                                                    else 160
                                                )
                                                if state == 159:
                                                    state = (
                                                        191
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9747696)
                                                        else 192
                                                    )
                                                    if state == 191:
                                                        return 0.020782616
                                                    if state == 192:
                                                        return -0.196785048
                                                if state == 160:
                                                    state = (
                                                        193
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0704384)
                                                        else 194
                                                    )
                                                    if state == 193:
                                                        return 0.114120133
                                                    if state == 194:
                                                        return -0.107622243
                                if state == 54:
                                    state = (
                                        73
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.57880944)
                                        else 74
                                    )
                                    if state == 73:
                                        return 0.204980403
                                    if state == 74:
                                        state = (
                                            99
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.819642961)
                                            else 100
                                        )
                                        if state == 99:
                                            state = (
                                                131
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.740714192)
                                                else 132
                                            )
                                            if state == 131:
                                                state = (
                                                    161
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 39.4475784)
                                                    else 162
                                                )
                                                if state == 161:
                                                    state = (
                                                        195
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2064285)
                                                        else 196
                                                    )
                                                    if state == 195:
                                                        return 0.164445668
                                                    if state == 196:
                                                        return 0.0095248837
                                                if state == 162:
                                                    return -0.0744366348
                                            if state == 132:
                                                state = (
                                                    163
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 18.0038261)
                                                    else 164
                                                )
                                                if state == 163:
                                                    return -0.168310419
                                                if state == 164:
                                                    return 0.0765470341
                                        if state == 100:
                                            return 0.188421696
                        if state == 22:
                            state = (
                                39
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9152489)
                                else 40
                            )
                            if state == 39:
                                return -0.211322054
                            if state == 40:
                                state = 55 if x["maggaia_med"] < 19.9174118 else 56
                                if state == 55:
                                    state = (
                                        75
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.790714145)
                                        else 76
                                    )
                                    if state == 75:
                                        return -0.176658809
                                    if state == 76:
                                        state = (
                                            103
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.904285908)
                                            else 104
                                        )
                                        if state == 103:
                                            return 0.161765084
                                        if state == 104:
                                            state = (
                                                135
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.949285507)
                                                else 136
                                            )
                                            if state == 135:
                                                return -0.118289009
                                            if state == 136:
                                                return 0.134719759
                                if state == 56:
                                    state = (
                                        77
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.627738118)
                                        else 78
                                    )
                                    if state == 77:
                                        return -0.0649609119
                                    if state == 78:
                                        return 0.166559443
                    if state == 12:
                        state = 23 if x["maggaia_med"] < 17.761898 else 24
                        if state == 23:
                            return -0.0316230468
                        if state == 24:
                            state = (
                                43
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.15275)
                                else 44
                            )
                            if state == 43:
                                return -0.17932643
                            if state == 44:
                                return 0.0536390431
                if state == 6:
                    state = 13 if x["col_peak"] < -0.251962662 else 14
                    if state == 13:
                        state = 25 if x["maggaia_med"] < 19.3569031 else 26
                        if state == 25:
                            return -0.014050087
                        if state == 26:
                            return -0.197613567
                    if state == 14:
                        state = 27 if x["maggaia_med"] < 16.3206024 else 28
                        if state == 27:
                            state = (
                                47
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.0820999)
                                else 48
                            )
                            if state == 47:
                                state = 63 if x["maggaia_med"] < 15.1379414 else 64
                                if state == 63:
                                    state = (
                                        79
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.672499835)
                                        else 80
                                    )
                                    if state == 79:
                                        return 0.149971604
                                    if state == 80:
                                        state = (
                                            107
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.780833364)
                                            else 108
                                        )
                                        if state == 107:
                                            return -0.103160203
                                        if state == 108:
                                            return 0.104388818
                                if state == 64:
                                    state = (
                                        81
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.661428571)
                                        else 82
                                    )
                                    if state == 81:
                                        return 0.0334083997
                                    if state == 82:
                                        return -0.178138629
                            if state == 48:
                                return -0.201750979
                        if state == 28:
                            state = (
                                49
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9361992)
                                else 50
                            )
                            if state == 49:
                                state = (
                                    65
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 17.6461601)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        83
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.673333049)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            113
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.596666694)
                                            else 114
                                        )
                                        if state == 113:
                                            state = (
                                                137
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.537261844)
                                                else 138
                                            )
                                            if state == 137:
                                                state = (
                                                    165
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 9.96658516)
                                                    else 166
                                                )
                                                if state == 165:
                                                    return 0.00360961002
                                                if state == 166:
                                                    state = (
                                                        201
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.787838)
                                                        else 202
                                                    )
                                                    if state == 201:
                                                        return 0.182902217
                                                    if state == 202:
                                                        return -0.0296480507
                                            if state == 138:
                                                return -0.0985145122
                                        if state == 114:
                                            return 0.189463019
                                    if state == 84:
                                        state = (
                                            115
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.746666849)
                                            else 116
                                        )
                                        if state == 115:
                                            state = (
                                                139
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.743333519)
                                                else 140
                                            )
                                            if state == 139:
                                                state = (
                                                    169
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 18.5420761)
                                                    else 170
                                                )
                                                if state == 169:
                                                    state = (
                                                        203
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1812363)
                                                        else 204
                                                    )
                                                    if state == 203:
                                                        return 0.201672688
                                                    if state == 204:
                                                        return -0.0327583104
                                                if state == 170:
                                                    return -0.0243902802
                                            if state == 140:
                                                return -0.0685890317
                                        if state == 116:
                                            state = (
                                                141
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.756071448)
                                                else 142
                                            )
                                            if state == 141:
                                                return 0.20419924
                                            if state == 142:
                                                state = (
                                                    171
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 22.0552025)
                                                    else 172
                                                )
                                                if state == 171:
                                                    state = (
                                                        207
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2594872)
                                                        else 208
                                                    )
                                                    if state == 207:
                                                        return 0.124820642
                                                    if state == 208:
                                                        return -0.134788737
                                                if state == 172:
                                                    state = (
                                                        209
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4719276)
                                                        else 210
                                                    )
                                                    if state == 209:
                                                        return -0.100707404
                                                    if state == 210:
                                                        return 0.0516907945
                                if state == 66:
                                    state = (
                                        85
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.95142889)
                                        else 86
                                    )
                                    if state == 85:
                                        state = (
                                            117
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.928571463)
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                143
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.825714111)
                                                else 144
                                            )
                                            if state == 143:
                                                state = (
                                                    173
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 7.99663782)
                                                    else 174
                                                )
                                                if state == 173:
                                                    return -0.164162576
                                                if state == 174:
                                                    state = (
                                                        211
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.5558491)
                                                        else 212
                                                    )
                                                    if state == 211:
                                                        return 0.183573067
                                                    if state == 212:
                                                        state = (
                                                            239
                                                            if x["col_last"]
                                                            < -0.0616588593
                                                            else 240
                                                        )
                                                        if state == 239:
                                                            return -0.0934688598
                                                        if state == 240:
                                                            return 0.0186350998
                                            if state == 144:
                                                return -0.0844329074
                                        if state == 118:
                                            state = (
                                                145
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.948571563)
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    177
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 11.9744911)
                                                    else 178
                                                )
                                                if state == 177:
                                                    return -0.0214454774
                                                if state == 178:
                                                    return 0.211187899
                                            if state == 146:
                                                return 0.0200029686
                                    if state == 86:
                                        return -0.116874248
                            if state == 50:
                                state = 67 if x["maggaia_med"] < 17.3424873 else 68
                                if state == 67:
                                    state = (
                                        87
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.742499948)
                                        else 88
                                    )
                                    if state == 87:
                                        return 0.209178358
                                    if state == 88:
                                        state = (
                                            119
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.881785631)
                                            else 120
                                        )
                                        if state == 119:
                                            return -0.137652129
                                        if state == 120:
                                            return 0.0934207588
                                if state == 68:
                                    state = (
                                        89
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.921428561)
                                        else 90
                                    )
                                    if state == 89:
                                        state = (
                                            121
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.910714269)
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                147
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.900714219)
                                                else 148
                                            )
                                            if state == 147:
                                                state = (
                                                    179
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 44.7733383)
                                                    else 180
                                                )
                                                if state == 179:
                                                    state = (
                                                        219
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9718876)
                                                        else 220
                                                    )
                                                    if state == 219:
                                                        return 0.104143582
                                                    if state == 220:
                                                        state = (
                                                            249
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.311579704
                                                            )
                                                            else 250
                                                        )
                                                        if state == 249:
                                                            return -0.112853616
                                                        if state == 250:
                                                            return -0.00414601853
                                                if state == 180:
                                                    state = (
                                                        221
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0584354)
                                                        else 222
                                                    )
                                                    if state == 221:
                                                        return -0.0659337863
                                                    if state == 222:
                                                        state = (
                                                            253
                                                            if x["col_last"]
                                                            < 0.765559673
                                                            else 254
                                                        )
                                                        if state == 253:
                                                            return -0.0581523143
                                                        if state == 254:
                                                            return 0.101436682
                                            if state == 148:
                                                return 0.150432467
                                        if state == 122:
                                            return -0.185260758
                                    if state == 90:
                                        state = (
                                            123
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.945714355)
                                            else 124
                                        )
                                        if state == 123:
                                            state = (
                                                149
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.926428556)
                                                else 150
                                            )
                                            if state == 149:
                                                return 0.0131111098
                                            if state == 150:
                                                state = (
                                                    181
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 16.5417252)
                                                    else 182
                                                )
                                                if state == 181:
                                                    return 0.191588193
                                                if state == 182:
                                                    return 0.00969741121
                                        if state == 124:
                                            return -0.0660313442
    elif num_booster == 41:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.974750042)
                else 2
            )
            if state == 1:
                state = 3 if x["sgscore1_med"] < 0.601415515 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["col_last"]) or (x["col_last"] < 0.584717274)
                        else 8
                    )
                    if state == 7:
                        state = 13 if x["sgscore1_med"] < 0.0799582973 else 14
                        if state == 13:
                            state = 25 if x["sgscore1_med"] < 0.0584731996 else 26
                            if state == 25:
                                state = (
                                    45
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.817749977)
                                    else 46
                                )
                                if state == 45:
                                    return -0.179177672
                                if state == 46:
                                    state = (
                                        75
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 14.9590902)
                                        else 76
                                    )
                                    if state == 75:
                                        state = (
                                            107
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 1.59416866)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                133
                                                if x["col_last"] < 0.0847834349
                                                else 134
                                            )
                                            if state == 133:
                                                state = (
                                                    149
                                                    if x["neargaia_med"] < 11.3280182
                                                    else 150
                                                )
                                                if state == 149:
                                                    state = (
                                                        171
                                                        if x["maggaia_med"] < 18.7199516
                                                        else 172
                                                    )
                                                    if state == 171:
                                                        return 0.0031790107
                                                    if state == 172:
                                                        state = (
                                                            199
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.966250002
                                                            )
                                                            else 200
                                                        )
                                                        if state == 199:
                                                            return -0.140549406
                                                        if state == 200:
                                                            return 0.0583923347
                                                if state == 150:
                                                    return 0.187466413
                                            if state == 134:
                                                state = (
                                                    151
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 7.05427599)
                                                    else 152
                                                )
                                                if state == 151:
                                                    state = (
                                                        173
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 18.6666603
                                                        )
                                                        else 174
                                                    )
                                                    if state == 173:
                                                        return -0.122762382
                                                    if state == 174:
                                                        state = (
                                                            203
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.967750013
                                                            )
                                                            else 204
                                                        )
                                                        if state == 203:
                                                            return -0.0337302871
                                                        if state == 204:
                                                            return 0.12459109
                                                if state == 152:
                                                    state = (
                                                        175
                                                        if x["maggaia_med"] < 17.9363766
                                                        else 176
                                                    )
                                                    if state == 175:
                                                        return 0.174469426
                                                    if state == 176:
                                                        return -0.0211361572
                                        if state == 108:
                                            return -0.107203595
                                    if state == 76:
                                        state = (
                                            109
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.371750712)
                                            else 110
                                        )
                                        if state == 109:
                                            return 0.11763899
                                        if state == 110:
                                            state = (
                                                137
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < -0.109493732)
                                                else 138
                                            )
                                            if state == 137:
                                                state = (
                                                    155
                                                    if x["neargaia_med"] < 31.3435116
                                                    else 156
                                                )
                                                if state == 155:
                                                    return -0.190258816
                                                if state == 156:
                                                    state = (
                                                        177
                                                        if x["maggaia_med"] < 20.1634254
                                                        else 178
                                                    )
                                                    if state == 177:
                                                        state = (
                                                            205
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.923500001
                                                            )
                                                            else 206
                                                        )
                                                        if state == 205:
                                                            return 0.0877457038
                                                        if state == 206:
                                                            return -0.155800819
                                                    if state == 178:
                                                        return 0.0377467908
                                            if state == 138:
                                                state = (
                                                    157
                                                    if x["neargaia_med"] < 38.5971031
                                                    else 158
                                                )
                                                if state == 157:
                                                    state = (
                                                        179
                                                        if x["maggaia_med"] < 19.1935673
                                                        else 180
                                                    )
                                                    if state == 179:
                                                        state = (
                                                            207
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.920750022
                                                            )
                                                            else 208
                                                        )
                                                        if state == 207:
                                                            return 0.0951240957
                                                        if state == 208:
                                                            return -0.1475631
                                                    if state == 180:
                                                        return -0.120980509
                                                if state == 158:
                                                    state = (
                                                        181
                                                        if x["maggaia_med"] < 18.8911247
                                                        else 182
                                                    )
                                                    if state == 181:
                                                        return 0.0755862072
                                                    if state == 182:
                                                        return -0.0935068876
                            if state == 26:
                                return -0.234891102
                        if state == 14:
                            state = 27 if x["sgscore1_med"] < 0.196565509 else 28
                            if state == 27:
                                state = (
                                    47
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.878499985)
                                    else 48
                                )
                                if state == 47:
                                    return 0.206309408
                                if state == 48:
                                    state = (
                                        77
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 7.08279705)
                                        else 78
                                    )
                                    if state == 77:
                                        return -0.136877447
                                    if state == 78:
                                        return 0.178509831
                            if state == 28:
                                state = (
                                    49
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.879750013)
                                    else 50
                                )
                                if state == 49:
                                    return -0.195925325
                                if state == 50:
                                    state = 79 if x["neargaia_med"] < 68.9147644 else 80
                                    if state == 79:
                                        state = (
                                            113
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 8.75906372)
                                            else 114
                                        )
                                        if state == 113:
                                            state = (
                                                139
                                                if x["col_last"] < 0.280994415
                                                else 140
                                            )
                                            if state == 139:
                                                state = (
                                                    159
                                                    if x["neargaia_med"] < 37.1358948
                                                    else 160
                                                )
                                                if state == 159:
                                                    return -0.212314114
                                                if state == 160:
                                                    return 0.0161953326
                                            if state == 140:
                                                state = (
                                                    161
                                                    if x["neargaia_med"] < 18.6354599
                                                    else 162
                                                )
                                                if state == 161:
                                                    state = (
                                                        183
                                                        if x["maggaia_med"] < 18.5600166
                                                        else 184
                                                    )
                                                    if state == 183:
                                                        state = (
                                                            211
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.973749995
                                                            )
                                                            else 212
                                                        )
                                                        if state == 211:
                                                            return -0.208910942
                                                        if state == 212:
                                                            return 0.0241915807
                                                    if state == 184:
                                                        state = (
                                                            213
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.965000033
                                                            )
                                                            else 214
                                                        )
                                                        if state == 213:
                                                            return -0.030697152
                                                        if state == 214:
                                                            return 0.184201896
                                                if state == 162:
                                                    state = (
                                                        185
                                                        if x["maggaia_med"] < 19.0775318
                                                        else 186
                                                    )
                                                    if state == 185:
                                                        state = (
                                                            215
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.940500021
                                                            )
                                                            else 216
                                                        )
                                                        if state == 215:
                                                            return 0.0214760061
                                                        if state == 216:
                                                            return -0.197516516
                                                    if state == 186:
                                                        return 0.0199777596
                                        if state == 114:
                                            return 0.09310247
                                    if state == 80:
                                        state = (
                                            115
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 1.30652523)
                                            else 116
                                        )
                                        if state == 115:
                                            return -0.135210678
                                        if state == 116:
                                            return 0.144447193
                    if state == 8:
                        state = 15 if x["sgscore1_med"] < 0.0155833494 else 16
                        if state == 15:
                            return 0.084252581
                        if state == 16:
                            state = 31 if x["sgscore1_med"] < 0.0564166494 else 32
                            if state == 31:
                                return -0.111362465
                            if state == 32:
                                state = (
                                    53
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.963249981)
                                    else 54
                                )
                                if state == 53:
                                    return 0.0889763013
                                if state == 54:
                                    return -0.0499041677
                if state == 4:
                    return -0.211348534
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.484214485 else 6
                if state == 5:
                    state = 9 if x["col_last"] < -0.0263199806 else 10
                    if state == 9:
                        state = 17 if x["sgscore1_med"] < 0.166740999 else 18
                        if state == 17:
                            state = 33 if x["sgscore1_med"] < 0.0130000003 else 34
                            if state == 33:
                                state = (
                                    55
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.976750016)
                                    else 56
                                )
                                if state == 55:
                                    return -0.045002915
                                if state == 56:
                                    state = 85 if x["neargaia_med"] < 8.21233845 else 86
                                    if state == 85:
                                        return -0.088398315
                                    if state == 86:
                                        state = (
                                            119
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 2.20976734)
                                            else 120
                                        )
                                        if state == 119:
                                            return 0.132335812
                                        if state == 120:
                                            state = (
                                                141
                                                if x["col_last"] < -0.154857635
                                                else 142
                                            )
                                            if state == 141:
                                                return 0.0884336382
                                            if state == 142:
                                                return -0.0928586647
                            if state == 34:
                                return 0.163761437
                        if state == 18:
                            return -0.0795464143
                    if state == 10:
                        state = 19 if x["sgscore1_med"] < 0.310276985 else 20
                        if state == 19:
                            state = 37 if x["sgscore1_med"] < 0.186567992 else 38
                            if state == 37:
                                state = (
                                    59
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.985249996)
                                    else 60
                                )
                                if state == 59:
                                    state = 87 if x["neargaia_med"] < 1.03120327 else 88
                                    if state == 87:
                                        state = (
                                            121
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.718070269)
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                143
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.214292526)
                                                else 144
                                            )
                                            if state == 143:
                                                state = (
                                                    163
                                                    if x["neargaia_med"] < 0.274741352
                                                    else 164
                                                )
                                                if state == 163:
                                                    state = (
                                                        187
                                                        if x["maggaia_med"] < 18.6219044
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        return -0.228013277
                                                    if state == 188:
                                                        return 0.0306511186
                                                if state == 164:
                                                    return 0.108337015
                                            if state == 144:
                                                return -0.128584787
                                        if state == 122:
                                            return -0.161325455
                                    if state == 88:
                                        state = (
                                            123
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.140456647)
                                            else 124
                                        )
                                        if state == 123:
                                            return 0.167618334
                                        if state == 124:
                                            state = (
                                                145
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.311607361)
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    167
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 12.1875896)
                                                    else 168
                                                )
                                                if state == 167:
                                                    state = (
                                                        191
                                                        if x["maggaia_med"] < 18.5186653
                                                        else 192
                                                    )
                                                    if state == 191:
                                                        return 0.147037983
                                                    if state == 192:
                                                        state = (
                                                            225
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.981250048
                                                            )
                                                            else 226
                                                        )
                                                        if state == 225:
                                                            return -0.0115222633
                                                        if state == 226:
                                                            return 0.103844918
                                                if state == 168:
                                                    state = (
                                                        193
                                                        if x["maggaia_med"] < 20.0387783
                                                        else 194
                                                    )
                                                    if state == 193:
                                                        state = (
                                                            227
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.981750011
                                                            )
                                                            else 228
                                                        )
                                                        if state == 227:
                                                            return -0.0387559161
                                                        if state == 228:
                                                            return -0.0950863361
                                                    if state == 194:
                                                        return 0.0429579802
                                            if state == 146:
                                                state = (
                                                    169
                                                    if x["neargaia_med"] < 11.8671551
                                                    else 170
                                                )
                                                if state == 169:
                                                    return 0.159218669
                                                if state == 170:
                                                    state = (
                                                        197
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 18.9433174
                                                        )
                                                        else 198
                                                    )
                                                    if state == 197:
                                                        state = (
                                                            231
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.978249967
                                                            )
                                                            else 232
                                                        )
                                                        if state == 231:
                                                            return -0.0100213019
                                                        if state == 232:
                                                            return 0.134090751
                                                    if state == 198:
                                                        return -0.0763169974
                                if state == 60:
                                    state = 89 if x["neargaia_med"] < 12.9605637 else 90
                                    if state == 89:
                                        return -0.210682929
                                    if state == 90:
                                        return 0.0890337676
                            if state == 38:
                                state = (
                                    61
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.980250001)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        91
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 10.582799)
                                        else 92
                                    )
                                    if state == 91:
                                        return -0.0934589654
                                    if state == 92:
                                        return 0.124432787
                                if state == 62:
                                    return 0.186828867
                        if state == 20:
                            state = 39 if x["sgscore1_med"] < 0.395309508 else 40
                            if state == 39:
                                return -0.246523112
                            if state == 40:
                                state = (
                                    65
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.979249954)
                                    else 66
                                )
                                if state == 65:
                                    return 0.125584349
                                if state == 66:
                                    return -0.111598417
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["col_last"]) or (x["col_last"] < -0.170930386)
                        else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.505678535)
                            else 22
                        )
                        if state == 21:
                            return 0.0563313849
                        if state == 22:
                            state = 41 if x["sgscore1_med"] < 0.969916999 else 42
                            if state == 41:
                                state = (
                                    67
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.980250001)
                                    else 68
                                )
                                if state == 67:
                                    return -0.15367581
                                if state == 68:
                                    state = 95 if x["neargaia_med"] < 12.7136841 else 96
                                    if state == 95:
                                        return -0.137642547
                                    if state == 96:
                                        return 0.0242758337
                            if state == 42:
                                state = (
                                    69
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.981250048)
                                    else 70
                                )
                                if state == 69:
                                    state = 97 if x["neargaia_med"] < 16.7246094 else 98
                                    if state == 97:
                                        return -0.0735771582
                                    if state == 98:
                                        return 0.156305417
                                if state == 70:
                                    return -0.0603910573
                    if state == 12:
                        state = 23 if x["sgscore1_med"] < 0.562545002 else 24
                        if state == 23:
                            return 0.120829985
                        if state == 24:
                            state = 43 if x["sgscore1_med"] < 0.969916999 else 44
                            if state == 43:
                                return -0.0512551889
                            if state == 44:
                                state = (
                                    73
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.978500009)
                                    else 74
                                )
                                if state == 73:
                                    return -0.0693265051
                                if state == 74:
                                    state = (
                                        105 if x["neargaia_med"] < 61.1504593 else 106
                                    )
                                    if state == 105:
                                        return 0.154803813
                                    if state == 106:
                                        return -0.0436931327
    elif num_booster == 42:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.969500005)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["col_det"]) or (x["col_det"] < -0.076107502) else 4
                )
                if state == 3:
                    state = 7 if x["sgscore1_med"] < 0.249001503 else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.0664997)
                            else 16
                        )
                        if state == 15:
                            return -0.129440024
                        if state == 16:
                            state = 31 if x["col_peak"] < 0.0666937828 else 32
                            if state == 31:
                                return 0.128114641
                            if state == 32:
                                state = (
                                    53
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.8107986)
                                    else 54
                                )
                                if state == 53:
                                    return 0.0972300172
                                if state == 54:
                                    state = (
                                        81
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 27.9913654)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            111 if x["maggaia_med"] < 18.963377 else 112
                                        )
                                        if state == 111:
                                            state = (
                                                153
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.73741686)
                                                else 154
                                            )
                                            if state == 153:
                                                state = (
                                                    207
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 20.3579998)
                                                    else 208
                                                )
                                                if state == 207:
                                                    return 0.238091975
                                                if state == 208:
                                                    return -0.0672798529
                                            if state == 154:
                                                return -0.0434658825
                                        if state == 112:
                                            return -0.105705932
                                    if state == 82:
                                        return -0.110635199
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.5272503)
                            else 18
                        )
                        if state == 17:
                            return -0.29440102
                        if state == 18:
                            state = 33 if x["col_peak"] < 0.85104847 else 34
                            if state == 33:
                                return -0.109633058
                            if state == 34:
                                state = (
                                    55
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.4276009)
                                    else 56
                                )
                                if state == 55:
                                    return -0.200664803
                                if state == 56:
                                    state = (
                                        83
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 13.9572048)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            115
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.6724548)
                                            else 116
                                        )
                                        if state == 115:
                                            return -0.110899642
                                        if state == 116:
                                            return 0.0639932677
                                    if state == 84:
                                        state = (
                                            117
                                            if x["maggaia_med"] < 18.8512001
                                            else 118
                                        )
                                        if state == 117:
                                            return -0.0693594664
                                        if state == 118:
                                            state = (
                                                159
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.96641183)
                                                else 160
                                            )
                                            if state == 159:
                                                return -0.0465427563
                                            if state == 160:
                                                return 0.203655586
                if state == 4:
                    state = 9 if x["sgscore1_med"] < 0.0377708524 else 10
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.0529995)
                            else 20
                        )
                        if state == 19:
                            return -0.18782413
                        if state == 20:
                            state = 35 if x["col_peak"] < 1.11804104 else 36
                            if state == 35:
                                return -0.0611144975
                            if state == 36:
                                state = (
                                    57
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.1785507)
                                    else 58
                                )
                                if state == 57:
                                    return -0.0903429165
                                if state == 58:
                                    return 0.112716153
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.3137512)
                            else 22
                        )
                        if state == 21:
                            return -0.0248010345
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < -0.00775623322)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    59
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.3856506)
                                    else 60
                                )
                                if state == 59:
                                    return 0.138323352
                                if state == 60:
                                    state = (
                                        85
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 29.9414997)
                                        else 86
                                    )
                                    if state == 85:
                                        state = (
                                            119
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.7513924)
                                            else 120
                                        )
                                        if state == 119:
                                            state = (
                                                161
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.77781963)
                                                else 162
                                            )
                                            if state == 161:
                                                state = (
                                                    211
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.9107494)
                                                    else 212
                                                )
                                                if state == 211:
                                                    return -0.157377496
                                                if state == 212:
                                                    return 0.030512264
                                            if state == 162:
                                                return 0.0196546707
                                        if state == 120:
                                            return 0.0913381875
                                    if state == 86:
                                        return 0.116581418
                            if state == 38:
                                return -0.024519911
            if state == 2:
                state = 5 if x["col_det"] < 0.29579258 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.523211002)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.7975006)
                            else 24
                        )
                        if state == 23:
                            state = (
                                39
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < -0.00736427307)
                                else 40
                            )
                            if state == 39:
                                return 0.178106308
                            if state == 40:
                                return 0.0762229264
                        if state == 24:
                            state = (
                                41
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.241897583)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    61
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.8675499)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        87
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 11.9791145)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            121
                                            if x["maggaia_med"] < 18.9212799
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                165
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.12122726)
                                                else 166
                                            )
                                            if state == 165:
                                                state = (
                                                    213
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.6357498)
                                                    else 214
                                                )
                                                if state == 213:
                                                    return -0.184379309
                                                if state == 214:
                                                    return 0.029926002
                                            if state == 166:
                                                return 0.0444563963
                                        if state == 122:
                                            state = (
                                                167
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.704968929)
                                                else 168
                                            )
                                            if state == 167:
                                                return -0.102667451
                                            if state == 168:
                                                return 0.144222707
                                    if state == 88:
                                        state = (
                                            123
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.8910027)
                                            else 124
                                        )
                                        if state == 123:
                                            state = (
                                                169
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.02752638)
                                                else 170
                                            )
                                            if state == 169:
                                                state = (
                                                    217
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.4819984)
                                                    else 218
                                                )
                                                if state == 217:
                                                    return -0.118800439
                                                if state == 218:
                                                    state = (
                                                        265
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 0.9121539
                                                        )
                                                        else 266
                                                    )
                                                    if state == 265:
                                                        return 0.0810208246
                                                    if state == 266:
                                                        return -0.112185583
                                            if state == 170:
                                                state = (
                                                    219
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.9669991)
                                                    else 220
                                                )
                                                if state == 219:
                                                    return 0.206119388
                                                if state == 220:
                                                    state = (
                                                        267
                                                        if x["distpsnr1_med"]
                                                        < 1.71393037
                                                        else 268
                                                    )
                                                    if state == 267:
                                                        return 0.178396523
                                                    if state == 268:
                                                        state = (
                                                            311
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.1967506
                                                            )
                                                            else 312
                                                        )
                                                        if state == 311:
                                                            return -0.149746731
                                                        if state == 312:
                                                            return 0.00389777613
                                        if state == 124:
                                            state = (
                                                171
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.35582447)
                                                else 172
                                            )
                                            if state == 171:
                                                state = (
                                                    221
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.8195)
                                                    else 222
                                                )
                                                if state == 221:
                                                    return 0.182006404
                                                if state == 222:
                                                    state = (
                                                        269
                                                        if x["distpsnr1_med"]
                                                        < 0.99940753
                                                        else 270
                                                    )
                                                    if state == 269:
                                                        return -0.177286789
                                                    if state == 270:
                                                        return 0.111493334
                                            if state == 172:
                                                state = (
                                                    223
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 20.8099995)
                                                    else 224
                                                )
                                                if state == 223:
                                                    return 0.240781099
                                                if state == 224:
                                                    state = (
                                                        273
                                                        if x["distpsnr1_med"]
                                                        < 6.35677242
                                                        else 274
                                                    )
                                                    if state == 273:
                                                        return -0.0660833716
                                                    if state == 274:
                                                        state = (
                                                            315
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.4034996
                                                            )
                                                            else 316
                                                        )
                                                        if state == 315:
                                                            return -0.120324172
                                                        if state == 316:
                                                            return 0.174598306
                                if state == 62:
                                    state = (
                                        89
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 39.9493713)
                                        else 90
                                    )
                                    if state == 89:
                                        state = (
                                            125
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 20.1948986)
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                173
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 2.06562114)
                                                else 174
                                            )
                                            if state == 173:
                                                state = (
                                                    225
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 21.7485008)
                                                    else 226
                                                )
                                                if state == 225:
                                                    state = (
                                                        275
                                                        if x["distpsnr1_med"]
                                                        < 0.388218403
                                                        else 276
                                                    )
                                                    if state == 275:
                                                        return -0.157527581
                                                    if state == 276:
                                                        state = (
                                                            317
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.8232498
                                                            )
                                                            else 318
                                                        )
                                                        if state == 317:
                                                            return 0.139491439
                                                        if state == 318:
                                                            return -0.0725756362
                                                if state == 226:
                                                    return 0.216009289
                                            if state == 174:
                                                state = (
                                                    227
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 20.8470001)
                                                    else 228
                                                )
                                                if state == 227:
                                                    state = (
                                                        277
                                                        if x["distpsnr1_med"]
                                                        < 3.33872938
                                                        else 278
                                                    )
                                                    if state == 277:
                                                        state = (
                                                            319
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.3255005
                                                            )
                                                            else 320
                                                        )
                                                        if state == 319:
                                                            return 0.0814097598
                                                        if state == 320:
                                                            return -0.158935994
                                                    if state == 278:
                                                        return -0.244207874
                                                if state == 228:
                                                    state = (
                                                        279
                                                        if x["distpsnr1_med"]
                                                        < 6.59480381
                                                        else 280
                                                    )
                                                    if state == 279:
                                                        return -0.0469641425
                                                    if state == 280:
                                                        return 0.104382396
                                        if state == 126:
                                            return -0.160030514
                                    if state == 90:
                                        return 0.0847731605
                            if state == 42:
                                state = (
                                    63
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.5377007)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        91
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 33.0037155)
                                        else 92
                                    )
                                    if state == 91:
                                        state = (
                                            129
                                            if x["maggaia_med"] < 17.4616547
                                            else 130
                                        )
                                        if state == 129:
                                            return -0.100218087
                                        if state == 130:
                                            return 0.0814637616
                                    if state == 92:
                                        return 0.0807719454
                                if state == 64:
                                    return 0.208471075
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 22.3129997)
                            else 26
                        )
                        if state == 25:
                            return -0.129987225
                        if state == 26:
                            state = (
                                43
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < -0.0846438408)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    65
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 18.5426502)
                                    else 66
                                )
                                if state == 65:
                                    return -0.0543958806
                                if state == 66:
                                    return 0.129743829
                            if state == 44:
                                return -0.0650008321
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.0527232513)
                        else 14
                    )
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.2700005)
                            else 28
                        )
                        if state == 27:
                            state = 45 if x["col_peak"] < -0.0788087845 else 46
                            if state == 45:
                                return 0.206728637
                            if state == 46:
                                state = (
                                    67
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 18.9604492)
                                    else 68
                                )
                                if state == 67:
                                    return 0.197672337
                                if state == 68:
                                    state = (
                                        93
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 15.919693)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            131
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.926445)
                                            else 132
                                        )
                                        if state == 131:
                                            return 0.195899367
                                        if state == 132:
                                            state = (
                                                177
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.46521157)
                                                else 178
                                            )
                                            if state == 177:
                                                return 0.0981960148
                                            if state == 178:
                                                state = (
                                                    229
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.8845005)
                                                    else 230
                                                )
                                                if state == 229:
                                                    return -0.192344368
                                                if state == 230:
                                                    return 0.111921817
                                    if state == 94:
                                        state = (
                                            133
                                            if x["maggaia_med"] < 19.1049004
                                            else 134
                                        )
                                        if state == 133:
                                            state = (
                                                179
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.1590209)
                                                else 180
                                            )
                                            if state == 179:
                                                state = (
                                                    231
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.7140007)
                                                    else 232
                                                )
                                                if state == 231:
                                                    return 0.0158697106
                                                if state == 232:
                                                    return 0.175373718
                                            if state == 180:
                                                return -0.114429593
                                        if state == 134:
                                            state = (
                                                181
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.696424842)
                                                else 182
                                            )
                                            if state == 181:
                                                state = (
                                                    235
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.1064987)
                                                    else 236
                                                )
                                                if state == 235:
                                                    return 0.166661456
                                                if state == 236:
                                                    state = (
                                                        283
                                                        if x["distpsnr1_med"]
                                                        < 0.586771727
                                                        else 284
                                                    )
                                                    if state == 283:
                                                        state = (
                                                            329
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.0939999
                                                            )
                                                            else 330
                                                        )
                                                        if state == 329:
                                                            return -0.200277343
                                                        if state == 330:
                                                            return 0.0916197002
                                                    if state == 284:
                                                        return 0.0811901391
                                            if state == 182:
                                                state = (
                                                    237
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 18.0340004)
                                                    else 238
                                                )
                                                if state == 237:
                                                    return 0.0863222033
                                                if state == 238:
                                                    state = (
                                                        285
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 3.58172917
                                                        )
                                                        else 286
                                                    )
                                                    if state == 285:
                                                        state = (
                                                            331
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.9189987
                                                            )
                                                            else 332
                                                        )
                                                        if state == 331:
                                                            return -0.244548678
                                                        if state == 332:
                                                            return 0.0249953866
                                                    if state == 286:
                                                        state = (
                                                            333
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.3862495
                                                            )
                                                            else 334
                                                        )
                                                        if state == 333:
                                                            return -0.127695188
                                                        if state == 334:
                                                            return 0.100653701
                        if state == 28:
                            state = 47 if x["col_peak"] < -0.123041153 else 48
                            if state == 47:
                                return -0.110609107
                            if state == 48:
                                state = (
                                    71
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.4500999)
                                    else 72
                                )
                                if state == 71:
                                    state = (
                                        95
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 19.0437908)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            135
                                            if x["maggaia_med"] < 18.3018284
                                            else 136
                                        )
                                        if state == 135:
                                            return -0.0862363204
                                        if state == 136:
                                            state = (
                                                185
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.61668992)
                                                else 186
                                            )
                                            if state == 185:
                                                state = (
                                                    241
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 20.894001)
                                                    else 242
                                                )
                                                if state == 241:
                                                    state = (
                                                        289
                                                        if x["distpsnr1_med"]
                                                        < 0.674907923
                                                        else 290
                                                    )
                                                    if state == 289:
                                                        return 0.0749859288
                                                    if state == 290:
                                                        return -0.144737884
                                                if state == 242:
                                                    return 0.0776293725
                                            if state == 186:
                                                state = (
                                                    243
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 21.6497498)
                                                    else 244
                                                )
                                                if state == 243:
                                                    state = (
                                                        293
                                                        if x["distpsnr1_med"]
                                                        < 5.23323441
                                                        else 294
                                                    )
                                                    if state == 293:
                                                        return 0.0889485776
                                                    if state == 294:
                                                        return -0.0782444403
                                                if state == 244:
                                                    return 0.138054475
                                    if state == 96:
                                        state = (
                                            137
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 17.3723068)
                                            else 138
                                        )
                                        if state == 137:
                                            state = (
                                                187
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.16061783)
                                                else 188
                                            )
                                            if state == 187:
                                                return 0.173048526
                                            if state == 188:
                                                state = (
                                                    245
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 20.1409988)
                                                    else 246
                                                )
                                                if state == 245:
                                                    return -0.31728676
                                                if state == 246:
                                                    return 0.0837810487
                                        if state == 138:
                                            return 0.181581631
                                if state == 72:
                                    state = (
                                        97
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 13.0181541)
                                        else 98
                                    )
                                    if state == 97:
                                        return 0.135787234
                                    if state == 98:
                                        state = (
                                            139
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.6316299)
                                            else 140
                                        )
                                        if state == 139:
                                            state = (
                                                189
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.40110874)
                                                else 190
                                            )
                                            if state == 189:
                                                state = (
                                                    247
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 20.6502495)
                                                    else 248
                                                )
                                                if state == 247:
                                                    return 0.00915452372
                                                if state == 248:
                                                    return -0.180938751
                                            if state == 190:
                                                return 0.131063953
                                        if state == 140:
                                            return -0.241453335
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.8950005)
                            else 30
                        )
                        if state == 29:
                            state = (
                                49
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.424764633)
                                else 50
                            )
                            if state == 49:
                                state = (
                                    73
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.3823109)
                                    else 74
                                )
                                if state == 73:
                                    return -0.266361505
                                if state == 74:
                                    state = (
                                        99
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 26.9105606)
                                        else 100
                                    )
                                    if state == 99:
                                        return 0.0893445313
                                    if state == 100:
                                        return -0.0992121994
                            if state == 50:
                                return 0.020328952
                        if state == 30:
                            state = 51 if x["col_peak"] < -0.0956530571 else 52
                            if state == 51:
                                state = (
                                    75
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.5948505)
                                    else 76
                                )
                                if state == 75:
                                    return -0.0371943414
                                if state == 76:
                                    state = (
                                        103
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 19.9696808)
                                        else 104
                                    )
                                    if state == 103:
                                        return -0.0352363139
                                    if state == 104:
                                        state = (
                                            143
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 16.2534504)
                                            else 144
                                        )
                                        if state == 143:
                                            return -0.026741704
                                        if state == 144:
                                            return 0.215867728
                            if state == 52:
                                state = (
                                    77
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 18.9777508)
                                    else 78
                                )
                                if state == 77:
                                    state = (
                                        105
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 44.9101219)
                                        else 106
                                    )
                                    if state == 105:
                                        state = (
                                            145
                                            if x["maggaia_med"] < 19.4089413
                                            else 146
                                        )
                                        if state == 145:
                                            return 0.018124463
                                        if state == 146:
                                            return -0.230087951
                                    if state == 106:
                                        return 0.0210847035
                                if state == 78:
                                    state = (
                                        107
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 53.9858551)
                                        else 108
                                    )
                                    if state == 107:
                                        state = (
                                            149
                                            if x["maggaia_med"] < 16.5801506
                                            else 150
                                        )
                                        if state == 149:
                                            state = (
                                                199
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.15790677)
                                                else 200
                                            )
                                            if state == 199:
                                                state = (
                                                    253
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 21.4539986)
                                                    else 254
                                                )
                                                if state == 253:
                                                    state = (
                                                        299
                                                        if x["distpsnr1_med"]
                                                        < 2.26480198
                                                        else 300
                                                    )
                                                    if state == 299:
                                                        return -0.153277084
                                                    if state == 300:
                                                        return 0.0637748092
                                                if state == 254:
                                                    return 0.0872644633
                                            if state == 200:
                                                return -0.212117717
                                        if state == 150:
                                            state = (
                                                201
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.365908563)
                                                else 202
                                            )
                                            if state == 201:
                                                state = (
                                                    255
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 21.3785)
                                                    else 256
                                                )
                                                if state == 255:
                                                    state = (
                                                        301
                                                        if x["distpsnr1_med"]
                                                        < 0.372682512
                                                        else 302
                                                    )
                                                    if state == 301:
                                                        return -0.218716443
                                                    if state == 302:
                                                        return 0.0367940031
                                                if state == 256:
                                                    return -0.0259442534
                                            if state == 202:
                                                state = (
                                                    257
                                                    if np.isnan(x["magnr_med"])
                                                    or (x["magnr_med"] < 19.7210007)
                                                    else 258
                                                )
                                                if state == 257:
                                                    state = (
                                                        303
                                                        if x["distpsnr1_med"]
                                                        < 3.83397651
                                                        else 304
                                                    )
                                                    if state == 303:
                                                        state = (
                                                            337
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.3234997
                                                            )
                                                            else 338
                                                        )
                                                        if state == 337:
                                                            return -0.00350928213
                                                        if state == 338:
                                                            return 0.14478001
                                                    if state == 304:
                                                        return 0.185487494
                                                if state == 258:
                                                    state = (
                                                        305
                                                        if x["distpsnr1_med"]
                                                        < 0.99974519
                                                        else 306
                                                    )
                                                    if state == 305:
                                                        state = (
                                                            341
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 20.9775009
                                                            )
                                                            else 342
                                                        )
                                                        if state == 341:
                                                            return 0.111656517
                                                        if state == 342:
                                                            return -0.063333191
                                                    if state == 306:
                                                        state = (
                                                            343
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.3530006
                                                            )
                                                            else 344
                                                        )
                                                        if state == 343:
                                                            return -0.136650413
                                                        if state == 344:
                                                            return 0.0540388823
                                    if state == 108:
                                        state = (
                                            151
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 20.080719)
                                            else 152
                                        )
                                        if state == 151:
                                            state = (
                                                203
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.4314785)
                                                else 204
                                            )
                                            if state == 203:
                                                return -0.0428560078
                                            if state == 204:
                                                return 0.163848981
                                        if state == 152:
                                            return -0.0204773806
    elif num_booster == 43:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.9933681) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.0426562503)
                    else 4
                )
                if state == 3:
                    state = 7 if x["mag_peak"] < 18.5562019 else 8
                    if state == 7:
                        state = 13 if x["col_last"] < 0.000434875488 else 14
                        if state == 13:
                            return -0.0780363828
                        if state == 14:
                            state = (
                                21
                                if np.isnan(x["col_det"]) or (x["col_det"] < -1.622159)
                                else 22
                            )
                            if state == 21:
                                state = (
                                    35
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.573)
                                    else 36
                                )
                                if state == 35:
                                    state = 53 if x["col_last"] < 0.508498192 else 54
                                    if state == 53:
                                        return 0.0502915233
                                    if state == 54:
                                        state = (
                                            69
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.9230003)
                                            else 70
                                        )
                                        if state == 69:
                                            return 0.0592843443
                                        if state == 70:
                                            state = (
                                                87
                                                if x["col_peak"] < 0.117361546
                                                else 88
                                            )
                                            if state == 87:
                                                return 0.0332163163
                                            if state == 88:
                                                return -0.201732785
                                if state == 36:
                                    return 0.1199812
                            if state == 22:
                                return 0.122505218
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["col_last"]) or (x["col_last"] < 0.34346962)
                            else 16
                        )
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < 0.100020409)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    37
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 20.0100002)
                                    else 38
                                )
                                if state == 37:
                                    return -0.232330963
                                if state == 38:
                                    state = 55 if x["col_last"] < 0.675416052 else 56
                                    if state == 55:
                                        return -0.109335974
                                    if state == 56:
                                        state = (
                                            71
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 20.0535011)
                                            else 72
                                        )
                                        if state == 71:
                                            return 0.0937500224
                                        if state == 72:
                                            return -0.0658541098
                            if state == 24:
                                return 0.135956824
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < 0.0890197754)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    39
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 20.0112495)
                                    else 40
                                )
                                if state == 39:
                                    return -0.0787698999
                                if state == 40:
                                    return 0.109252281
                            if state == 26:
                                return 0.110173635
                if state == 4:
                    state = 9 if x["mag_peak"] < 17.7473316 else 10
                    if state == 9:
                        state = 17 if x["col_last"] < 0.0784301758 else 18
                        if state == 17:
                            return -0.0112661468
                        if state == 18:
                            state = 29 if x["col_det"] < -0.107580185 else 30
                            if state == 29:
                                state = (
                                    43
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 20.7527504)
                                    else 44
                                )
                                if state == 43:
                                    return 0.0560871363
                                if state == 44:
                                    return -0.107148029
                            if state == 30:
                                state = (
                                    45
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 15.7690001)
                                    else 46
                                )
                                if state == 45:
                                    return -0.0916052386
                                if state == 46:
                                    state = (
                                        59
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 1.21998215)
                                        else 60
                                    )
                                    if state == 59:
                                        state = (
                                            73
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 18.5240002)
                                            else 74
                                        )
                                        if state == 73:
                                            return 0.240611956
                                        if state == 74:
                                            state = (
                                                91
                                                if x["col_peak"] < -0.195018768
                                                else 92
                                            )
                                            if state == 91:
                                                return -0.115573354
                                            if state == 92:
                                                return 0.112477034
                                    if state == 60:
                                        return -0.0108339833
                    if state == 10:
                        state = 19 if x["col_last"] < -0.235190868 else 20
                        if state == 19:
                            state = 31 if x["col_det"] < -0.103473186 else 32
                            if state == 31:
                                return 0.0278074984
                            if state == 32:
                                state = (
                                    47
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 21.3344994)
                                    else 48
                                )
                                if state == 47:
                                    return -0.148039624
                                if state == 48:
                                    return 0.038154427
                        if state == 20:
                            state = (
                                33
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < -0.200027466)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    49
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 17.3364983)
                                    else 50
                                )
                                if state == 49:
                                    state = 61 if x["col_last"] < 0.867224693 else 62
                                    if state == 61:
                                        state = (
                                            75
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 16.644001)
                                            else 76
                                        )
                                        if state == 75:
                                            return 0.0950804502
                                        if state == 76:
                                            return -0.0749833211
                                    if state == 62:
                                        return -0.152717561
                                if state == 50:
                                    state = (
                                        63
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.918670654)
                                        else 64
                                    )
                                    if state == 63:
                                        state = (
                                            79
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.7654991)
                                            else 80
                                        )
                                        if state == 79:
                                            state = (
                                                95
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.268950462)
                                                else 96
                                            )
                                            if state == 95:
                                                state = (
                                                    111
                                                    if x["col_last"] < -0.204569817
                                                    else 112
                                                )
                                                if state == 111:
                                                    return -0.00671492098
                                                if state == 112:
                                                    state = (
                                                        125
                                                        if x["col_peak"] < -0.0664424896
                                                        else 126
                                                    )
                                                    if state == 125:
                                                        return 0.16844058
                                                    if state == 126:
                                                        return 0.0793458819
                                            if state == 96:
                                                return -0.0997426435
                                        if state == 80:
                                            state = (
                                                97
                                                if x["col_peak"] < -0.196563721
                                                else 98
                                            )
                                            if state == 97:
                                                return 0.123094909
                                            if state == 98:
                                                state = (
                                                    113
                                                    if x["col_last"] < -0.0865936279
                                                    else 114
                                                )
                                                if state == 113:
                                                    return 0.0735027641
                                                if state == 114:
                                                    state = (
                                                        127
                                                        if x["col_peak"] < -0.137862206
                                                        else 128
                                                    )
                                                    if state == 127:
                                                        return -0.162182748
                                                    if state == 128:
                                                        return -0.0179342479
                                    if state == 64:
                                        state = (
                                            81
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.6429996)
                                            else 82
                                        )
                                        if state == 81:
                                            return 0.0314537846
                                        if state == 82:
                                            return -0.137608618
                            if state == 34:
                                state = (
                                    51
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 16.5725002)
                                    else 52
                                )
                                if state == 51:
                                    return -0.0798337683
                                if state == 52:
                                    state = (
                                        67
                                        if np.isnan(x["col_last"])
                                        or (x["col_last"] < 0.138302803)
                                        else 68
                                    )
                                    if state == 67:
                                        state = (
                                            83
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.6650009)
                                            else 84
                                        )
                                        if state == 83:
                                            state = (
                                                101
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.293001175)
                                                else 102
                                            )
                                            if state == 101:
                                                state = (
                                                    117
                                                    if x["col_last"] < -0.14642635
                                                    else 118
                                                )
                                                if state == 117:
                                                    return 0.0484872349
                                                if state == 118:
                                                    state = (
                                                        129
                                                        if x["col_peak"] < -0.161782265
                                                        else 130
                                                    )
                                                    if state == 129:
                                                        return 0.101660863
                                                    if state == 130:
                                                        return -0.0447081514
                                            if state == 102:
                                                return 0.0896346644
                                        if state == 84:
                                            state = (
                                                103
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.16416502)
                                                else 104
                                            )
                                            if state == 103:
                                                return 0.135736227
                                            if state == 104:
                                                return -0.0668380857
                                    if state == 68:
                                        state = (
                                            85
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.6194992)
                                            else 86
                                        )
                                        if state == 85:
                                            state = (
                                                105
                                                if x["col_peak"] < 0.369381905
                                                else 106
                                            )
                                            if state == 105:
                                                return -0.142611369
                                            if state == 106:
                                                state = (
                                                    119
                                                    if x["col_last"] < 0.600543022
                                                    else 120
                                                )
                                                if state == 119:
                                                    state = (
                                                        131
                                                        if np.isnan(x["col_peak"])
                                                        or (x["col_peak"] < 0.420983315)
                                                        else 132
                                                    )
                                                    if state == 131:
                                                        state = (
                                                            143
                                                            if x["col_last"]
                                                            < 0.216013581
                                                            else 144
                                                        )
                                                        if state == 143:
                                                            return 0.105900191
                                                        if state == 144:
                                                            return -0.0394443236
                                                    if state == 132:
                                                        return -0.0159203839
                                                if state == 120:
                                                    return 0.10062059
                                        if state == 86:
                                            return 0.127741978
            if state == 2:
                state = (
                    5
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.91072893)
                    else 6
                )
                if state == 5:
                    return -0.0224412363
                if state == 6:
                    return -0.222825363
    elif num_booster == 44:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.042345) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 19.0849991)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 17.8480148)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 10.9247046)
                            else 14
                        )
                        if state == 13:
                            state = (
                                25
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.946071267)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    49
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 0.589378595)
                                    else 50
                                )
                                if state == 49:
                                    return 0.0449418053
                                if state == 50:
                                    state = (
                                        81
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 17.2248802)
                                        else 82
                                    )
                                    if state == 81:
                                        return -0.0557160228
                                    if state == 82:
                                        state = (
                                            119
                                            if x["sgscore1_med"] < 0.178169504
                                            else 120
                                        )
                                        if state == 119:
                                            state = (
                                                167
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.625476122)
                                                else 168
                                            )
                                            if state == 167:
                                                return -0.0114496313
                                            if state == 168:
                                                return 0.283526123
                                        if state == 120:
                                            return 0.0653029308
                            if state == 26:
                                return -0.0567291453
                        if state == 14:
                            state = (
                                27
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.813095152)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    51
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 4.33557034)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        83
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.0410786)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            121
                                            if x["sgscore1_med"] < 0.0754881054
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                171
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.687856913)
                                                else 172
                                            )
                                            if state == 171:
                                                state = (
                                                    227
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 16.0449181)
                                                    else 228
                                                )
                                                if state == 227:
                                                    return 0.0434129089
                                                if state == 228:
                                                    return -0.112103894
                                            if state == 172:
                                                state = (
                                                    229
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 11.7438374)
                                                    else 230
                                                )
                                                if state == 229:
                                                    return 0.171580911
                                                if state == 230:
                                                    state = (
                                                        289
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 14.9984779)
                                                        else 290
                                                    )
                                                    if state == 289:
                                                        return -0.135256544
                                                    if state == 290:
                                                        return 0.0456388406
                                        if state == 122:
                                            state = (
                                                173
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.751428783)
                                                else 174
                                            )
                                            if state == 173:
                                                state = (
                                                    231
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 38.2608986)
                                                    else 232
                                                )
                                                if state == 231:
                                                    state = (
                                                        291
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 18.9011345)
                                                        else 292
                                                    )
                                                    if state == 291:
                                                        return -0.164726257
                                                    if state == 292:
                                                        state = (
                                                            351
                                                            if x["sgscore1_med"]
                                                            < 0.156288505
                                                            else 352
                                                        )
                                                        if state == 351:
                                                            return 0.021677196
                                                        if state == 352:
                                                            return -0.148796603
                                                if state == 232:
                                                    return 0.115398116
                                            if state == 174:
                                                state = (
                                                    233
                                                    if x["neargaia_med"] < 0.64962709
                                                    else 234
                                                )
                                                if state == 233:
                                                    state = (
                                                        295
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 14.9037437)
                                                        else 296
                                                    )
                                                    if state == 295:
                                                        return 0.0714047849
                                                    if state == 296:
                                                        state = (
                                                            353
                                                            if x["sgscore1_med"]
                                                            < 0.199701995
                                                            else 354
                                                        )
                                                        if state == 353:
                                                            return -0.184737384
                                                        if state == 354:
                                                            return 0.0605724528
                                                if state == 234:
                                                    return -0.288836181
                                    if state == 84:
                                        return 0.1335489
                                if state == 52:
                                    return 0.153745979
                            if state == 28:
                                state = 53 if x["distpsnr1_med"] < 0.151279241 else 54
                                if state == 53:
                                    return -0.0608710311
                                if state == 54:
                                    state = (
                                        85
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.8340588)
                                        else 86
                                    )
                                    if state == 85:
                                        return 0.210794568
                                    if state == 86:
                                        state = (
                                            125
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0392291471)
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                175
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.950357199)
                                                else 176
                                            )
                                            if state == 175:
                                                return -0.123300247
                                            if state == 176:
                                                return 0.0810528249
                                        if state == 126:
                                            return 0.0896886215
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 19.9196529)
                            else 16
                        )
                        if state == 15:
                            return 0.080608651
                        if state == 16:
                            state = (
                                31
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.7961905)
                                else 32
                            )
                            if state == 31:
                                state = 57 if x["distpsnr1_med"] < 1.98010921 else 58
                                if state == 57:
                                    state = (
                                        89
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.9871178)
                                        else 90
                                    )
                                    if state == 89:
                                        return -0.246917158
                                    if state == 90:
                                        return 0.0242347103
                                if state == 58:
                                    return 0.0642482415
                            if state == 32:
                                return 0.0449272655
                if state == 4:
                    state = 9 if x["mag_peak"] < 18.592186 else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 15.8844099)
                            else 18
                        )
                        if state == 17:
                            return -0.152253151
                        if state == 18:
                            state = (
                                35
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.519166589)
                                else 36
                            )
                            if state == 35:
                                return 0.153891757
                            if state == 36:
                                state = 61 if x["distpsnr1_med"] < 11.4957047 else 62
                                if state == 61:
                                    state = (
                                        93
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.9763451)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            131
                                            if x["sgscore1_med"] < 0.342750013
                                            else 132
                                        )
                                        if state == 131:
                                            state = (
                                                177
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.776904941)
                                                else 178
                                            )
                                            if state == 177:
                                                return -0.100672178
                                            if state == 178:
                                                return 0.0539943576
                                        if state == 132:
                                            state = (
                                                179
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.587499976)
                                                else 180
                                            )
                                            if state == 179:
                                                return -0.0677377135
                                            if state == 180:
                                                state = (
                                                    239
                                                    if x["neargaia_med"] < 8.96864033
                                                    else 240
                                                )
                                                if state == 239:
                                                    return -0.0604906715
                                                if state == 240:
                                                    return 0.181824297
                                    if state == 94:
                                        return -0.16750823
                                if state == 62:
                                    return 0.136210978
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 17.9649124)
                            else 20
                        )
                        if state == 19:
                            state = (
                                37
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.545833349)
                                else 38
                            )
                            if state == 37:
                                return 0.186860546
                            if state == 38:
                                state = (
                                    63
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 4.28192759)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        95
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.0017929)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            133
                                            if x["sgscore1_med"] < 0.0017708349
                                            else 134
                                        )
                                        if state == 133:
                                            return -0.0342601538
                                        if state == 134:
                                            state = (
                                                181
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.948571503)
                                                else 182
                                            )
                                            if state == 181:
                                                state = (
                                                    241
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 41.9889526)
                                                    else 242
                                                )
                                                if state == 241:
                                                    return 0.209164485
                                                if state == 242:
                                                    return 0.0116229858
                                            if state == 182:
                                                return -0.0339523964
                                    if state == 96:
                                        state = (
                                            135
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.03125)
                                            else 136
                                        )
                                        if state == 135:
                                            return -0.11763826
                                        if state == 136:
                                            return 0.125990048
                                if state == 64:
                                    state = (
                                        97
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.2857285)
                                        else 98
                                    )
                                    if state == 97:
                                        return 0.178008392
                                    if state == 98:
                                        state = (
                                            137
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.00520833489)
                                            else 138
                                        )
                                        if state == 137:
                                            return 0.101300813
                                        if state == 138:
                                            state = (
                                                183
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.807857156)
                                                else 184
                                            )
                                            if state == 183:
                                                state = (
                                                    243
                                                    if x["neargaia_med"] < 59.2231712
                                                    else 244
                                                )
                                                if state == 243:
                                                    state = (
                                                        305
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 10.9596119)
                                                        else 306
                                                    )
                                                    if state == 305:
                                                        return 0.00671060057
                                                    if state == 306:
                                                        return -0.203801617
                                                if state == 244:
                                                    return 0.0168702472
                                            if state == 184:
                                                state = (
                                                    245
                                                    if x["neargaia_med"] < 13.9271736
                                                    else 246
                                                )
                                                if state == 245:
                                                    return -0.0685724914
                                                if state == 246:
                                                    return 0.136266559
                        if state == 20:
                            state = (
                                39
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.43749994)
                                else 40
                            )
                            if state == 39:
                                return -0.0559873432
                            if state == 40:
                                state = 65 if x["distpsnr1_med"] < 0.233294994 else 66
                                if state == 65:
                                    return -0.00135323044
                                if state == 66:
                                    return 0.26053533
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.2805004)
                    else 6
                )
                if state == 5:
                    return 0.078055419
                if state == 6:
                    state = 11 if x["mag_peak"] < 18.9933681 else 12
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 50.9063339)
                            else 22
                        )
                        if state == 21:
                            state = (
                                41
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.720714331)
                                else 42
                            )
                            if state == 41:
                                state = 67 if x["distpsnr1_med"] < 0.671045482 else 68
                                if state == 67:
                                    state = (
                                        101
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.1536522)
                                        else 102
                                    )
                                    if state == 101:
                                        return -0.0121385111
                                    if state == 102:
                                        state = (
                                            139
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.000812500017)
                                            else 140
                                        )
                                        if state == 139:
                                            return -0.00493363617
                                        if state == 140:
                                            state = (
                                                185
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.507976413)
                                                else 186
                                            )
                                            if state == 185:
                                                return -0.0238209665
                                            if state == 186:
                                                state = (
                                                    247
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 0.187046707)
                                                    else 248
                                                )
                                                if state == 247:
                                                    return -0.0364716873
                                                if state == 248:
                                                    return 0.19097507
                                if state == 68:
                                    state = (
                                        103
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.3391838)
                                        else 104
                                    )
                                    if state == 103:
                                        state = (
                                            141
                                            if x["sgscore1_med"] < 0.0622500032
                                            else 142
                                        )
                                        if state == 141:
                                            state = (
                                                187
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.680357158)
                                                else 188
                                            )
                                            if state == 187:
                                                state = (
                                                    249
                                                    if x["neargaia_med"] < 33.0807114
                                                    else 250
                                                )
                                                if state == 249:
                                                    return 0.045717366
                                                if state == 250:
                                                    return -0.151759356
                                            if state == 188:
                                                return -0.209767416
                                        if state == 142:
                                            state = (
                                                189
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.536904693)
                                                else 190
                                            )
                                            if state == 189:
                                                state = (
                                                    253
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 6.17912865)
                                                    else 254
                                                )
                                                if state == 253:
                                                    state = (
                                                        315
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 29.9689007)
                                                        else 316
                                                    )
                                                    if state == 315:
                                                        return -0.0736389905
                                                    if state == 316:
                                                        return 0.08894106
                                                if state == 254:
                                                    return 0.0853017345
                                            if state == 190:
                                                state = (
                                                    255
                                                    if x["neargaia_med"] < 28.5154305
                                                    else 256
                                                )
                                                if state == 255:
                                                    return -0.0153775373
                                                if state == 256:
                                                    return -0.150576249
                                    if state == 104:
                                        state = (
                                            143
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.120351501)
                                            else 144
                                        )
                                        if state == 143:
                                            state = (
                                                191
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.716666937)
                                                else 192
                                            )
                                            if state == 191:
                                                state = (
                                                    257
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 1.43907511)
                                                    else 258
                                                )
                                                if state == 257:
                                                    return -0.0735350996
                                                if state == 258:
                                                    state = (
                                                        325
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 49.9130669)
                                                        else 326
                                                    )
                                                    if state == 325:
                                                        state = (
                                                            367
                                                            if x["sgscore1_med"]
                                                            < 0.0177321509
                                                            else 368
                                                        )
                                                        if state == 367:
                                                            return -0.062432304
                                                        if state == 368:
                                                            return 0.149113506
                                                    if state == 326:
                                                        return -0.0536676906
                                            if state == 192:
                                                return -0.100518934
                                        if state == 144:
                                            state = (
                                                193
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.710000038)
                                                else 194
                                            )
                                            if state == 193:
                                                state = (
                                                    259
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 17.9192924)
                                                    else 260
                                                )
                                                if state == 259:
                                                    state = (
                                                        327
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 39.8754196)
                                                        else 328
                                                    )
                                                    if state == 327:
                                                        return -0.162853181
                                                    if state == 328:
                                                        state = (
                                                            371
                                                            if x["sgscore1_med"]
                                                            < 0.2103865
                                                            else 372
                                                        )
                                                        if state == 371:
                                                            return -0.131137744
                                                        if state == 372:
                                                            return 0.061598435
                                                if state == 260:
                                                    state = (
                                                        329
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 32.9624367)
                                                        else 330
                                                    )
                                                    if state == 329:
                                                        state = (
                                                            373
                                                            if x["sgscore1_med"]
                                                            < 0.226543009
                                                            else 374
                                                        )
                                                        if state == 373:
                                                            return -0.10478133
                                                        if state == 374:
                                                            return 0.127780452
                                                    if state == 330:
                                                        state = (
                                                            375
                                                            if x["sgscore1_med"]
                                                            < 0.273406327
                                                            else 376
                                                        )
                                                        if state == 375:
                                                            return -0.132237062
                                                        if state == 376:
                                                            return 0.026509732
                                            if state == 194:
                                                return -0.174848691
                            if state == 42:
                                state = (
                                    69
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 1.41555083)
                                    else 70
                                )
                                if state == 69:
                                    state = (
                                        105
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.2529678)
                                        else 106
                                    )
                                    if state == 105:
                                        state = (
                                            145
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.007125)
                                            else 146
                                        )
                                        if state == 145:
                                            return 0.119226627
                                        if state == 146:
                                            return -0.0555318743
                                    if state == 106:
                                        state = (
                                            147
                                            if x["sgscore1_med"] < 0.588041544
                                            else 148
                                        )
                                        if state == 147:
                                            state = (
                                                199
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.92785722)
                                                else 200
                                            )
                                            if state == 199:
                                                state = (
                                                    261
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 0.114306986)
                                                    else 262
                                                )
                                                if state == 261:
                                                    state = (
                                                        331
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 24.5075989)
                                                        else 332
                                                    )
                                                    if state == 331:
                                                        return 0.122556813
                                                    if state == 332:
                                                        return -0.110278562
                                                if state == 262:
                                                    return 0.198357493
                                            if state == 200:
                                                return 0.0493463092
                                        if state == 148:
                                            return -0.0184339434
                                if state == 70:
                                    state = (
                                        107
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.4249096)
                                        else 108
                                    )
                                    if state == 107:
                                        return 0.0484303236
                                    if state == 108:
                                        state = (
                                            151
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0315416493)
                                            else 152
                                        )
                                        if state == 151:
                                            state = (
                                                207
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.951428771)
                                                else 208
                                            )
                                            if state == 207:
                                                return -0.141032293
                                            if state == 208:
                                                return 0.0365456566
                                        if state == 152:
                                            state = (
                                                209
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.780000031)
                                                else 210
                                            )
                                            if state == 209:
                                                return 0.136855364
                                            if state == 210:
                                                state = (
                                                    273
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 19.7509613)
                                                    else 274
                                                )
                                                if state == 273:
                                                    return 0.0693832636
                                                if state == 274:
                                                    return -0.0840195343
                        if state == 22:
                            state = (
                                43
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.359880954)
                                else 44
                            )
                            if state == 43:
                                return -0.115692228
                            if state == 44:
                                state = 71 if x["distpsnr1_med"] < 0.350984573 else 72
                                if state == 71:
                                    return -0.100633837
                                if state == 72:
                                    return 0.157974333
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 9.05076981)
                            else 24
                        )
                        if state == 23:
                            state = (
                                45
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.637261808)
                                else 46
                            )
                            if state == 45:
                                state = 73 if x["distpsnr1_med"] < 11.8767948 else 74
                                if state == 73:
                                    state = (
                                        111
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.1806564)
                                        else 112
                                    )
                                    if state == 111:
                                        return 0.186748058
                                    if state == 112:
                                        state = (
                                            155
                                            if x["sgscore1_med"] < 0.00204166491
                                            else 156
                                        )
                                        if state == 155:
                                            return 0.073105365
                                        if state == 156:
                                            return -0.0813319013
                                if state == 74:
                                    return -0.117539383
                            if state == 46:
                                state = (
                                    75
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 6.5132494)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        113
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.5861492)
                                        else 114
                                    )
                                    if state == 113:
                                        state = (
                                            157
                                            if x["sgscore1_med"] < 0.0335208476
                                            else 158
                                        )
                                        if state == 157:
                                            state = (
                                                213
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.816428661)
                                                else 214
                                            )
                                            if state == 213:
                                                return 0.142624483
                                            if state == 214:
                                                return -0.0406729281
                                        if state == 158:
                                            return -0.167908728
                                    if state == 114:
                                        return -0.216300249
                                if state == 76:
                                    return 0.0304551572
                        if state == 24:
                            state = (
                                47
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.700000048)
                                else 48
                            )
                            if state == 47:
                                state = (
                                    77
                                    if np.isnan(x["distpsnr1_med"])
                                    or (x["distpsnr1_med"] < 3.66116571)
                                    else 78
                                )
                                if state == 77:
                                    state = (
                                        115
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.5525703)
                                        else 116
                                    )
                                    if state == 115:
                                        state = (
                                            159
                                            if x["sgscore1_med"] < 0.122875005
                                            else 160
                                        )
                                        if state == 159:
                                            state = (
                                                217
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.587738156)
                                                else 218
                                            )
                                            if state == 217:
                                                state = (
                                                    279
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 9.58067703)
                                                    else 280
                                                )
                                                if state == 279:
                                                    return 0.0129189454
                                                if state == 280:
                                                    state = (
                                                        345
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 12.0735931)
                                                        else 346
                                                    )
                                                    if state == 345:
                                                        return -0.025250474
                                                    if state == 346:
                                                        return 0.182271972
                                            if state == 218:
                                                state = (
                                                    281
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 41.0266838)
                                                    else 282
                                                )
                                                if state == 281:
                                                    return -0.183442771
                                                if state == 282:
                                                    return 0.121187948
                                        if state == 160:
                                            state = (
                                                219
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.625833333)
                                                else 220
                                            )
                                            if state == 219:
                                                return -0.184197858
                                            if state == 220:
                                                state = (
                                                    283
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 13.7240047)
                                                    else 284
                                                )
                                                if state == 283:
                                                    return 0.0913390368
                                                if state == 284:
                                                    return -0.161076233
                                    if state == 116:
                                        return -0.176074684
                                if state == 78:
                                    state = (
                                        117
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.1613522)
                                        else 118
                                    )
                                    if state == 117:
                                        state = (
                                            163
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0170833506)
                                            else 164
                                        )
                                        if state == 163:
                                            return 0.137802362
                                        if state == 164:
                                            return -0.0940981805
                                    if state == 118:
                                        return -0.290599495
                            if state == 48:
                                return -0.252348065
    elif num_booster == 45:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.6515484)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.981250048)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 18.7069359)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["col_det"]) or (x["col_det"] < 0.294762135)
                            else 14
                        )
                        if state == 13:
                            state = (
                                21
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 18.2555981)
                                else 22
                            )
                            if state == 21:
                                state = (
                                    37
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.727761388)
                                    else 38
                                )
                                if state == 37:
                                    state = 61 if x["col_det"] < -0.311834335 else 62
                                    if state == 61:
                                        return 0.124202378
                                    if state == 62:
                                        state = (
                                            95 if x["col_det"] < 0.00310230255 else 96
                                        )
                                        if state == 95:
                                            return -0.132370219
                                        if state == 96:
                                            state = (
                                                125
                                                if x["col_det"] < 0.134214878
                                                else 126
                                            )
                                            if state == 125:
                                                return 0.0688562915
                                            if state == 126:
                                                state = (
                                                    151
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 14.8546133)
                                                    else 152
                                                )
                                                if state == 151:
                                                    state = (
                                                        171
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.341097414
                                                        )
                                                        else 172
                                                    )
                                                    if state == 171:
                                                        state = (
                                                            181
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.1395493
                                                            )
                                                            else 182
                                                        )
                                                        if state == 181:
                                                            return -0.0742971748
                                                        if state == 182:
                                                            return 0.138312832
                                                    if state == 172:
                                                        return -0.113896325
                                                if state == 152:
                                                    state = (
                                                        173
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 0.52175045
                                                        )
                                                        else 174
                                                    )
                                                    if state == 173:
                                                        return -0.183186397
                                                    if state == 174:
                                                        state = (
                                                            187
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 19.1740379
                                                            )
                                                            else 188
                                                        )
                                                        if state == 187:
                                                            return -0.0655466765
                                                        if state == 188:
                                                            return 0.0516456701
                                if state == 38:
                                    state = (
                                        63
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.12334013)
                                        else 64
                                    )
                                    if state == 63:
                                        state = (
                                            97
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < 0.077735588)
                                            else 98
                                        )
                                        if state == 97:
                                            state = (
                                                127
                                                if x["col_det"] < -0.300703049
                                                else 128
                                            )
                                            if state == 127:
                                                state = (
                                                    153
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 17.9423866)
                                                    else 154
                                                )
                                                if state == 153:
                                                    return -0.233241618
                                                if state == 154:
                                                    return 0.108546965
                                            if state == 128:
                                                state = (
                                                    155
                                                    if x["maggaia_med"] < 14.9214439
                                                    else 156
                                                )
                                                if state == 155:
                                                    return -0.181990877
                                                if state == 156:
                                                    state = (
                                                        175
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 3.15620375
                                                        )
                                                        else 176
                                                    )
                                                    if state == 175:
                                                        state = (
                                                            189
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.5946007
                                                            )
                                                            else 190
                                                        )
                                                        if state == 189:
                                                            return 0.0622197613
                                                        if state == 190:
                                                            return 0.205301687
                                                    if state == 176:
                                                        state = (
                                                            191
                                                            if np.isnan(x["mag_det"])
                                                            or (x["mag_det"] < 19.9965)
                                                            else 192
                                                        )
                                                        if state == 191:
                                                            return 0.0899129659
                                                        if state == 192:
                                                            return -0.189131841
                                        if state == 98:
                                            return -0.20841296
                                    if state == 64:
                                        state = (
                                            99 if x["col_det"] < 0.235238075 else 100
                                        )
                                        if state == 99:
                                            return 0.19109644
                                        if state == 100:
                                            state = (
                                                131
                                                if x["col_det"] < 0.237286568
                                                else 132
                                            )
                                            if state == 131:
                                                return -0.123679332
                                            if state == 132:
                                                return 0.0877474248
                            if state == 22:
                                state = (
                                    39
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.308600724)
                                    else 40
                                )
                                if state == 39:
                                    return 0.110923275
                                if state == 40:
                                    state = (
                                        65
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.211561203)
                                        else 66
                                    )
                                    if state == 65:
                                        state = (
                                            101 if x["col_det"] < -0.190054417 else 102
                                        )
                                        if state == 101:
                                            state = (
                                                133
                                                if x["col_det"] < -0.194549084
                                                else 134
                                            )
                                            if state == 133:
                                                return -0.121639416
                                            if state == 134:
                                                return 0.103529692
                                        if state == 102:
                                            return -0.182641506
                                    if state == 66:
                                        return 0.0569525398
                        if state == 14:
                            state = (
                                23
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 18.4749031)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    41
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.07412362)
                                    else 42
                                )
                                if state == 41:
                                    return -0.055588536
                                if state == 42:
                                    return -0.240586683
                            if state == 24:
                                return 0.0605186187
                    if state == 8:
                        state = 15 if x["col_det"] < 0.286120892 else 16
                        if state == 15:
                            state = 25 if x["maggaia_med"] < 18.7680016 else 26
                            if state == 25:
                                return 0.219826713
                            if state == 26:
                                state = (
                                    43
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.10087562)
                                    else 44
                                )
                                if state == 43:
                                    state = 69 if x["col_det"] < -0.092455864 else 70
                                    if state == 69:
                                        state = (
                                            105 if x["col_det"] < -0.201274395 else 106
                                        )
                                        if state == 105:
                                            return -0.0500424877
                                        if state == 106:
                                            return 0.101604253
                                    if state == 70:
                                        state = (
                                            107 if x["col_det"] < -0.0121068954 else 108
                                        )
                                        if state == 107:
                                            return -0.176202849
                                        if state == 108:
                                            state = (
                                                139
                                                if x["col_det"] < 0.0206851959
                                                else 140
                                            )
                                            if state == 139:
                                                return 0.118059002
                                            if state == 140:
                                                return -0.115644768
                                if state == 44:
                                    state = 71 if x["col_det"] < -0.147325039 else 72
                                    if state == 71:
                                        state = (
                                            109 if x["col_det"] < -0.199238449 else 110
                                        )
                                        if state == 109:
                                            state = (
                                                141
                                                if x["col_det"] < -0.341450691
                                                else 142
                                            )
                                            if state == 141:
                                                return -0.0161791909
                                            if state == 142:
                                                state = (
                                                    163
                                                    if x["maggaia_med"] < 20.1797237
                                                    else 164
                                                )
                                                if state == 163:
                                                    return 0.180078194
                                                if state == 164:
                                                    return -0.0608069487
                                        if state == 110:
                                            return -0.187979221
                                    if state == 72:
                                        state = (
                                            111 if x["col_det"] < -0.0757932663 else 112
                                        )
                                        if state == 111:
                                            return 0.192140713
                                        if state == 112:
                                            state = (
                                                143
                                                if x["col_det"] < 0.186699867
                                                else 144
                                            )
                                            if state == 143:
                                                state = (
                                                    165
                                                    if x["maggaia_med"] < 19.9358177
                                                    else 166
                                                )
                                                if state == 165:
                                                    state = (
                                                        177
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 4.69606113
                                                        )
                                                        else 178
                                                    )
                                                    if state == 177:
                                                        return -0.191155329
                                                    if state == 178:
                                                        state = (
                                                            193
                                                            if np.isnan(x["mag_det"])
                                                            or (
                                                                x["mag_det"]
                                                                < 20.2490005
                                                            )
                                                            else 194
                                                        )
                                                        if state == 193:
                                                            return -0.11692331
                                                        if state == 194:
                                                            return 0.0798850283
                                                if state == 166:
                                                    return 0.120832942
                                            if state == 144:
                                                return 0.152713791
                        if state == 16:
                            state = 27 if x["maggaia_med"] < 19.7461147 else 28
                            if state == 27:
                                state = (
                                    45
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.48165751)
                                    else 46
                                )
                                if state == 45:
                                    return 0.0880318359
                                if state == 46:
                                    return -0.0660836101
                            if state == 28:
                                state = (
                                    47
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.36316657)
                                    else 48
                                )
                                if state == 47:
                                    return -0.129077986
                                if state == 48:
                                    state = 75 if x["col_det"] < 0.462750435 else 76
                                    if state == 75:
                                        return -0.123189919
                                    if state == 76:
                                        return 0.00843961164
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.3988266)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["col_det"] < 0.173688889 else 18
                        if state == 17:
                            state = (
                                29
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 17.5174026)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    49
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.702530146)
                                    else 50
                                )
                                if state == 49:
                                    state = 77 if x["col_det"] < 0.0312004089 else 78
                                    if state == 77:
                                        state = (
                                            115 if x["col_det"] < -0.223949432 else 116
                                        )
                                        if state == 115:
                                            return 0.0930838361
                                        if state == 116:
                                            return -0.155278713
                                    if state == 78:
                                        return 0.10881938
                                if state == 50:
                                    state = 79 if x["col_det"] < -0.0286417007 else 80
                                    if state == 79:
                                        return 0.176165387
                                    if state == 80:
                                        return -0.0265592784
                            if state == 30:
                                state = (
                                    51
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.12580681)
                                    else 52
                                )
                                if state == 51:
                                    state = 81 if x["col_det"] < -0.050303936 else 82
                                    if state == 81:
                                        return -0.167920977
                                    if state == 82:
                                        state = (
                                            119 if x["col_det"] < 0.125375748 else 120
                                        )
                                        if state == 119:
                                            return 0.085998036
                                        if state == 120:
                                            return -0.128282994
                                if state == 52:
                                    state = 83 if x["col_det"] < -0.201316357 else 84
                                    if state == 83:
                                        return 0.140771925
                                    if state == 84:
                                        state = (
                                            121 if x["col_det"] < -0.163951874 else 122
                                        )
                                        if state == 121:
                                            return -0.143656686
                                        if state == 122:
                                            state = (
                                                147
                                                if x["col_det"] < -0.0725550652
                                                else 148
                                            )
                                            if state == 147:
                                                return 0.115679286
                                            if state == 148:
                                                state = (
                                                    169
                                                    if x["maggaia_med"] < 18.4533234
                                                    else 170
                                                )
                                                if state == 169:
                                                    return -0.115889423
                                                if state == 170:
                                                    return 0.101769507
                        if state == 18:
                            state = (
                                31
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 17.2125778)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    53
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.355992019)
                                    else 54
                                )
                                if state == 53:
                                    return -0.12336164
                                if state == 54:
                                    return 0.0448583923
                            if state == 32:
                                state = (
                                    55
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.962032676)
                                    else 56
                                )
                                if state == 55:
                                    return 0.0457113869
                                if state == 56:
                                    return 0.178825468
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["col_det"]) or (x["col_det"] < -0.0195178986)
                            else 20
                        )
                        if state == 19:
                            state = 33 if x["maggaia_med"] < 19.7014084 else 34
                            if state == 33:
                                state = (
                                    57
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.74744153)
                                    else 58
                                )
                                if state == 57:
                                    return -0.0443929918
                                if state == 58:
                                    state = 89 if x["col_det"] < -0.127769947 else 90
                                    if state == 89:
                                        return 0.0945663154
                                    if state == 90:
                                        return -0.22740382
                            if state == 34:
                                state = (
                                    59
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 3.12731886)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        91
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.129219055)
                                        else 92
                                    )
                                    if state == 91:
                                        return 0.117871203
                                    if state == 92:
                                        return -0.0908626541
                                if state == 60:
                                    return -0.0817046091
                        if state == 20:
                            return 0.206667781
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.982249975)
                    else 6
                )
                if state == 5:
                    state = 11 if x["maggaia_med"] < 21.0364685 else 12
                    if state == 11:
                        return -0.206237108
                    if state == 12:
                        return 0.0747863501
                if state == 6:
                    return -0.00508274511
    elif num_booster == 46:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0250549) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 17.188097) else 4
                )
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 25.5390739) else 8
                    if state == 7:
                        state = 15 if x["distpsnr1_med"] < 0.663879395 else 16
                        if state == 15:
                            return -0.133534938
                        if state == 16:
                            state = 31 if x["col_last"] < 0.0469403267 else 32
                            if state == 31:
                                return 0.0622617379
                            if state == 32:
                                state = (
                                    51
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 8.00714684)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        79
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.627857208)
                                        else 80
                                    )
                                    if state == 79:
                                        return 0.099087961
                                    if state == 80:
                                        return -0.0463661216
                                if state == 52:
                                    return 0.11112079
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 0.564254761)
                            else 18
                        )
                        if state == 17:
                            return -0.0493166596
                        if state == 18:
                            return 0.17011334
                if state == 4:
                    state = 9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 23.0580616) else 10
                    if state == 9:
                        return -0.160858259
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 3.07928586)
                            else 22
                        )
                        if state == 21:
                            state = (
                                33
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.36754638)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    53
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 9.06599522)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        81
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.762499988)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            117
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 18.1623135)
                                            else 118
                                        )
                                        if state == 117:
                                            return 0.0501849428
                                        if state == 118:
                                            state = (
                                                153
                                                if x["mag_peak"] < 18.7616272
                                                else 154
                                            )
                                            if state == 153:
                                                state = (
                                                    175
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.6752567)
                                                    else 176
                                                )
                                                if state == 175:
                                                    return -0.112624802
                                                if state == 176:
                                                    return 0.0986848697
                                            if state == 154:
                                                return 0.0178864319
                                    if state == 82:
                                        return 0.0297495425
                                if state == 54:
                                    return -0.155574605
                            if state == 34:
                                return -0.0082544703
                        if state == 22:
                            state = 35 if x["col_last"] < 0.714103699 else 36
                            if state == 35:
                                return -0.0506488904
                            if state == 36:
                                state = (
                                    57
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 4.96550369)
                                    else 58
                                )
                                if state == 57:
                                    return 0.133210123
                                if state == 58:
                                    state = (
                                        85
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.830714285)
                                        else 86
                                    )
                                    if state == 85:
                                        return 0.11384096
                                    if state == 86:
                                        return -0.126693889
            if state == 2:
                state = 5 if x["mag_peak"] < 18.3341484 else 6
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 24.0245953) else 12
                    )
                    if state == 11:
                        state = 23 if x["distpsnr1_med"] < 0.241050869 else 24
                        if state == 23:
                            return -0.141975865
                        if state == 24:
                            state = 37 if x["col_last"] < 0.710278511 else 38
                            if state == 37:
                                return 0.0748695806
                            if state == 38:
                                state = (
                                    59
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 5.98138905)
                                    else 60
                                )
                                if state == 59:
                                    return -0.0614668764
                                if state == 60:
                                    return 0.0937400907
                    if state == 12:
                        state = 25 if x["distpsnr1_med"] < 0.282780468 else 26
                        if state == 25:
                            return -0.0233299397
                        if state == 26:
                            state = (
                                41
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.909618378)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    63
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.85043979)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        91
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.586190403)
                                        else 92
                                    )
                                    if state == 91:
                                        return -0.00953385327
                                    if state == 92:
                                        state = (
                                            125
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.53265)
                                            else 126
                                        )
                                        if state == 125:
                                            return -0.0982798934
                                        if state == 126:
                                            return 0.183178693
                                if state == 64:
                                    return 0.202155098
                            if state == 42:
                                return 0.0431946181
                if state == 6:
                    state = (
                        13 if np.isnan(x["t_lc"]) or (x["t_lc"] < 33.9640617) else 14
                    )
                    if state == 13:
                        state = 27 if x["distpsnr1_med"] < 4.54923773 else 28
                        if state == 27:
                            state = (
                                43
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.580882549)
                                else 44
                            )
                            if state == 43:
                                state = (
                                    67
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 7.95272589)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        93
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.914285779)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            127
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.2000504)
                                            else 128
                                        )
                                        if state == 127:
                                            return 0.115336962
                                        if state == 128:
                                            state = (
                                                157
                                                if x["mag_peak"] < 18.7789078
                                                else 158
                                            )
                                            if state == 157:
                                                state = (
                                                    179
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.0310764)
                                                    else 180
                                                )
                                                if state == 179:
                                                    state = (
                                                        207
                                                        if x["mag_peak"] < 18.638504
                                                        else 208
                                                    )
                                                    if state == 207:
                                                        return -0.0527901053
                                                    if state == 208:
                                                        return 0.0892744064
                                                if state == 180:
                                                    state = (
                                                        209
                                                        if x["mag_peak"] < 18.638504
                                                        else 210
                                                    )
                                                    if state == 209:
                                                        return -0.00116296252
                                                    if state == 210:
                                                        return 0.204761207
                                            if state == 158:
                                                state = (
                                                    181
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.1206665)
                                                    else 182
                                                )
                                                if state == 181:
                                                    state = (
                                                        211
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.8361969)
                                                        else 212
                                                    )
                                                    if state == 211:
                                                        state = (
                                                            233
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.401001
                                                            )
                                                            else 234
                                                        )
                                                        if state == 233:
                                                            return -0.00711545767
                                                        if state == 234:
                                                            return 0.0802476779
                                                    if state == 212:
                                                        return -0.0195611417
                                                if state == 182:
                                                    state = (
                                                        213
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.8823204)
                                                        else 214
                                                    )
                                                    if state == 213:
                                                        state = (
                                                            235
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.9414997
                                                            )
                                                            else 236
                                                        )
                                                        if state == 235:
                                                            return -0.183085829
                                                        if state == 236:
                                                            return 0.043020945
                                                    if state == 214:
                                                        state = (
                                                            237
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.5354996
                                                            )
                                                            else 238
                                                        )
                                                        if state == 237:
                                                            return 0.0512387902
                                                        if state == 238:
                                                            return -0.128986239
                                    if state == 94:
                                        state = (
                                            129
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.1608505)
                                            else 130
                                        )
                                        if state == 129:
                                            state = (
                                                159
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.896637)
                                                else 160
                                            )
                                            if state == 159:
                                                state = (
                                                    183
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.3974648)
                                                    else 184
                                                )
                                                if state == 183:
                                                    return 0.158266589
                                                if state == 184:
                                                    return -0.0220858064
                                            if state == 160:
                                                return -0.0358311012
                                        if state == 130:
                                            state = (
                                                161
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.5630875)
                                                else 162
                                            )
                                            if state == 161:
                                                return 0.0304319821
                                            if state == 162:
                                                return -0.120435327
                                if state == 68:
                                    state = (
                                        95
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.868452191)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            131
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4318733)
                                            else 132
                                        )
                                        if state == 131:
                                            state = (
                                                163
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.8440399)
                                                else 164
                                            )
                                            if state == 163:
                                                state = (
                                                    191
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.491991)
                                                    else 192
                                                )
                                                if state == 191:
                                                    return 0.0462182388
                                                if state == 192:
                                                    state = (
                                                        217
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.6789589)
                                                        else 218
                                                    )
                                                    if state == 217:
                                                        state = (
                                                            239
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.043499
                                                            )
                                                            else 240
                                                        )
                                                        if state == 239:
                                                            return -0.268979609
                                                        if state == 240:
                                                            return 0.0292109698
                                                    if state == 218:
                                                        state = (
                                                            241
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 18.1765003
                                                            )
                                                            else 242
                                                        )
                                                        if state == 241:
                                                            return 0.0826179609
                                                        if state == 242:
                                                            return -0.119567417
                                            if state == 164:
                                                return 0.0228385944
                                        if state == 132:
                                            return 0.101103894
                                    if state == 96:
                                        return 0.00443454646
                            if state == 44:
                                state = (
                                    69
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.09635973)
                                    else 70
                                )
                                if state == 69:
                                    return 0.135068774
                                if state == 70:
                                    return -0.025661733
                        if state == 28:
                            state = (
                                45
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.386878967)
                                else 46
                            )
                            if state == 45:
                                state = (
                                    71
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 4.0040102)
                                    else 72
                                )
                                if state == 71:
                                    state = (
                                        101
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.381547749)
                                        else 102
                                    )
                                    if state == 101:
                                        return -0.0791173428
                                    if state == 102:
                                        state = (
                                            139
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 21.1266499)
                                            else 140
                                        )
                                        if state == 139:
                                            return 0.16417256
                                        if state == 140:
                                            return -0.104627468
                                if state == 72:
                                    state = (
                                        103
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.88214308)
                                        else 104
                                    )
                                    if state == 103:
                                        state = (
                                            141
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.4262009)
                                            else 142
                                        )
                                        if state == 141:
                                            state = (
                                                165
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.7675896)
                                                else 166
                                            )
                                            if state == 165:
                                                state = (
                                                    195
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.1333656)
                                                    else 196
                                                )
                                                if state == 195:
                                                    return 0.0026836365
                                                if state == 196:
                                                    return -0.197708458
                                            if state == 166:
                                                return 0.120609857
                                        if state == 142:
                                            return -0.162818551
                                    if state == 104:
                                        return 0.136036649
                            if state == 46:
                                state = (
                                    73
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.97050929)
                                    else 74
                                )
                                if state == 73:
                                    return 0.0837157369
                                if state == 74:
                                    return -0.0869632959
                    if state == 14:
                        state = 29 if x["distpsnr1_med"] < 2.04390907 else 30
                        if state == 29:
                            state = 47 if x["col_last"] < 0.835433006 else 48
                            if state == 47:
                                return -0.162551641
                            if state == 48:
                                state = (
                                    75
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 7.00134277)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        107
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.753333449)
                                        else 108
                                    )
                                    if state == 107:
                                        state = (
                                            145
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.6931)
                                            else 146
                                        )
                                        if state == 145:
                                            return -0.239343256
                                        if state == 146:
                                            state = (
                                                167
                                                if x["mag_peak"] < 18.8463936
                                                else 168
                                            )
                                            if state == 167:
                                                return 0.0391964726
                                            if state == 168:
                                                return -0.110057965
                                    if state == 108:
                                        state = (
                                            147
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.2749729)
                                            else 148
                                        )
                                        if state == 147:
                                            return -0.0455852635
                                        if state == 148:
                                            state = (
                                                169
                                                if x["mag_peak"] < 18.9998856
                                                else 170
                                            )
                                            if state == 169:
                                                state = (
                                                    201
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.402977)
                                                    else 202
                                                )
                                                if state == 201:
                                                    return -0.0486980043
                                                if state == 202:
                                                    return 0.120053284
                                            if state == 170:
                                                return -0.0543066524
                                if state == 76:
                                    state = (
                                        109
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.719166517)
                                        else 110
                                    )
                                    if state == 109:
                                        return 0.0855970979
                                    if state == 110:
                                        return -0.073705487
                        if state == 30:
                            state = (
                                49
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.940133095)
                                else 50
                            )
                            if state == 49:
                                state = (
                                    77
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.0935243517)
                                    else 78
                                )
                                if state == 77:
                                    return -0.113290079
                                if state == 78:
                                    state = (
                                        111
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.464642912)
                                        else 112
                                    )
                                    if state == 111:
                                        return -0.101704247
                                    if state == 112:
                                        state = (
                                            151
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.4099464)
                                            else 152
                                        )
                                        if state == 151:
                                            return 0.143057361
                                        if state == 152:
                                            state = (
                                                173
                                                if x["mag_peak"] < 18.9069786
                                                else 174
                                            )
                                            if state == 173:
                                                return 0.0984778702
                                            if state == 174:
                                                state = (
                                                    205
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.1705189)
                                                    else 206
                                                )
                                                if state == 205:
                                                    return 0.112726092
                                                if state == 206:
                                                    state = (
                                                        227
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.954813)
                                                        else 228
                                                    )
                                                    if state == 227:
                                                        return -0.171263665
                                                    if state == 228:
                                                        return 0.0246180836
                            if state == 50:
                                return -0.0697442144
    elif num_booster == 47:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.966500044)
                else 2
            )
            if state == 1:
                state = 3 if x["col_last"] < -0.0816631317 else 4
                if state == 3:
                    return -0.145657554
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.8361511)
                        else 10
                    )
                    if state == 9:
                        return 0.116362736
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 20.0413513)
                            else 16
                        )
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.6057835)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    43
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.700357139)
                                    else 44
                                )
                                if state == 43:
                                    state = (
                                        73
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < 0.070189476)
                                        else 74
                                    )
                                    if state == 73:
                                        state = (
                                            105
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.4329491)
                                            else 106
                                        )
                                        if state == 105:
                                            state = (
                                                131
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.345724583)
                                                else 132
                                            )
                                            if state == 131:
                                                return 0.00426224573
                                            if state == 132:
                                                return -0.136203229
                                        if state == 106:
                                            return 0.105268657
                                    if state == 74:
                                        return -0.0771677122
                                if state == 44:
                                    return -0.167788774
                            if state == 26:
                                state = (
                                    45
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.564642906)
                                    else 46
                                )
                                if state == 45:
                                    return -0.174974471
                                if state == 46:
                                    state = 77 if x["col_peak"] < 0.00593852997 else 78
                                    if state == 77:
                                        return 0.0307806693
                                    if state == 78:
                                        state = (
                                            109
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.9050007)
                                            else 110
                                        )
                                        if state == 109:
                                            return -0.167060271
                                        if state == 110:
                                            state = (
                                                133
                                                if x["col_last"] < 1.01987743
                                                else 134
                                            )
                                            if state == 133:
                                                return -0.116502851
                                            if state == 134:
                                                state = (
                                                    157
                                                    if x["mag_peak"] < 18.8934402
                                                    else 158
                                                )
                                                if state == 157:
                                                    return 0.124805219
                                                if state == 158:
                                                    state = (
                                                        179
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 3.65327835
                                                        )
                                                        else 180
                                                    )
                                                    if state == 179:
                                                        return -0.185464531
                                                    if state == 180:
                                                        return 0.0647925064
                        if state == 16:
                            return 0.0837476477
            if state == 2:
                state = (
                    5 if np.isnan(x["col_last"]) or (x["col_last"] < 0.300816536) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0985889)
                        else 12
                    )
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 17.8537903)
                            else 18
                        )
                        if state == 17:
                            state = (
                                27
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.0415573)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    47
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.758452475)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        79
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < 0.110124588)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            111
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.3276176)
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                135
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.200652122)
                                                else 136
                                            )
                                            if state == 135:
                                                state = (
                                                    159
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 17.7020035)
                                                    else 160
                                                )
                                                if state == 159:
                                                    state = (
                                                        181
                                                        if x["distpsnr1_med"]
                                                        < 2.69660449
                                                        else 182
                                                    )
                                                    if state == 181:
                                                        state = (
                                                            201
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 13.7958298
                                                            )
                                                            else 202
                                                        )
                                                        if state == 201:
                                                            return -0.0548523329
                                                        if state == 202:
                                                            return 0.0933503285
                                                    if state == 182:
                                                        return 0.228509083
                                                if state == 160:
                                                    return -0.0291390717
                                            if state == 136:
                                                return 0.00474028336
                                        if state == 112:
                                            state = (
                                                137
                                                if x["col_last"] < -0.012488842
                                                else 138
                                            )
                                            if state == 137:
                                                return -0.0261665955
                                            if state == 138:
                                                state = (
                                                    161
                                                    if x["mag_peak"] < 16.6219139
                                                    else 162
                                                )
                                                if state == 161:
                                                    return -0.0608011149
                                                if state == 162:
                                                    state = (
                                                        183
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 5.25151491
                                                        )
                                                        else 184
                                                    )
                                                    if state == 183:
                                                        state = (
                                                            203
                                                            if x["neargaia_med"]
                                                            < 13.9240465
                                                            else 204
                                                        )
                                                        if state == 203:
                                                            return -0.0962985903
                                                        if state == 204:
                                                            return 0.0590780154
                                                    if state == 184:
                                                        return 0.119620465
                                    if state == 80:
                                        state = (
                                            113
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.3319588)
                                            else 114
                                        )
                                        if state == 113:
                                            return -0.281857818
                                        if state == 114:
                                            return 0.0437742844
                                if state == 48:
                                    state = (
                                        81
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.194044024)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            115
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.8879433)
                                            else 116
                                        )
                                        if state == 115:
                                            state = (
                                                139
                                                if x["col_last"] < -0.245074749
                                                else 140
                                            )
                                            if state == 139:
                                                return -0.0893328711
                                            if state == 140:
                                                state = (
                                                    163
                                                    if x["mag_peak"] < 16.8842545
                                                    else 164
                                                )
                                                if state == 163:
                                                    return -0.10943269
                                                if state == 164:
                                                    state = (
                                                        185
                                                        if x["distpsnr1_med"]
                                                        < 0.113676399
                                                        else 186
                                                    )
                                                    if state == 185:
                                                        return -0.114569776
                                                    if state == 186:
                                                        state = (
                                                            207
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 62.1356049
                                                            )
                                                            else 208
                                                        )
                                                        if state == 207:
                                                            return 0.124690086
                                                        if state == 208:
                                                            return -0.042067375
                                        if state == 116:
                                            state = (
                                                141
                                                if x["col_last"] < -0.126667976
                                                else 142
                                            )
                                            if state == 141:
                                                return -0.113256335
                                            if state == 142:
                                                return 0.0530364215
                                    if state == 82:
                                        return 0.240015566
                            if state == 28:
                                state = (
                                    49
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.685000002)
                                    else 50
                                )
                                if state == 49:
                                    return -0.00788997766
                                if state == 50:
                                    state = (
                                        83
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.0822582245)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            117
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.0578156)
                                            else 118
                                        )
                                        if state == 117:
                                            return -0.0669125468
                                        if state == 118:
                                            return 0.114083476
                                    if state == 84:
                                        return 0.220413432
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.3700142)
                                else 30
                            )
                            if state == 29:
                                return -0.0879359692
                            if state == 30:
                                state = (
                                    53
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.447023809)
                                    else 54
                                )
                                if state == 53:
                                    return -0.0937087685
                                if state == 54:
                                    state = (
                                        89
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.195209026)
                                        else 90
                                    )
                                    if state == 89:
                                        return 0.075314641
                                    if state == 90:
                                        state = (
                                            119
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.090477)
                                            else 120
                                        )
                                        if state == 119:
                                            state = (
                                                145
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.138400078)
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    165
                                                    if x["mag_peak"] < 18.5902863
                                                    else 166
                                                )
                                                if state == 165:
                                                    state = (
                                                        187
                                                        if x["distpsnr1_med"]
                                                        < 0.259880602
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        return -0.133510917
                                                    if state == 188:
                                                        state = (
                                                            209
                                                            if np.isnan(
                                                                x["neargaia_med"]
                                                            )
                                                            or (
                                                                x["neargaia_med"]
                                                                < 5.81007624
                                                            )
                                                            else 210
                                                        )
                                                        if state == 209:
                                                            return 0.126531839
                                                        if state == 210:
                                                            return -0.0691576302
                                                if state == 166:
                                                    return 0.0361922458
                                            if state == 146:
                                                return 0.036018692
                                        if state == 120:
                                            return -0.0880588591
                    if state == 12:
                        state = 19 if x["mag_peak"] < 19.0330086 else 20
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.1073341)
                                else 32
                            )
                            if state == 31:
                                return -0.204722539
                            if state == 32:
                                state = (
                                    55
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.941071391)
                                    else 56
                                )
                                if state == 55:
                                    state = (
                                        91
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < 0.330463886)
                                        else 92
                                    )
                                    if state == 91:
                                        state = (
                                            121
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.1411209)
                                            else 122
                                        )
                                        if state == 121:
                                            return 0.107364029
                                        if state == 122:
                                            state = (
                                                149
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.167316437)
                                                else 150
                                            )
                                            if state == 149:
                                                state = (
                                                    167
                                                    if x["mag_peak"] < 18.7742252
                                                    else 168
                                                )
                                                if state == 167:
                                                    state = (
                                                        191
                                                        if x["distpsnr1_med"]
                                                        < 0.708943665
                                                        else 192
                                                    )
                                                    if state == 191:
                                                        state = (
                                                            213
                                                            if x["neargaia_med"]
                                                            < 13.3966274
                                                            else 214
                                                        )
                                                        if state == 213:
                                                            return -0.0288987961
                                                        if state == 214:
                                                            return 0.115943141
                                                    if state == 192:
                                                        state = (
                                                            215
                                                            if x["neargaia_med"]
                                                            < 42.0150185
                                                            else 216
                                                        )
                                                        if state == 215:
                                                            return 0.00230681687
                                                        if state == 216:
                                                            return -0.146390602
                                                if state == 168:
                                                    state = (
                                                        193
                                                        if x["distpsnr1_med"]
                                                        < 0.393039227
                                                        else 194
                                                    )
                                                    if state == 193:
                                                        return -0.104434125
                                                    if state == 194:
                                                        return 0.0538062677
                                            if state == 150:
                                                return -0.0443028435
                                    if state == 92:
                                        state = (
                                            123
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.2723083)
                                            else 124
                                        )
                                        if state == 123:
                                            return -0.0418529101
                                        if state == 124:
                                            return 0.161657169
                                if state == 56:
                                    state = (
                                        93
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < 0.126894951)
                                        else 94
                                    )
                                    if state == 93:
                                        return -0.134505436
                                    if state == 94:
                                        return 0.076199621
                        if state == 20:
                            state = (
                                33
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.1601257)
                                else 34
                            )
                            if state == 33:
                                return -0.0169481449
                            if state == 34:
                                return -0.241908267
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.2342033)
                        else 14
                    )
                    if state == 13:
                        state = 21 if x["mag_peak"] < 18.3046837 else 22
                        if state == 21:
                            return 0.027070526
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.7100487)
                                else 38
                            )
                            if state == 37:
                                return 0.0644783676
                            if state == 38:
                                state = (
                                    63
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.922857046)
                                    else 64
                                )
                                if state == 63:
                                    return -0.129305378
                                if state == 64:
                                    return 0.0667912662
                    if state == 14:
                        state = (
                            23
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.872139)
                            else 24
                        )
                        if state == 23:
                            state = (
                                39
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 20.3109646)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    65
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.917857051)
                                    else 66
                                )
                                if state == 65:
                                    state = (
                                        97
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.0665621758)
                                        else 98
                                    )
                                    if state == 97:
                                        return 0.153198943
                                    if state == 98:
                                        return 0.0263566487
                                if state == 66:
                                    return 0.018690154
                            if state == 40:
                                return -0.00461299112
                        if state == 24:
                            return -0.0419926569
    elif num_booster == 48:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.295628816) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["col_last"]) or (x["col_last"] < -0.0825862885)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.281188965)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["col_last"] < -0.222251892 else 16
                        if state == 15:
                            return -0.0117208296
                        if state == 16:
                            state = 25 if x["mag_peak"] < 18.0338192 else 26
                            if state == 25:
                                return 0.0189009123
                            if state == 26:
                                state = (
                                    43
                                    if np.isnan(x["neargaia_med"])
                                    or (x["neargaia_med"] < 12.3384552)
                                    else 44
                                )
                                if state == 43:
                                    return -0.153659835
                                if state == 44:
                                    return -0.00691187289
                    if state == 8:
                        return -0.017420385
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.157966137)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["col_last"] < 0.151088715 else 18
                        if state == 17:
                            return 0.0579402782
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 18.1143627)
                                else 30
                            )
                            if state == 29:
                                return -0.0745967925
                            if state == 30:
                                return 0.0737697557
                    if state == 10:
                        return -0.0772963315
            if state == 2:
                state = 5 if x["col_last"] < -0.104930401 else 6
                if state == 5:
                    return 0.044717893
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.599546432)
                        else 14
                    )
                    if state == 13:
                        state = 21 if x["col_last"] < -0.074555397 else 22
                        if state == 21:
                            return -0.057351172
                        if state == 22:
                            state = 37 if x["mag_peak"] < 18.5428104 else 38
                            if state == 37:
                                state = 57 if x["neargaia_med"] < 18.6943779 else 58
                                if state == 57:
                                    state = (
                                        65
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.120340824)
                                        else 66
                                    )
                                    if state == 65:
                                        state = (
                                            73 if x["neargaia_med"] < 5.04460049 else 74
                                        )
                                        if state == 73:
                                            return 0.0879028291
                                        if state == 74:
                                            state = (
                                                87
                                                if x["col_peak"] < -0.200276285
                                                else 88
                                            )
                                            if state == 87:
                                                state = (
                                                    103
                                                    if x["mag_peak"] < 17.9338284
                                                    else 104
                                                )
                                                if state == 103:
                                                    return -0.107706554
                                                if state == 104:
                                                    return 0.120960355
                                            if state == 88:
                                                state = (
                                                    105
                                                    if x["mag_peak"] < 17.7473316
                                                    else 106
                                                )
                                                if state == 105:
                                                    return 0.0283806864
                                                if state == 106:
                                                    return -0.132479206
                                    if state == 66:
                                        state = (
                                            75 if x["neargaia_med"] < 7.76898861 else 76
                                        )
                                        if state == 75:
                                            state = (
                                                89
                                                if x["col_peak"] < 0.178718567
                                                else 90
                                            )
                                            if state == 89:
                                                state = (
                                                    107
                                                    if x["mag_peak"] < 17.0162849
                                                    else 108
                                                )
                                                if state == 107:
                                                    return -0.00610180898
                                                if state == 108:
                                                    return 0.288646072
                                            if state == 90:
                                                return 0.0019554419
                                        if state == 76:
                                            state = (
                                                91
                                                if x["col_peak"] < 0.368918419
                                                else 92
                                            )
                                            if state == 91:
                                                state = (
                                                    111
                                                    if x["mag_peak"] < 18.1291008
                                                    else 112
                                                )
                                                if state == 111:
                                                    state = (
                                                        133
                                                        if x["sgscore1_med"]
                                                        < 0.184482008
                                                        else 134
                                                    )
                                                    if state == 133:
                                                        return -0.0785311833
                                                    if state == 134:
                                                        return 0.107370123
                                                if state == 112:
                                                    return -0.188042611
                                            if state == 92:
                                                return 0.052787248
                                if state == 58:
                                    state = (
                                        67
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < 0.458701134)
                                        else 68
                                    )
                                    if state == 67:
                                        state = (
                                            77
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 21.83708)
                                            else 78
                                        )
                                        if state == 77:
                                            return 0.197441682
                                        if state == 78:
                                            state = (
                                                93
                                                if x["col_peak"] < -0.210697651
                                                else 94
                                            )
                                            if state == 93:
                                                state = (
                                                    113
                                                    if x["mag_peak"] < 17.3786259
                                                    else 114
                                                )
                                                if state == 113:
                                                    return -0.133607462
                                                if state == 114:
                                                    return 0.0642091557
                                            if state == 94:
                                                state = (
                                                    115
                                                    if x["mag_peak"] < 18.0875778
                                                    else 116
                                                )
                                                if state == 115:
                                                    state = (
                                                        137
                                                        if x["sgscore1_med"]
                                                        < 0.0985832959
                                                        else 138
                                                    )
                                                    if state == 137:
                                                        return -0.0603798814
                                                    if state == 138:
                                                        state = (
                                                            159
                                                            if x["col_peak"]
                                                            < 0.854340613
                                                            else 160
                                                        )
                                                        if state == 159:
                                                            return 0.173542276
                                                        if state == 160:
                                                            return -0.0287830606
                                                if state == 116:
                                                    state = (
                                                        139
                                                        if x["sgscore1_med"]
                                                        < 0.0017708349
                                                        else 140
                                                    )
                                                    if state == 139:
                                                        return -0.0349765532
                                                    if state == 140:
                                                        state = (
                                                            161
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < 0.168091297
                                                            )
                                                            else 162
                                                        )
                                                        if state == 161:
                                                            return 0.243342295
                                                        if state == 162:
                                                            return -0.0709411874
                                    if state == 68:
                                        return -0.189376622
                            if state == 38:
                                state = 59 if x["neargaia_med"] < 0.848255277 else 60
                                if state == 59:
                                    state = 69 if x["col_peak"] < 0.180881023 else 70
                                    if state == 69:
                                        return -0.0122254007
                                    if state == 70:
                                        state = (
                                            79 if x["neargaia_med"] < 0.25707221 else 80
                                        )
                                        if state == 79:
                                            return 0.0518654883
                                        if state == 80:
                                            return -0.186756507
                                if state == 60:
                                    state = 71 if x["col_peak"] < -0.0656123161 else 72
                                    if state == 71:
                                        state = (
                                            81 if x["neargaia_med"] < 34.4991608 else 82
                                        )
                                        if state == 81:
                                            state = (
                                                95
                                                if x["col_peak"] < -0.19457531
                                                else 96
                                            )
                                            if state == 95:
                                                return 0.089792937
                                            if state == 96:
                                                state = (
                                                    119
                                                    if x["mag_peak"] < 18.8187485
                                                    else 120
                                                )
                                                if state == 119:
                                                    state = (
                                                        141
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.0130654853
                                                        )
                                                        else 142
                                                    )
                                                    if state == 141:
                                                        return 0.134322435
                                                    if state == 142:
                                                        state = (
                                                            165
                                                            if x["col_peak"]
                                                            < -0.149497509
                                                            else 166
                                                        )
                                                        if state == 165:
                                                            return 0.130584806
                                                        if state == 166:
                                                            return -0.133528233
                                                if state == 120:
                                                    return -0.169693634
                                        if state == 82:
                                            return -0.160280347
                                    if state == 72:
                                        state = (
                                            83 if x["neargaia_med"] < 10.1566992 else 84
                                        )
                                        if state == 83:
                                            state = (
                                                97
                                                if x["col_peak"] < 0.477316856
                                                else 98
                                            )
                                            if state == 97:
                                                state = (
                                                    121
                                                    if x["mag_peak"] < 18.8579197
                                                    else 122
                                                )
                                                if state == 121:
                                                    return -0.227012992
                                                if state == 122:
                                                    state = (
                                                        145
                                                        if x["sgscore1_med"]
                                                        < 0.02135415
                                                        else 146
                                                    )
                                                    if state == 145:
                                                        return 0.123343423
                                                    if state == 146:
                                                        return -0.0825433582
                                            if state == 98:
                                                state = (
                                                    123
                                                    if x["mag_peak"] < 18.6807518
                                                    else 124
                                                )
                                                if state == 123:
                                                    state = (
                                                        147
                                                        if x["sgscore1_med"]
                                                        < 0.717687488
                                                        else 148
                                                    )
                                                    if state == 147:
                                                        return -0.074919112
                                                    if state == 148:
                                                        return 0.121736355
                                                if state == 124:
                                                    state = (
                                                        149
                                                        if x["sgscore1_med"]
                                                        < 0.0280833505
                                                        else 150
                                                    )
                                                    if state == 149:
                                                        return 0.0421868637
                                                    if state == 150:
                                                        return -0.0426673703
                                        if state == 84:
                                            state = (
                                                99
                                                if x["col_peak"] < -0.0241351128
                                                else 100
                                            )
                                            if state == 99:
                                                return 0.152305827
                                            if state == 100:
                                                state = (
                                                    125
                                                    if x["mag_peak"] < 18.6295261
                                                    else 126
                                                )
                                                if state == 125:
                                                    state = (
                                                        151
                                                        if x["sgscore1_med"]
                                                        < 0.00604167022
                                                        else 152
                                                    )
                                                    if state == 151:
                                                        return 0.0657960549
                                                    if state == 152:
                                                        state = (
                                                            171
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < 0.10965538
                                                            )
                                                            else 172
                                                        )
                                                        if state == 171:
                                                            return -0.203411996
                                                        if state == 172:
                                                            return 0.013502622
                                                if state == 126:
                                                    state = (
                                                        153
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.0320119001
                                                        )
                                                        else 154
                                                    )
                                                    if state == 153:
                                                        state = (
                                                            173
                                                            if x["col_peak"]
                                                            < 0.0747847557
                                                            else 174
                                                        )
                                                        if state == 173:
                                                            return -0.142385155
                                                        if state == 174:
                                                            return -0.00589672523
                                                    if state == 154:
                                                        state = (
                                                            175
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < 0.439348698
                                                            )
                                                            else 176
                                                        )
                                                        if state == 175:
                                                            return 0.0607340895
                                                        if state == 176:
                                                            return -0.0926357433
                    if state == 14:
                        return 0.0900707245
    elif num_booster == 49:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.42490506) else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.7830162) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.29701245)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["neargaia_med"] < 13.9411545 else 16
                        if state == 15:
                            state = (
                                31
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 18.1905098)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    53
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.15902638)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        89 if x["distpsnr1_med"] < 0.113736264 else 90
                                    )
                                    if state == 89:
                                        return -0.118029334
                                    if state == 90:
                                        state = (
                                            135
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.985249996)
                                            else 136
                                        )
                                        if state == 135:
                                            state = (
                                                177
                                                if x["distpsnr1_med"] < 0.661810577
                                                else 178
                                            )
                                            if state == 177:
                                                state = (
                                                    215
                                                    if x["col_last"] < 4.18439579
                                                    else 216
                                                )
                                                if state == 215:
                                                    state = (
                                                        243
                                                        if x["neargaia_med"]
                                                        < 0.518124461
                                                        else 244
                                                    )
                                                    if state == 243:
                                                        return 0.0579789355
                                                    if state == 244:
                                                        return -0.114482932
                                                if state == 216:
                                                    return 0.20976077
                                            if state == 178:
                                                state = (
                                                    217
                                                    if x["col_last"] < 0.0216379166
                                                    else 218
                                                )
                                                if state == 217:
                                                    return -0.02055737
                                                if state == 218:
                                                    state = (
                                                        245
                                                        if x["neargaia_med"]
                                                        < 0.664475739
                                                        else 246
                                                    )
                                                    if state == 245:
                                                        return -0.243801609
                                                    if state == 246:
                                                        return 0.0811113864
                                        if state == 136:
                                            return -0.0238661319
                                if state == 54:
                                    return -0.0738238692
                            if state == 32:
                                return -0.0357890092
                        if state == 16:
                            state = (
                                33
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 16.814621)
                                else 34
                            )
                            if state == 33:
                                return 0.194270864
                            if state == 34:
                                state = (
                                    57
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.355637491)
                                    else 58
                                )
                                if state == 57:
                                    return -0.0767180696
                                if state == 58:
                                    return 0.123559229
                    if state == 8:
                        state = 17 if x["neargaia_med"] < 42.2602348 else 18
                        if state == 17:
                            return -0.111025274
                        if state == 18:
                            return 0.113767534
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.07495904)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 43.4236946)
                            else 20
                        )
                        if state == 19:
                            state = 35 if x["mag_peak"] < 18.9846382 else 36
                            if state == 35:
                                state = (
                                    59
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.885065436)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        97
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 0.686535418)
                                        else 98
                                    )
                                    if state == 97:
                                        state = (
                                            139
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.979000032)
                                            else 140
                                        )
                                        if state == 139:
                                            state = (
                                                179
                                                if x["distpsnr1_med"] < 0.440493643
                                                else 180
                                            )
                                            if state == 179:
                                                return -0.0989057049
                                            if state == 180:
                                                state = (
                                                    221
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.341342926)
                                                    else 222
                                                )
                                                if state == 221:
                                                    state = (
                                                        249
                                                        if x["neargaia_med"]
                                                        < 20.7441101
                                                        else 250
                                                    )
                                                    if state == 249:
                                                        return -0.0120905722
                                                    if state == 250:
                                                        return 0.10835167
                                                if state == 222:
                                                    return -0.0262388345
                                        if state == 140:
                                            state = (
                                                181
                                                if x["distpsnr1_med"] < 0.134371087
                                                else 182
                                            )
                                            if state == 181:
                                                return -0.0801072121
                                            if state == 182:
                                                return 0.15664725
                                    if state == 98:
                                        state = (
                                            141
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.980250001)
                                            else 142
                                        )
                                        if state == 141:
                                            state = (
                                                183
                                                if x["distpsnr1_med"] < 1.87419724
                                                else 184
                                            )
                                            if state == 183:
                                                return -0.302147001
                                            if state == 184:
                                                return -0.00209909305
                                        if state == 142:
                                            state = (
                                                185
                                                if x["distpsnr1_med"] < 0.845134854
                                                else 186
                                            )
                                            if state == 185:
                                                return -0.139033943
                                            if state == 186:
                                                return 0.0842447355
                                if state == 60:
                                    state = (
                                        99 if x["distpsnr1_med"] < 1.02480173 else 100
                                    )
                                    if state == 99:
                                        state = (
                                            143
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.980749965)
                                            else 144
                                        )
                                        if state == 143:
                                            return 0.177477792
                                        if state == 144:
                                            return -0.00674312888
                                    if state == 100:
                                        state = (
                                            145
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.977749944)
                                            else 146
                                        )
                                        if state == 145:
                                            return 0.125766516
                                        if state == 146:
                                            state = (
                                                187
                                                if x["distpsnr1_med"] < 1.02625179
                                                else 188
                                            )
                                            if state == 187:
                                                return -0.205512255
                                            if state == 188:
                                                return 0.0608576052
                            if state == 36:
                                state = (
                                    61
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.798083544)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        101 if x["distpsnr1_med"] < 0.640152395 else 102
                                    )
                                    if state == 101:
                                        state = (
                                            147
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.981750011)
                                            else 148
                                        )
                                        if state == 147:
                                            state = (
                                                189
                                                if x["distpsnr1_med"] < 0.162655652
                                                else 190
                                            )
                                            if state == 189:
                                                return 0.00897089858
                                            if state == 190:
                                                state = (
                                                    227
                                                    if x["col_last"] < 0.0415830612
                                                    else 228
                                                )
                                                if state == 227:
                                                    state = (
                                                        255
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 12.0589285
                                                        )
                                                        else 256
                                                    )
                                                    if state == 255:
                                                        return -0.106969863
                                                    if state == 256:
                                                        return 0.0753270388
                                                if state == 228:
                                                    return -0.197271869
                                        if state == 148:
                                            return 0.00114572735
                                    if state == 102:
                                        state = (
                                            149
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.976250052)
                                            else 150
                                        )
                                        if state == 149:
                                            return -0.0870709419
                                        if state == 150:
                                            return 0.108515747
                                if state == 62:
                                    state = (
                                        103 if x["distpsnr1_med"] < 0.849471509 else 104
                                    )
                                    if state == 103:
                                        state = (
                                            151
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.975749969)
                                            else 152
                                        )
                                        if state == 151:
                                            return -0.0989135653
                                        if state == 152:
                                            return 0.116355628
                                    if state == 104:
                                        return -0.184812427
                        if state == 20:
                            state = 37 if x["mag_peak"] < 18.401577 else 38
                            if state == 37:
                                return 0.0208422579
                            if state == 38:
                                state = (
                                    65
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.278945625)
                                    else 66
                                )
                                if state == 65:
                                    return -0.00331552257
                                if state == 66:
                                    return -0.188347563
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 11.8333054)
                            else 22
                        )
                        if state == 21:
                            return 0.157841995
                        if state == 22:
                            state = 39 if x["mag_peak"] < 18.9391136 else 40
                            if state == 39:
                                state = (
                                    67
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.2205503)
                                    else 68
                                )
                                if state == 67:
                                    return 0.162775472
                                if state == 68:
                                    state = (
                                        107 if x["distpsnr1_med"] < 1.39975071 else 108
                                    )
                                    if state == 107:
                                        return -0.0710020289
                                    if state == 108:
                                        return 0.131022021
                            if state == 40:
                                return -0.0234494787
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.2586708) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.49937558)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 38.5461578)
                            else 24
                        )
                        if state == 23:
                            state = 41 if x["mag_peak"] < 18.9939499 else 42
                            if state == 41:
                                return -0.00973354839
                            if state == 42:
                                return -0.245911822
                        if state == 24:
                            return 0.0157878362
                    if state == 12:
                        state = 25 if x["neargaia_med"] < 37.6759911 else 26
                        if state == 25:
                            state = 43 if x["mag_peak"] < 17.9873276 else 44
                            if state == 43:
                                state = (
                                    71
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.93278193)
                                    else 72
                                )
                                if state == 71:
                                    return 0.00950557366
                                if state == 72:
                                    state = (
                                        111 if x["distpsnr1_med"] < 2.69529915 else 112
                                    )
                                    if state == 111:
                                        return -0.219370618
                                    if state == 112:
                                        state = (
                                            155
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.983749986)
                                            else 156
                                        )
                                        if state == 155:
                                            state = (
                                                199
                                                if x["distpsnr1_med"] < 3.9873364
                                                else 200
                                            )
                                            if state == 199:
                                                return 0.0798771456
                                            if state == 200:
                                                return -0.132111579
                                        if state == 156:
                                            return 0.0615566261
                            if state == 44:
                                state = (
                                    73
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.67113328)
                                    else 74
                                )
                                if state == 73:
                                    return 0.122211643
                                if state == 74:
                                    state = (
                                        115 if x["distpsnr1_med"] < 4.55275965 else 116
                                    )
                                    if state == 115:
                                        state = (
                                            159
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.983250022)
                                            else 160
                                        )
                                        if state == 159:
                                            state = (
                                                201
                                                if x["distpsnr1_med"] < 2.90293813
                                                else 202
                                            )
                                            if state == 201:
                                                state = (
                                                    229
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < -0.202954292)
                                                    else 230
                                                )
                                                if state == 229:
                                                    state = (
                                                        257
                                                        if x["neargaia_med"]
                                                        < 10.1146603
                                                        else 258
                                                    )
                                                    if state == 257:
                                                        return -0.100977689
                                                    if state == 258:
                                                        state = (
                                                            279
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < -0.30873251
                                                            )
                                                            else 280
                                                        )
                                                        if state == 279:
                                                            return 0.085051544
                                                        if state == 280:
                                                            return -0.0745514557
                                                if state == 230:
                                                    return 0.0876101106
                                            if state == 202:
                                                state = (
                                                    231
                                                    if x["col_last"] < 0.228674889
                                                    else 232
                                                )
                                                if state == 231:
                                                    return -0.150411338
                                                if state == 232:
                                                    state = (
                                                        261
                                                        if x["neargaia_med"]
                                                        < 15.2942142
                                                        else 262
                                                    )
                                                    if state == 261:
                                                        return 0.0556764267
                                                    if state == 262:
                                                        return -0.105686888
                                        if state == 160:
                                            return -0.108651571
                                    if state == 116:
                                        state = (
                                            161
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982749999)
                                            else 162
                                        )
                                        if state == 161:
                                            state = (
                                                203
                                                if x["distpsnr1_med"] < 4.9734149
                                                else 204
                                            )
                                            if state == 203:
                                                return 0.144802377
                                            if state == 204:
                                                state = (
                                                    233
                                                    if x["col_last"] < -0.0222234726
                                                    else 234
                                                )
                                                if state == 233:
                                                    return 0.0838672072
                                                if state == 234:
                                                    state = (
                                                        265
                                                        if x["neargaia_med"]
                                                        < 34.5105782
                                                        else 266
                                                    )
                                                    if state == 265:
                                                        return 0.0199813265
                                                    if state == 266:
                                                        return -0.179013804
                                        if state == 162:
                                            return 0.181290999
                        if state == 26:
                            state = (
                                45
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 18.8359947)
                                else 46
                            )
                            if state == 45:
                                state = (
                                    75
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 2.17573977)
                                    else 76
                                )
                                if state == 75:
                                    return 0.024013631
                                if state == 76:
                                    state = (
                                        119
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 2.55405498)
                                        else 120
                                    )
                                    if state == 119:
                                        return -0.0180538092
                                    if state == 120:
                                        state = (
                                            167
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.963750005)
                                            else 168
                                        )
                                        if state == 167:
                                            return -0.0648071542
                                        if state == 168:
                                            return 0.172830477
                            if state == 46:
                                return -0.0198666882
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.58117163)
                        else 14
                    )
                    if state == 13:
                        return 0.0528257973
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 44.7333755)
                            else 30
                        )
                        if state == 29:
                            state = 49 if x["mag_peak"] < 18.8777504 else 50
                            if state == 49:
                                state = (
                                    81
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 2.01389503)
                                    else 82
                                )
                                if state == 81:
                                    return 0.124165475
                                if state == 82:
                                    state = (
                                        127
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 9.69988823)
                                        else 128
                                    )
                                    if state == 127:
                                        state = (
                                            171
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.978249967)
                                            else 172
                                        )
                                        if state == 171:
                                            state = (
                                                207
                                                if x["distpsnr1_med"] < 6.1966095
                                                else 208
                                            )
                                            if state == 207:
                                                return 0.115682483
                                            if state == 208:
                                                return -0.0719701499
                                        if state == 172:
                                            state = (
                                                209
                                                if x["distpsnr1_med"] < 6.02312899
                                                else 210
                                            )
                                            if state == 209:
                                                return -0.105761491
                                            if state == 210:
                                                return 0.0614065491
                                    if state == 128:
                                        return 0.147435829
                            if state == 50:
                                state = (
                                    83
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.62510943)
                                    else 84
                                )
                                if state == 83:
                                    return -0.00102667662
                                if state == 84:
                                    state = (
                                        129
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 3.44804287)
                                        else 130
                                    )
                                    if state == 129:
                                        return -0.214061111
                                    if state == 130:
                                        state = (
                                            175
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.952250004)
                                            else 176
                                        )
                                        if state == 175:
                                            state = (
                                                211
                                                if x["distpsnr1_med"] < 5.29194736
                                                else 212
                                            )
                                            if state == 211:
                                                return 0.124891825
                                            if state == 212:
                                                return -0.108329311
                                        if state == 176:
                                            state = (
                                                213
                                                if x["distpsnr1_med"] < 3.83499098
                                                else 214
                                            )
                                            if state == 213:
                                                return 0.0932177752
                                            if state == 214:
                                                state = (
                                                    241
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.30126667)
                                                    else 242
                                                )
                                                if state == 241:
                                                    state = (
                                                        273
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 33.4013672
                                                        )
                                                        else 274
                                                    )
                                                    if state == 273:
                                                        return -0.264328212
                                                    if state == 274:
                                                        return -0.00303846714
                                                if state == 242:
                                                    return -0.0365823954
                        if state == 30:
                            state = (
                                51
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 18.5550404)
                                else 52
                            )
                            if state == 51:
                                return -0.1795239
                            if state == 52:
                                return -0.0205714926
    elif num_booster == 50:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.963500023)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.707000017)
                    else 4
                )
                if state == 3:
                    return -0.16801919
                if state == 4:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.740000069) else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4433002)
                            else 14
                        )
                        if state == 13:
                            state = (
                                25
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.339644909)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    47
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 4.0058794)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        79
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 21.0354996)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            125
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 31.0137978)
                                            else 126
                                        )
                                        if state == 125:
                                            return 0.157922402
                                        if state == 126:
                                            return -0.0731432959
                                    if state == 80:
                                        return -0.0599359684
                                if state == 48:
                                    state = (
                                        81
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.300499)
                                        else 82
                                    )
                                    if state == 81:
                                        return -0.133238167
                                    if state == 82:
                                        return 0.0506839491
                            if state == 26:
                                return -0.0935509801
                        if state == 14:
                            state = 27 if x["col_last"] < 0.333820343 else 28
                            if state == 27:
                                return -0.154532671
                            if state == 28:
                                state = (
                                    49
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.92727423)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        83
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 20.5682487)
                                        else 84
                                    )
                                    if state == 83:
                                        return 0.136362731
                                    if state == 84:
                                        return -0.0919961259
                                if state == 50:
                                    return -0.123093314
                    if state == 8:
                        return -0.12909025
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.980250001)
                    else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.786547661)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.8857899)
                            else 18
                        )
                        if state == 17:
                            state = 31 if x["col_last"] < -0.13097477 else 32
                            if state == 31:
                                return 0.0907474682
                            if state == 32:
                                state = (
                                    53
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.47574067)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        87
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 20.9905014)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            137
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 14.0825462)
                                            else 138
                                        )
                                        if state == 137:
                                            state = (
                                                183
                                                if x["col_last"] < 0.0824971199
                                                else 184
                                            )
                                            if state == 183:
                                                return -0.073521249
                                            if state == 184:
                                                return 0.112904102
                                        if state == 138:
                                            state = (
                                                185
                                                if x["col_last"] < 1.05318117
                                                else 186
                                            )
                                            if state == 185:
                                                state = (
                                                    221
                                                    if x["sgscore1_med"] < 0.284357011
                                                    else 222
                                                )
                                                if state == 221:
                                                    state = (
                                                        259
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.68083334)
                                                        else 260
                                                    )
                                                    if state == 259:
                                                        return 0.141452342
                                                    if state == 260:
                                                        return -0.0374530628
                                                if state == 222:
                                                    return -0.0909433439
                                            if state == 186:
                                                state = (
                                                    223
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0887842029
                                                    )
                                                    else 224
                                                )
                                                if state == 223:
                                                    state = (
                                                        263
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.648452401)
                                                        else 264
                                                    )
                                                    if state == 263:
                                                        return -0.189267412
                                                    if state == 264:
                                                        return 0.0168691278
                                                if state == 224:
                                                    state = (
                                                        265
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.715833306)
                                                        else 266
                                                    )
                                                    if state == 265:
                                                        state = (
                                                            303
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 3.11898565
                                                            )
                                                            else 304
                                                        )
                                                        if state == 303:
                                                            return 0.103666089
                                                        if state == 304:
                                                            return -0.0596755035
                                                    if state == 266:
                                                        return -0.114582911
                                    if state == 88:
                                        state = (
                                            139
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 17.0414066)
                                            else 140
                                        )
                                        if state == 139:
                                            return -0.154718488
                                        if state == 140:
                                            state = (
                                                187
                                                if x["col_last"] < 0.850654602
                                                else 188
                                            )
                                            if state == 187:
                                                return -0.0234361142
                                            if state == 188:
                                                state = (
                                                    225
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.163731992)
                                                    else 226
                                                )
                                                if state == 225:
                                                    return 0.114314936
                                                if state == 226:
                                                    return -0.0655894727
                                if state == 54:
                                    state = (
                                        89
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 21.434)
                                        else 90
                                    )
                                    if state == 89:
                                        state = (
                                            141
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 30.9685059)
                                            else 142
                                        )
                                        if state == 141:
                                            state = (
                                                189
                                                if x["col_last"] < 0.194330215
                                                else 190
                                            )
                                            if state == 189:
                                                return -0.0380398408
                                            if state == 190:
                                                state = (
                                                    229
                                                    if x["sgscore1_med"] < 0.0429444499
                                                    else 230
                                                )
                                                if state == 229:
                                                    state = (
                                                        271
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.594642878)
                                                        else 272
                                                    )
                                                    if state == 271:
                                                        return 0.0269081574
                                                    if state == 272:
                                                        state = (
                                                            309
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.323625505
                                                            )
                                                            else 310
                                                        )
                                                        if state == 309:
                                                            return 0.113237172
                                                        if state == 310:
                                                            return -0.150570229
                                                if state == 230:
                                                    return -0.179371208
                                        if state == 142:
                                            state = (
                                                191
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.759440899)
                                                else 192
                                            )
                                            if state == 191:
                                                state = (
                                                    231
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.155675501)
                                                    else 232
                                                )
                                                if state == 231:
                                                    state = (
                                                        273
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.749285698)
                                                        else 274
                                                    )
                                                    if state == 273:
                                                        state = (
                                                            311
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.709908724
                                                            )
                                                            else 312
                                                        )
                                                        if state == 311:
                                                            return -0.129018188
                                                        if state == 312:
                                                            return -0.00462969253
                                                    if state == 274:
                                                        return 0.136496112
                                                if state == 232:
                                                    state = (
                                                        275
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.647261977)
                                                        else 276
                                                    )
                                                    if state == 275:
                                                        return -0.126715302
                                                    if state == 276:
                                                        return 0.0518152118
                                            if state == 192:
                                                return -0.12560077
                                    if state == 90:
                                        return 0.031840723
                        if state == 18:
                            return 0.064385131
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1086845)
                            else 20
                        )
                        if state == 19:
                            state = (
                                35
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.090218544)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    59
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.524675965)
                                    else 60
                                )
                                if state == 59:
                                    return -0.0561895557
                                if state == 60:
                                    return 0.209035546
                            if state == 36:
                                return -0.0605455115
                        if state == 20:
                            state = 37 if x["col_last"] < 0.185033798 else 38
                            if state == 37:
                                state = (
                                    61
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.98397565)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        97
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 21.8209991)
                                        else 98
                                    )
                                    if state == 97:
                                        state = (
                                            147
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 6.55493641)
                                            else 148
                                        )
                                        if state == 147:
                                            return 0.0610753149
                                        if state == 148:
                                            return -0.154215246
                                    if state == 98:
                                        return 0.122201972
                                if state == 62:
                                    return -0.120915093
                            if state == 38:
                                state = (
                                    63
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.45948505)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        99
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.1317501)
                                        else 100
                                    )
                                    if state == 99:
                                        return 0.0861642808
                                    if state == 100:
                                        return -0.174415901
                                if state == 64:
                                    state = (
                                        101
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 20.6500015)
                                        else 102
                                    )
                                    if state == 101:
                                        return 0.158363998
                                    if state == 102:
                                        return -0.0298247952
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.623452425)
                        else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0270309)
                            else 22
                        )
                        if state == 21:
                            state = (
                                39
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.33856678)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    65
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.0585300997)
                                    else 66
                                )
                                if state == 65:
                                    return -0.0723325834
                                if state == 66:
                                    state = (
                                        103
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 15.8042507)
                                        else 104
                                    )
                                    if state == 103:
                                        return -0.101406254
                                    if state == 104:
                                        state = (
                                            153
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 28.8890343)
                                            else 154
                                        )
                                        if state == 153:
                                            return 0.233165026
                                        if state == 154:
                                            return 0.0163558964
                            if state == 40:
                                return -0.0396028683
                        if state == 22:
                            state = (
                                41
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.0558176041)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    69
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.93539953)
                                    else 70
                                )
                                if state == 69:
                                    return 0.0514432229
                                if state == 70:
                                    state = (
                                        107
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.862999)
                                        else 108
                                    )
                                    if state == 107:
                                        return 0.0399707258
                                    if state == 108:
                                        return -0.0944891647
                            if state == 42:
                                return 0.125847518
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.9925613)
                            else 24
                        )
                        if state == 23:
                            state = 43 if x["col_last"] < -0.104584694 else 44
                            if state == 43:
                                return -0.0481656082
                            if state == 44:
                                state = (
                                    73
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.99402761)
                                    else 74
                                )
                                if state == 73:
                                    state = (
                                        113
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.8722496)
                                        else 114
                                    )
                                    if state == 113:
                                        state = (
                                            163
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 20.9711914)
                                            else 164
                                        )
                                        if state == 163:
                                            return 0.240791678
                                        if state == 164:
                                            return 0.0342300795
                                    if state == 114:
                                        return 0.0076245158
                                if state == 74:
                                    state = (
                                        115
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.5100002)
                                        else 116
                                    )
                                    if state == 115:
                                        return -0.0925084874
                                    if state == 116:
                                        state = (
                                            169
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 23.9148674)
                                            else 170
                                        )
                                        if state == 169:
                                            state = (
                                                207
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < -0.00928401947)
                                                else 208
                                            )
                                            if state == 207:
                                                state = (
                                                    241
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00531250006
                                                    )
                                                    else 242
                                                )
                                                if state == 241:
                                                    return 0.0778161287
                                                if state == 242:
                                                    return -0.114921287
                                            if state == 208:
                                                return 0.039488934
                                        if state == 170:
                                            return 0.0879591703
                        if state == 24:
                            state = (
                                45
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.355218887)
                                else 46
                            )
                            if state == 45:
                                state = (
                                    75
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.04078126)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        117
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 17.5657501)
                                        else 118
                                    )
                                    if state == 117:
                                        return -0.0132629117
                                    if state == 118:
                                        state = (
                                            171
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 43.9564247)
                                            else 172
                                        )
                                        if state == 171:
                                            return 0.168110564
                                        if state == 172:
                                            return -0.0221389271
                                if state == 76:
                                    state = (
                                        119
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.2539997)
                                        else 120
                                    )
                                    if state == 119:
                                        state = (
                                            173
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 35.926384)
                                            else 174
                                        )
                                        if state == 173:
                                            state = (
                                                211
                                                if x["col_last"] < 0.178458214
                                                else 212
                                            )
                                            if state == 211:
                                                return 0.123504393
                                            if state == 212:
                                                state = (
                                                    247
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00700000022
                                                    )
                                                    else 248
                                                )
                                                if state == 247:
                                                    return 0.0820112526
                                                if state == 248:
                                                    return -0.128630042
                                        if state == 174:
                                            return 0.0325663537
                                    if state == 120:
                                        state = (
                                            175
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 23.9619274)
                                            else 176
                                        )
                                        if state == 175:
                                            return -0.193737939
                                        if state == 176:
                                            state = (
                                                213
                                                if x["col_last"] < 0.688952506
                                                else 214
                                            )
                                            if state == 213:
                                                return 0.0677947998
                                            if state == 214:
                                                state = (
                                                    249
                                                    if x["sgscore1_med"] < 0.00208333507
                                                    else 250
                                                )
                                                if state == 249:
                                                    return -0.157686397
                                                if state == 250:
                                                    state = (
                                                        291
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.73011905)
                                                        else 292
                                                    )
                                                    if state == 291:
                                                        return -0.0431421436
                                                    if state == 292:
                                                        return 0.0877467543
                            if state == 46:
                                return 0.0173985995
    elif num_booster == 51:
        state = 0
        if state == 0:
            state = 1 if x["col_det"] < 0.235700607 else 2
            if state == 1:
                state = 3 if x["col_last"] < 0.144599438 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.46043944)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["col_det"] < -0.217223167 else 16
                        if state == 15:
                            return -0.0536750369
                        if state == 16:
                            return 0.0797206089
                    if state == 8:
                        state = 17 if x["col_det"] < -0.199289322 else 18
                        if state == 17:
                            return 0.0769891739
                        if state == 18:
                            state = 35 if x["col_det"] < 0.135037899 else 36
                            if state == 35:
                                state = 57 if x["mag_peak"] < 18.6436691 else 58
                                if state == 57:
                                    return -0.0156798009
                                if state == 58:
                                    state = 75 if x["neargaia_med"] < 72.0438385 else 76
                                    if state == 75:
                                        return -0.184700325
                                    if state == 76:
                                        return 0.0363605022
                            if state == 36:
                                return 0.046039585
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.307901531)
                        else 10
                    )
                    if state == 9:
                        return -0.0751356259
                    if state == 10:
                        state = 21 if x["col_det"] < 0.174955845 else 22
                        if state == 21:
                            state = 39 if x["col_det"] < 0.0598936081 else 40
                            if state == 39:
                                state = (
                                    61
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 17.7559853)
                                    else 62
                                )
                                if state == 61:
                                    state = 81 if x["neargaia_med"] < 5.03299236 else 82
                                    if state == 81:
                                        return -0.101365566
                                    if state == 82:
                                        state = (
                                            107
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 34.4966507)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                135
                                                if x["col_peak"] < -0.120340824
                                                else 136
                                            )
                                            if state == 135:
                                                return -0.150315285
                                            if state == 136:
                                                state = (
                                                    159
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.315133572)
                                                    else 160
                                                )
                                                if state == 159:
                                                    state = (
                                                        177
                                                        if x["neargaia_med"] < 18.266674
                                                        else 178
                                                    )
                                                    if state == 177:
                                                        state = (
                                                            199
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.09802675
                                                            )
                                                            else 200
                                                        )
                                                        if state == 199:
                                                            return 0.105388589
                                                        if state == 200:
                                                            return -0.0578439459
                                                    if state == 178:
                                                        return 0.101051308
                                                if state == 160:
                                                    return -0.0356058069
                                        if state == 108:
                                            return -0.0739650875
                                if state == 62:
                                    state = 83 if x["neargaia_med"] < 9.17612267 else 84
                                    if state == 83:
                                        state = (
                                            109
                                            if x["neargaia_med"] < 7.47751808
                                            else 110
                                        )
                                        if state == 109:
                                            state = (
                                                137
                                                if x["col_peak"] < 0.221316338
                                                else 138
                                            )
                                            if state == 137:
                                                return -0.0885524526
                                            if state == 138:
                                                return 0.116996467
                                        if state == 110:
                                            return -0.144537255
                                    if state == 84:
                                        state = (
                                            111
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 47.9965973)
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                139
                                                if x["col_peak"] < -0.0865001678
                                                else 140
                                            )
                                            if state == 139:
                                                state = (
                                                    161
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.360531807)
                                                    else 162
                                                )
                                                if state == 161:
                                                    state = (
                                                        181
                                                        if x["neargaia_med"]
                                                        < 18.5604897
                                                        else 182
                                                    )
                                                    if state == 181:
                                                        return -0.0809759274
                                                    if state == 182:
                                                        return 0.0934670195
                                                if state == 162:
                                                    return -0.0024160801
                                            if state == 140:
                                                return 0.141222894
                                        if state == 112:
                                            state = (
                                                141
                                                if x["col_peak"] < -0.0846371651
                                                else 142
                                            )
                                            if state == 141:
                                                return -0.107772499
                                            if state == 142:
                                                return 0.0468935631
                            if state == 40:
                                state = 63 if x["mag_peak"] < 18.7502975 else 64
                                if state == 63:
                                    state = 85 if x["neargaia_med"] < 10.3355694 else 86
                                    if state == 85:
                                        return -0.060052447
                                    if state == 86:
                                        return 0.131217882
                                if state == 64:
                                    return -0.130804896
                        if state == 22:
                            state = 41 if x["col_det"] < 0.18708992 else 42
                            if state == 41:
                                return 0.193925783
                            if state == 42:
                                state = (
                                    65
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 17.7780991)
                                    else 66
                                )
                                if state == 65:
                                    return 0.0485320501
                                if state == 66:
                                    return 0.216268912
            if state == 2:
                state = 5 if x["col_last"] < 0.280451775 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 5.3577137)
                        else 12
                    )
                    if state == 11:
                        state = 23 if x["col_det"] < 0.39645195 else 24
                        if state == 23:
                            return -0.0414095074
                        if state == 24:
                            state = 45 if x["col_det"] < 0.526796341 else 46
                            if state == 45:
                                return 0.0844424516
                            if state == 46:
                                state = (
                                    67
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 18.8008881)
                                    else 68
                                )
                                if state == 67:
                                    state = (
                                        91
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 31.2537193)
                                        else 92
                                    )
                                    if state == 91:
                                        state = (
                                            117
                                            if x["neargaia_med"] < 1.64681053
                                            else 118
                                        )
                                        if state == 117:
                                            return 0.0693057925
                                        if state == 118:
                                            state = (
                                                145
                                                if x["col_peak"] < 0.00418329239
                                                else 146
                                            )
                                            if state == 145:
                                                return 0.0825218409
                                            if state == 146:
                                                state = (
                                                    165
                                                    if x["col_last"] < 0.127847672
                                                    else 166
                                                )
                                                if state == 165:
                                                    state = (
                                                        183
                                                        if x["neargaia_med"]
                                                        < 22.0942993
                                                        else 184
                                                    )
                                                    if state == 183:
                                                        return -0.0568394922
                                                    if state == 184:
                                                        state = (
                                                            205
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 0.723341942
                                                            )
                                                            else 206
                                                        )
                                                        if state == 205:
                                                            return 0.121507801
                                                        if state == 206:
                                                            return -0.0599667504
                                                if state == 166:
                                                    return -0.0824261084
                                    if state == 92:
                                        state = (
                                            119
                                            if x["neargaia_med"] < 38.4149933
                                            else 120
                                        )
                                        if state == 119:
                                            return 0.179289311
                                        if state == 120:
                                            return -0.00426895078
                                if state == 68:
                                    return -0.0395358279
                    if state == 12:
                        return -0.110142559
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 3.12839842)
                        else 14
                    )
                    if state == 13:
                        state = 25 if x["col_det"] < 0.38904953 else 26
                        if state == 25:
                            return -0.145855904
                        if state == 26:
                            state = 49 if x["col_det"] < 0.438000679 else 50
                            if state == 49:
                                return 0.106933735
                            if state == 50:
                                state = 69 if x["mag_peak"] < 18.3082199 else 70
                                if state == 69:
                                    state = (
                                        95
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 51.0698929)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            123
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 43.6426086)
                                            else 124
                                        )
                                        if state == 123:
                                            state = (
                                                147
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.162279129)
                                                else 148
                                            )
                                            if state == 147:
                                                state = (
                                                    167
                                                    if x["col_last"] < 0.80030632
                                                    else 168
                                                )
                                                if state == 167:
                                                    return -0.0535350703
                                                if state == 168:
                                                    state = (
                                                        187
                                                        if x["neargaia_med"]
                                                        < 0.214884967
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        return -0.0735911503
                                                    if state == 188:
                                                        state = (
                                                            209
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 1.9140172
                                                            )
                                                            else 210
                                                        )
                                                        if state == 209:
                                                            return 0.0824305117
                                                        if state == 210:
                                                            return -0.0534333289
                                            if state == 148:
                                                return 0.0923911631
                                        if state == 124:
                                            return -0.126823664
                                    if state == 96:
                                        return 0.163983077
                                if state == 70:
                                    state = (
                                        97
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 1.0638113)
                                        else 98
                                    )
                                    if state == 97:
                                        state = (
                                            125
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 1.00934935)
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                149
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < 0.426573277)
                                                else 150
                                            )
                                            if state == 149:
                                                state = (
                                                    171
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.640884876)
                                                    else 172
                                                )
                                                if state == 171:
                                                    state = (
                                                        191
                                                        if x["neargaia_med"]
                                                        < 0.319359034
                                                        else 192
                                                    )
                                                    if state == 191:
                                                        return -0.0156183317
                                                    if state == 192:
                                                        state = (
                                                            215
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.33208036
                                                            )
                                                            else 216
                                                        )
                                                        if state == 215:
                                                            return -0.160556063
                                                        if state == 216:
                                                            return 0.0549462177
                                                if state == 172:
                                                    return 0.0254732762
                                            if state == 150:
                                                return 0.0617290363
                                        if state == 126:
                                            return -0.303384453
                                    if state == 98:
                                        state = (
                                            127
                                            if x["neargaia_med"] < 41.9921837
                                            else 128
                                        )
                                        if state == 127:
                                            state = (
                                                151
                                                if x["col_peak"] < -0.141354561
                                                else 152
                                            )
                                            if state == 151:
                                                return -0.0847256184
                                            if state == 152:
                                                state = (
                                                    173
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.871717453)
                                                    else 174
                                                )
                                                if state == 173:
                                                    state = (
                                                        193
                                                        if x["neargaia_med"] < 36.373909
                                                        else 194
                                                    )
                                                    if state == 193:
                                                        state = (
                                                            217
                                                            if np.isnan(x["distnr_med"])
                                                            or (
                                                                x["distnr_med"]
                                                                < 2.44250107
                                                            )
                                                            else 218
                                                        )
                                                        if state == 217:
                                                            return 0.00639317185
                                                        if state == 218:
                                                            return 0.155272514
                                                    if state == 194:
                                                        return 0.163602501
                                                if state == 174:
                                                    return -0.0454387963
                                        if state == 128:
                                            state = (
                                                153
                                                if x["col_peak"] < 0.520922661
                                                else 154
                                            )
                                            if state == 153:
                                                return -0.169037089
                                            if state == 154:
                                                state = (
                                                    175
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.324394226)
                                                    else 176
                                                )
                                                if state == 175:
                                                    state = (
                                                        197
                                                        if x["neargaia_med"]
                                                        < 43.9666901
                                                        else 198
                                                    )
                                                    if state == 197:
                                                        return -0.166866422
                                                    if state == 198:
                                                        return 0.0463707596
                                                if state == 176:
                                                    return 0.0674281418
                    if state == 14:
                        state = 27 if x["col_det"] < 0.423643112 else 28
                        if state == 27:
                            return -0.149485752
                        if state == 28:
                            state = 51 if x["col_det"] < 2.37376499 else 52
                            if state == 51:
                                return 0.0293602813
                            if state == 52:
                                state = 71 if x["mag_peak"] < 18.5446568 else 72
                                if state == 71:
                                    state = (
                                        99 if x["neargaia_med"] < 6.32108307 else 100
                                    )
                                    if state == 99:
                                        return -0.0722838417
                                    if state == 100:
                                        return 0.093598105
                                if state == 72:
                                    state = (
                                        101 if x["neargaia_med"] < 34.657959 else 102
                                    )
                                    if state == 101:
                                        state = (
                                            131
                                            if x["neargaia_med"] < 23.3028755
                                            else 132
                                        )
                                        if state == 131:
                                            state = (
                                                157
                                                if x["col_peak"] < -0.105252028
                                                else 158
                                            )
                                            if state == 157:
                                                return 0.0680693835
                                            if state == 158:
                                                return -0.195183933
                                        if state == 132:
                                            return 0.126876026
                                    if state == 102:
                                        return -0.200626165
    elif num_booster == 52:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 15.6147394 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 4.93690968)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.4734344)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["col_det"] < 0.235238075 else 16
                        if state == 15:
                            return 0.0267654005
                        if state == 16:
                            return -0.152901247
                    if state == 8:
                        return -0.0149575425
                if state == 4:
                    state = 9 if x["mag_peak"] < 17.6320095 else 10
                    if state == 9:
                        return 0.0695213005
                    if state == 10:
                        state = 19 if x["col_det"] < 0.174049377 else 20
                        if state == 19:
                            return -0.146816149
                        if state == 20:
                            return 0.0962382779
            if state == 2:
                state = (
                    5
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 4.89207172)
                    else 6
                )
                if state == 5:
                    state = 11 if x["mag_peak"] < 16.9013996 else 12
                    if state == 11:
                        return -0.0995578244
                    if state == 12:
                        state = 23 if x["col_det"] < 0.29579258 else 24
                        if state == 23:
                            state = (
                                37
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0161607489)
                                else 38
                            )
                            if state == 37:
                                state = 49 if x["col_peak"] < 0.0848903656 else 50
                                if state == 49:
                                    state = 65 if x["col_det"] < -0.307900429 else 66
                                    if state == 65:
                                        return -0.0712969527
                                    if state == 66:
                                        return 0.125901476
                                if state == 50:
                                    state = 67 if x["col_det"] < -0.0675584525 else 68
                                    if state == 67:
                                        state = (
                                            83 if x["maggaia_med"] < 19.9749374 else 84
                                        )
                                        if state == 83:
                                            state = (
                                                105
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.2737617)
                                                else 106
                                            )
                                            if state == 105:
                                                state = (
                                                    125
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.1926994)
                                                    else 126
                                                )
                                                if state == 125:
                                                    return 0.139618665
                                                if state == 126:
                                                    return -0.0836093575
                                            if state == 106:
                                                return -0.0528684258
                                        if state == 84:
                                            return -0.166498542
                                    if state == 68:
                                        state = (
                                            85 if x["maggaia_med"] < 17.5025101 else 86
                                        )
                                        if state == 85:
                                            return 0.066696316
                                        if state == 86:
                                            return -0.172221079
                            if state == 38:
                                state = 51 if x["col_peak"] < -0.21003437 else 52
                                if state == 51:
                                    return -0.033431638
                                if state == 52:
                                    state = 69 if x["col_det"] < -0.00176382065 else 70
                                    if state == 69:
                                        state = (
                                            87 if x["maggaia_med"] < 19.8056984 else 88
                                        )
                                        if state == 87:
                                            state = (
                                                107
                                                if x["mag_peak"] < 18.8462486
                                                else 108
                                            )
                                            if state == 107:
                                                return 0.1198183
                                            if state == 108:
                                                state = (
                                                    129
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.3293495)
                                                    else 130
                                                )
                                                if state == 129:
                                                    return -0.120732404
                                                if state == 130:
                                                    return 0.163486898
                                        if state == 88:
                                            return 0.157725304
                                    if state == 70:
                                        state = (
                                            89 if x["maggaia_med"] < 17.3968182 else 90
                                        )
                                        if state == 89:
                                            return -0.0180829354
                                        if state == 90:
                                            return 0.220957115
                        if state == 24:
                            state = 39 if x["sgscore1_med"] < 0.163503006 else 40
                            if state == 39:
                                state = (
                                    53
                                    if np.isnan(x["col_peak"])
                                    or (x["col_peak"] < 0.451997757)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        71
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.615605354)
                                        else 72
                                    )
                                    if state == 71:
                                        state = (
                                            91
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.2332077)
                                            else 92
                                        )
                                        if state == 91:
                                            state = (
                                                111
                                                if x["mag_peak"] < 18.9997444
                                                else 112
                                            )
                                            if state == 111:
                                                state = (
                                                    131
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.2669506)
                                                    else 132
                                                )
                                                if state == 131:
                                                    state = (
                                                        161
                                                        if x["mag_peak"] < 18.3335533
                                                        else 162
                                                    )
                                                    if state == 161:
                                                        return 0.104471624
                                                    if state == 162:
                                                        return -0.0598098375
                                                if state == 132:
                                                    return 0.203914031
                                            if state == 112:
                                                state = (
                                                    133
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.9259491)
                                                    else 134
                                                )
                                                if state == 133:
                                                    return 0.00389944809
                                                if state == 134:
                                                    state = (
                                                        163
                                                        if x["mag_peak"] < 20.039463
                                                        else 164
                                                    )
                                                    if state == 163:
                                                        return -0.0269273762
                                                    if state == 164:
                                                        state = (
                                                            189
                                                            if x["distpsnr1_med"]
                                                            < 0.968741179
                                                            else 190
                                                        )
                                                        if state == 189:
                                                            return -0.0210333429
                                                        if state == 190:
                                                            return 0.184881479
                                        if state == 92:
                                            state = (
                                                113
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.0867767)
                                                else 114
                                            )
                                            if state == 113:
                                                state = (
                                                    135
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.7360001)
                                                    else 136
                                                )
                                                if state == 135:
                                                    return -0.193853736
                                                if state == 136:
                                                    return -0.0392861813
                                            if state == 114:
                                                state = (
                                                    137
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.9463005)
                                                    else 138
                                                )
                                                if state == 137:
                                                    state = (
                                                        167
                                                        if x["mag_peak"] < 18.8400459
                                                        else 168
                                                    )
                                                    if state == 167:
                                                        return 0.161229491
                                                    if state == 168:
                                                        return -0.0380059332
                                                if state == 138:
                                                    return -0.017836377
                                    if state == 72:
                                        return -0.0994946957
                                if state == 54:
                                    return -0.12309847
                            if state == 40:
                                state = (
                                    55
                                    if np.isnan(x["col_peak"])
                                    or (x["col_peak"] < 0.583332062)
                                    else 56
                                )
                                if state == 55:
                                    return -0.0970509648
                                if state == 56:
                                    return 0.0733708665
                if state == 6:
                    state = 13 if x["mag_peak"] < 17.3567867 else 14
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["col_det"]) or (x["col_det"] < -0.0303421021)
                            else 26
                        )
                        if state == 25:
                            state = 41 if x["sgscore1_med"] < 0.652570009 else 42
                            if state == 41:
                                return 0.163236782
                            if state == 42:
                                return -0.0246605948
                        if state == 26:
                            return 0.011606642
                    if state == 14:
                        state = 27 if x["col_det"] < 0.404681206 else 28
                        if state == 27:
                            state = (
                                43
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.00112499995)
                                else 44
                            )
                            if state == 43:
                                state = 57 if x["col_peak"] < -0.129648209 else 58
                                if state == 57:
                                    return -0.073493436
                                if state == 58:
                                    state = 75 if x["col_det"] < -0.208782196 else 76
                                    if state == 75:
                                        return -0.0671923682
                                    if state == 76:
                                        state = (
                                            95
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.0919418)
                                            else 96
                                        )
                                        if state == 95:
                                            return -0.026475165
                                        if state == 96:
                                            return 0.164506957
                            if state == 44:
                                state = 59 if x["col_peak"] < -0.285781384 else 60
                                if state == 59:
                                    return 0.0649390444
                                if state == 60:
                                    state = 77 if x["col_det"] < -0.187553406 else 78
                                    if state == 77:
                                        state = (
                                            97 if x["maggaia_med"] < 17.4412708 else 98
                                        )
                                        if state == 97:
                                            return 0.186129332
                                        if state == 98:
                                            state = (
                                                115
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.6345406)
                                                else 116
                                            )
                                            if state == 115:
                                                state = (
                                                    139
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.2283497)
                                                    else 140
                                                )
                                                if state == 139:
                                                    return 0.108446956
                                                if state == 140:
                                                    return -0.184907272
                                            if state == 116:
                                                return 0.0115316538
                                    if state == 78:
                                        state = (
                                            99
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 17.5995407)
                                            else 100
                                        )
                                        if state == 99:
                                            state = (
                                                117
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.2128792)
                                                else 118
                                            )
                                            if state == 117:
                                                state = (
                                                    143
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.0553513)
                                                    else 144
                                                )
                                                if state == 143:
                                                    state = (
                                                        171
                                                        if x["mag_peak"] < 17.8929214
                                                        else 172
                                                    )
                                                    if state == 171:
                                                        state = (
                                                            197
                                                            if x["distpsnr1_med"]
                                                            < 0.678662181
                                                            else 198
                                                        )
                                                        if state == 197:
                                                            return 0.0319749974
                                                        if state == 198:
                                                            return -0.167263925
                                                    if state == 172:
                                                        state = (
                                                            199
                                                            if x["distpsnr1_med"]
                                                            < 0.678662181
                                                            else 200
                                                        )
                                                        if state == 199:
                                                            return 0.0128015811
                                                        if state == 200:
                                                            return -0.17114307
                                                if state == 144:
                                                    return 0.0261123218
                                            if state == 118:
                                                return 0.0233802944
                                        if state == 100:
                                            state = (
                                                119
                                                if x["mag_peak"] < 18.5628719
                                                else 120
                                            )
                                            if state == 119:
                                                state = (
                                                    147
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.7641487)
                                                    else 148
                                                )
                                                if state == 147:
                                                    state = (
                                                        175
                                                        if x["mag_peak"] < 18.163271
                                                        else 176
                                                    )
                                                    if state == 175:
                                                        return -0.149323404
                                                    if state == 176:
                                                        return 0.0310524218
                                                if state == 148:
                                                    return 0.101595782
                                            if state == 120:
                                                state = (
                                                    149
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.3971481)
                                                    else 150
                                                )
                                                if state == 149:
                                                    return -0.000992843998
                                                if state == 150:
                                                    return -0.25252369
                        if state == 28:
                            state = (
                                45
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0126041993)
                                else 46
                            )
                            if state == 45:
                                state = (
                                    61
                                    if np.isnan(x["col_peak"])
                                    or (x["col_peak"] < 0.229323387)
                                    else 62
                                )
                                if state == 61:
                                    return 0.0658818036
                                if state == 62:
                                    return -0.0839469582
                            if state == 46:
                                state = 63 if x["col_peak"] < -0.194995403 else 64
                                if state == 63:
                                    return 0.123202384
                                if state == 64:
                                    state = 79 if x["col_det"] < 0.943312645 else 80
                                    if state == 79:
                                        return 0.06192296
                                    if state == 80:
                                        state = (
                                            103
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.7759438)
                                            else 104
                                        )
                                        if state == 103:
                                            state = (
                                                121
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.3068542)
                                                else 122
                                            )
                                            if state == 121:
                                                state = (
                                                    151
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.624649)
                                                    else 152
                                                )
                                                if state == 151:
                                                    state = (
                                                        181
                                                        if x["mag_peak"] < 18.0748825
                                                        else 182
                                                    )
                                                    if state == 181:
                                                        return -0.0852340311
                                                    if state == 182:
                                                        state = (
                                                            209
                                                            if x["distpsnr1_med"]
                                                            < 0.240813553
                                                            else 210
                                                        )
                                                        if state == 209:
                                                            return -0.0399011895
                                                        if state == 210:
                                                            return 0.130606785
                                                if state == 152:
                                                    return -0.0949477702
                                            if state == 122:
                                                state = (
                                                    153
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.835701)
                                                    else 154
                                                )
                                                if state == 153:
                                                    return -0.25753057
                                                if state == 154:
                                                    return 0.0433206409
                                        if state == 104:
                                            state = (
                                                123
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 17.6343632)
                                                else 124
                                            )
                                            if state == 123:
                                                return -0.0704909116
                                            if state == 124:
                                                return 0.126377031
    elif num_booster == 53:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 0.112469688 else 2
            if state == 1:
                return -0.135205939
            if state == 2:
                state = (
                    5 if np.isnan(x["col_last"]) or (x["col_last"] < 0.385879993) else 6
                )
                if state == 5:
                    state = (
                        7
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 61.4970322)
                        else 8
                    )
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 53.6951599)
                            else 12
                        )
                        if state == 11:
                            state = (
                                19
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 17.9187584)
                                else 20
                            )
                            if state == 19:
                                state = (
                                    29
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.6437702)
                                    else 30
                                )
                                if state == 29:
                                    state = (
                                        45
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 3.47752142)
                                        else 46
                                    )
                                    if state == 45:
                                        state = (
                                            65
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.976000011)
                                            else 66
                                        )
                                        if state == 65:
                                            state = (
                                                95
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 2.85351181)
                                                else 96
                                            )
                                            if state == 95:
                                                state = (
                                                    135
                                                    if x["neargaia_med"] < 37.9096107
                                                    else 136
                                                )
                                                if state == 135:
                                                    return -0.100704618
                                                if state == 136:
                                                    return 0.0028690591
                                            if state == 96:
                                                return 0.0287657678
                                        if state == 66:
                                            state = (
                                                97
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.74570322)
                                                else 98
                                            )
                                            if state == 97:
                                                state = (
                                                    139
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 0.661829174)
                                                    else 140
                                                )
                                                if state == 139:
                                                    state = (
                                                        177
                                                        if x["neargaia_med"]
                                                        < 0.649042845
                                                        else 178
                                                    )
                                                    if state == 177:
                                                        return -0.0336413123
                                                    if state == 178:
                                                        return 0.0680769831
                                                if state == 140:
                                                    return -0.0352784954
                                            if state == 98:
                                                state = (
                                                    141
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 11.8303795)
                                                    else 142
                                                )
                                                if state == 141:
                                                    return 0.130567461
                                                if state == 142:
                                                    state = (
                                                        181
                                                        if x["neargaia_med"]
                                                        < 13.5338297
                                                        else 182
                                                    )
                                                    if state == 181:
                                                        return -0.124268822
                                                    if state == 182:
                                                        state = (
                                                            219
                                                            if x["col_det"]
                                                            < -0.159150451
                                                            else 220
                                                        )
                                                        if state == 219:
                                                            return -0.0429004431
                                                        if state == 220:
                                                            return 0.0951031372
                                    if state == 46:
                                        state = (
                                            67
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.980250001)
                                            else 68
                                        )
                                        if state == 67:
                                            state = (
                                                99
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 4.2533493)
                                                else 100
                                            )
                                            if state == 99:
                                                return -0.139209211
                                            if state == 100:
                                                state = (
                                                    143
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 14.6278639)
                                                    else 144
                                                )
                                                if state == 143:
                                                    return 0.0522922911
                                                if state == 144:
                                                    return -0.0901199654
                                        if state == 68:
                                            return -0.00916847959
                                if state == 30:
                                    state = (
                                        47
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.742086172)
                                        else 48
                                    )
                                    if state == 47:
                                        state = (
                                            69
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.966250002)
                                            else 70
                                        )
                                        if state == 69:
                                            state = (
                                                103
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.285384506)
                                                else 104
                                            )
                                            if state == 103:
                                                return 0.0590147115
                                            if state == 104:
                                                return -0.1116006
                                        if state == 70:
                                            state = (
                                                105
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.36599806)
                                                else 106
                                            )
                                            if state == 105:
                                                return -0.0285514798
                                            if state == 106:
                                                return 0.148431763
                                    if state == 48:
                                        state = (
                                            71
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.920249999)
                                            else 72
                                        )
                                        if state == 71:
                                            return 0.0157367997
                                        if state == 72:
                                            state = (
                                                109
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.33160019)
                                                else 110
                                            )
                                            if state == 109:
                                                state = (
                                                    153
                                                    if x["neargaia_med"] < 1.86742926
                                                    else 154
                                                )
                                                if state == 153:
                                                    return -0.197347686
                                                if state == 154:
                                                    state = (
                                                        193
                                                        if x["neargaia_med"]
                                                        < 11.6336107
                                                        else 194
                                                    )
                                                    if state == 193:
                                                        return 0.0743076652
                                                    if state == 194:
                                                        state = (
                                                            225
                                                            if np.isnan(x["col_det"])
                                                            or (
                                                                x["col_det"]
                                                                < 0.124150276
                                                            )
                                                            else 226
                                                        )
                                                        if state == 225:
                                                            return -0.140708447
                                                        if state == 226:
                                                            return 0.000366357184
                                            if state == 110:
                                                state = (
                                                    155
                                                    if x["neargaia_med"] < 8.44950199
                                                    else 156
                                                )
                                                if state == 155:
                                                    return -0.188227907
                                                if state == 156:
                                                    state = (
                                                        195
                                                        if x["neargaia_med"]
                                                        < 48.0172081
                                                        else 196
                                                    )
                                                    if state == 195:
                                                        state = (
                                                            227
                                                            if x["col_det"]
                                                            < 0.0169687271
                                                            else 228
                                                        )
                                                        if state == 227:
                                                            return -0.0531227924
                                                        if state == 228:
                                                            return 0.0932560787
                                                    if state == 196:
                                                        return -0.0849926472
                            if state == 20:
                                state = (
                                    31
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.8322067)
                                    else 32
                                )
                                if state == 31:
                                    state = (
                                        49
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.56664991)
                                        else 50
                                    )
                                    if state == 49:
                                        state = (
                                            73
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.971750021)
                                            else 74
                                        )
                                        if state == 73:
                                            state = (
                                                111
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.894346535)
                                                else 112
                                            )
                                            if state == 111:
                                                return -0.13293907
                                            if state == 112:
                                                return 0.0316022374
                                        if state == 74:
                                            state = (
                                                113
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.335050762)
                                                else 114
                                            )
                                            if state == 113:
                                                return -0.0688072965
                                            if state == 114:
                                                return 0.0788618475
                                    if state == 50:
                                        state = (
                                            75
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.954750001)
                                            else 76
                                        )
                                        if state == 75:
                                            return 0.0466045476
                                        if state == 76:
                                            state = (
                                                117
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 2.30666614)
                                                else 118
                                            )
                                            if state == 117:
                                                return -0.171736807
                                            if state == 118:
                                                return 0.0146606928
                                if state == 32:
                                    state = (
                                        51
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 5.86598635)
                                        else 52
                                    )
                                    if state == 51:
                                        state = (
                                            77
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.973249972)
                                            else 78
                                        )
                                        if state == 77:
                                            state = (
                                                119
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.264775276)
                                                else 120
                                            )
                                            if state == 119:
                                                return 0.0114839328
                                            if state == 120:
                                                state = (
                                                    169
                                                    if x["neargaia_med"] < 27.5573692
                                                    else 170
                                                )
                                                if state == 169:
                                                    return 0.163443565
                                                if state == 170:
                                                    return 0.00195895438
                                        if state == 78:
                                            state = (
                                                121
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.55667758)
                                                else 122
                                            )
                                            if state == 121:
                                                state = (
                                                    171
                                                    if x["neargaia_med"] < 41.7265663
                                                    else 172
                                                )
                                                if state == 171:
                                                    return 0.0526481122
                                                if state == 172:
                                                    return -0.134407535
                                            if state == 122:
                                                state = (
                                                    173
                                                    if x["neargaia_med"] < 13.1439362
                                                    else 174
                                                )
                                                if state == 173:
                                                    return -0.0584489293
                                                if state == 174:
                                                    return 0.192802772
                                    if state == 52:
                                        return -0.0338401124
                        if state == 12:
                            return 0.147045493
                    if state == 8:
                        state = 13 if x["neargaia_med"] < 64.2057648 else 14
                        if state == 13:
                            return -0.233691946
                        if state == 14:
                            state = 23 if x["mag_peak"] < 18.5625896 else 24
                            if state == 23:
                                return 0.168987915
                            if state == 24:
                                state = 35 if x["maggaia_med"] < 18.5129223 else 36
                                if state == 35:
                                    return -0.0752162114
                                if state == 36:
                                    return 0.0620753691
                if state == 6:
                    state = 9 if x["neargaia_med"] < 1.00998712 else 10
                    if state == 9:
                        return -0.0594631806
                    if state == 10:
                        state = 17 if x["neargaia_med"] < 9.80568123 else 18
                        if state == 17:
                            return 0.173277795
                        if state == 18:
                            state = (
                                27
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 18.6984291)
                                else 28
                            )
                            if state == 27:
                                state = 41 if x["maggaia_med"] < 19.5912361 else 42
                                if state == 41:
                                    state = (
                                        57
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.8633939)
                                        else 58
                                    )
                                    if state == 57:
                                        state = (
                                            83
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.979249954)
                                            else 84
                                        )
                                        if state == 83:
                                            state = (
                                                127
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.368890405)
                                                else 128
                                            )
                                            if state == 127:
                                                return 0.0672256649
                                            if state == 128:
                                                return -0.123981819
                                        if state == 84:
                                            return -0.0147573417
                                    if state == 58:
                                        state = (
                                            85
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.966749966)
                                            else 86
                                        )
                                        if state == 85:
                                            return -0.0546435937
                                        if state == 86:
                                            return 0.102999821
                                if state == 42:
                                    return 0.0847179741
                            if state == 28:
                                return -0.0397428535
    elif num_booster == 54:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.2334995) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distpsnr1_med"])
                    or (x["distpsnr1_med"] < 0.549478471)
                    else 4
                )
                if state == 3:
                    return -0.162809685
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.983250022)
                        else 8
                    )
                    if state == 7:
                        state = 13 if x["maggaia_med"] < 17.2786026 else 14
                        if state == 13:
                            return -0.152475134
                        if state == 14:
                            state = 23 if x["sgscore1_med"] < 0.0904256031 else 24
                            if state == 23:
                                state = 33 if x["mag_peak"] < 18.7165508 else 34
                                if state == 33:
                                    state = (
                                        47
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.709908724)
                                        else 48
                                    )
                                    if state == 47:
                                        return 0.0429225452
                                    if state == 48:
                                        state = (
                                            59 if x["col_last"] < 0.491456032 else 60
                                        )
                                        if state == 59:
                                            return 0.0545273013
                                        if state == 60:
                                            state = (
                                                73
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 16.7475014)
                                                else 74
                                            )
                                            if state == 73:
                                                state = (
                                                    95
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.715226054)
                                                    else 96
                                                )
                                                if state == 95:
                                                    return -0.298262358
                                                if state == 96:
                                                    return 0.0230694488
                                            if state == 74:
                                                return -0.0590736754
                                if state == 34:
                                    return 0.130180493
                            if state == 24:
                                return 0.124554127
                    if state == 8:
                        return -0.139675811
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.113708369 else 6
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.981750011)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 18.9108887)
                            else 18
                        )
                        if state == 17:
                            return -0.107535511
                        if state == 18:
                            state = (
                                25
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.00385416998)
                                else 26
                            )
                            if state == 25:
                                return 0.105856255
                            if state == 26:
                                return -0.0629440993
                    if state == 10:
                        return -0.146245107
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.963500023)
                        else 12
                    )
                    if state == 11:
                        state = 19 if x["maggaia_med"] < 16.0023899 else 20
                        if state == 19:
                            return 0.0814037025
                        if state == 20:
                            state = 27 if x["sgscore1_med"] < 0.00204166491 else 28
                            if state == 27:
                                return 0.0876000524
                            if state == 28:
                                state = (
                                    39
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 18.712574)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        51
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.61936951)
                                        else 52
                                    )
                                    if state == 51:
                                        state = (
                                            61
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.333711624)
                                            else 62
                                        )
                                        if state == 61:
                                            state = (
                                                75
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.6310005)
                                                else 76
                                            )
                                            if state == 75:
                                                state = (
                                                    99
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.23764873)
                                                    else 100
                                                )
                                                if state == 99:
                                                    return -0.0591505468
                                                if state == 100:
                                                    state = (
                                                        125
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.473999)
                                                        else 126
                                                    )
                                                    if state == 125:
                                                        return -0.0659984052
                                                    if state == 126:
                                                        return 0.133252546
                                            if state == 76:
                                                return -0.106643513
                                        if state == 62:
                                            return 0.0198770519
                                    if state == 52:
                                        return -0.159825861
                                if state == 40:
                                    return -0.0231443606
                    if state == 12:
                        state = 21 if x["maggaia_med"] < 14.4461384 else 22
                        if state == 21:
                            return -0.108005114
                        if state == 22:
                            state = 31 if x["sgscore1_med"] < 0.00095833349 else 32
                            if state == 31:
                                return -0.107558168
                            if state == 32:
                                state = (
                                    45
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 18.8398895)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        55
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.688045323)
                                        else 56
                                    )
                                    if state == 55:
                                        state = (
                                            65 if x["col_last"] < 0.0189905167 else 66
                                        )
                                        if state == 65:
                                            return 0.0122753298
                                        if state == 66:
                                            state = (
                                                81
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 21.574501)
                                                else 82
                                            )
                                            if state == 81:
                                                state = (
                                                    105
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.15959239)
                                                    else 106
                                                )
                                                if state == 105:
                                                    return -0.0729408562
                                                if state == 106:
                                                    return 0.140246093
                                            if state == 82:
                                                state = (
                                                    107
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.658147216)
                                                    else 108
                                                )
                                                if state == 107:
                                                    return -0.094032146
                                                if state == 108:
                                                    return 0.0806071982
                                    if state == 56:
                                        state = (
                                            67 if x["col_last"] < -0.172714233 else 68
                                        )
                                        if state == 67:
                                            return -0.0454874411
                                        if state == 68:
                                            state = (
                                                85
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.512001)
                                                else 86
                                            )
                                            if state == 85:
                                                state = (
                                                    111
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.55960512)
                                                    else 112
                                                )
                                                if state == 111:
                                                    state = (
                                                        131
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.0637512)
                                                        else 132
                                                    )
                                                    if state == 131:
                                                        state = (
                                                            151
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < -0.194478035
                                                            )
                                                            else 152
                                                        )
                                                        if state == 151:
                                                            return 0.111454971
                                                        if state == 152:
                                                            return -0.0517874211
                                                    if state == 132:
                                                        return -0.111942828
                                                if state == 112:
                                                    state = (
                                                        133
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 17.9389992)
                                                        else 134
                                                    )
                                                    if state == 133:
                                                        return -0.063816525
                                                    if state == 134:
                                                        return 0.12132106
                                            if state == 86:
                                                state = (
                                                    113
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.962777734)
                                                    else 114
                                                )
                                                if state == 113:
                                                    state = (
                                                        135
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 21.7154999)
                                                        else 136
                                                    )
                                                    if state == 135:
                                                        state = (
                                                            159
                                                            if x["col_peak"]
                                                            < 0.113852501
                                                            else 160
                                                        )
                                                        if state == 159:
                                                            return -0.0803706348
                                                        if state == 160:
                                                            return 0.0566859916
                                                    if state == 136:
                                                        return -0.172019407
                                                if state == 114:
                                                    state = (
                                                        137
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.0014992)
                                                        else 138
                                                    )
                                                    if state == 137:
                                                        return 0.104696907
                                                    if state == 138:
                                                        state = (
                                                            161
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < 0.0523672104
                                                            )
                                                            else 162
                                                        )
                                                        if state == 161:
                                                            return 0.0528839827
                                                        if state == 162:
                                                            return -0.028972581
                                if state == 46:
                                    state = (
                                        57
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.59416866)
                                        else 58
                                    )
                                    if state == 57:
                                        state = (
                                            69 if x["col_last"] < 0.365742683 else 70
                                        )
                                        if state == 69:
                                            return -0.0568205267
                                        if state == 70:
                                            state = (
                                                89
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.7275009)
                                                else 90
                                            )
                                            if state == 89:
                                                state = (
                                                    115
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.963937402)
                                                    else 116
                                                )
                                                if state == 115:
                                                    state = (
                                                        139
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.0924988)
                                                        else 140
                                                    )
                                                    if state == 139:
                                                        return 0.0369077548
                                                    if state == 140:
                                                        return -0.155718386
                                                if state == 116:
                                                    return 0.106084548
                                            if state == 90:
                                                state = (
                                                    117
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.10180426)
                                                    else 118
                                                )
                                                if state == 117:
                                                    state = (
                                                        141
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 19.4922485)
                                                        else 142
                                                    )
                                                    if state == 141:
                                                        return -0.0862913355
                                                    if state == 142:
                                                        state = (
                                                            163
                                                            if x["col_peak"]
                                                            < 3.35850239
                                                            else 164
                                                        )
                                                        if state == 163:
                                                            return -0.0357599966
                                                        if state == 164:
                                                            return 0.136861369
                                                if state == 118:
                                                    return 0.137328371
                                    if state == 58:
                                        state = (
                                            71 if x["col_last"] < 0.819818497 else 72
                                        )
                                        if state == 71:
                                            state = (
                                                91
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.3214989)
                                                else 92
                                            )
                                            if state == 91:
                                                return 0.063850522
                                            if state == 92:
                                                return -0.0796795487
                                        if state == 72:
                                            return -0.113884248
    elif num_booster == 55:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 0.649827957)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.12629032)
                    else 4
                )
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 37.7228317) else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.760357141)
                            else 16
                        )
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.678571224)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    45
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 29.9719963)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        63
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.6240005)
                                        else 64
                                    )
                                    if state == 63:
                                        state = (
                                            91
                                            if x["sgscore1_med"] < 0.102827199
                                            else 92
                                        )
                                        if state == 91:
                                            return 0.118508115
                                        if state == 92:
                                            return -0.103604257
                                    if state == 64:
                                        return -0.0830192342
                                if state == 46:
                                    return 0.049513869
                            if state == 30:
                                state = (
                                    47
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 11.9995136)
                                    else 48
                                )
                                if state == 47:
                                    return 0.0133071877
                                if state == 48:
                                    state = (
                                        69
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.6119995)
                                        else 70
                                    )
                                    if state == 69:
                                        state = (
                                            95
                                            if x["sgscore1_med"] < 0.0528690517
                                            else 96
                                        )
                                        if state == 95:
                                            return 0.0944247022
                                        if state == 96:
                                            return -0.122981787
                                    if state == 70:
                                        return -0.167880893
                        if state == 16:
                            state = (
                                31
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.954642892)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    49
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 18.974369)
                                    else 50
                                )
                                if state == 49:
                                    return 0.129091933
                                if state == 50:
                                    state = (
                                        71
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 17.7352486)
                                        else 72
                                    )
                                    if state == 71:
                                        return -0.0758849084
                                    if state == 72:
                                        state = (
                                            97
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0142232003)
                                            else 98
                                        )
                                        if state == 97:
                                            return 0.110419616
                                        if state == 98:
                                            return -0.0729114935
                            if state == 32:
                                return -0.0867982432
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.731666744)
                            else 18
                        )
                        if state == 17:
                            return -0.0291446876
                        if state == 18:
                            return -0.252651364
                if state == 4:
                    state = 9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.57844305) else 10
                    if state == 9:
                        return 0.0909577683
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.208333492)
                            else 20
                        )
                        if state == 19:
                            return -0.109921984
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.700952411)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    51
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 17.0291939)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        73
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.368)
                                        else 74
                                    )
                                    if state == 73:
                                        return 0.0384396724
                                    if state == 74:
                                        return -0.117119163
                                if state == 52:
                                    state = (
                                        75
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.9420013)
                                        else 76
                                    )
                                    if state == 75:
                                        state = (
                                            103
                                            if x["sgscore1_med"] < 0.0493511483
                                            else 104
                                        )
                                        if state == 103:
                                            state = (
                                                129
                                                if x["col_peak"] < 0.14082098
                                                else 130
                                            )
                                            if state == 129:
                                                return 0.102883965
                                            if state == 130:
                                                return -0.131361187
                                        if state == 104:
                                            return 0.127489284
                                    if state == 76:
                                        state = (
                                            105
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0126666501)
                                            else 106
                                        )
                                        if state == 105:
                                            return -0.126247063
                                        if state == 106:
                                            return 0.0556472875
                            if state == 36:
                                return 0.0513911545
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.741319656)
                    else 6
                )
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 9.05870438) else 12
                    )
                    if state == 11:
                        return -0.0261255559
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.571428597)
                            else 24
                        )
                        if state == 23:
                            return -0.0786228403
                        if state == 24:
                            state = (
                                41
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.768571496)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    55
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 11.9679165)
                                    else 56
                                )
                                if state == 55:
                                    return 0.213895634
                                if state == 56:
                                    state = (
                                        79
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 21.8535004)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            107
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0078125)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                135
                                                if x["col_peak"] < 0.0393447876
                                                else 136
                                            )
                                            if state == 135:
                                                return 0.0291916654
                                            if state == 136:
                                                state = (
                                                    153
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.578538597)
                                                    else 154
                                                )
                                                if state == 153:
                                                    state = (
                                                        169
                                                        if x["distpsnr1_med"]
                                                        < 0.0997312516
                                                        else 170
                                                    )
                                                    if state == 169:
                                                        return 0.0709977821
                                                    if state == 170:
                                                        state = (
                                                            189
                                                            if x["sgscore1_med"]
                                                            < 0.00218750001
                                                            else 190
                                                        )
                                                        if state == 189:
                                                            return 0.071254015
                                                        if state == 190:
                                                            return -0.0739343539
                                                if state == 154:
                                                    return -0.0946230367
                                        if state == 108:
                                            return 0.10891372
                                    if state == 80:
                                        return -0.0220971089
                            if state == 42:
                                state = (
                                    57
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 12.0145378)
                                    else 58
                                )
                                if state == 57:
                                    return 0.0536441542
                                if state == 58:
                                    state = (
                                        81
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.5302505)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            111
                                            if x["sgscore1_med"] < 0.00700000022
                                            else 112
                                        )
                                        if state == 111:
                                            return 0.126522467
                                        if state == 112:
                                            return -0.024738552
                                    if state == 82:
                                        return -0.0878311098
                if state == 6:
                    state = (
                        13 if np.isnan(x["t_lc"]) or (x["t_lc"] < 7.04211807) else 14
                    )
                    if state == 13:
                        return 0.125635281
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.403333187)
                            else 28
                        )
                        if state == 27:
                            return -0.116321154
                        if state == 28:
                            state = (
                                43
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.50690496)
                                else 44
                            )
                            if state == 43:
                                return 0.043714527
                            if state == 44:
                                state = (
                                    61
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 56.9836426)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        87
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 21.5209999)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            123
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.00485416967)
                                            else 124
                                        )
                                        if state == 123:
                                            state = (
                                                143
                                                if x["col_peak"] < -0.159108162
                                                else 144
                                            )
                                            if state == 143:
                                                return -0.0396979079
                                            if state == 144:
                                                state = (
                                                    161
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.36768961)
                                                    else 162
                                                )
                                                if state == 161:
                                                    state = (
                                                        175
                                                        if x["distpsnr1_med"]
                                                        < 1.23273087
                                                        else 176
                                                    )
                                                    if state == 175:
                                                        return 0.0918958783
                                                    if state == 176:
                                                        state = (
                                                            193
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.0036249999
                                                            )
                                                            else 194
                                                        )
                                                        if state == 193:
                                                            return -0.115132757
                                                        if state == 194:
                                                            return 0.0736425743
                                                if state == 162:
                                                    return 0.112173311
                                        if state == 124:
                                            state = (
                                                145
                                                if x["col_peak"] < 0.0447359085
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    163
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.07391691)
                                                    else 164
                                                )
                                                if state == 163:
                                                    return -0.052092053
                                                if state == 164:
                                                    state = (
                                                        181
                                                        if x["distpsnr1_med"]
                                                        < 4.66621017
                                                        else 182
                                                    )
                                                    if state == 181:
                                                        state = (
                                                            197
                                                            if x["sgscore1_med"]
                                                            < 0.0060416651
                                                            else 198
                                                        )
                                                        if state == 197:
                                                            return -0.137364745
                                                        if state == 198:
                                                            return 0.0567091927
                                                    if state == 182:
                                                        return 0.159504414
                                            if state == 146:
                                                state = (
                                                    165
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.19851923)
                                                    else 166
                                                )
                                                if state == 165:
                                                    state = (
                                                        183
                                                        if x["distpsnr1_med"]
                                                        < 1.02355134
                                                        else 184
                                                    )
                                                    if state == 183:
                                                        state = (
                                                            199
                                                            if x["sgscore1_med"]
                                                            < 0.113619
                                                            else 200
                                                        )
                                                        if state == 199:
                                                            return -0.132865205
                                                        if state == 200:
                                                            return 0.0381425433
                                                    if state == 184:
                                                        state = (
                                                            201
                                                            if x["sgscore1_med"]
                                                            < 0.00818154495
                                                            else 202
                                                        )
                                                        if state == 201:
                                                            return -0.168362707
                                                        if state == 202:
                                                            return 0.0390157104
                                                if state == 166:
                                                    state = (
                                                        185
                                                        if x["distpsnr1_med"]
                                                        < 3.98129106
                                                        else 186
                                                    )
                                                    if state == 185:
                                                        state = (
                                                            203
                                                            if x["sgscore1_med"]
                                                            < 0.26255399
                                                            else 204
                                                        )
                                                        if state == 203:
                                                            return 0.0501916781
                                                        if state == 204:
                                                            return -0.0525893793
                                                    if state == 186:
                                                        state = (
                                                            205
                                                            if x["sgscore1_med"]
                                                            < 0.0123541504
                                                            else 206
                                                        )
                                                        if state == 205:
                                                            return 0.0368988849
                                                        if state == 206:
                                                            return -0.144989118
                                    if state == 88:
                                        state = (
                                            125
                                            if x["sgscore1_med"] < 0.412961483
                                            else 126
                                        )
                                        if state == 125:
                                            return -0.130172685
                                        if state == 126:
                                            state = (
                                                147
                                                if x["col_peak"] < -0.0834789276
                                                else 148
                                            )
                                            if state == 147:
                                                return -0.11693617
                                            if state == 148:
                                                return 0.0663922429
                                if state == 62:
                                    return 0.0859211981
    elif num_booster == 56:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_last"]) or (x["col_last"] < 0.939619064) else 2
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 4.51287556 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.6058998)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 4.90205002)
                            else 16
                        )
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 18.1645508)
                                else 28
                            )
                            if state == 27:
                                state = 41 if x["sgscore1_med"] < 0.00145833497 else 42
                                if state == 41:
                                    state = (
                                        61
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.9784355)
                                        else 62
                                    )
                                    if state == 61:
                                        return 0.0308336839
                                    if state == 62:
                                        return -0.207832187
                                if state == 42:
                                    state = (
                                        63
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.2767525)
                                        else 64
                                    )
                                    if state == 63:
                                        state = (
                                            85
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.17379)
                                            else 86
                                        )
                                        if state == 85:
                                            state = (
                                                111
                                                if x["col_det"] < -0.222620964
                                                else 112
                                            )
                                            if state == 111:
                                                state = (
                                                    147
                                                    if x["neargaia_med"] < 61.8114929
                                                    else 148
                                                )
                                                if state == 147:
                                                    return 0.153452769
                                                if state == 148:
                                                    state = (
                                                        185
                                                        if x["sgscore1_med"]
                                                        < 0.006645835
                                                        else 186
                                                    )
                                                    if state == 185:
                                                        return 0.0996459201
                                                    if state == 186:
                                                        return -0.0715559199
                                            if state == 112:
                                                state = (
                                                    149
                                                    if x["neargaia_med"] < 36.6490097
                                                    else 150
                                                )
                                                if state == 149:
                                                    state = (
                                                        187
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.00281250011
                                                        )
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        return 0.070877105
                                                    if state == 188:
                                                        state = (
                                                            221
                                                            if x["distpsnr1_med"]
                                                            < 1.09697556
                                                            else 222
                                                        )
                                                        if state == 221:
                                                            return -0.0423722677
                                                        if state == 222:
                                                            return -0.183776319
                                                if state == 150:
                                                    state = (
                                                        189
                                                        if x["sgscore1_med"]
                                                        < 0.121815503
                                                        else 190
                                                    )
                                                    if state == 189:
                                                        state = (
                                                            223
                                                            if x["distpsnr1_med"]
                                                            < 0.274134547
                                                            else 224
                                                        )
                                                        if state == 223:
                                                            return -0.0801125169
                                                        if state == 224:
                                                            return 0.121777885
                                                    if state == 190:
                                                        state = (
                                                            225
                                                            if x["distpsnr1_med"]
                                                            < 1.5874393
                                                            else 226
                                                        )
                                                        if state == 225:
                                                            return -0.102873534
                                                        if state == 226:
                                                            return 0.0365768224
                                        if state == 86:
                                            state = (
                                                113
                                                if x["col_det"] < -0.199872017
                                                else 114
                                            )
                                            if state == 113:
                                                return 0.0269097015
                                            if state == 114:
                                                state = (
                                                    151
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 36.5582352)
                                                    else 152
                                                )
                                                if state == 151:
                                                    return -0.224534243
                                                if state == 152:
                                                    return 0.0504553355
                                    if state == 64:
                                        state = (
                                            87
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.526186)
                                            else 88
                                        )
                                        if state == 87:
                                            state = (
                                                115
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < 0.190923691)
                                                else 116
                                            )
                                            if state == 115:
                                                state = (
                                                    153
                                                    if np.isnan(x["neargaia_med"])
                                                    or (x["neargaia_med"] < 22.4601116)
                                                    else 154
                                                )
                                                if state == 153:
                                                    state = (
                                                        191
                                                        if x["sgscore1_med"]
                                                        < 0.249266505
                                                        else 192
                                                    )
                                                    if state == 191:
                                                        state = (
                                                            227
                                                            if x["distpsnr1_med"]
                                                            < 0.451360106
                                                            else 228
                                                        )
                                                        if state == 227:
                                                            return -0.045467861
                                                        if state == 228:
                                                            return 0.146167323
                                                    if state == 192:
                                                        return 0.0157934707
                                                if state == 154:
                                                    state = (
                                                        193
                                                        if x["sgscore1_med"]
                                                        < 0.0166250002
                                                        else 194
                                                    )
                                                    if state == 193:
                                                        return -0.081200026
                                                    if state == 194:
                                                        return 0.105462104
                                            if state == 116:
                                                return -0.0104900245
                                        if state == 88:
                                            return -0.0900150239
                            if state == 28:
                                state = 43 if x["sgscore1_med"] < 0.120351501 else 44
                                if state == 43:
                                    state = (
                                        65
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.3688469)
                                        else 66
                                    )
                                    if state == 65:
                                        state = (
                                            89
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.6268368)
                                            else 90
                                        )
                                        if state == 89:
                                            state = (
                                                117
                                                if x["col_det"] < -0.0468096733
                                                else 118
                                            )
                                            if state == 117:
                                                return -0.012361859
                                            if state == 118:
                                                return 0.138163239
                                        if state == 90:
                                            state = (
                                                119
                                                if x["col_det"] < -0.338736534
                                                else 120
                                            )
                                            if state == 119:
                                                return -0.134158209
                                            if state == 120:
                                                state = (
                                                    159
                                                    if x["neargaia_med"] < 53.8891678
                                                    else 160
                                                )
                                                if state == 159:
                                                    state = (
                                                        199
                                                        if x["sgscore1_med"]
                                                        < 0.00262499996
                                                        else 200
                                                    )
                                                    if state == 199:
                                                        return 0.12884748
                                                    if state == 200:
                                                        state = (
                                                            241
                                                            if x["distpsnr1_med"]
                                                            < 1.49817348
                                                            else 242
                                                        )
                                                        if state == 241:
                                                            return 0.0398925804
                                                        if state == 242:
                                                            return -0.0812453032
                                                if state == 160:
                                                    return 0.116028585
                                    if state == 66:
                                        state = (
                                            91
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.4392509)
                                            else 92
                                        )
                                        if state == 91:
                                            state = (
                                                121
                                                if x["col_det"] < 0.434972763
                                                else 122
                                            )
                                            if state == 121:
                                                return -0.0177103393
                                            if state == 122:
                                                return 0.19701457
                                        if state == 92:
                                            return 0.0291380379
                                if state == 44:
                                    state = (
                                        67
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.0525932)
                                        else 68
                                    )
                                    if state == 67:
                                        state = (
                                            93
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.9360161)
                                            else 94
                                        )
                                        if state == 93:
                                            state = (
                                                125
                                                if x["col_det"] < -0.0824098587
                                                else 126
                                            )
                                            if state == 125:
                                                return 0.0962632746
                                            if state == 126:
                                                state = (
                                                    167
                                                    if x["neargaia_med"] < 13.598978
                                                    else 168
                                                )
                                                if state == 167:
                                                    state = (
                                                        205
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.175543502
                                                        )
                                                        else 206
                                                    )
                                                    if state == 205:
                                                        return 0.0634105429
                                                    if state == 206:
                                                        return -0.148492351
                                                if state == 168:
                                                    state = (
                                                        207
                                                        if x["sgscore1_med"]
                                                        < 0.509500027
                                                        else 208
                                                    )
                                                    if state == 207:
                                                        return 0.120509192
                                                    if state == 208:
                                                        return -0.0475206934
                                        if state == 94:
                                            return 0.0967260748
                                    if state == 68:
                                        state = (
                                            95
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.1749306)
                                            else 96
                                        )
                                        if state == 95:
                                            return -0.161902159
                                        if state == 96:
                                            state = (
                                                129
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.14687252)
                                                else 130
                                            )
                                            if state == 129:
                                                state = (
                                                    169
                                                    if x["neargaia_med"] < 8.81546021
                                                    else 170
                                                )
                                                if state == 169:
                                                    return 0.0506369956
                                                if state == 170:
                                                    return -0.115765713
                                            if state == 130:
                                                return 0.0540596396
                        if state == 16:
                            return -0.187796861
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.184072256)
                            else 18
                        )
                        if state == 17:
                            return 0.017484013
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 18.7929726)
                                else 30
                            )
                            if state == 29:
                                return -0.107844517
                            if state == 30:
                                state = (
                                    47
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.00682440493)
                                    else 48
                                )
                                if state == 47:
                                    return -0.107714474
                                if state == 48:
                                    state = (
                                        73
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.2205048)
                                        else 74
                                    )
                                    if state == 73:
                                        state = (
                                            101
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 20.0211277)
                                            else 102
                                        )
                                        if state == 101:
                                            state = (
                                                135
                                                if x["col_det"] < 0.140773773
                                                else 136
                                            )
                                            if state == 135:
                                                return -0.0870776027
                                            if state == 136:
                                                return 0.0589690246
                                        if state == 102:
                                            return -0.0820477158
                                    if state == 74:
                                        return 0.0441321321
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0134773)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 9.06095409)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 18.1781998)
                                else 32
                            )
                            if state == 31:
                                return 0.194491372
                            if state == 32:
                                state = (
                                    51
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.695366025)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        75
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 17.9801064)
                                        else 76
                                    )
                                    if state == 75:
                                        return 0.151208088
                                    if state == 76:
                                        state = (
                                            103
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.7298279)
                                            else 104
                                        )
                                        if state == 103:
                                            return -0.0353643857
                                        if state == 104:
                                            state = (
                                                139
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.299348354)
                                                else 140
                                            )
                                            if state == 139:
                                                return 0.175943092
                                            if state == 140:
                                                return -0.0550023019
                                if state == 52:
                                    return -0.0444148816
                        if state == 20:
                            return 0.00124748133
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 1.77575278)
                            else 22
                        )
                        if state == 21:
                            state = (
                                35
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 16.3812389)
                                else 36
                            )
                            if state == 35:
                                return -0.0306967571
                            if state == 36:
                                return 0.119880751
                        if state == 22:
                            state = 37 if x["maggaia_med"] < 18.1449318 else 38
                            if state == 37:
                                return 0.0376339369
                            if state == 38:
                                state = (
                                    59
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.00352083007)
                                    else 60
                                )
                                if state == 59:
                                    return 0.0670761019
                                if state == 60:
                                    state = (
                                        83
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.4748306)
                                        else 84
                                    )
                                    if state == 83:
                                        return -0.14098303
                                    if state == 84:
                                        state = (
                                            109
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.5148201)
                                            else 110
                                        )
                                        if state == 109:
                                            return 0.0460001752
                                        if state == 110:
                                            state = (
                                                145
                                                if x["col_det"] < -0.181256801
                                                else 146
                                            )
                                            if state == 145:
                                                return 0.0532236733
                                            if state == 146:
                                                state = (
                                                    183
                                                    if x["neargaia_med"] < 11.6595802
                                                    else 184
                                                )
                                                if state == 183:
                                                    return 0.00790119357
                                                if state == 184:
                                                    state = (
                                                        219
                                                        if x["sgscore1_med"]
                                                        < 0.267831981
                                                        else 220
                                                    )
                                                    if state == 219:
                                                        return -0.118594542
                                                    if state == 220:
                                                        state = (
                                                            251
                                                            if x["distpsnr1_med"]
                                                            < 8.14615631
                                                            else 252
                                                        )
                                                        if state == 251:
                                                            return 0.0685585663
                                                        if state == 252:
                                                            return -0.116627619
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 1.02200341)
                    else 6
                )
                if state == 5:
                    return 0.050388623
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.1793709)
                        else 14
                    )
                    if state == 13:
                        return 0.000362666062
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 1.51233697)
                            else 26
                        )
                        if state == 25:
                            return -0.281185389
                        if state == 26:
                            return -0.041781377
    elif num_booster == 57:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 0.228492394 else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 37.0324173) else 4
                if state == 3:
                    state = 7 if x["neargaia_med"] < 0.184773356 else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.180042386)
                            else 16
                        )
                        if state == 15:
                            return -0.0307450946
                        if state == 16:
                            state = 29 if x["neargaia_med"] < 0.112815864 else 30
                            if state == 29:
                                return -0.0605837889
                            if state == 30:
                                return 0.124245875
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.145539582)
                            else 18
                        )
                        if state == 17:
                            return 0.0355346799
                        if state == 18:
                            state = 31 if x["neargaia_med"] < 15.2522297 else 32
                            if state == 31:
                                return -0.130221054
                            if state == 32:
                                state = (
                                    53
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.8994751)
                                    else 54
                                )
                                if state == 53:
                                    return -0.0726989731
                                if state == 54:
                                    return 0.0940159634
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 15.0737906)
                        else 10
                    )
                    if state == 9:
                        return -0.211713225
                    if state == 10:
                        return 0.00400846731
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 24.0966301) else 6
                if state == 5:
                    state = 11 if x["neargaia_med"] < 1.47886324 else 12
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.74479568)
                            else 22
                        )
                        if state == 21:
                            return -0.0235798694
                        if state == 22:
                            state = 37 if x["neargaia_med"] < 0.729093134 else 38
                            if state == 37:
                                return 0.16382511
                            if state == 38:
                                state = 57 if x["maggaia_med"] < 18.7930412 else 58
                                if state == 57:
                                    return 0.0917865336
                                if state == 58:
                                    return -0.0522703119
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 1.8623091)
                            else 24
                        )
                        if state == 23:
                            state = 39 if x["neargaia_med"] < 38.6015472 else 40
                            if state == 39:
                                state = 59 if x["maggaia_med"] < 17.4604111 else 60
                                if state == 59:
                                    state = 85 if x["maggaia_med"] < 14.4459991 else 86
                                    if state == 85:
                                        return -0.109794401
                                    if state == 86:
                                        state = (
                                            119
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.738095045)
                                            else 120
                                        )
                                        if state == 119:
                                            state = (
                                                149
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.665833235)
                                                else 150
                                            )
                                            if state == 149:
                                                state = (
                                                    181
                                                    if x["distpsnr1_med"] < 1.12977898
                                                    else 182
                                                )
                                                if state == 181:
                                                    return 0.109937832
                                                if state == 182:
                                                    return -0.05624355
                                            if state == 150:
                                                return -0.0771790817
                                        if state == 120:
                                            return 0.104917526
                                if state == 60:
                                    state = 87 if x["maggaia_med"] < 19.2674866 else 88
                                    if state == 87:
                                        return -0.132455841
                                    if state == 88:
                                        state = (
                                            121
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.76666683)
                                            else 122
                                        )
                                        if state == 121:
                                            state = (
                                                153
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.546666861)
                                                else 154
                                            )
                                            if state == 153:
                                                return -0.0122629181
                                            if state == 154:
                                                state = (
                                                    183
                                                    if x["distpsnr1_med"] < 1.86461544
                                                    else 184
                                                )
                                                if state == 183:
                                                    state = (
                                                        207
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 20.5657501)
                                                        else 208
                                                    )
                                                    if state == 207:
                                                        return -0.213884205
                                                    if state == 208:
                                                        return -0.00492579909
                                                if state == 184:
                                                    return 0.091224581
                                        if state == 122:
                                            state = (
                                                155
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.902142823)
                                                else 156
                                            )
                                            if state == 155:
                                                return 0.153694659
                                            if state == 156:
                                                return -0.0379922837
                            if state == 40:
                                state = (
                                    61
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.8911247)
                                    else 62
                                )
                                if state == 61:
                                    state = (
                                        89
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 17.9418373)
                                        else 90
                                    )
                                    if state == 89:
                                        state = (
                                            123
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.493333161)
                                            else 124
                                        )
                                        if state == 123:
                                            return -0.098364599
                                        if state == 124:
                                            state = (
                                                159
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.699285507)
                                                else 160
                                            )
                                            if state == 159:
                                                state = (
                                                    189
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 1.51227355)
                                                    else 190
                                                )
                                                if state == 189:
                                                    return 0.0688028187
                                                if state == 190:
                                                    return -0.0626622736
                                            if state == 160:
                                                return 0.0951129869
                                    if state == 90:
                                        return 0.0983513966
                                if state == 62:
                                    state = 91 if x["maggaia_med"] < 20.4119263 else 92
                                    if state == 91:
                                        return -0.138715327
                                    if state == 92:
                                        return 0.037332058
                        if state == 24:
                            state = 41 if x["neargaia_med"] < 26.3777695 else 42
                            if state == 41:
                                state = 63 if x["maggaia_med"] < 20.1856232 else 64
                                if state == 63:
                                    state = 93 if x["maggaia_med"] < 15.5831375 else 94
                                    if state == 93:
                                        return -0.0784976855
                                    if state == 94:
                                        state = (
                                            127
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.95142889)
                                            else 128
                                        )
                                        if state == 127:
                                            state = (
                                                161
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.465833336)
                                                else 162
                                            )
                                            if state == 161:
                                                return -0.0587477311
                                            if state == 162:
                                                state = (
                                                    195
                                                    if x["distpsnr1_med"] < 5.68455887
                                                    else 196
                                                )
                                                if state == 195:
                                                    state = (
                                                        219
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.9265003)
                                                        else 220
                                                    )
                                                    if state == 219:
                                                        state = (
                                                            233
                                                            if np.isnan(x["col_det"])
                                                            or (
                                                                x["col_det"]
                                                                < -0.0860643387
                                                            )
                                                            else 234
                                                        )
                                                        if state == 233:
                                                            return 0.0694952309
                                                        if state == 234:
                                                            return -0.0736736134
                                                    if state == 220:
                                                        state = (
                                                            235
                                                            if x["col_det"]
                                                            < -0.0873308182
                                                            else 236
                                                        )
                                                        if state == 235:
                                                            return 0.0129046356
                                                        if state == 236:
                                                            return 0.176375657
                                                if state == 196:
                                                    state = (
                                                        221
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 22.5494995)
                                                        else 222
                                                    )
                                                    if state == 221:
                                                        state = (
                                                            237
                                                            if np.isnan(x["col_det"])
                                                            or (
                                                                x["col_det"]
                                                                < 0.0538234711
                                                            )
                                                            else 238
                                                        )
                                                        if state == 237:
                                                            return -0.113234371
                                                        if state == 238:
                                                            return 0.107196301
                                                    if state == 222:
                                                        return 0.0706689879
                                        if state == 128:
                                            return -0.0889497772
                                if state == 64:
                                    return -0.152837783
                            if state == 42:
                                state = (
                                    65
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.8742332)
                                    else 66
                                )
                                if state == 65:
                                    state = 95 if x["maggaia_med"] < 16.4610462 else 96
                                    if state == 95:
                                        return -0.129213452
                                    if state == 96:
                                        state = (
                                            131
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.535000145)
                                            else 132
                                        )
                                        if state == 131:
                                            state = (
                                                165
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.506904721)
                                                else 166
                                            )
                                            if state == 165:
                                                state = (
                                                    197
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 8.75913811)
                                                    else 198
                                                )
                                                if state == 197:
                                                    return -0.102877937
                                                if state == 198:
                                                    return 0.0784055069
                                            if state == 166:
                                                return -0.141648829
                                        if state == 132:
                                            state = (
                                                167
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.720714331)
                                                else 168
                                            )
                                            if state == 167:
                                                state = (
                                                    199
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 8.54924297)
                                                    else 200
                                                )
                                                if state == 199:
                                                    state = (
                                                        223
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.0100002)
                                                        else 224
                                                    )
                                                    if state == 223:
                                                        return -0.0813335478
                                                    if state == 224:
                                                        return 0.12916334
                                                if state == 200:
                                                    return -0.14635098
                                            if state == 168:
                                                return -0.058413364
                                if state == 66:
                                    return 0.144428581
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["neargaia_med"])
                        or (x["neargaia_med"] < 0.672370434)
                        else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.711328506)
                            else 26
                        )
                        if state == 25:
                            return 0.0396777727
                        if state == 26:
                            state = 45 if x["neargaia_med"] < 0.650448203 else 46
                            if state == 45:
                                return -0.156629577
                            if state == 46:
                                return -0.00645196112
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 1.40783978)
                            else 28
                        )
                        if state == 27:
                            state = 47 if x["neargaia_med"] < 22.8309689 else 48
                            if state == 47:
                                state = 71 if x["maggaia_med"] < 18.7455368 else 72
                                if state == 71:
                                    return 0.159430847
                                if state == 72:
                                    state = (
                                        103 if x["maggaia_med"] < 19.5730591 else 104
                                    )
                                    if state == 103:
                                        state = (
                                            133
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.690000176)
                                            else 134
                                        )
                                        if state == 133:
                                            return -0.132256866
                                        if state == 134:
                                            return 0.0428776443
                                    if state == 104:
                                        return 0.112953298
                            if state == 48:
                                state = 73 if x["maggaia_med"] < 19.6913605 else 74
                                if state == 73:
                                    state = (
                                        105 if x["maggaia_med"] < 19.5966339 else 106
                                    )
                                    if state == 105:
                                        state = (
                                            135
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.627500057)
                                            else 136
                                        )
                                        if state == 135:
                                            state = (
                                                171
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.563928723)
                                                else 172
                                            )
                                            if state == 171:
                                                return 0.0611062348
                                            if state == 172:
                                                return -0.109143496
                                        if state == 136:
                                            return 0.109786212
                                    if state == 106:
                                        return 0.14053975
                                if state == 74:
                                    return -0.06161936
                        if state == 28:
                            state = 49 if x["neargaia_med"] < 6.66806459 else 50
                            if state == 49:
                                state = 75 if x["maggaia_med"] < 18.3850746 else 76
                                if state == 75:
                                    return 0.0250732023
                                if state == 76:
                                    state = (
                                        111 if x["maggaia_med"] < 19.8187428 else 112
                                    )
                                    if state == 111:
                                        state = (
                                            141
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.636190474)
                                            else 142
                                        )
                                        if state == 141:
                                            return -0.103220642
                                        if state == 142:
                                            return 0.0473313071
                                    if state == 112:
                                        return -0.144056097
                            if state == 50:
                                state = 77 if x["maggaia_med"] < 15.603734 else 78
                                if state == 77:
                                    state = (
                                        113 if x["maggaia_med"] < 14.0823374 else 114
                                    )
                                    if state == 113:
                                        return 0.0513051003
                                    if state == 114:
                                        return -0.130520552
                                if state == 78:
                                    state = (
                                        115 if x["maggaia_med"] < 20.2907104 else 116
                                    )
                                    if state == 115:
                                        state = (
                                            145
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.741904676)
                                            else 146
                                        )
                                        if state == 145:
                                            state = (
                                                175
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.707142949)
                                                else 176
                                            )
                                            if state == 175:
                                                state = (
                                                    203
                                                    if x["distpsnr1_med"] < 8.15908527
                                                    else 204
                                                )
                                                if state == 203:
                                                    state = (
                                                        227
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.4575005)
                                                        else 228
                                                    )
                                                    if state == 227:
                                                        return -0.098423548
                                                    if state == 228:
                                                        state = (
                                                            247
                                                            if x["col_det"]
                                                            < -0.0998678207
                                                            else 248
                                                        )
                                                        if state == 247:
                                                            return -0.00974276569
                                                        if state == 248:
                                                            return 0.167486012
                                                if state == 204:
                                                    return -0.0453593023
                                            if state == 176:
                                                state = (
                                                    205
                                                    if x["distpsnr1_med"] < 2.71264648
                                                    else 206
                                                )
                                                if state == 205:
                                                    return -0.148684159
                                                if state == 206:
                                                    return 0.0490786843
                                        if state == 146:
                                            return 0.0900607482
                                    if state == 116:
                                        state = (
                                            147
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.589642882)
                                            else 148
                                        )
                                        if state == 147:
                                            return -0.101048626
                                        if state == 148:
                                            state = (
                                                179
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.724642992)
                                                else 180
                                            )
                                            if state == 179:
                                                return 0.106338024
                                            if state == 180:
                                                return -0.096421659
    elif num_booster == 58:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.651818275) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.115356952)
                    else 4
                )
                if state == 3:
                    return 0.0800816268
                if state == 4:
                    state = 7 if x["maggaia_med"] < 14.8518419 else 8
                    if state == 7:
                        return 0.129140809
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.7829056)
                            else 14
                        )
                        if state == 13:
                            state = (
                                23
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 1.48500001)
                                else 24
                            )
                            if state == 23:
                                return -0.0401136354
                            if state == 24:
                                state = (
                                    39
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 20.3273296)
                                    else 40
                                )
                                if state == 39:
                                    return 0.107713595
                                if state == 40:
                                    return -0.0735298246
                        if state == 14:
                            state = (
                                25
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 4.98894691)
                                else 26
                            )
                            if state == 25:
                                state = 41 if x["maggaia_med"] < 18.6666603 else 42
                                if state == 41:
                                    return -0.164958492
                                if state == 42:
                                    return -0.0591273978
                            if state == 26:
                                state = (
                                    43
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.9120789)
                                    else 44
                                )
                                if state == 43:
                                    state = (
                                        65
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.0224953)
                                        else 66
                                    )
                                    if state == 65:
                                        return 0.00441391999
                                    if state == 66:
                                        state = (
                                            93
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.571547568)
                                            else 94
                                        )
                                        if state == 93:
                                            return 0.0512816235
                                        if state == 94:
                                            return -0.150205359
                                if state == 44:
                                    return 0.0316145495
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.7442168)
                    else 6
                )
                if state == 5:
                    state = 9 if x["maggaia_med"] < 18.1419449 else 10
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.2307625)
                            else 16
                        )
                        if state == 15:
                            return -0.049826812
                        if state == 16:
                            return 0.159168363
                    if state == 10:
                        return 0.0119936327
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 19.4600811)
                        else 12
                    )
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4512863)
                            else 20
                        )
                        if state == 19:
                            state = (
                                29
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.0001564)
                                else 30
                            )
                            if state == 29:
                                return -0.0218981728
                            if state == 30:
                                state = 49 if x["maggaia_med"] < 17.1172829 else 50
                                if state == 49:
                                    state = (
                                        75
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 17.9490891)
                                        else 76
                                    )
                                    if state == 75:
                                        return 0.0628614277
                                    if state == 76:
                                        state = (
                                            105
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.59821403)
                                            else 106
                                        )
                                        if state == 105:
                                            return 0.0759990811
                                        if state == 106:
                                            state = (
                                                135
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.934642911)
                                                else 136
                                            )
                                            if state == 135:
                                                state = (
                                                    157
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.29186392)
                                                    else 158
                                                )
                                                if state == 157:
                                                    return 0.0758297965
                                                if state == 158:
                                                    return -0.15819025
                                            if state == 136:
                                                return 0.0228541046
                                if state == 50:
                                    state = (
                                        77
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.4333992)
                                        else 78
                                    )
                                    if state == 77:
                                        state = (
                                            107
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.564285874)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                137
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.240833491)
                                                else 138
                                            )
                                            if state == 137:
                                                return -0.0633419082
                                            if state == 138:
                                                state = (
                                                    161
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.03641748)
                                                    else 162
                                                )
                                                if state == 161:
                                                    return -0.081908606
                                                if state == 162:
                                                    state = (
                                                        185
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.40308022
                                                        )
                                                        else 186
                                                    )
                                                    if state == 185:
                                                        return 0.104503989
                                                    if state == 186:
                                                        state = (
                                                            205
                                                            if x["maggaia_med"]
                                                            < 18.824316
                                                            else 206
                                                        )
                                                        if state == 205:
                                                            return -0.120743349
                                                        if state == 206:
                                                            return 0.122709349
                                        if state == 108:
                                            state = (
                                                139
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.929642856)
                                                else 140
                                            )
                                            if state == 139:
                                                state = (
                                                    163
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 4.70824051)
                                                    else 164
                                                )
                                                if state == 163:
                                                    state = (
                                                        187
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.765944242
                                                        )
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        return -0.0129738115
                                                    if state == 188:
                                                        state = (
                                                            209
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 18.772707
                                                            )
                                                            else 210
                                                        )
                                                        if state == 209:
                                                            return 0.132372975
                                                        if state == 210:
                                                            return -0.00470215688
                                                if state == 164:
                                                    return -0.0511403494
                                            if state == 140:
                                                return 0.196397588
                                    if state == 78:
                                        return -0.0197256207
                        if state == 20:
                            state = (
                                31
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 8.03011513)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    51
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.8780937)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        79
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 20.3896618)
                                        else 80
                                    )
                                    if state == 79:
                                        state = (
                                            109
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.589999974)
                                            else 110
                                        )
                                        if state == 109:
                                            state = (
                                                141
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.423333406)
                                                else 142
                                            )
                                            if state == 141:
                                                return -0.00148526987
                                            if state == 142:
                                                return -0.190021828
                                        if state == 110:
                                            state = (
                                                143
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.600000083)
                                                else 144
                                            )
                                            if state == 143:
                                                return 0.0401100069
                                            if state == 144:
                                                state = (
                                                    169
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.90871644)
                                                    else 170
                                                )
                                                if state == 169:
                                                    state = (
                                                        191
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.88516402
                                                        )
                                                        else 192
                                                    )
                                                    if state == 191:
                                                        return -0.0641766712
                                                    if state == 192:
                                                        state = (
                                                            213
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 18.5208187
                                                            )
                                                            else 214
                                                        )
                                                        if state == 213:
                                                            return 0.112413883
                                                        if state == 214:
                                                            return -0.0970873833
                                                if state == 170:
                                                    return -0.106195621
                                    if state == 80:
                                        return 0.0419800058
                                if state == 52:
                                    state = (
                                        81
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.9001274)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            113
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.823928595)
                                            else 114
                                        )
                                        if state == 113:
                                            return 0.111658558
                                        if state == 114:
                                            return -0.04561501
                                    if state == 82:
                                        return -0.0538577363
                            if state == 32:
                                state = 53 if x["maggaia_med"] < 17.086895 else 54
                                if state == 53:
                                    return -0.0683754086
                                if state == 54:
                                    return 0.0894484296
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.6216469)
                            else 22
                        )
                        if state == 21:
                            state = (
                                33
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.99928236)
                                else 34
                            )
                            if state == 33:
                                return 0.123953581
                            if state == 34:
                                state = 57 if x["maggaia_med"] < 20.1092148 else 58
                                if state == 57:
                                    return -0.0784609243
                                if state == 58:
                                    return 0.0950668454
                        if state == 22:
                            state = (
                                35
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.00137734995)
                                else 36
                            )
                            if state == 35:
                                return 0.110904053
                            if state == 36:
                                state = 59 if x["maggaia_med"] < 19.6128483 else 60
                                if state == 59:
                                    return -0.179175407
                                if state == 60:
                                    state = (
                                        83
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.6552525)
                                        else 84
                                    )
                                    if state == 83:
                                        return -0.118525155
                                    if state == 84:
                                        state = (
                                            117
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.676547587)
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                145
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.581547856)
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    171
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.10144448)
                                                    else 172
                                                )
                                                if state == 171:
                                                    return 0.0887629986
                                                if state == 172:
                                                    state = (
                                                        195
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 3.61888885
                                                        )
                                                        else 196
                                                    )
                                                    if state == 195:
                                                        return -0.140925333
                                                    if state == 196:
                                                        return 0.00878219027
                                            if state == 146:
                                                state = (
                                                    173
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.09587669)
                                                    else 174
                                                )
                                                if state == 173:
                                                    return -0.112321012
                                                if state == 174:
                                                    state = (
                                                        197
                                                        if np.isnan(x["distnr_med"])
                                                        or (x["distnr_med"] < 1.9510299)
                                                        else 198
                                                    )
                                                    if state == 197:
                                                        return 0.113560431
                                                    if state == 198:
                                                        return -0.055112768
                                        if state == 118:
                                            state = (
                                                147
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.906428576)
                                                else 148
                                            )
                                            if state == 147:
                                                state = (
                                                    175
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.64982307)
                                                    else 176
                                                )
                                                if state == 175:
                                                    return -0.0166765153
                                                if state == 176:
                                                    return 0.1344973
                                            if state == 148:
                                                return -0.066631414
    elif num_booster == 59:
        state = 0
        if state == 0:
            state = 1 if x["col_det"] < -0.370721817 else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.6208878) else 4
                )
                if state == 3:
                    return -0.123157918
                if state == 4:
                    return 0.0380019322
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 19.1144104) else 6
                )
                if state == 5:
                    state = 9 if x["maggaia_med"] < 19.3613243 else 10
                    if state == 9:
                        state = 13 if x["neargaia_med"] < 0.648653567 else 14
                        if state == 13:
                            state = (
                                17
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0523274019)
                                else 18
                            )
                            if state == 17:
                                return 0.101951852
                            if state == 18:
                                return -0.157387823
                        if state == 14:
                            state = (
                                19
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.503687501)
                                else 20
                            )
                            if state == 19:
                                state = (
                                    29
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.213896006)
                                    else 30
                                )
                                if state == 29:
                                    state = (
                                        45
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 16.8460007)
                                        else 46
                                    )
                                    if state == 45:
                                        return 0.143667489
                                    if state == 46:
                                        state = (
                                            61
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < -0.0669438094)
                                            else 62
                                        )
                                        if state == 61:
                                            state = (
                                                75
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.162369728)
                                                else 76
                                            )
                                            if state == 75:
                                                state = (
                                                    91
                                                    if x["mag_peak"] < 18.7087708
                                                    else 92
                                                )
                                                if state == 91:
                                                    state = (
                                                        115
                                                        if x["neargaia_med"]
                                                        < 10.3406086
                                                        else 116
                                                    )
                                                    if state == 115:
                                                        return -0.0214075521
                                                    if state == 116:
                                                        return 0.183244437
                                                if state == 92:
                                                    state = (
                                                        117
                                                        if x["neargaia_med"]
                                                        < 24.9866486
                                                        else 118
                                                    )
                                                    if state == 117:
                                                        return 0.060799323
                                                    if state == 118:
                                                        return -0.08082477
                                            if state == 76:
                                                state = (
                                                    93
                                                    if x["mag_peak"] < 18.6018543
                                                    else 94
                                                )
                                                if state == 93:
                                                    state = (
                                                        119
                                                        if x["neargaia_med"] < 14.296689
                                                        else 120
                                                    )
                                                    if state == 119:
                                                        return 0.160678104
                                                    if state == 120:
                                                        return -0.108603768
                                                if state == 94:
                                                    state = (
                                                        121
                                                        if x["neargaia_med"]
                                                        < 4.56419468
                                                        else 122
                                                    )
                                                    if state == 121:
                                                        return -0.0170171298
                                                    if state == 122:
                                                        return 0.166394964
                                        if state == 62:
                                            state = (
                                                77
                                                if x["col_peak"] < -0.053841114
                                                else 78
                                            )
                                            if state == 77:
                                                return -0.122652143
                                            if state == 78:
                                                state = (
                                                    95
                                                    if x["mag_peak"] < 18.7534027
                                                    else 96
                                                )
                                                if state == 95:
                                                    state = (
                                                        123
                                                        if x["neargaia_med"] < 1.0079298
                                                        else 124
                                                    )
                                                    if state == 123:
                                                        return 0.151961207
                                                    if state == 124:
                                                        return 0.017369315
                                                if state == 96:
                                                    state = (
                                                        125
                                                        if x["neargaia_med"]
                                                        < 33.2159042
                                                        else 126
                                                    )
                                                    if state == 125:
                                                        state = (
                                                            159
                                                            if np.isnan(x["col_last"])
                                                            or (
                                                                x["col_last"]
                                                                < 0.514489651
                                                            )
                                                            else 160
                                                        )
                                                        if state == 159:
                                                            return -0.136411756
                                                        if state == 160:
                                                            return 0.0464076698
                                                    if state == 126:
                                                        return 0.0212902054
                                if state == 30:
                                    state = (
                                        47
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 17.8220005)
                                        else 48
                                    )
                                    if state == 47:
                                        return -0.0900935456
                                    if state == 48:
                                        state = (
                                            63
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < 0.0969724655)
                                            else 64
                                        )
                                        if state == 63:
                                            state = (
                                                79
                                                if x["col_peak"] < 0.733886838
                                                else 80
                                            )
                                            if state == 79:
                                                return 0.0551709644
                                            if state == 80:
                                                state = (
                                                    99
                                                    if x["mag_peak"] < 18.8980637
                                                    else 100
                                                )
                                                if state == 99:
                                                    state = (
                                                        129
                                                        if x["neargaia_med"]
                                                        < 12.7403049
                                                        else 130
                                                    )
                                                    if state == 129:
                                                        return -0.0233653188
                                                    if state == 130:
                                                        return 0.16103062
                                                if state == 100:
                                                    state = (
                                                        131
                                                        if x["neargaia_med"]
                                                        < 4.49557734
                                                        else 132
                                                    )
                                                    if state == 131:
                                                        return 0.106277213
                                                    if state == 132:
                                                        return -0.109507896
                                        if state == 64:
                                            return 0.106930815
                            if state == 20:
                                return -0.0843100324
                    if state == 10:
                        state = 15 if x["neargaia_med"] < 8.503685 else 16
                        if state == 15:
                            state = (
                                21
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.364273489)
                                else 22
                            )
                            if state == 21:
                                state = 31 if x["sgscore1_med"] < 0.0048750001 else 32
                                if state == 31:
                                    return 0.0335929096
                                if state == 32:
                                    return -0.178802311
                            if state == 22:
                                return 0.0339068323
                        if state == 16:
                            state = 23 if x["sgscore1_med"] < 0.00741666462 else 24
                            if state == 23:
                                state = 35 if x["sgscore1_med"] < 0.00135416491 else 36
                                if state == 35:
                                    state = (
                                        55
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.6982498)
                                        else 56
                                    )
                                    if state == 55:
                                        return 0.147230625
                                    if state == 56:
                                        state = (
                                            65
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < -0.314507484)
                                            else 66
                                        )
                                        if state == 65:
                                            return -0.123063721
                                        if state == 66:
                                            return 0.0483162925
                                if state == 36:
                                    state = (
                                        57
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.1974983)
                                        else 58
                                    )
                                    if state == 57:
                                        state = (
                                            67
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < -0.0443992615)
                                            else 68
                                        )
                                        if state == 67:
                                            state = (
                                                81
                                                if x["col_peak"] < 0.237222821
                                                else 82
                                            )
                                            if state == 81:
                                                return -0.0713177994
                                            if state == 82:
                                                state = (
                                                    101
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 18.1081276)
                                                    else 102
                                                )
                                                if state == 101:
                                                    return -0.103390366
                                                if state == 102:
                                                    return 0.10649614
                                        if state == 68:
                                            return 0.0880953446
                                    if state == 58:
                                        state = (
                                            69 if x["col_det"] < -0.332094669 else 70
                                        )
                                        if state == 69:
                                            return 0.020024674
                                        if state == 70:
                                            return -0.173821896
                            if state == 24:
                                state = (
                                    37
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.952381015)
                                    else 38
                                )
                                if state == 37:
                                    state = (
                                        59
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.1102505)
                                        else 60
                                    )
                                    if state == 59:
                                        state = 71 if x["col_det"] < 0.557847023 else 72
                                        if state == 71:
                                            state = (
                                                83
                                                if x["col_peak"] < 0.293700218
                                                else 84
                                            )
                                            if state == 83:
                                                state = (
                                                    103
                                                    if x["mag_peak"] < 18.7174168
                                                    else 104
                                                )
                                                if state == 103:
                                                    return 0.0602127016
                                                if state == 104:
                                                    return -0.103367426
                                            if state == 84:
                                                return 0.0746323764
                                        if state == 72:
                                            state = (
                                                85
                                                if x["col_peak"] < 0.00135564804
                                                else 86
                                            )
                                            if state == 85:
                                                return 0.0895936787
                                            if state == 86:
                                                state = (
                                                    107
                                                    if x["mag_peak"] < 18.8704491
                                                    else 108
                                                )
                                                if state == 107:
                                                    state = (
                                                        139
                                                        if x["neargaia_med"] < 49.416687
                                                        else 140
                                                    )
                                                    if state == 139:
                                                        state = (
                                                            171
                                                            if x["col_last"]
                                                            < 2.76220036
                                                            else 172
                                                        )
                                                        if state == 171:
                                                            return -0.0973457769
                                                        if state == 172:
                                                            return 0.0892768353
                                                    if state == 140:
                                                        return -0.122287177
                                                if state == 108:
                                                    return -0.213199839
                                    if state == 60:
                                        state = (
                                            73
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < -0.25635004)
                                            else 74
                                        )
                                        if state == 73:
                                            state = (
                                                87
                                                if x["col_peak"] < -0.22789669
                                                else 88
                                            )
                                            if state == 87:
                                                return -0.0233447794
                                            if state == 88:
                                                state = (
                                                    109
                                                    if x["mag_peak"] < 18.769907
                                                    else 110
                                                )
                                                if state == 109:
                                                    state = (
                                                        141
                                                        if x["neargaia_med"]
                                                        < 22.4532471
                                                        else 142
                                                    )
                                                    if state == 141:
                                                        return -0.0884958953
                                                    if state == 142:
                                                        return 0.0848494247
                                                if state == 110:
                                                    return 0.158915788
                                        if state == 74:
                                            state = (
                                                89
                                                if np.isnan(x["col_peak"])
                                                or (x["col_peak"] < -0.243048668)
                                                else 90
                                            )
                                            if state == 89:
                                                state = (
                                                    111
                                                    if np.isnan(x["mag_peak"])
                                                    or (x["mag_peak"] < 17.8287048)
                                                    else 112
                                                )
                                                if state == 111:
                                                    state = (
                                                        143
                                                        if x["neargaia_med"]
                                                        < 27.2100296
                                                        else 144
                                                    )
                                                    if state == 143:
                                                        return 0.0405797474
                                                    if state == 144:
                                                        return -0.116344362
                                                if state == 112:
                                                    return 0.0288279261
                                            if state == 90:
                                                return 0.0651955456
                                if state == 38:
                                    return -0.113545626
                if state == 6:
                    return -0.103939414
    elif num_booster == 60:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.2205009) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.50147009)
                    else 4
                )
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 14.9414005) else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 8.97057343)
                            else 16
                        )
                        if state == 15:
                            return -0.141994998
                        if state == 16:
                            return 0.0268930346
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 49.8166733)
                            else 18
                        )
                        if state == 17:
                            state = (
                                31
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 33.9397469)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    43
                                    if np.isnan(x["col_last"])
                                    or (x["col_last"] < 0.591712475)
                                    else 44
                                )
                                if state == 43:
                                    state = (
                                        51
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 29.9615974)
                                        else 52
                                    )
                                    if state == 51:
                                        return -0.210636452
                                    if state == 52:
                                        return -0.0248856209
                                if state == 44:
                                    return 0.0914916247
                            if state == 32:
                                return -0.24677214
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 57.8490906)
                                else 34
                            )
                            if state == 33:
                                return 0.0405462869
                            if state == 34:
                                return -0.111965366
                if state == 4:
                    return 0.0710566342
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 6.41968918)
                    else 6
                )
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.04031849) else 12
                    )
                    if state == 11:
                        return 0.0977305993
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 8.95166683)
                            else 24
                        )
                        if state == 23:
                            return -0.0601969063
                        if state == 24:
                            state = (
                                37
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 8.97799778)
                                else 38
                            )
                            if state == 37:
                                return 0.103960827
                            if state == 38:
                                state = (
                                    49
                                    if np.isnan(x["col_last"])
                                    or (x["col_last"] < 0.0417423248)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        55
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 21.0423088)
                                        else 56
                                    )
                                    if state == 55:
                                        state = (
                                            61
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 15.9189472)
                                            else 62
                                        )
                                        if state == 61:
                                            state = (
                                                67
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.500732005)
                                                else 68
                                            )
                                            if state == 67:
                                                state = (
                                                    79
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 7.97646999)
                                                    else 80
                                                )
                                                if state == 79:
                                                    state = (
                                                        101
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 4.08502674
                                                        )
                                                        else 102
                                                    )
                                                    if state == 101:
                                                        return 0.0604972765
                                                    if state == 102:
                                                        return -0.0653563812
                                                if state == 80:
                                                    return -0.0499385819
                                            if state == 68:
                                                return -0.065917708
                                        if state == 62:
                                            state = (
                                                69
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00504166493)
                                                else 70
                                            )
                                            if state == 69:
                                                return 0.0317623392
                                            if state == 70:
                                                state = (
                                                    83
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.04353523)
                                                    else 84
                                                )
                                                if state == 83:
                                                    return -0.0671179965
                                                if state == 84:
                                                    return 0.0707886815
                                    if state == 56:
                                        state = (
                                            63
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 27.9917011)
                                            else 64
                                        )
                                        if state == 63:
                                            state = (
                                                71
                                                if x["sgscore1_med"] < 0.324702501
                                                else 72
                                            )
                                            if state == 71:
                                                state = (
                                                    85
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.90263891)
                                                    else 86
                                                )
                                                if state == 85:
                                                    return 0.025471624
                                                if state == 86:
                                                    state = (
                                                        113
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.304758459
                                                        )
                                                        else 114
                                                    )
                                                    if state == 113:
                                                        return -0.00918926764
                                                    if state == 114:
                                                        state = (
                                                            141
                                                            if np.isnan(x["col_peak"])
                                                            or (
                                                                x["col_peak"]
                                                                < 0.268717766
                                                            )
                                                            else 142
                                                        )
                                                        if state == 141:
                                                            return 0.12016046
                                                        if state == 142:
                                                            return -0.0740476623
                                            if state == 72:
                                                return -0.015401382
                                        if state == 64:
                                            state = (
                                                73
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00745833479)
                                                else 74
                                            )
                                            if state == 73:
                                                state = (
                                                    89
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 8.99066544)
                                                    else 90
                                                )
                                                if state == 89:
                                                    state = (
                                                        119
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.41410506
                                                        )
                                                        else 120
                                                    )
                                                    if state == 119:
                                                        return 0.00808116328
                                                    if state == 120:
                                                        return -0.101802006
                                                if state == 90:
                                                    return 0.0591120049
                                            if state == 74:
                                                state = (
                                                    91
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 3.06284714)
                                                    else 92
                                                )
                                                if state == 91:
                                                    state = (
                                                        121
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.294536382
                                                        )
                                                        else 122
                                                    )
                                                    if state == 121:
                                                        return -0.062563315
                                                    if state == 122:
                                                        return 0.0853172392
                                                if state == 92:
                                                    return -0.00633317558
                                if state == 50:
                                    state = (
                                        57
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 49.9331436)
                                        else 58
                                    )
                                    if state == 57:
                                        state = (
                                            65
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 30.0725517)
                                            else 66
                                        )
                                        if state == 65:
                                            state = (
                                                75
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.0798184499)
                                                else 76
                                            )
                                            if state == 75:
                                                state = (
                                                    93
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 9.01866913)
                                                    else 94
                                                )
                                                if state == 93:
                                                    state = (
                                                        125
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.485808313
                                                        )
                                                        else 126
                                                    )
                                                    if state == 125:
                                                        return 0.0584293343
                                                    if state == 126:
                                                        return -0.0785546228
                                                if state == 94:
                                                    return 0.0655084625
                                            if state == 76:
                                                state = (
                                                    95
                                                    if np.isnan(x["t_predetect"])
                                                    or (x["t_predetect"] < 2.97935176)
                                                    else 96
                                                )
                                                if state == 95:
                                                    return 0.0800358951
                                                if state == 96:
                                                    state = (
                                                        129
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 3.50196266
                                                        )
                                                        else 130
                                                    )
                                                    if state == 129:
                                                        return -0.061438892
                                                    if state == 130:
                                                        return 0.0813465044
                                        if state == 66:
                                            return -0.055330988
                                    if state == 58:
                                        return 0.0623980984
                if state == 6:
                    return -0.057798855
    elif num_booster == 61:
        state = 0
        if state == 0:
            state = 1 if x["maggaia_med"] < 17.3726292 else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["col_det"]) or (x["col_det"] < 0.187469482) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.977500021)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 1.18192649)
                            else 16
                        )
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.00316666486)
                                else 30
                            )
                            if state == 29:
                                return -0.0516230948
                            if state == 30:
                                state = 47 if x["maggaia_med"] < 16.5549965 else 48
                                if state == 47:
                                    return 0.134618357
                                if state == 48:
                                    return -0.045424331
                        if state == 16:
                            return -0.132901117
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 2.94587588)
                            else 18
                        )
                        if state == 17:
                            state = 33 if x["sgscore1_med"] < 0.101774 else 34
                            if state == 33:
                                state = 51 if x["maggaia_med"] < 16.9727993 else 52
                                if state == 51:
                                    state = (
                                        65 if x["distpsnr1_med"] < 1.46262336 else 66
                                    )
                                    if state == 65:
                                        return 0.101703897
                                    if state == 66:
                                        state = (
                                            87
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.713501)
                                            else 88
                                        )
                                        if state == 87:
                                            return -0.104074843
                                        if state == 88:
                                            return 0.0953197926
                                if state == 52:
                                    return -0.10343691
                            if state == 34:
                                state = 53 if x["maggaia_med"] < 14.4461384 else 54
                                if state == 53:
                                    return -0.0390254855
                                if state == 54:
                                    state = (
                                        67 if x["distpsnr1_med"] < 0.503322363 else 68
                                    )
                                    if state == 67:
                                        return -0.0461673103
                                    if state == 68:
                                        state = (
                                            89
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.7029991)
                                            else 90
                                        )
                                        if state == 89:
                                            return -0.0109615233
                                        if state == 90:
                                            return 0.227373883
                        if state == 18:
                            state = (
                                35
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.00479166489)
                                else 36
                            )
                            if state == 35:
                                return 0.0594703741
                            if state == 36:
                                state = 55 if x["maggaia_med"] < 17.0634613 else 56
                                if state == 55:
                                    state = (
                                        69 if x["distpsnr1_med"] < 4.72400188 else 70
                                    )
                                    if state == 69:
                                        return -0.109675296
                                    if state == 70:
                                        return 0.116999194
                                if state == 56:
                                    return -0.146806717
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.982249975)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.709908724)
                            else 20
                        )
                        if state == 19:
                            return -0.00289299642
                        if state == 20:
                            return -0.135539398
                    if state == 10:
                        return 0.0679545403
            if state == 2:
                state = (
                    5 if np.isnan(x["col_det"]) or (x["col_det"] < 0.457087517) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.981250048)
                        else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.116178885)
                            else 22
                        )
                        if state == 21:
                            return 0.0912887156
                        if state == 22:
                            state = 39 if x["sgscore1_med"] < 0.00204166491 else 40
                            if state == 39:
                                state = (
                                    57
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 19.1971416)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        71 if x["distpsnr1_med"] < 0.936633766 else 72
                                    )
                                    if state == 71:
                                        return 0.151182443
                                    if state == 72:
                                        return -0.0233924929
                                if state == 58:
                                    state = (
                                        73 if x["distpsnr1_med"] < 1.11035347 else 74
                                    )
                                    if state == 73:
                                        return -0.108956873
                                    if state == 74:
                                        return 0.0766288638
                            if state == 40:
                                state = (
                                    59
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 20.0049973)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        75 if x["distpsnr1_med"] < 4.95913029 else 76
                                    )
                                    if state == 75:
                                        state = (
                                            93
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.1017494)
                                            else 94
                                        )
                                        if state == 93:
                                            state = (
                                                107
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.36449218)
                                                else 108
                                            )
                                            if state == 107:
                                                state = (
                                                    125
                                                    if x["sgscore1_med"] < 0.00956845004
                                                    else 126
                                                )
                                                if state == 125:
                                                    state = (
                                                        147
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.739166677)
                                                        else 148
                                                    )
                                                    if state == 147:
                                                        return -0.00957304705
                                                    if state == 148:
                                                        state = (
                                                            171
                                                            if x["maggaia_med"]
                                                            < 18.417944
                                                            else 172
                                                        )
                                                        if state == 171:
                                                            return -0.101015925
                                                        if state == 172:
                                                            return 0.147641227
                                                if state == 126:
                                                    state = (
                                                        149
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.771904707)
                                                        else 150
                                                    )
                                                    if state == 149:
                                                        state = (
                                                            173
                                                            if x["maggaia_med"]
                                                            < 18.2484779
                                                            else 174
                                                        )
                                                        if state == 173:
                                                            return 0.0783887804
                                                        if state == 174:
                                                            return -0.081754297
                                                    if state == 150:
                                                        state = (
                                                            175
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 19.4417686
                                                            )
                                                            else 176
                                                        )
                                                        if state == 175:
                                                            return -0.195305154
                                                        if state == 176:
                                                            return 0.0605934449
                                            if state == 108:
                                                state = (
                                                    127
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0628899038
                                                    )
                                                    else 128
                                                )
                                                if state == 127:
                                                    return -0.073683776
                                                if state == 128:
                                                    return 0.15357995
                                        if state == 94:
                                            state = (
                                                109
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.87319541)
                                                else 110
                                            )
                                            if state == 109:
                                                state = (
                                                    129
                                                    if x["sgscore1_med"] < 0.0678422451
                                                    else 130
                                                )
                                                if state == 129:
                                                    state = (
                                                        151
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.706666708)
                                                        else 152
                                                    )
                                                    if state == 151:
                                                        return 0.125679255
                                                    if state == 152:
                                                        state = (
                                                            177
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 19.4435253
                                                            )
                                                            else 178
                                                        )
                                                        if state == 177:
                                                            return -0.142276347
                                                        if state == 178:
                                                            return 0.118865386
                                                if state == 130:
                                                    state = (
                                                        153
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.847142935)
                                                        else 154
                                                    )
                                                    if state == 153:
                                                        state = (
                                                            179
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 19.2117958
                                                            )
                                                            else 180
                                                        )
                                                        if state == 179:
                                                            return -0.199872166
                                                        if state == 180:
                                                            return 0.0719958171
                                                    if state == 154:
                                                        return 0.0156485457
                                            if state == 110:
                                                state = (
                                                    131
                                                    if x["sgscore1_med"] < 0.0459582992
                                                    else 132
                                                )
                                                if state == 131:
                                                    state = (
                                                        155
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.860357165)
                                                        else 156
                                                    )
                                                    if state == 155:
                                                        state = (
                                                            181
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 18.3942223
                                                            )
                                                            else 182
                                                        )
                                                        if state == 181:
                                                            return -0.0732116327
                                                        if state == 182:
                                                            return 0.0971892774
                                                    if state == 156:
                                                        return -0.0354924798
                                                if state == 132:
                                                    state = (
                                                        157
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.529285431)
                                                        else 158
                                                    )
                                                    if state == 157:
                                                        return -0.055310294
                                                    if state == 158:
                                                        return 0.167078614
                                    if state == 76:
                                        state = (
                                            95
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.8055)
                                            else 96
                                        )
                                        if state == 95:
                                            state = (
                                                111
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 8.14969254)
                                                else 112
                                            )
                                            if state == 111:
                                                state = (
                                                    133
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (x["sgscore1_med"] < 0.584270954)
                                                    else 134
                                                )
                                                if state == 133:
                                                    state = (
                                                        159
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.495357007)
                                                        else 160
                                                    )
                                                    if state == 159:
                                                        return -0.0167351887
                                                    if state == 160:
                                                        state = (
                                                            189
                                                            if x["maggaia_med"]
                                                            < 17.9493942
                                                            else 190
                                                        )
                                                        if state == 189:
                                                            return 0.112040646
                                                        if state == 190:
                                                            return -0.23281233
                                                if state == 134:
                                                    return 0.0142954262
                                            if state == 112:
                                                return 0.0417027771
                                        if state == 96:
                                            return 0.0819583833
                                if state == 60:
                                    state = (
                                        77 if x["distpsnr1_med"] < 2.51608515 else 78
                                    )
                                    if state == 77:
                                        return -0.184620321
                                    if state == 78:
                                        state = (
                                            99
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.8984985)
                                            else 100
                                        )
                                        if state == 99:
                                            return -0.0799061731
                                        if state == 100:
                                            return 0.081692107
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 8.52913189)
                            else 24
                        )
                        if state == 23:
                            state = 41 if x["sgscore1_med"] < 0.00593749993 else 42
                            if state == 41:
                                state = 61 if x["maggaia_med"] < 19.3768768 else 62
                                if state == 61:
                                    return 0.044829309
                                if state == 62:
                                    state = (
                                        81 if x["distpsnr1_med"] < 1.87882471 else 82
                                    )
                                    if state == 81:
                                        return -0.152148768
                                    if state == 82:
                                        return 0.0673173144
                            if state == 42:
                                state = (
                                    63
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 20.5073128)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        83 if x["distpsnr1_med"] < 1.59405434 else 84
                                    )
                                    if state == 83:
                                        state = (
                                            103
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.8722496)
                                            else 104
                                        )
                                        if state == 103:
                                            state = (
                                                117
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.47813368)
                                                else 118
                                            )
                                            if state == 117:
                                                state = (
                                                    135
                                                    if x["sgscore1_med"] < 0.187119007
                                                    else 136
                                                )
                                                if state == 135:
                                                    return 0.0308456123
                                                if state == 136:
                                                    return 0.172814742
                                            if state == 118:
                                                return -0.0613753945
                                        if state == 104:
                                            state = (
                                                119
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.804715633)
                                                else 120
                                            )
                                            if state == 119:
                                                state = (
                                                    137
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"] < 0.0267291497
                                                    )
                                                    else 138
                                                )
                                                if state == 137:
                                                    return 0.103541136
                                                if state == 138:
                                                    return -0.0819927827
                                            if state == 120:
                                                return -0.108729519
                                    if state == 84:
                                        state = (
                                            105
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 22.1122513)
                                            else 106
                                        )
                                        if state == 105:
                                            state = (
                                                121
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 2.5225029)
                                                else 122
                                            )
                                            if state == 121:
                                                state = (
                                                    141
                                                    if x["sgscore1_med"] < 0.0643005967
                                                    else 142
                                                )
                                                if state == 141:
                                                    state = (
                                                        163
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.784999967)
                                                        else 164
                                                    )
                                                    if state == 163:
                                                        return 0.154847741
                                                    if state == 164:
                                                        return -0.0656726584
                                                if state == 142:
                                                    state = (
                                                        165
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.323333502)
                                                        else 166
                                                    )
                                                    if state == 165:
                                                        return -0.0206373353
                                                    if state == 166:
                                                        return 0.219762877
                                            if state == 122:
                                                state = (
                                                    143
                                                    if x["sgscore1_med"] < 0.664931536
                                                    else 144
                                                )
                                                if state == 143:
                                                    state = (
                                                        167
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.778571546)
                                                        else 168
                                                    )
                                                    if state == 167:
                                                        return 0.106650144
                                                    if state == 168:
                                                        return -0.0427792035
                                                if state == 144:
                                                    return -0.0814521909
                                        if state == 106:
                                            state = (
                                                123
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 2.93469763)
                                                else 124
                                            )
                                            if state == 123:
                                                return -0.0971852094
                                            if state == 124:
                                                return 0.136235073
                                if state == 64:
                                    return -0.034330301
                        if state == 24:
                            return -0.0468017943
                if state == 6:
                    return 0.079920806
    elif num_booster == 62:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.977500021)
                else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 1.70576191)
                    else 4
                )
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.00865173) else 8
                    if state == 7:
                        return 0.0716898218
                    if state == 8:
                        state = 15 if x["mag_peak"] < 18.3330421 else 16
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0292707998)
                                else 28
                            )
                            if state == 27:
                                return 0.138640031
                            if state == 28:
                                return -0.0277945716
                        if state == 16:
                            state = (
                                29
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0016369049)
                                else 30
                            )
                            if state == 29:
                                return -0.177428246
                            if state == 30:
                                state = 49 if x["distpsnr1_med"] < 0.636338353 else 50
                                if state == 49:
                                    state = (
                                        75
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.114415169)
                                        else 76
                                    )
                                    if state == 75:
                                        state = (
                                            103
                                            if x["sgscore1_med"] < 0.0223958492
                                            else 104
                                        )
                                        if state == 103:
                                            state = (
                                                133
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.5410995)
                                                else 134
                                            )
                                            if state == 133:
                                                state = (
                                                    167
                                                    if x["maggaia_med"] < 19.6941071
                                                    else 168
                                                )
                                                if state == 167:
                                                    return 0.133438185
                                                if state == 168:
                                                    return -0.0787951946
                                            if state == 134:
                                                return -0.0367742702
                                        if state == 104:
                                            state = (
                                                135
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.1106567)
                                                else 136
                                            )
                                            if state == 135:
                                                return -0.118074052
                                            if state == 136:
                                                state = (
                                                    171
                                                    if x["maggaia_med"] < 19.6112099
                                                    else 172
                                                )
                                                if state == 171:
                                                    state = (
                                                        207
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.585984468
                                                        )
                                                        else 208
                                                    )
                                                    if state == 207:
                                                        return -0.0948423296
                                                    if state == 208:
                                                        return 0.188545242
                                                if state == 172:
                                                    return -0.0659483522
                                    if state == 76:
                                        return -0.0999265239
                                if state == 50:
                                    state = 77 if x["col_peak"] < 0.181346893 else 78
                                    if state == 77:
                                        return 0.0537671633
                                    if state == 78:
                                        state = (
                                            107
                                            if x["sgscore1_med"] < 0.0404732004
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                137
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.3896999)
                                                else 138
                                            )
                                            if state == 137:
                                                return -0.0765830055
                                            if state == 138:
                                                return 0.0788024515
                                        if state == 108:
                                            return -0.115949087
                if state == 4:
                    state = 9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 71.76548) else 10
                    if state == 9:
                        state = 17 if x["mag_peak"] < 18.5483932 else 18
                        if state == 17:
                            return 0.0710820705
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0669374987)
                                else 34
                            )
                            if state == 33:
                                state = 55 if x["distpsnr1_med"] < 2.18816566 else 56
                                if state == 55:
                                    return 0.00330692995
                                if state == 56:
                                    state = (
                                        79
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.116640091)
                                        else 80
                                    )
                                    if state == 79:
                                        return -0.160243422
                                    if state == 80:
                                        return 0.0106291249
                            if state == 34:
                                state = 57 if x["distpsnr1_med"] < 2.16112757 else 58
                                if state == 57:
                                    return 0.121244431
                                if state == 58:
                                    state = 81 if x["col_peak"] < 0.877120495 else 82
                                    if state == 81:
                                        return -0.0815739855
                                    if state == 82:
                                        state = (
                                            111
                                            if x["sgscore1_med"] < 0.937333465
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                143
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.3168488)
                                                else 144
                                            )
                                            if state == 143:
                                                return -0.070535399
                                            if state == 144:
                                                state = (
                                                    181
                                                    if x["maggaia_med"] < 17.2462921
                                                    else 182
                                                )
                                                if state == 181:
                                                    return -0.0174979158
                                                if state == 182:
                                                    state = (
                                                        213
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 4.37316418
                                                        )
                                                        else 214
                                                    )
                                                    if state == 213:
                                                        return 0.124271579
                                                    if state == 214:
                                                        return -0.0623459965
                                        if state == 112:
                                            return -0.0611116141
                    if state == 10:
                        return 0.0692766905
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distpsnr1_med"])
                    or (x["distpsnr1_med"] < 0.685946465)
                    else 6
                )
                if state == 5:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 11.0626335) else 12
                    )
                    if state == 11:
                        return -0.0536813103
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 17.7645493)
                            else 22
                        )
                        if state == 21:
                            state = 37 if x["sgscore1_med"] < 2.00000095 else 38
                            if state == 37:
                                state = 59 if x["distpsnr1_med"] < 0.260414749 else 60
                                if state == 59:
                                    return -0.0866851807
                                if state == 60:
                                    state = 83 if x["col_peak"] < 0.430439949 else 84
                                    if state == 83:
                                        return 0.0336054042
                                    if state == 84:
                                        state = (
                                            113
                                            if x["sgscore1_med"] < 0.0139583498
                                            else 114
                                        )
                                        if state == 113:
                                            return -0.0422355495
                                        if state == 114:
                                            state = (
                                                147
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 18.7631493)
                                                else 148
                                            )
                                            if state == 147:
                                                return -0.0605507381
                                            if state == 148:
                                                return 0.108297214
                            if state == 38:
                                return 0.0872397125
                        if state == 22:
                            state = (
                                39
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0857499987)
                                else 40
                            )
                            if state == 39:
                                state = 61 if x["distpsnr1_med"] < 0.133541346 else 62
                                if state == 61:
                                    return -0.00942540169
                                if state == 62:
                                    state = 87 if x["col_peak"] < 0.164114952 else 88
                                    if state == 87:
                                        return 0.0193907544
                                    if state == 88:
                                        return 0.166451365
                            if state == 40:
                                state = 63 if x["distpsnr1_med"] < 0.37286818 else 64
                                if state == 63:
                                    return -0.146721631
                                if state == 64:
                                    return 0.136880159
                if state == 6:
                    state = (
                        13 if np.isnan(x["t_lc"]) or (x["t_lc"] < 10.9645424) else 14
                    )
                    if state == 13:
                        state = 23 if x["mag_peak"] < 18.8552628 else 24
                        if state == 23:
                            return -0.0220588576
                        if state == 24:
                            state = (
                                41
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.151544511)
                                else 42
                            )
                            if state == 41:
                                return 0.119049594
                            if state == 42:
                                return -0.0160625428
                    if state == 14:
                        state = 25 if x["mag_peak"] < 17.9187584 else 26
                        if state == 25:
                            state = (
                                43
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.085660696)
                                else 44
                            )
                            if state == 43:
                                state = 67 if x["distpsnr1_med"] < 0.721055269 else 68
                                if state == 67:
                                    return -0.219379157
                                if state == 68:
                                    return -0.0496097319
                            if state == 44:
                                state = 69 if x["distpsnr1_med"] < 2.8950572 else 70
                                if state == 69:
                                    return -0.0273161829
                                if state == 70:
                                    state = (
                                        95
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.248513222)
                                        else 96
                                    )
                                    if state == 95:
                                        state = (
                                            121
                                            if x["sgscore1_med"] < 0.658279538
                                            else 122
                                        )
                                        if state == 121:
                                            return 0.0483720638
                                        if state == 122:
                                            return -0.124718532
                                    if state == 96:
                                        return 0.121971786
                        if state == 26:
                            state = 45 if x["sgscore1_med"] < 0.00170833501 else 46
                            if state == 45:
                                state = 71 if x["distpsnr1_med"] < 1.87882471 else 72
                                if state == 71:
                                    state = (
                                        97
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.150143147)
                                        else 98
                                    )
                                    if state == 97:
                                        return -0.174300373
                                    if state == 98:
                                        return 0.0401333869
                                if state == 72:
                                    return 0.0712266415
                            if state == 46:
                                state = 73 if x["distpsnr1_med"] < 3.8118906 else 74
                                if state == 73:
                                    state = (
                                        99
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < 0.111668587)
                                        else 100
                                    )
                                    if state == 99:
                                        state = (
                                            125
                                            if x["sgscore1_med"] < 0.120351501
                                            else 126
                                        )
                                        if state == 125:
                                            state = (
                                                155
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.7792511)
                                                else 156
                                            )
                                            if state == 155:
                                                return 0.100152127
                                            if state == 156:
                                                state = (
                                                    187
                                                    if x["maggaia_med"] < 20.5931511
                                                    else 188
                                                )
                                                if state == 187:
                                                    return 0.0601356067
                                                if state == 188:
                                                    return -0.137870193
                                        if state == 126:
                                            state = (
                                                157
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.5799503)
                                                else 158
                                            )
                                            if state == 157:
                                                state = (
                                                    189
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 18.5982151)
                                                    else 190
                                                )
                                                if state == 189:
                                                    return 0.0345216356
                                                if state == 190:
                                                    return -0.137374267
                                            if state == 158:
                                                state = (
                                                    191
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 18.9259834)
                                                    else 192
                                                )
                                                if state == 191:
                                                    return -0.0647511035
                                                if state == 192:
                                                    return 0.060030207
                                    if state == 100:
                                        return -0.0695709214
                                if state == 74:
                                    state = (
                                        101
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.134606361)
                                        else 102
                                    )
                                    if state == 101:
                                        state = (
                                            129
                                            if x["sgscore1_med"] < 0.229857504
                                            else 130
                                        )
                                        if state == 129:
                                            state = (
                                                161
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.7001095)
                                                else 162
                                            )
                                            if state == 161:
                                                return 0.162044615
                                            if state == 162:
                                                state = (
                                                    195
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 16.8168221)
                                                    else 196
                                                )
                                                if state == 195:
                                                    return 0.100542173
                                                if state == 196:
                                                    return -0.099351041
                                        if state == 130:
                                            state = (
                                                163
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.7842503)
                                                else 164
                                            )
                                            if state == 163:
                                                state = (
                                                    197
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 18.1071968)
                                                    else 198
                                                )
                                                if state == 197:
                                                    return 0.234505028
                                                if state == 198:
                                                    return 0.0335033648
                                            if state == 164:
                                                state = (
                                                    199
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 19.7707806)
                                                    else 200
                                                )
                                                if state == 199:
                                                    return -0.104130909
                                                if state == 200:
                                                    return 0.133497775
                                    if state == 102:
                                        return 0.0132191442
    elif num_booster == 63:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["sgscore1_med"]) or (x["sgscore1_med"] < 0.504097998)
                else 2
            )
            if state == 1:
                state = 3 if x["mag_peak"] < 18.6978874 else 4
                if state == 3:
                    state = 7 if x["col_det"] < -0.34149456 else 8
                    if state == 7:
                        return -0.0547117405
                    if state == 8:
                        state = 17 if x["mag_peak"] < 18.638504 else 18
                        if state == 17:
                            state = (
                                23
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.7249985)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    31
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.0965004)
                                    else 32
                                )
                                if state == 31:
                                    state = (
                                        41 if x["distpsnr1_med"] < 0.25555259 else 42
                                    )
                                    if state == 41:
                                        state = (
                                            53
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.6023941)
                                            else 54
                                        )
                                        if state == 53:
                                            state = (
                                                71 if x["mag_peak"] < 18.0338192 else 72
                                            )
                                            if state == 71:
                                                return 0.0735785514
                                            if state == 72:
                                                return -0.161352441
                                        if state == 54:
                                            return 0.0290686525
                                    if state == 42:
                                        state = (
                                            55
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.4737167)
                                            else 56
                                        )
                                        if state == 55:
                                            state = (
                                                75 if x["mag_peak"] < 18.5949402 else 76
                                            )
                                            if state == 75:
                                                state = (
                                                    91
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (
                                                        x["distpsnr1_med"] < 0.667829394
                                                    )
                                                    else 92
                                                )
                                                if state == 91:
                                                    state = (
                                                        113
                                                        if x["maggaia_med"] < 19.3110046
                                                        else 114
                                                    )
                                                    if state == 113:
                                                        return 0.116702579
                                                    if state == 114:
                                                        return -0.0365982801
                                                if state == 92:
                                                    state = (
                                                        115
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 19.2580395
                                                        )
                                                        else 116
                                                    )
                                                    if state == 115:
                                                        state = (
                                                            139
                                                            if x["maggaia_med"]
                                                            < 17.3352966
                                                            else 140
                                                        )
                                                        if state == 139:
                                                            return -0.0189469457
                                                        if state == 140:
                                                            return 0.101280324
                                                    if state == 116:
                                                        return -0.121467926
                                            if state == 76:
                                                return -0.150931641
                                        if state == 56:
                                            return 0.128537402
                                if state == 32:
                                    state = (
                                        43
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 8.0921917)
                                        else 44
                                    )
                                    if state == 43:
                                        state = (
                                            57
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 20.5160751)
                                            else 58
                                        )
                                        if state == 57:
                                            state = (
                                                79 if x["mag_peak"] < 17.5063152 else 80
                                            )
                                            if state == 79:
                                                return 0.0219109003
                                            if state == 80:
                                                state = (
                                                    95
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 6.19440365)
                                                    else 96
                                                )
                                                if state == 95:
                                                    state = (
                                                        117
                                                        if x["maggaia_med"] < 18.0273895
                                                        else 118
                                                    )
                                                    if state == 117:
                                                        state = (
                                                            141
                                                            if x["maggaia_med"]
                                                            < 17.0083351
                                                            else 142
                                                        )
                                                        if state == 141:
                                                            return 0.106578097
                                                        if state == 142:
                                                            return -0.104866512
                                                    if state == 118:
                                                        return 0.216708571
                                                if state == 96:
                                                    return 0.0177304186
                                        if state == 58:
                                            return -0.0300763287
                                    if state == 44:
                                        return 0.0158323292
                            if state == 24:
                                return -0.111666232
                        if state == 18:
                            return 0.0981533974
                if state == 4:
                    state = 9 if x["col_det"] < -0.292696953 else 10
                    if state == 9:
                        return 0.0627674758
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 19.0851231)
                            else 20
                        )
                        if state == 19:
                            state = (
                                27
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 19.0475006)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    37
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 18.8614998)
                                    else 38
                                )
                                if state == 37:
                                    state = (
                                        47
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 4.09055424)
                                        else 48
                                    )
                                    if state == 47:
                                        state = (
                                            61
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 17.7472382)
                                            else 62
                                        )
                                        if state == 61:
                                            state = (
                                                81
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.9560719)
                                                else 82
                                            )
                                            if state == 81:
                                                state = (
                                                    97
                                                    if x["distpsnr1_med"] < 0.676601768
                                                    else 98
                                                )
                                                if state == 97:
                                                    state = (
                                                        119
                                                        if x["maggaia_med"] < 17.4755039
                                                        else 120
                                                    )
                                                    if state == 119:
                                                        return 0.0290817022
                                                    if state == 120:
                                                        return -0.115999147
                                                if state == 98:
                                                    return -0.140400141
                                            if state == 82:
                                                return 0.0354694836
                                        if state == 62:
                                            state = (
                                                83
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.9022293)
                                                else 84
                                            )
                                            if state == 83:
                                                state = (
                                                    99
                                                    if x["distpsnr1_med"] < 1.94655728
                                                    else 100
                                                )
                                                if state == 99:
                                                    state = (
                                                        123
                                                        if x["maggaia_med"] < 18.7173119
                                                        else 124
                                                    )
                                                    if state == 123:
                                                        return 0.0895673409
                                                    if state == 124:
                                                        return -0.0504473336
                                                if state == 100:
                                                    return -0.104516894
                                            if state == 84:
                                                return 0.0440723151
                                    if state == 48:
                                        return 0.131157815
                                if state == 38:
                                    state = (
                                        49 if x["distpsnr1_med"] < 0.399305999 else 50
                                    )
                                    if state == 49:
                                        return 0.0173496511
                                    if state == 50:
                                        return -0.192582175
                            if state == 28:
                                state = (
                                    39
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 22.8055)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        51 if x["distpsnr1_med"] < 9.10007858 else 52
                                    )
                                    if state == 51:
                                        state = (
                                            67 if x["maggaia_med"] < 19.9612751 else 68
                                        )
                                        if state == 67:
                                            state = (
                                                85 if x["mag_peak"] < 18.9013786 else 86
                                            )
                                            if state == 85:
                                                state = (
                                                    103
                                                    if x["distpsnr1_med"] < 5.8225441
                                                    else 104
                                                )
                                                if state == 103:
                                                    return 0.122524023
                                                if state == 104:
                                                    return -0.0886156633
                                            if state == 86:
                                                state = (
                                                    105
                                                    if x["distpsnr1_med"] < 2.80203104
                                                    else 106
                                                )
                                                if state == 105:
                                                    state = (
                                                        131
                                                        if x["maggaia_med"] < 18.5120487
                                                        else 132
                                                    )
                                                    if state == 131:
                                                        state = (
                                                            153
                                                            if x["maggaia_med"]
                                                            < 17.2727356
                                                            else 154
                                                        )
                                                        if state == 153:
                                                            return 0.0557151064
                                                        if state == 154:
                                                            return -0.0997759104
                                                    if state == 132:
                                                        state = (
                                                            155
                                                            if x["maggaia_med"]
                                                            < 18.8900852
                                                            else 156
                                                        )
                                                        if state == 155:
                                                            return 0.144155532
                                                        if state == 156:
                                                            return 0.00611972203
                                                if state == 106:
                                                    state = (
                                                        133
                                                        if x["maggaia_med"] < 18.8772411
                                                        else 134
                                                    )
                                                    if state == 133:
                                                        return -0.0990871862
                                                    if state == 134:
                                                        return 0.0327135436
                                        if state == 68:
                                            state = (
                                                87 if x["mag_peak"] < 18.9506588 else 88
                                            )
                                            if state == 87:
                                                state = (
                                                    107
                                                    if x["distpsnr1_med"] < 0.146524608
                                                    else 108
                                                )
                                                if state == 107:
                                                    return 0.00078492699
                                                if state == 108:
                                                    state = (
                                                        135
                                                        if np.isnan(x["maggaia_med"])
                                                        or (
                                                            x["maggaia_med"]
                                                            < 20.4867477
                                                        )
                                                        else 136
                                                    )
                                                    if state == 135:
                                                        return -0.249072149
                                                    if state == 136:
                                                        return 0.0436687693
                                            if state == 88:
                                                state = (
                                                    109
                                                    if x["distpsnr1_med"] < 4.67592573
                                                    else 110
                                                )
                                                if state == 109:
                                                    state = (
                                                        137
                                                        if x["maggaia_med"] < 20.4152145
                                                        else 138
                                                    )
                                                    if state == 137:
                                                        return -0.0685138553
                                                    if state == 138:
                                                        return 0.0730884075
                                                if state == 110:
                                                    return -0.115937553
                                    if state == 52:
                                        return 0.0805603936
                                if state == 40:
                                    return 0.108538255
                        if state == 20:
                            return -0.113184296
            if state == 2:
                state = 5 if x["mag_peak"] < 18.4303322 else 6
                if state == 5:
                    return -0.142877623
                if state == 6:
                    state = 13 if x["col_det"] < -0.190968513 else 14
                    if state == 13:
                        return 0.0459982567
                    if state == 14:
                        state = 21 if x["mag_peak"] < 18.7881889 else 22
                        if state == 21:
                            return 0.0804512575
                        if state == 22:
                            return -0.0732826442
    elif num_booster == 64:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.9275513) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.115643501) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.1909523)
                        else 8
                    )
                    if state == 7:
                        return -0.188806206
                    if state == 8:
                        return 0.0471630804
                if state == 4:
                    return 0.015287092
            if state == 2:
                state = (
                    5 if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.47830677) else 6
                )
                if state == 5:
                    state = 9 if x["maggaia_med"] < 17.9588547 else 10
                    if state == 9:
                        state = 13 if x["maggaia_med"] < 17.3398094 else 14
                        if state == 13:
                            state = (
                                21
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5533504)
                                else 22
                            )
                            if state == 21:
                                state = 31 if x["neargaia_med"] < 0.641189873 else 32
                                if state == 31:
                                    return -0.11421831
                                if state == 32:
                                    state = (
                                        45
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.4388542)
                                        else 46
                                    )
                                    if state == 45:
                                        state = (
                                            61
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.978249967)
                                            else 62
                                        )
                                        if state == 61:
                                            state = (
                                                77
                                                if x["neargaia_med"] < 30.4252167
                                                else 78
                                            )
                                            if state == 77:
                                                return 0.0613782518
                                            if state == 78:
                                                return -0.0973272696
                                        if state == 62:
                                            state = (
                                                79
                                                if x["neargaia_med"] < 0.902266145
                                                else 80
                                            )
                                            if state == 79:
                                                return -0.205240473
                                            if state == 80:
                                                state = (
                                                    101
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 2.69751263)
                                                    else 102
                                                )
                                                if state == 101:
                                                    return 0.101807095
                                                if state == 102:
                                                    state = (
                                                        133
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.679166675)
                                                        else 134
                                                    )
                                                    if state == 133:
                                                        return 0.0941386297
                                                    if state == 134:
                                                        return -0.0947643965
                                    if state == 46:
                                        state = (
                                            63
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.970750034)
                                            else 64
                                        )
                                        if state == 63:
                                            return -0.0344793126
                                        if state == 64:
                                            return 0.156802014
                            if state == 22:
                                state = 33 if x["neargaia_med"] < 31.7390366 else 34
                                if state == 33:
                                    return -0.175067812
                                if state == 34:
                                    return 0.0464627631
                        if state == 14:
                            state = (
                                23
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8200531)
                                else 24
                            )
                            if state == 23:
                                state = 35 if x["neargaia_med"] < 1.5573796 else 36
                                if state == 35:
                                    return 0.0066408678
                                if state == 36:
                                    return 0.20344992
                            if state == 24:
                                state = 37 if x["neargaia_med"] < 13.6507206 else 38
                                if state == 37:
                                    return -0.0724257901
                                if state == 38:
                                    return 0.0732669234
                    if state == 10:
                        state = 15 if x["maggaia_med"] < 18.1645508 else 16
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.9578838)
                                else 26
                            )
                            if state == 25:
                                state = 39 if x["neargaia_med"] < 11.7457848 else 40
                                if state == 39:
                                    return -0.10913448
                                if state == 40:
                                    return 0.0710510388
                            if state == 26:
                                return -0.189104065
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.8308506)
                                else 28
                            )
                            if state == 27:
                                state = 41 if x["neargaia_med"] < 0.411553144 else 42
                                if state == 41:
                                    return 0.14634797
                                if state == 42:
                                    state = (
                                        55
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.1360435)
                                        else 56
                                    )
                                    if state == 55:
                                        return 0.103775121
                                    if state == 56:
                                        state = (
                                            67
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.982749999)
                                            else 68
                                        )
                                        if state == 67:
                                            state = (
                                                85
                                                if x["neargaia_med"] < 16.3572445
                                                else 86
                                            )
                                            if state == 85:
                                                state = (
                                                    107
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.47384501)
                                                    else 108
                                                )
                                                if state == 107:
                                                    state = (
                                                        137
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.632380962)
                                                        else 138
                                                    )
                                                    if state == 137:
                                                        return 0.0924204364
                                                    if state == 138:
                                                        return -0.0871275291
                                                if state == 108:
                                                    return -0.181615129
                                            if state == 86:
                                                state = (
                                                    109
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.13659739)
                                                    else 110
                                                )
                                                if state == 109:
                                                    state = (
                                                        141
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.613333166)
                                                        else 142
                                                    )
                                                    if state == 141:
                                                        return -0.00824388117
                                                    if state == 142:
                                                        state = (
                                                            161
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.982249975
                                                            )
                                                            else 162
                                                        )
                                                        if state == 161:
                                                            return -0.133340776
                                                        if state == 162:
                                                            return 0.0379655771
                                                if state == 110:
                                                    state = (
                                                        143
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.344642997)
                                                        else 144
                                                    )
                                                    if state == 143:
                                                        return -0.135612488
                                                    if state == 144:
                                                        return 0.0548752584
                                        if state == 68:
                                            state = (
                                                87
                                                if x["neargaia_med"] < 5.98063469
                                                else 88
                                            )
                                            if state == 87:
                                                return -0.0525484942
                                            if state == 88:
                                                state = (
                                                    113
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.263226092)
                                                    else 114
                                                )
                                                if state == 113:
                                                    return -0.046734076
                                                if state == 114:
                                                    state = (
                                                        145
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.95142889)
                                                        else 146
                                                    )
                                                    if state == 145:
                                                        return 0.133966655
                                                    if state == 146:
                                                        return -0.0668151304
                            if state == 28:
                                state = 43 if x["neargaia_med"] < 12.2609997 else 44
                                if state == 43:
                                    state = (
                                        57
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.0678215)
                                        else 58
                                    )
                                    if state == 57:
                                        return 0.122380771
                                    if state == 58:
                                        state = (
                                            71
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.979249954)
                                            else 72
                                        )
                                        if state == 71:
                                            state = (
                                                91
                                                if x["neargaia_med"] < 8.18851566
                                                else 92
                                            )
                                            if state == 91:
                                                return -0.108167484
                                            if state == 92:
                                                state = (
                                                    117
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 0.97524488)
                                                    else 118
                                                )
                                                if state == 117:
                                                    return -0.0472129062
                                                if state == 118:
                                                    return 0.13908273
                                        if state == 72:
                                            return 0.0839575008
                                if state == 44:
                                    state = (
                                        59
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.1400852)
                                        else 60
                                    )
                                    if state == 59:
                                        state = (
                                            73
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.973749995)
                                            else 74
                                        )
                                        if state == 73:
                                            return 0.145929903
                                        if state == 74:
                                            state = (
                                                93
                                                if np.isnan(x["neargaia_med"])
                                                or (x["neargaia_med"] < 13.9240465)
                                                else 94
                                            )
                                            if state == 93:
                                                return -0.0419450924
                                            if state == 94:
                                                state = (
                                                    121
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.29414654)
                                                    else 122
                                                )
                                                if state == 121:
                                                    state = (
                                                        151
                                                        if np.isnan(x["rb_med"])
                                                        or (x["rb_med"] < 0.624642849)
                                                        else 152
                                                    )
                                                    if state == 151:
                                                        return -0.0609450452
                                                    if state == 152:
                                                        return 0.208274797
                                                if state == 122:
                                                    return 0.0257044155
                                    if state == 60:
                                        state = (
                                            75
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.978500009)
                                            else 76
                                        )
                                        if state == 75:
                                            return -0.10693825
                                        if state == 76:
                                            return -0.000324061606
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 17.9216843)
                        else 12
                    )
                    if state == 11:
                        return -0.0109477732
                    if state == 12:
                        return 0.194080278
    elif num_booster == 65:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 20.898756) else 2
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 1.03340185 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.82756376)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["distpsnr1_med"] < 0.67264843 else 16
                        if state == 15:
                            return 0.073878713
                        if state == 16:
                            return -0.0840093791
                    if state == 8:
                        state = 17 if x["distpsnr1_med"] < 0.538845718 else 18
                        if state == 17:
                            return -0.0022630759
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["col_det"]) or (x["col_det"] < 0.20382452)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    59
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.09939814)
                                    else 60
                                )
                                if state == 59:
                                    return 0.00797696691
                                if state == 60:
                                    state = (
                                        95
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 18.0897465)
                                        else 96
                                    )
                                    if state == 95:
                                        return -0.193087146
                                    if state == 96:
                                        return 0.0101089915
                            if state == 34:
                                return -0.0403913446
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.96097231)
                        else 10
                    )
                    if state == 9:
                        state = 19 if x["distpsnr1_med"] < 3.51217771 else 20
                        if state == 19:
                            state = 35 if x["col_det"] < 0.188334465 else 36
                            if state == 35:
                                return 0.113181137
                            if state == 36:
                                return 0.0265235361
                        if state == 20:
                            state = (
                                37
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < -0.135229111)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    65
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 15.0203991)
                                    else 66
                                )
                                if state == 65:
                                    return 0.036218144
                                if state == 66:
                                    return -0.0796800107
                            if state == 38:
                                return 0.0474979542
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 1.27332497)
                            else 22
                        )
                        if state == 21:
                            return 0.0622508936
                        if state == 22:
                            state = 41 if x["col_det"] < -0.190848351 else 42
                            if state == 41:
                                return 0.0312008448
                            if state == 42:
                                return -0.114581101
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.372830689 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.88561344)
                        else 12
                    )
                    if state == 11:
                        return -0.128869817
                    if state == 12:
                        return -0.00588920852
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.47443867)
                        else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 1.02318192)
                            else 26
                        )
                        if state == 25:
                            state = (
                                47
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < -0.199074268)
                                else 48
                            )
                            if state == 47:
                                return 0.0416461788
                            if state == 48:
                                return -0.102132246
                        if state == 26:
                            state = (
                                49
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < -0.122538567)
                                else 50
                            )
                            if state == 49:
                                state = (
                                    79
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 23.4481354)
                                    else 80
                                )
                                if state == 79:
                                    return -0.0188146904
                                if state == 80:
                                    state = 115 if x["mag_peak"] < 18.9513416 else 116
                                    if state == 115:
                                        return 0.0775935501
                                    if state == 116:
                                        state = (
                                            141
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < 0.0812520981)
                                            else 142
                                        )
                                        if state == 141:
                                            state = (
                                                155
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.4713516)
                                                else 156
                                            )
                                            if state == 155:
                                                return -0.135533527
                                            if state == 156:
                                                return 0.0432450771
                                        if state == 142:
                                            return 0.0115892068
                            if state == 50:
                                state = (
                                    81
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 32.9976425)
                                    else 82
                                )
                                if state == 81:
                                    state = (
                                        117
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 18.3080711)
                                        else 118
                                    )
                                    if state == 117:
                                        return 0.00184947415
                                    if state == 118:
                                        return 0.317490548
                                if state == 82:
                                    return 0.0717829987
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 1.19808567)
                            else 28
                        )
                        if state == 27:
                            state = 51 if x["col_det"] < -0.218172073 else 52
                            if state == 51:
                                return -0.0397671312
                            if state == 52:
                                state = (
                                    83
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 58.3980103)
                                    else 84
                                )
                                if state == 83:
                                    state = (
                                        121
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 18.8937645)
                                        else 122
                                    )
                                    if state == 121:
                                        return 0.111037828
                                    if state == 122:
                                        return -0.0385829099
                                if state == 84:
                                    return -0.0835026726
                        if state == 28:
                            state = 53 if x["col_det"] < 0.0348577499 else 54
                            if state == 53:
                                state = (
                                    85
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 28.074955)
                                    else 86
                                )
                                if state == 85:
                                    return -0.035009142
                                if state == 86:
                                    state = (
                                        125
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 17.7411461)
                                        else 126
                                    )
                                    if state == 125:
                                        return 0.133361191
                                    if state == 126:
                                        state = (
                                            147 if x["col_peak"] < 0.143339157 else 148
                                        )
                                        if state == 147:
                                            return -0.0655793473
                                        if state == 148:
                                            return 0.106530368
                            if state == 54:
                                state = (
                                    87
                                    if np.isnan(x["t_lc"]) or (x["t_lc"] < 23.8984604)
                                    else 88
                                )
                                if state == 87:
                                    return 0.0496523641
                                if state == 88:
                                    state = 129 if x["mag_peak"] < 17.3361511 else 130
                                    if state == 129:
                                        return 0.117536947
                                    if state == 130:
                                        state = (
                                            149 if x["col_peak"] < -0.194008827 else 150
                                        )
                                        if state == 149:
                                            return 0.0523036942
                                        if state == 150:
                                            state = (
                                                159
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.1336498)
                                                else 160
                                            )
                                            if state == 159:
                                                return -0.176053077
                                            if state == 160:
                                                return 0.0122280726
    elif num_booster == 66:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6673737) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6275482) else 4
                )
                if state == 3:
                    state = 7 if x["mag_peak"] < 17.523365 else 8
                    if state == 7:
                        return -0.0896926522
                    if state == 8:
                        return 0.0511219539
                if state == 4:
                    return -0.136137232
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6799011) else 6
                )
                if state == 5:
                    return 0.0509782098
                if state == 6:
                    state = 9 if x["mag_peak"] < 18.3040504 else 10
                    if state == 9:
                        state = 13 if x["col_det"] < -0.0198745728 else 14
                        if state == 13:
                            return -0.0200872235
                        if state == 14:
                            state = (
                                21
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.26095521)
                                else 22
                            )
                            if state == 21:
                                return 0.142878368
                            if state == 22:
                                state = (
                                    31
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 17.5175018)
                                    else 32
                                )
                                if state == 31:
                                    return -0.0904467404
                                if state == 32:
                                    return 0.0856339335
                    if state == 10:
                        state = 15 if x["col_det"] < -0.0382790565 else 16
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 4.48150826)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    33
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 17.8035011)
                                    else 34
                                )
                                if state == 33:
                                    return -0.0830668584
                                if state == 34:
                                    state = (
                                        45
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.606666684)
                                        else 46
                                    )
                                    if state == 45:
                                        state = (
                                            53
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.1153488)
                                            else 54
                                        )
                                        if state == 53:
                                            return -0.0968986899
                                        if state == 54:
                                            state = (
                                                69
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.1645336)
                                                else 70
                                            )
                                            if state == 69:
                                                return 0.0697282031
                                            if state == 70:
                                                state = (
                                                    95
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.1824989)
                                                    else 96
                                                )
                                                if state == 95:
                                                    return 0.0585390404
                                                if state == 96:
                                                    return -0.116545856
                                    if state == 46:
                                        state = (
                                            55
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.8675499)
                                            else 56
                                        )
                                        if state == 55:
                                            state = (
                                                71
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.5510178)
                                                else 72
                                            )
                                            if state == 71:
                                                state = (
                                                    97
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.739399)
                                                    else 98
                                                )
                                                if state == 97:
                                                    state = (
                                                        115
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.21839285
                                                        )
                                                        else 116
                                                    )
                                                    if state == 115:
                                                        return -0.099900201
                                                    if state == 116:
                                                        return 0.0685996637
                                                if state == 98:
                                                    return 0.170068949
                                            if state == 72:
                                                return -0.0154962679
                                        if state == 56:
                                            state = (
                                                73
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.2838898)
                                                else 74
                                            )
                                            if state == 73:
                                                state = (
                                                    101
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.1601505)
                                                    else 102
                                                )
                                                if state == 101:
                                                    return -0.130274728
                                                if state == 102:
                                                    state = (
                                                        119
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"] < 1.70280147
                                                        )
                                                        else 120
                                                    )
                                                    if state == 119:
                                                        return 0.100069582
                                                    if state == 120:
                                                        return -0.0801215544
                                            if state == 74:
                                                return 0.0193709228
                            if state == 24:
                                return 0.101119429
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 8.77619839)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    35
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 21.519249)
                                    else 36
                                )
                                if state == 35:
                                    state = (
                                        47
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.886785686)
                                        else 48
                                    )
                                    if state == 47:
                                        state = (
                                            57
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 20.8931007)
                                            else 58
                                        )
                                        if state == 57:
                                            state = (
                                                75
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.0253754)
                                                else 76
                                            )
                                            if state == 75:
                                                state = (
                                                    105
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.0276489)
                                                    else 106
                                                )
                                                if state == 105:
                                                    return 0.182246655
                                                if state == 106:
                                                    state = (
                                                        123
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.173996642
                                                        )
                                                        else 124
                                                    )
                                                    if state == 123:
                                                        return -0.0752380937
                                                    if state == 124:
                                                        return 0.0530636944
                                            if state == 76:
                                                state = (
                                                    107
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.6187496)
                                                    else 108
                                                )
                                                if state == 107:
                                                    state = (
                                                        125
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.349350452
                                                        )
                                                        else 126
                                                    )
                                                    if state == 125:
                                                        state = (
                                                            137
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.627738178
                                                            )
                                                            else 138
                                                        )
                                                        if state == 137:
                                                            return 0.11440295
                                                        if state == 138:
                                                            return -0.0334583558
                                                    if state == 126:
                                                        state = (
                                                            139
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.578333437
                                                            )
                                                            else 140
                                                        )
                                                        if state == 139:
                                                            return -0.00244024233
                                                        if state == 140:
                                                            return -0.075558804
                                                if state == 108:
                                                    return -0.172769874
                                        if state == 58:
                                            state = (
                                                77
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.643362)
                                                else 78
                                            )
                                            if state == 77:
                                                return 0.159683868
                                            if state == 78:
                                                return -0.0275600012
                                    if state == 48:
                                        state = (
                                            59
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.1422882)
                                            else 60
                                        )
                                        if state == 59:
                                            return -0.158110783
                                        if state == 60:
                                            state = (
                                                79
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.089447)
                                                else 80
                                            )
                                            if state == 79:
                                                return 0.119346499
                                            if state == 80:
                                                state = (
                                                    111
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 20.6355)
                                                    else 112
                                                )
                                                if state == 111:
                                                    return 0.0500951894
                                                if state == 112:
                                                    return -0.091099821
                                if state == 36:
                                    state = (
                                        49
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.699285746)
                                        else 50
                                    )
                                    if state == 49:
                                        state = (
                                            61
                                            if np.isnan(x["mag_det"])
                                            or (x["mag_det"] < 19.8239994)
                                            else 62
                                        )
                                        if state == 61:
                                            return -0.0288798548
                                        if state == 62:
                                            state = (
                                                83
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.7723465)
                                                else 84
                                            )
                                            if state == 83:
                                                return 0.0290861912
                                            if state == 84:
                                                return -0.18238467
                                    if state == 50:
                                        return -0.0183289889
                            if state == 26:
                                return 0.0650460422
    elif num_booster == 67:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.0446816981)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.5237961) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.5990009)
                        else 8
                    )
                    if state == 7:
                        return 0.0165453181
                    if state == 8:
                        return -0.103136308
                if state == 4:
                    return -0.00364582287
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.492157) else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 15.8009996)
                        else 12
                    )
                    if state == 11:
                        return -0.0454103611
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 5.99787045)
                            else 22
                        )
                        if state == 21:
                            return -0.0927115008
                        if state == 22:
                            state = 29 if x["mag_peak"] < 17.5326328 else 30
                            if state == 29:
                                return -0.00960949529
                            if state == 30:
                                return 0.151641473
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.5690002)
                        else 14
                    )
                    if state == 13:
                        state = (
                            23
                            if np.isnan(x["t_lc"]) or (x["t_lc"] < 57.9059296)
                            else 24
                        )
                        if state == 23:
                            state = 31 if x["mag_peak"] < 18.7803097 else 32
                            if state == 31:
                                state = (
                                    43
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 17.4995003)
                                    else 44
                                )
                                if state == 43:
                                    state = (
                                        57
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 17.473999)
                                        else 58
                                    )
                                    if state == 57:
                                        state = (
                                            77
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.977749944)
                                            else 78
                                        )
                                        if state == 77:
                                            return 0.116115674
                                        if state == 78:
                                            state = (
                                                107
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 3.48612833)
                                                else 108
                                            )
                                            if state == 107:
                                                return -0.15932481
                                            if state == 108:
                                                state = (
                                                    133
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 52.8962326)
                                                    else 134
                                                )
                                                if state == 133:
                                                    return -0.0344861969
                                                if state == 134:
                                                    return 0.0821141154
                                    if state == 58:
                                        return -0.114657871
                                if state == 44:
                                    return 0.0392067097
                            if state == 32:
                                state = (
                                    45
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 18.0919991)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        61
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 17.8155003)
                                        else 62
                                    )
                                    if state == 61:
                                        state = (
                                            83
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.97874999)
                                            else 84
                                        )
                                        if state == 83:
                                            return -0.183468446
                                        if state == 84:
                                            return 0.0585320517
                                    if state == 62:
                                        return 0.0443231724
                                if state == 46:
                                    return -0.119674467
                        if state == 24:
                            state = 33 if x["mag_peak"] < 17.7162476 else 34
                            if state == 33:
                                return 0.0833254382
                            if state == 34:
                                return -0.179856732
                    if state == 14:
                        state = (
                            25 if np.isnan(x["t_lc"]) or (x["t_lc"] < 25.928484) else 26
                        )
                        if state == 25:
                            state = (
                                35
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 18.6263809)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    47
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.0844994)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        63
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 18.8532486)
                                        else 64
                                    )
                                    if state == 63:
                                        state = (
                                            87
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.979750037)
                                            else 88
                                        )
                                        if state == 87:
                                            return -0.106415868
                                        if state == 88:
                                            return 0.0709319562
                                    if state == 64:
                                        return -0.154171526
                                if state == 48:
                                    state = (
                                        65
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.3260002)
                                        else 66
                                    )
                                    if state == 65:
                                        return 0.0575835295
                                    if state == 66:
                                        state = (
                                            91
                                            if np.isnan(x["classtar_med"])
                                            or (x["classtar_med"] < 0.923500001)
                                            else 92
                                        )
                                        if state == 91:
                                            return 0.00654935697
                                        if state == 92:
                                            state = (
                                                121
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 2.83081603)
                                                else 122
                                            )
                                            if state == 121:
                                                return 0.0409872383
                                            if state == 122:
                                                state = (
                                                    151
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 8.97931671)
                                                    else 152
                                                )
                                                if state == 151:
                                                    return 0.0120360367
                                                if state == 152:
                                                    state = (
                                                        171
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9949131)
                                                        else 172
                                                    )
                                                    if state == 171:
                                                        return -0.0154526019
                                                    if state == 172:
                                                        return -0.169584513
                            if state == 36:
                                state = (
                                    49
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.581501)
                                    else 50
                                )
                                if state == 49:
                                    return 0.0828163773
                                if state == 50:
                                    return -0.0273005925
                        if state == 26:
                            state = 37 if x["mag_peak"] < 19.0851231 else 38
                            if state == 37:
                                state = (
                                    51
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.5670013)
                                    else 52
                                )
                                if state == 51:
                                    return 0.118468203
                                if state == 52:
                                    state = (
                                        71
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 20.0584984)
                                        else 72
                                    )
                                    if state == 71:
                                        return -0.0504130758
                                    if state == 72:
                                        return 0.0606776848
                            if state == 38:
                                state = (
                                    53
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 20.5195007)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        73
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 19.5345001)
                                        else 74
                                    )
                                    if state == 73:
                                        return -0.117313661
                                    if state == 74:
                                        return 0.109584957
                                if state == 54:
                                    return -0.118107535
    elif num_booster == 68:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.5685482) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.462553) else 4
                )
                if state == 3:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 33.8574142) else 8
                    if state == 7:
                        state = 13 if x["distpsnr1_med"] < 6.47604275 else 14
                        if state == 13:
                            state = (
                                25
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 6.02176476)
                                else 26
                            )
                            if state == 25:
                                state = 45 if x["mag_peak"] < 17.7735558 else 46
                                if state == 45:
                                    state = (
                                        81
                                        if np.isnan(x["classtar_med"])
                                        or (x["classtar_med"] < 0.978500009)
                                        else 82
                                    )
                                    if state == 81:
                                        return -0.00829132274
                                    if state == 82:
                                        state = (
                                            111
                                            if x["distpsnr1_med"] < 0.687021434
                                            else 112
                                        )
                                        if state == 111:
                                            return -0.329057693
                                        if state == 112:
                                            state = (
                                                143
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.0242996)
                                                else 144
                                            )
                                            if state == 143:
                                                return 0.047369197
                                            if state == 144:
                                                return -0.139806613
                                if state == 46:
                                    state = (
                                        83
                                        if np.isnan(x["classtar_med"])
                                        or (x["classtar_med"] < 0.982749999)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            113
                                            if x["distpsnr1_med"] < 0.723939896
                                            else 114
                                        )
                                        if state == 113:
                                            state = (
                                                145
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.1159191)
                                                else 146
                                            )
                                            if state == 145:
                                                state = (
                                                    167
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.1085606)
                                                    else 168
                                                )
                                                if state == 167:
                                                    return -0.0156866182
                                                if state == 168:
                                                    state = (
                                                        183
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 15.0087852)
                                                        else 184
                                                    )
                                                    if state == 183:
                                                        state = (
                                                            195
                                                            if np.isnan(
                                                                x["maggaia_med"]
                                                            )
                                                            or (
                                                                x["maggaia_med"]
                                                                < 17.5000839
                                                            )
                                                            else 196
                                                        )
                                                        if state == 195:
                                                            return 0.201292738
                                                        if state == 196:
                                                            return 0.0345100649
                                                    if state == 184:
                                                        return -0.00950782187
                                            if state == 146:
                                                return -0.0971695632
                                        if state == 114:
                                            state = (
                                                147
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.6336536)
                                                else 148
                                            )
                                            if state == 147:
                                                return 0.0497563593
                                            if state == 148:
                                                state = (
                                                    169
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 19.3222351)
                                                    else 170
                                                )
                                                if state == 169:
                                                    state = (
                                                        185
                                                        if np.isnan(x["t_lc"])
                                                        or (x["t_lc"] < 8.97821236)
                                                        else 186
                                                    )
                                                    if state == 185:
                                                        return 0.101616636
                                                    if state == 186:
                                                        state = (
                                                            199
                                                            if x["maggaia_med"]
                                                            < 18.5183487
                                                            else 200
                                                        )
                                                        if state == 199:
                                                            return -0.00748286117
                                                        if state == 200:
                                                            return -0.110711567
                                                if state == 170:
                                                    return -0.121575132
                                    if state == 84:
                                        return 0.037982244
                            if state == 26:
                                state = 47 if x["mag_peak"] < 18.3804855 else 48
                                if state == 47:
                                    return -0.00140692107
                                if state == 48:
                                    state = (
                                        87
                                        if np.isnan(x["classtar_med"])
                                        or (x["classtar_med"] < 0.967499971)
                                        else 88
                                    )
                                    if state == 87:
                                        return -0.0454273708
                                    if state == 88:
                                        state = (
                                            121
                                            if x["distpsnr1_med"] < 0.368035108
                                            else 122
                                        )
                                        if state == 121:
                                            return -0.0264259335
                                        if state == 122:
                                            state = (
                                                153
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.0955009)
                                                else 154
                                            )
                                            if state == 153:
                                                return 0.134706467
                                            if state == 154:
                                                return -0.0421763249
                        if state == 14:
                            state = (
                                27
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 4.02657986)
                                else 28
                            )
                            if state == 27:
                                state = 49 if x["mag_peak"] < 17.6902924 else 50
                                if state == 49:
                                    return -0.0475415289
                                if state == 50:
                                    return 0.130417585
                            if state == 28:
                                return -0.0139626283
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 0.235476851)
                            else 16
                        )
                        if state == 15:
                            return -0.11138054
                        if state == 16:
                            state = (
                                31
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.00194454)
                                else 32
                            )
                            if state == 31:
                                state = 55 if x["mag_peak"] < 18.3040504 else 56
                                if state == 55:
                                    return 0.046488557
                                if state == 56:
                                    return -0.0876629204
                            if state == 32:
                                state = 57 if x["mag_peak"] < 17.3361511 else 58
                                if state == 57:
                                    return 0.15011768
                                if state == 58:
                                    state = (
                                        95
                                        if np.isnan(x["classtar_med"])
                                        or (x["classtar_med"] < 0.978249967)
                                        else 96
                                    )
                                    if state == 95:
                                        return -0.00772805652
                                    if state == 96:
                                        state = (
                                            133
                                            if x["distpsnr1_med"] < 1.11773992
                                            else 134
                                        )
                                        if state == 133:
                                            return 0.235405505
                                        if state == 134:
                                            return 0.0400924161
                if state == 4:
                    return 0.0924879164
            if state == 2:
                state = 5 if x["mag_peak"] < 18.6883812 else 6
                if state == 5:
                    state = 9 if np.isnan(x["t_lc"]) or (x["t_lc"] < 28.0183563) else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 1.01260233)
                            else 18
                        )
                        if state == 17:
                            return 0.0809862465
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.97407413)
                                else 34
                            )
                            if state == 33:
                                return -0.0324202999
                            if state == 34:
                                state = 61 if x["mag_peak"] < 18.6810589 else 62
                                if state == 61:
                                    return -0.084983021
                                if state == 62:
                                    return -0.354667902
                    if state == 10:
                        state = 19 if x["distpsnr1_med"] < 6.50275707 else 20
                        if state == 19:
                            state = (
                                35
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 6.04403353)
                                else 36
                            )
                            if state == 35:
                                state = 63 if x["mag_peak"] < 18.6269588 else 64
                                if state == 63:
                                    return -0.14464587
                                if state == 64:
                                    return 0.0135675399
                            if state == 36:
                                return 0.00823978242
                        if state == 20:
                            return 0.0769192949
                if state == 6:
                    state = (
                        11 if np.isnan(x["t_lc"]) or (x["t_lc"] < 30.9525528) else 12
                    )
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 2.00497437)
                            else 22
                        )
                        if state == 21:
                            state = (
                                37
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.96706593)
                                else 38
                            )
                            if state == 37:
                                return 0.0783226117
                            if state == 38:
                                state = 67 if x["mag_peak"] < 18.7803097 else 68
                                if state == 67:
                                    return 0.0457973965
                                if state == 68:
                                    return -0.0795310885
                        if state == 22:
                            state = (
                                39
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.91058445)
                                else 40
                            )
                            if state == 39:
                                return 0.00957260653
                            if state == 40:
                                state = 71 if x["mag_peak"] < 18.7593765 else 72
                                if state == 71:
                                    return -0.0487685241
                                if state == 72:
                                    return 0.106267028
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 1.49742436)
                            else 24
                        )
                        if state == 23:
                            return 0.024154406
                        if state == 24:
                            state = (
                                43
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.05279517)
                                else 44
                            )
                            if state == 43:
                                state = 77 if x["mag_peak"] < 18.8980637 else 78
                                if state == 77:
                                    return 0.0693663731
                                if state == 78:
                                    return -0.0685999393
                            if state == 44:
                                return -0.125860959
    elif num_booster == 69:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.9933681) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["col_det"]) or (x["col_det"] < 0.388279259) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.3189125)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.722298265)
                            else 16
                        )
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 17.7686005)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    35
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.489266872)
                                    else 36
                                )
                                if state == 35:
                                    state = (
                                        47
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.464395493)
                                        else 48
                                    )
                                    if state == 47:
                                        state = (
                                            55 if x["maggaia_med"] < 19.7448616 else 56
                                        )
                                        if state == 55:
                                            return 0.132338911
                                        if state == 56:
                                            return -0.0407316312
                                    if state == 48:
                                        return -0.0853430629
                                if state == 36:
                                    return -0.00554205058
                            if state == 26:
                                return -0.218222246
                        if state == 16:
                            return 0.0933317617
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.115482539)
                            else 18
                        )
                        if state == 17:
                            return 0.0903961957
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 18.9845695)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    39
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.57106578)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        49 if x["sgscore1_med"] < 0.00095833349 else 50
                                    )
                                    if state == 49:
                                        return -0.0733711049
                                    if state == 50:
                                        state = (
                                            57
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 20.4152145)
                                            else 58
                                        )
                                        if state == 57:
                                            state = (
                                                63
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.8823204)
                                                else 64
                                            )
                                            if state == 63:
                                                state = (
                                                    75
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.07397389)
                                                    else 76
                                                )
                                                if state == 75:
                                                    state = (
                                                        91
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.9741516)
                                                        else 92
                                                    )
                                                    if state == 91:
                                                        return 0.0258667171
                                                    if state == 92:
                                                        state = (
                                                            107
                                                            if x["col_det"]
                                                            < -0.293830872
                                                            else 108
                                                        )
                                                        if state == 107:
                                                            return 0.0683243051
                                                        if state == 108:
                                                            return -0.0664558113
                                                if state == 76:
                                                    state = (
                                                        93
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.4075127)
                                                        else 94
                                                    )
                                                    if state == 93:
                                                        state = (
                                                            109
                                                            if x["col_det"]
                                                            < 0.257719994
                                                            else 110
                                                        )
                                                        if state == 109:
                                                            return 0.111724086
                                                        if state == 110:
                                                            return -0.0502356291
                                                    if state == 94:
                                                        return 0.0733244121
                                            if state == 64:
                                                return 0.102920592
                                        if state == 58:
                                            return 0.0663229004
                                if state == 40:
                                    state = (
                                        51
                                        if np.isnan(x["sgscore1_med"])
                                        or (x["sgscore1_med"] < 0.00818154495)
                                        else 52
                                    )
                                    if state == 51:
                                        state = (
                                            59
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 18.8075485)
                                            else 60
                                        )
                                        if state == 59:
                                            state = (
                                                67 if x["mag_peak"] < 18.2623005 else 68
                                            )
                                            if state == 67:
                                                return 0.0271929074
                                            if state == 68:
                                                state = (
                                                    81
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 6.89007568)
                                                    else 82
                                                )
                                                if state == 81:
                                                    return -0.204100758
                                                if state == 82:
                                                    return 0.0174633041
                                        if state == 60:
                                            return 0.0556341819
                                    if state == 52:
                                        state = (
                                            61 if x["maggaia_med"] < 18.4089432 else 62
                                        )
                                        if state == 61:
                                            state = (
                                                71 if x["mag_peak"] < 17.8694439 else 72
                                            )
                                            if state == 71:
                                                return 0.118687756
                                            if state == 72:
                                                state = (
                                                    87
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 1.86068654)
                                                    else 88
                                                )
                                                if state == 87:
                                                    return -0.0800916776
                                                if state == 88:
                                                    state = (
                                                        99
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.8452969)
                                                        else 100
                                                    )
                                                    if state == 99:
                                                        return -0.0385379344
                                                    if state == 100:
                                                        state = (
                                                            115
                                                            if np.isnan(x["col_det"])
                                                            or (
                                                                x["col_det"]
                                                                < 0.00940132141
                                                            )
                                                            else 116
                                                        )
                                                        if state == 115:
                                                            return 0.0730156749
                                                        if state == 116:
                                                            return -0.0542820618
                                        if state == 62:
                                            state = (
                                                73
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.8759308)
                                                else 74
                                            )
                                            if state == 73:
                                                state = (
                                                    89
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 3.70439911)
                                                    else 90
                                                )
                                                if state == 89:
                                                    state = (
                                                        101
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.8266792)
                                                        else 102
                                                    )
                                                    if state == 101:
                                                        state = (
                                                            117
                                                            if x["col_det"]
                                                            < -0.190948963
                                                            else 118
                                                        )
                                                        if state == 117:
                                                            return 0.0627737641
                                                        if state == 118:
                                                            return -0.0749623999
                                                    if state == 102:
                                                        return 0.044227954
                                                if state == 90:
                                                    return 0.0335206352
                                            if state == 74:
                                                return -0.200612307
                            if state == 30:
                                return 0.113400847
                if state == 4:
                    return 0.0464231744
            if state == 2:
                return -0.0675002038
    elif num_booster == 70:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.982749999)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 17.9457626) else 4
                )
                if state == 3:
                    return 0.16409485
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.13833332)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.910034776)
                            else 14
                        )
                        if state == 13:
                            state = (
                                23
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 4.96669483)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    43
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.2781487)
                                    else 44
                                )
                                if state == 43:
                                    return -0.0733931288
                                if state == 44:
                                    return 0.0405038781
                            if state == 24:
                                return -0.135933176
                        if state == 14:
                            state = 25 if x["distpsnr1_med"] < 0.357926458 else 26
                            if state == 25:
                                state = (
                                    45
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.0350494)
                                    else 46
                                )
                                if state == 45:
                                    return 0.0426606983
                                if state == 46:
                                    return -0.171714351
                            if state == 26:
                                state = (
                                    47
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.4857502)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        71
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 25.985363)
                                        else 72
                                    )
                                    if state == 71:
                                        state = (
                                            105
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 19.0247154)
                                            else 106
                                        )
                                        if state == 105:
                                            state = (
                                                137
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 15.1069965)
                                                else 138
                                            )
                                            if state == 137:
                                                state = (
                                                    161
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.7214508)
                                                    else 162
                                                )
                                                if state == 161:
                                                    return -0.00193019689
                                                if state == 162:
                                                    state = (
                                                        187
                                                        if np.isnan(x["neargaia_med"])
                                                        or (
                                                            x["neargaia_med"]
                                                            < 12.2169247
                                                        )
                                                        else 188
                                                    )
                                                    if state == 187:
                                                        return 0.108489208
                                                    if state == 188:
                                                        state = (
                                                            215
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 19.4552498
                                                            )
                                                            else 216
                                                        )
                                                        if state == 215:
                                                            return -0.0876539499
                                                        if state == 216:
                                                            return 0.0635331199
                                            if state == 138:
                                                return 0.0969411954
                                        if state == 106:
                                            state = (
                                                139
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 20.9912148)
                                                else 140
                                            )
                                            if state == 139:
                                                state = (
                                                    165
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.3206997)
                                                    else 166
                                                )
                                                if state == 165:
                                                    return -0.211515799
                                                if state == 166:
                                                    return 0.0195533894
                                            if state == 140:
                                                return 0.033958964
                                    if state == 72:
                                        state = (
                                            107
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 27.914526)
                                            else 108
                                        )
                                        if state == 107:
                                            return 0.181647494
                                        if state == 108:
                                            state = (
                                                141
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 28.0101223)
                                                else 142
                                            )
                                            if state == 141:
                                                return -0.0638366491
                                            if state == 142:
                                                return 0.0799560323
                                if state == 48:
                                    return 0.0138213886
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 5.03724527)
                            else 16
                        )
                        if state == 15:
                            state = (
                                27
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 0.28277272)
                                else 28
                            )
                            if state == 27:
                                return 0.0640754402
                            if state == 28:
                                state = (
                                    49
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.3195992)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        75
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 13.0383167)
                                        else 76
                                    )
                                    if state == 75:
                                        state = (
                                            111
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 12.0029163)
                                            else 112
                                        )
                                        if state == 111:
                                            return -0.109243579
                                        if state == 112:
                                            return 0.0575959571
                                    if state == 76:
                                        return -0.18061316
                                if state == 50:
                                    return -0.011373274
                        if state == 16:
                            state = 29 if x["distpsnr1_med"] < 0.669703484 else 30
                            if state == 29:
                                state = (
                                    51
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 18.7544518)
                                    else 52
                                )
                                if state == 51:
                                    return 0.0961306691
                                if state == 52:
                                    state = (
                                        81
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 46.4895668)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            117
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 14.0219965)
                                            else 118
                                        )
                                        if state == 117:
                                            return -0.0281901918
                                        if state == 118:
                                            state = (
                                                145
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 20.0028706)
                                                else 146
                                            )
                                            if state == 145:
                                                return 0.0637237132
                                            if state == 146:
                                                state = (
                                                    175
                                                    if np.isnan(x["mag_det"])
                                                    or (x["mag_det"] < 19.3693008)
                                                    else 176
                                                )
                                                if state == 175:
                                                    return -0.0907387584
                                                if state == 176:
                                                    return 0.0707840025
                                    if state == 82:
                                        return -0.0510089472
                            if state == 30:
                                state = (
                                    53
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.7502499)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        83
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 46.9204216)
                                        else 84
                                    )
                                    if state == 83:
                                        state = (
                                            119
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 43.4699936)
                                            else 120
                                        )
                                        if state == 119:
                                            state = (
                                                147
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 29.9323387)
                                                else 148
                                            )
                                            if state == 147:
                                                return -0.0848652646
                                            if state == 148:
                                                return 0.00550279533
                                        if state == 120:
                                            return -0.341861874
                                    if state == 84:
                                        return 0.0246589743
                                if state == 54:
                                    return 0.0254747123
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.2572975) else 6
                )
                if state == 5:
                    return 0.114748366
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.00221634)
                        else 12
                    )
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.0434664488)
                            else 20
                        )
                        if state == 19:
                            return 0.066280745
                        if state == 20:
                            state = (
                                37
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 0.146489277)
                                else 38
                            )
                            if state == 37:
                                return 0.0531350859
                            if state == 38:
                                state = (
                                    61
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.5984001)
                                    else 62
                                )
                                if state == 61:
                                    return -0.159231335
                                if state == 62:
                                    state = (
                                        89
                                        if np.isnan(x["t_lc"])
                                        or (x["t_lc"] < 16.0401688)
                                        else 90
                                    )
                                    if state == 89:
                                        return -0.0740236193
                                    if state == 90:
                                        return 0.124998689
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 4.96957159)
                            else 22
                        )
                        if state == 21:
                            return 0.117693819
                        if state == 22:
                            return -0.026673004
    elif num_booster == 71:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 6.01491356)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.9484367) else 4
                )
                if state == 3:
                    state = 7 if x["maggaia_med"] < 20.1613083 else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.59305)
                            else 16
                        )
                        if state == 15:
                            state = 27 if x["col_det"] < 0.0927276611 else 28
                            if state == 27:
                                return 0.0298595335
                            if state == 28:
                                state = (
                                    47
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.8681221)
                                    else 48
                                )
                                if state == 47:
                                    return -0.110455088
                                if state == 48:
                                    return 0.0545819253
                        if state == 16:
                            return 0.037863981
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.1725006)
                            else 18
                        )
                        if state == 17:
                            return -0.047022935
                        if state == 18:
                            state = 31 if x["col_det"] < -0.192074299 else 32
                            if state == 31:
                                return -0.0252088327
                            if state == 32:
                                return 0.164469644
                if state == 4:
                    state = 9 if x["maggaia_med"] < 16.1606369 else 10
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.0212498)
                            else 20
                        )
                        if state == 19:
                            return 0.0317052267
                        if state == 20:
                            return -0.169558659
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3143997)
                            else 22
                        )
                        if state == 21:
                            state = (
                                35
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < -0.00742483139)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    53
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.5239983)
                                    else 54
                                )
                                if state == 53:
                                    state = 81 if x["col_peak"] < -0.140570164 else 82
                                    if state == 81:
                                        return -0.0856954083
                                    if state == 82:
                                        state = (
                                            111
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.501378059)
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                129
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < 0.0713787079)
                                                else 130
                                            )
                                            if state == 129:
                                                state = (
                                                    141
                                                    if np.isnan(x["col_det"])
                                                    or (x["col_det"] < -0.450780869)
                                                    else 142
                                                )
                                                if state == 141:
                                                    state = (
                                                        153
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.97724998
                                                        )
                                                        else 154
                                                    )
                                                    if state == 153:
                                                        return -0.0464855246
                                                    if state == 154:
                                                        return 0.0722080469
                                                if state == 142:
                                                    state = (
                                                        155
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.97874999
                                                        )
                                                        else 156
                                                    )
                                                    if state == 155:
                                                        state = (
                                                            171
                                                            if x["maggaia_med"]
                                                            < 19.7976112
                                                            else 172
                                                        )
                                                        if state == 171:
                                                            return -0.106467701
                                                        if state == 172:
                                                            return 0.0810725763
                                                    if state == 156:
                                                        return -0.112884708
                                            if state == 130:
                                                return 0.0436093286
                                        if state == 112:
                                            return -0.0798470229
                                if state == 54:
                                    state = (
                                        83
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.176204354)
                                        else 84
                                    )
                                    if state == 83:
                                        return -0.13128978
                                    if state == 84:
                                        return 0.00806938391
                            if state == 36:
                                state = (
                                    55
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.0444794)
                                    else 56
                                )
                                if state == 55:
                                    return -0.0689076409
                                if state == 56:
                                    state = (
                                        87
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < 0.598741531)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            117
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.277059734)
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                135
                                                if np.isnan(x["col_last"])
                                                or (x["col_last"] < -0.111291885)
                                                else 136
                                            )
                                            if state == 135:
                                                state = (
                                                    145
                                                    if x["col_det"] < 0.40860939
                                                    else 146
                                                )
                                                if state == 145:
                                                    state = (
                                                        159
                                                        if np.isnan(x["classtar_med"])
                                                        or (
                                                            x["classtar_med"]
                                                            < 0.975250006
                                                        )
                                                        else 160
                                                    )
                                                    if state == 159:
                                                        return -0.0318734124
                                                    if state == 160:
                                                        return 0.123966835
                                                if state == 146:
                                                    return -0.0465635955
                                            if state == 136:
                                                return -0.069920063
                                        if state == 118:
                                            return 0.12982972
                                    if state == 88:
                                        return 0.00479140785
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < -0.114649773)
                                else 38
                            )
                            if state == 37:
                                return 0.0460692346
                            if state == 38:
                                return -0.0623606741
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.2734909) else 6
                )
                if state == 5:
                    state = 11 if x["maggaia_med"] < 17.7177849 else 12
                    if state == 11:
                        return -0.0666163638
                    if state == 12:
                        return 0.0717070773
                if state == 6:
                    state = 13 if x["maggaia_med"] < 19.4565926 else 14
                    if state == 13:
                        state = (
                            23
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.6619492)
                            else 24
                        )
                        if state == 23:
                            state = (
                                39
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < 0.0790200233)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    61
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.8720131)
                                    else 62
                                )
                                if state == 61:
                                    return -0.0359382667
                                if state == 62:
                                    state = (
                                        93
                                        if np.isnan(x["col_peak"])
                                        or (x["col_peak"] < -0.179085732)
                                        else 94
                                    )
                                    if state == 93:
                                        return 0.0707477778
                                    if state == 94:
                                        return -0.0563684925
                            if state == 40:
                                state = (
                                    63
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.5676327)
                                    else 64
                                )
                                if state == 63:
                                    return 0.21215266
                                if state == 64:
                                    return 0.00717763137
                        if state == 24:
                            state = 41 if x["col_det"] < 0.240211487 else 42
                            if state == 41:
                                return 0.145864934
                            if state == 42:
                                return 0.00633149501
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.7841988)
                            else 26
                        )
                        if state == 25:
                            return 0.0688572451
                        if state == 26:
                            state = 43 if x["col_det"] < 0.399600029 else 44
                            if state == 43:
                                return -0.0899869725
                            if state == 44:
                                state = (
                                    69
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 19.2286091)
                                    else 70
                                )
                                if state == 69:
                                    return 0.110109456
                                if state == 70:
                                    return -0.0292252731
    elif num_booster == 72:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.3438282) else 2
            if state == 1:
                state = 3 if x["neargaia_med"] < 18.7965927 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.2540016)
                        else 8
                    )
                    if state == 7:
                        return -0.174102813
                    if state == 8:
                        state = 17 if x["neargaia_med"] < 0.729093134 else 18
                        if state == 17:
                            return 0.086602591
                        if state == 18:
                            return -0.0487584658
                if state == 4:
                    return 0.0731482133
            if state == 2:
                state = 5 if x["neargaia_med"] < 0.67176646 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.2589989)
                        else 12
                    )
                    if state == 11:
                        return -0.0968936756
                    if state == 12:
                        state = 21 if x["neargaia_med"] < 0.112941489 else 22
                        if state == 21:
                            return -0.068997778
                        if state == 22:
                            state = (
                                33
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.1819992)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    45
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.5976486)
                                    else 46
                                )
                                if state == 45:
                                    return 0.111155622
                                if state == 46:
                                    return -0.0467712432
                            if state == 34:
                                return -0.0344291739
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.9015007)
                        else 14
                    )
                    if state == 13:
                        state = (
                            23
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 0.908918142)
                            else 24
                        )
                        if state == 23:
                            return 0.0126109244
                        if state == 24:
                            return 0.177296475
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["neargaia_med"])
                            or (x["neargaia_med"] < 41.9921837)
                            else 26
                        )
                        if state == 25:
                            state = (
                                39
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 21.8069992)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    51
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.1272011)
                                    else 52
                                )
                                if state == 51:
                                    state = (
                                        65
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.7773514)
                                        else 66
                                    )
                                    if state == 65:
                                        return 0.0712078884
                                    if state == 66:
                                        state = (
                                            79
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.9248219)
                                            else 80
                                        )
                                        if state == 79:
                                            return -0.0489959307
                                        if state == 80:
                                            state = (
                                                93
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.38019848)
                                                else 94
                                            )
                                            if state == 93:
                                                state = (
                                                    111
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 17.0196342)
                                                    else 112
                                                )
                                                if state == 111:
                                                    state = (
                                                        133
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.1354027)
                                                        else 134
                                                    )
                                                    if state == 133:
                                                        return 0.0678860918
                                                    if state == 134:
                                                        return -0.0997833982
                                                if state == 112:
                                                    return 0.0882880837
                                            if state == 94:
                                                state = (
                                                    113
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 12.0403881)
                                                    else 114
                                                )
                                                if state == 113:
                                                    return -0.102572098
                                                if state == 114:
                                                    state = (
                                                        139
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.2981796)
                                                        else 140
                                                    )
                                                    if state == 139:
                                                        return 0.055326689
                                                    if state == 140:
                                                        state = (
                                                            157
                                                            if np.isnan(x["magnr_med"])
                                                            or (
                                                                x["magnr_med"]
                                                                < 21.2119999
                                                            )
                                                            else 158
                                                        )
                                                        if state == 157:
                                                            return -0.0265440717
                                                        if state == 158:
                                                            return 0.134725258
                                if state == 52:
                                    state = (
                                        67
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 19.0197372)
                                        else 68
                                    )
                                    if state == 67:
                                        return 0.0465472192
                                    if state == 68:
                                        state = (
                                            83
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.2294731)
                                            else 84
                                        )
                                        if state == 83:
                                            state = (
                                                99
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.65082836)
                                                else 100
                                            )
                                            if state == 99:
                                                state = (
                                                    119
                                                    if np.isnan(x["t_lc"])
                                                    or (x["t_lc"] < 11.9853935)
                                                    else 120
                                                )
                                                if state == 119:
                                                    return 0.0274241641
                                                if state == 120:
                                                    return -0.155722469
                                            if state == 100:
                                                return 0.0061150617
                                        if state == 84:
                                            state = (
                                                101
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 2.95721006)
                                                else 102
                                            )
                                            if state == 101:
                                                return 0.0248521287
                                            if state == 102:
                                                return -0.0864893198
                            if state == 40:
                                state = (
                                    53
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.4934006)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        69
                                        if np.isnan(x["mag_last"])
                                        or (x["mag_last"] < 18.7315445)
                                        else 70
                                    )
                                    if state == 69:
                                        return -0.0817153528
                                    if state == 70:
                                        state = (
                                            85
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.2487068)
                                            else 86
                                        )
                                        if state == 85:
                                            state = (
                                                103
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 7.00233746)
                                                else 104
                                            )
                                            if state == 103:
                                                return 0.100094438
                                            if state == 104:
                                                return -0.0507813878
                                        if state == 86:
                                            return -0.0364506319
                                if state == 54:
                                    return -0.125512391
                        if state == 26:
                            state = (
                                41
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 22.9119987)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    55
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.4260006)
                                    else 56
                                )
                                if state == 55:
                                    return -0.0994307771
                                if state == 56:
                                    return 0.0690485612
                            if state == 42:
                                return 0.0869835839
    elif num_booster == 73:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.0730019) else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.8446541) else 4
                )
                if state == 3:
                    state = 7 if x["neargaia_med"] < 1.2534368 else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.762738109)
                            else 16
                        )
                        if state == 15:
                            return 0.0432565846
                        if state == 16:
                            return 0.180752307
                    if state == 8:
                        return -0.0834545866
                if state == 4:
                    state = 9 if x["neargaia_med"] < 0.651900291 else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.739166677)
                            else 18
                        )
                        if state == 17:
                            return -0.0582093857
                        if state == 18:
                            return 0.0748336241
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.750833392)
                            else 20
                        )
                        if state == 19:
                            return -0.211264133
                        if state == 20:
                            return 0.00774144055
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 17.940361) else 6
                )
                if state == 5:
                    return 0.0764379129
                if state == 6:
                    state = 13 if x["neargaia_med"] < 13.6749029 else 14
                    if state == 13:
                        state = (
                            23
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.699642956)
                            else 24
                        )
                        if state == 23:
                            state = 29 if x["col_peak"] < -0.194995403 else 30
                            if state == 29:
                                return 0.0308102984
                            if state == 30:
                                state = (
                                    37
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.7638512)
                                    else 38
                                )
                                if state == 37:
                                    return -0.107249938
                                if state == 38:
                                    return -0.00310205016
                        if state == 24:
                            state = 31 if x["col_peak"] < 0.325536728 else 32
                            if state == 31:
                                state = (
                                    39
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.9369011)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        51
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.955711901)
                                        else 52
                                    )
                                    if state == 51:
                                        return -0.135918647
                                    if state == 52:
                                        return 0.00733594503
                                if state == 40:
                                    return 0.0502684563
                            if state == 32:
                                state = (
                                    41
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.567749)
                                    else 42
                                )
                                if state == 41:
                                    return 0.0914780051
                                if state == 42:
                                    state = (
                                        55
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 2.54708862)
                                        else 56
                                    )
                                    if state == 55:
                                        state = (
                                            69 if x["col_peak"] < 0.428220272 else 70
                                        )
                                        if state == 69:
                                            return 0.0619008653
                                        if state == 70:
                                            state = (
                                                89
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 20.2425003)
                                                else 90
                                            )
                                            if state == 89:
                                                return -0.0420725867
                                            if state == 90:
                                                return 0.128578484
                                    if state == 56:
                                        return -0.076478295
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.344642997)
                            else 26
                        )
                        if state == 25:
                            return -0.0828387141
                        if state == 26:
                            state = (
                                33
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < -0.171945572)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    43
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.7579994)
                                    else 44
                                )
                                if state == 43:
                                    state = (
                                        57
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.12787342)
                                        else 58
                                    )
                                    if state == 57:
                                        state = (
                                            71
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.310999215)
                                            else 72
                                        )
                                        if state == 71:
                                            state = (
                                                91
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 17.9225006)
                                                else 92
                                            )
                                            if state == 91:
                                                return 0.0571432263
                                            if state == 92:
                                                state = (
                                                    111
                                                    if x["distpsnr1_med"] < 1.46403098
                                                    else 112
                                                )
                                                if state == 111:
                                                    return -0.0823560879
                                                if state == 112:
                                                    return 0.0499434695
                                        if state == 72:
                                            return 0.0285692811
                                    if state == 58:
                                        return 0.0755676627
                                if state == 44:
                                    state = (
                                        59
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.796976566)
                                        else 60
                                    )
                                    if state == 59:
                                        state = (
                                            73
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.265727997)
                                            else 74
                                        )
                                        if state == 73:
                                            state = (
                                                93
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.802)
                                                else 94
                                            )
                                            if state == 93:
                                                return 0.00273483316
                                            if state == 94:
                                                state = (
                                                    115
                                                    if x["distpsnr1_med"] < 0.743328214
                                                    else 116
                                                )
                                                if state == 115:
                                                    return 0.111993328
                                                if state == 116:
                                                    return -0.0496215187
                                        if state == 74:
                                            return -0.00653232308
                                    if state == 60:
                                        state = (
                                            75
                                            if np.isnan(x["col_peak"])
                                            or (x["col_peak"] < -0.267653465)
                                            else 76
                                        )
                                        if state == 75:
                                            state = (
                                                95
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.4189987)
                                                else 96
                                            )
                                            if state == 95:
                                                state = (
                                                    117
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 1.80020499)
                                                    else 118
                                                )
                                                if state == 117:
                                                    return -0.152993739
                                                if state == 118:
                                                    return -0.0094519509
                                            if state == 96:
                                                state = (
                                                    119
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 1.87533307)
                                                    else 120
                                                )
                                                if state == 119:
                                                    return -0.060287267
                                                if state == 120:
                                                    state = (
                                                        139
                                                        if x["distpsnr1_med"]
                                                        < 7.44950581
                                                        else 140
                                                    )
                                                    if state == 139:
                                                        return 0.103179142
                                                    if state == 140:
                                                        return -0.0779617056
                                        if state == 76:
                                            return -0.112440698
                            if state == 34:
                                state = (
                                    45
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.6357727)
                                    else 46
                                )
                                if state == 45:
                                    return 0.0195030607
                                if state == 46:
                                    state = (
                                        63
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.41390264)
                                        else 64
                                    )
                                    if state == 63:
                                        return 0.138021335
                                    if state == 64:
                                        state = (
                                            81 if x["col_peak"] < 0.140039116 else 82
                                        )
                                        if state == 81:
                                            return 0.0618568771
                                        if state == 82:
                                            return -0.0953302011
    elif num_booster == 74:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.2779999) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 0.672370434)
                    else 4
                )
                if state == 3:
                    return 0.0712980777
                if state == 4:
                    return 0.244142517
            if state == 2:
                state = 5 if x["neargaia_med"] < 1.00998712 else 6
                if state == 5:
                    state = 11 if x["distpsnr1_med"] < 0.724218547 else 12
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.1819992)
                            else 18
                        )
                        if state == 17:
                            return 0.0423621014
                        if state == 18:
                            return -0.0790036544
                    if state == 12:
                        return -0.138221651
                if state == 6:
                    state = 13 if x["distpsnr1_med"] < 0.37286818 else 14
                    if state == 13:
                        return -0.0754689872
                    if state == 14:
                        state = (
                            21
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.9095001)
                            else 22
                        )
                        if state == 21:
                            state = (
                                29
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.585833549)
                                else 30
                            )
                            if state == 29:
                                return 0.242358685
                            if state == 30:
                                return -0.00442011096
                        if state == 22:
                            state = (
                                31
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.606666684)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    43
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.574999928)
                                    else 44
                                )
                                if state == 43:
                                    state = (
                                        55
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.238675594)
                                        else 56
                                    )
                                    if state == 55:
                                        state = (
                                            65
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.114652753)
                                            else 66
                                        )
                                        if state == 65:
                                            return -0.102924243
                                        if state == 66:
                                            state = (
                                                81
                                                if x["maggaia_med"] < 18.8319931
                                                else 82
                                            )
                                            if state == 81:
                                                state = (
                                                    93
                                                    if x["distpsnr1_med"] < 2.83863068
                                                    else 94
                                                )
                                                if state == 93:
                                                    return 0.0208922252
                                                if state == 94:
                                                    return -0.111313343
                                            if state == 82:
                                                state = (
                                                    95
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (x["distpsnr1_med"] < 4.58022213)
                                                    else 96
                                                )
                                                if state == 95:
                                                    return 0.0302995834
                                                if state == 96:
                                                    return 0.140078962
                                    if state == 56:
                                        return -0.0985867456
                                if state == 44:
                                    state = (
                                        57
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.210308552)
                                        else 58
                                    )
                                    if state == 57:
                                        return -0.0824405104
                                    if state == 58:
                                        return 0.0428873748
                            if state == 32:
                                state = (
                                    45
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.623571515)
                                    else 46
                                )
                                if state == 45:
                                    return 0.0808115453
                                if state == 46:
                                    state = (
                                        61
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.124866009)
                                        else 62
                                    )
                                    if state == 61:
                                        state = (
                                            73
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.0172569491)
                                            else 74
                                        )
                                        if state == 73:
                                            return -0.0858796909
                                        if state == 74:
                                            state = (
                                                89
                                                if x["maggaia_med"] < 14.4506378
                                                else 90
                                            )
                                            if state == 89:
                                                return -0.115589239
                                            if state == 90:
                                                state = (
                                                    103
                                                    if np.isnan(x["distpsnr1_med"])
                                                    or (
                                                        x["distpsnr1_med"] < 0.744685233
                                                    )
                                                    else 104
                                                )
                                                if state == 103:
                                                    return 0.140498906
                                                if state == 104:
                                                    state = (
                                                        115
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 20.8354988)
                                                        else 116
                                                    )
                                                    if state == 115:
                                                        state = (
                                                            125
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.841428638
                                                            )
                                                            else 126
                                                        )
                                                        if state == 125:
                                                            return 0.0404921807
                                                        if state == 126:
                                                            return -0.0378449857
                                                    if state == 116:
                                                        state = (
                                                            127
                                                            if np.isnan(x["rb_med"])
                                                            or (
                                                                x["rb_med"]
                                                                < 0.726190507
                                                            )
                                                            else 128
                                                        )
                                                        if state == 127:
                                                            return -0.11261908
                                                        if state == 128:
                                                            return 0.00787233748
                                    if state == 62:
                                        state = (
                                            75
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.93513298)
                                            else 76
                                        )
                                        if state == 75:
                                            return 0.179750547
                                        if state == 76:
                                            state = (
                                                91
                                                if x["maggaia_med"] < 18.6042709
                                                else 92
                                            )
                                            if state == 91:
                                                return -0.0860125422
                                            if state == 92:
                                                return 0.0495198183
    elif num_booster == 75:
        state = 0
        if state == 0:
            state = 1 if x["mag_peak"] < 18.8004799 else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 17.9275513) else 4
                )
                if state == 3:
                    return -0.107186332
                if state == 4:
                    state = 9 if x["col_peak"] < 0.383770943 else 10
                    if state == 9:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.731666803)
                            else 16
                        )
                        if state == 15:
                            state = 21 if x["distpsnr1_med"] < 1.55287409 else 22
                            if state == 21:
                                state = (
                                    33
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.557857156)
                                    else 34
                                )
                                if state == 33:
                                    return 0.0609468035
                                if state == 34:
                                    state = (
                                        55
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.568384886)
                                        else 56
                                    )
                                    if state == 55:
                                        return 0.0352977775
                                    if state == 56:
                                        return -0.143867925
                            if state == 22:
                                state = (
                                    35
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.245000005)
                                    else 36
                                )
                                if state == 35:
                                    return -0.0441661403
                                if state == 36:
                                    state = (
                                        57
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.34271574)
                                        else 58
                                    )
                                    if state == 57:
                                        return -0.0670760646
                                    if state == 58:
                                        state = (
                                            89
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 8.95928764)
                                            else 90
                                        )
                                        if state == 89:
                                            state = (
                                                125
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.46805)
                                                else 126
                                            )
                                            if state == 125:
                                                return 0.105879731
                                            if state == 126:
                                                return -0.0588838644
                                        if state == 90:
                                            return -0.0340332165
                        if state == 16:
                            state = 23 if x["distpsnr1_med"] < 0.674440026 else 24
                            if state == 23:
                                state = (
                                    37
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.743333459)
                                    else 38
                                )
                                if state == 37:
                                    return 0.0533294342
                                if state == 38:
                                    state = (
                                        59
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.717114508)
                                        else 60
                                    )
                                    if state == 59:
                                        return -0.0157517288
                                    if state == 60:
                                        return -0.212598234
                            if state == 24:
                                state = (
                                    39
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.912500024)
                                    else 40
                                )
                                if state == 39:
                                    return 0.119471379
                                if state == 40:
                                    return -0.0381383933
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.579999924)
                            else 18
                        )
                        if state == 17:
                            state = (
                                25
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 3.42407608)
                                else 26
                            )
                            if state == 25:
                                return -0.103446148
                            if state == 26:
                                return 0.0692989007
                        if state == 18:
                            state = 27 if x["distpsnr1_med"] < 0.128420234 else 28
                            if state == 27:
                                return -0.0502890088
                            if state == 28:
                                state = (
                                    45
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.907500088)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        67
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 3.13612318)
                                        else 68
                                    )
                                    if state == 67:
                                        return 0.13419953
                                    if state == 68:
                                        return -0.0262248293
                                if state == 46:
                                    return 0.0137903709
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.7922497) else 6
                )
                if state == 5:
                    return 0.11914444
                if state == 6:
                    state = 11 if x["col_peak"] < -0.128970146 else 12
                    if state == 11:
                        return -0.115486085
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.708928466)
                            else 20
                        )
                        if state == 19:
                            state = (
                                29
                                if np.isnan(x["distpsnr1_med"])
                                or (x["distpsnr1_med"] < 1.86411941)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    47
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.698333263)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        71
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.780863047)
                                        else 72
                                    )
                                    if state == 71:
                                        return -0.00652613817
                                    if state == 72:
                                        state = (
                                            107
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 7.01430559)
                                            else 108
                                        )
                                        if state == 107:
                                            state = (
                                                137
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.448101)
                                                else 138
                                            )
                                            if state == 137:
                                                state = (
                                                    171
                                                    if np.isnan(x["sgscore1_med"])
                                                    or (
                                                        x["sgscore1_med"]
                                                        < 0.00372916507
                                                    )
                                                    else 172
                                                )
                                                if state == 171:
                                                    return -0.163810447
                                                if state == 172:
                                                    return 0.0186293479
                                            if state == 138:
                                                return -0.14699851
                                        if state == 108:
                                            return 0.0498906039
                                if state == 48:
                                    return 0.0673705265
                            if state == 30:
                                state = (
                                    49
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.560000122)
                                    else 50
                                )
                                if state == 49:
                                    return -0.0239703935
                                if state == 50:
                                    state = (
                                        77
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.9955318)
                                        else 78
                                    )
                                    if state == 77:
                                        return 0.144012779
                                    if state == 78:
                                        return 0.00184606749
                        if state == 20:
                            state = 31 if x["distpsnr1_med"] < 4.55362606 else 32
                            if state == 31:
                                state = (
                                    51
                                    if np.isnan(x["rb_med"])
                                    or (x["rb_med"] < 0.907500029)
                                    else 52
                                )
                                if state == 51:
                                    return -0.0981205553
                                if state == 52:
                                    return 0.0136789763
                            if state == 32:
                                return 0.0462184586
    elif num_booster == 76:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.2586708) else 2
            if state == 1:
                state = 3 if x["sgscore1_med"] < 0.105664 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.5321503)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.879500031)
                            else 16
                        )
                        if state == 15:
                            return -0.0279273167
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 12.1932354)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    45
                                    if np.isnan(x["col_last"])
                                    or (x["col_last"] < 0.31063652)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        67 if x["distpsnr1_med"] < 0.133981675 else 68
                                    )
                                    if state == 67:
                                        return -0.0777110979
                                    if state == 68:
                                        return 0.0828076005
                                if state == 46:
                                    return -0.0185595248
                            if state == 28:
                                state = 47 if x["col_last"] < 0.0841341019 else 48
                                if state == 47:
                                    return 0.0599225126
                                if state == 48:
                                    state = (
                                        71 if x["distpsnr1_med"] < 0.163341209 else 72
                                    )
                                    if state == 71:
                                        return 0.0828165635
                                    if state == 72:
                                        return -0.0550624467
                    if state == 8:
                        return -0.0453162901
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.678299)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.981750011)
                            else 18
                        )
                        if state == 17:
                            state = 29 if x["neargaia_med"] < 31.5755024 else 30
                            if state == 29:
                                state = (
                                    49
                                    if np.isnan(x["col_last"])
                                    or (x["col_last"] < 0.091840744)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        73 if x["distpsnr1_med"] < 3.51136827 else 74
                                    )
                                    if state == 73:
                                        return -0.0324525759
                                    if state == 74:
                                        return 0.0945785865
                                if state == 50:
                                    return -0.0442947671
                            if state == 30:
                                state = (
                                    51
                                    if np.isnan(x["col_last"])
                                    or (x["col_last"] < 0.0828375816)
                                    else 52
                                )
                                if state == 51:
                                    return -0.121666551
                                if state == 52:
                                    state = (
                                        79 if x["distpsnr1_med"] < 2.52095461 else 80
                                    )
                                    if state == 79:
                                        return -0.0901050195
                                    if state == 80:
                                        return 0.0751659125
                        if state == 18:
                            state = 31 if x["neargaia_med"] < 15.8212738 else 32
                            if state == 31:
                                state = (
                                    53
                                    if np.isnan(x["col_last"])
                                    or (x["col_last"] < -0.129797935)
                                    else 54
                                )
                                if state == 53:
                                    state = (
                                        81 if x["distpsnr1_med"] < 4.48163223 else 82
                                    )
                                    if state == 81:
                                        return -0.136168137
                                    if state == 82:
                                        return 0.0416624956
                                if state == 54:
                                    return 0.0197003987
                            if state == 32:
                                state = 55 if x["col_last"] < -0.100398064 else 56
                                if state == 55:
                                    return -0.0325012952
                                if state == 56:
                                    state = (
                                        85 if x["distpsnr1_med"] < 0.530721128 else 86
                                    )
                                    if state == 85:
                                        return -0.052325096
                                    if state == 86:
                                        return 0.144888476
                    if state == 10:
                        return 0.0979517922
            if state == 2:
                state = 5 if x["sgscore1_med"] < 0.0876875073 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4787998)
                        else 12
                    )
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.969249964)
                            else 20
                        )
                        if state == 19:
                            state = 33 if x["neargaia_med"] < 1.8679775 else 34
                            if state == 33:
                                return -0.0869081616
                            if state == 34:
                                state = (
                                    57
                                    if np.isnan(x["col_last"])
                                    or (x["col_last"] < 0.00699043274)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        87 if x["distpsnr1_med"] < 1.93157458 else 88
                                    )
                                    if state == 87:
                                        return 0.0521573275
                                    if state == 88:
                                        return -0.093683742
                                if state == 58:
                                    return 0.0273364801
                        if state == 20:
                            state = 35 if x["neargaia_med"] < 23.6988029 else 36
                            if state == 35:
                                state = 59 if x["col_last"] < 0.365996361 else 60
                                if state == 59:
                                    return -0.00745740114
                                if state == 60:
                                    state = (
                                        93 if x["distpsnr1_med"] < 0.607172728 else 94
                                    )
                                    if state == 93:
                                        return 0.00657854555
                                    if state == 94:
                                        state = (
                                            111
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.52378273)
                                            else 112
                                        )
                                        if state == 111:
                                            state = (
                                                127
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 25.9191551)
                                                else 128
                                            )
                                            if state == 127:
                                                return -0.00118076906
                                            if state == 128:
                                                return 0.171339661
                                        if state == 112:
                                            return 0.0204443038
                            if state == 36:
                                state = 61 if x["col_last"] < 0.307777405 else 62
                                if state == 61:
                                    return -0.0620729364
                                if state == 62:
                                    state = (
                                        95 if x["distpsnr1_med"] < 1.27908754 else 96
                                    )
                                    if state == 95:
                                        return 0.0741915107
                                    if state == 96:
                                        return -0.0441414416
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.981250048)
                            else 22
                        )
                        if state == 21:
                            return -0.138932049
                        if state == 22:
                            return 0.0458429903
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0257988)
                        else 14
                    )
                    if state == 13:
                        state = (
                            23
                            if np.isnan(x["classtar_med"])
                            or (x["classtar_med"] < 0.972749949)
                            else 24
                        )
                        if state == 23:
                            return -0.0186901242
                        if state == 24:
                            state = 39 if x["neargaia_med"] < 29.4478798 else 40
                            if state == 39:
                                return -0.344161242
                            if state == 40:
                                return 0.0154665168
                    if state == 14:
                        return -0.0158795752
    elif num_booster == 77:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.361666739) else 2
            if state == 1:
                return -0.078910403
            if state == 2:
                state = (
                    3 if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.47830677) else 4
                )
                if state == 3:
                    state = (
                        5
                        if np.isnan(x["col_last"]) or (x["col_last"] < 0.234057903)
                        else 6
                    )
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 20.6033096)
                            else 10
                        )
                        if state == 9:
                            state = 15 if x["neargaia_med"] < 0.651751518 else 16
                            if state == 15:
                                state = (
                                    27
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.3458214)
                                    else 28
                                )
                                if state == 27:
                                    return 0.168926671
                                if state == 28:
                                    state = 41 if x["mag_peak"] < 17.7748909 else 42
                                    if state == 41:
                                        return 0.122072116
                                    if state == 42:
                                        state = (
                                            53 if x["maggaia_med"] < 18.6837425 else 54
                                        )
                                        if state == 53:
                                            return -0.137629956
                                        if state == 54:
                                            state = (
                                                69
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.836904645)
                                                else 70
                                            )
                                            if state == 69:
                                                return 0.113909476
                                            if state == 70:
                                                return -0.0769633427
                            if state == 16:
                                state = (
                                    29
                                    if np.isnan(x["mag_last"])
                                    or (x["mag_last"] < 18.8619499)
                                    else 30
                                )
                                if state == 29:
                                    state = (
                                        43
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 17.7020035)
                                        else 44
                                    )
                                    if state == 43:
                                        state = (
                                            55 if x["maggaia_med"] < 18.4197159 else 56
                                        )
                                        if state == 55:
                                            state = (
                                                71
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.627857149)
                                                else 72
                                            )
                                            if state == 71:
                                                return 0.0482899919
                                            if state == 72:
                                                return -0.0973490104
                                        if state == 56:
                                            state = (
                                                73
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.71333313)
                                                else 74
                                            )
                                            if state == 73:
                                                return 0.0989766866
                                            if state == 74:
                                                return -0.0138871046
                                    if state == 44:
                                        state = (
                                            57 if x["maggaia_med"] < 19.0522499 else 58
                                        )
                                        if state == 57:
                                            state = (
                                                75
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.753095031)
                                                else 76
                                            )
                                            if state == 75:
                                                state = (
                                                    89
                                                    if x["col_peak"] < 0.0768756866
                                                    else 90
                                                )
                                                if state == 89:
                                                    return -0.0188997723
                                                if state == 90:
                                                    return -0.308665633
                                            if state == 76:
                                                return -0.00699757412
                                        if state == 58:
                                            return -0.032296896
                                if state == 30:
                                    state = 45 if x["mag_peak"] < 18.9864883 else 46
                                    if state == 45:
                                        state = (
                                            59
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 15.7432556)
                                            else 60
                                        )
                                        if state == 59:
                                            return -0.0313595347
                                        if state == 60:
                                            state = (
                                                81
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.941071391)
                                                else 82
                                            )
                                            if state == 81:
                                                state = (
                                                    99
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.180814743)
                                                    else 100
                                                )
                                                if state == 99:
                                                    state = (
                                                        111
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.958857775
                                                        )
                                                        else 112
                                                    )
                                                    if state == 111:
                                                        return 0.0242167283
                                                    if state == 112:
                                                        state = (
                                                            121
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.966250002
                                                            )
                                                            else 122
                                                        )
                                                        if state == 121:
                                                            return -0.0393823385
                                                        if state == 122:
                                                            return 0.111385599
                                                if state == 100:
                                                    return -0.028355917
                                            if state == 82:
                                                return -0.0316946991
                                    if state == 46:
                                        state = (
                                            61
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 19.5241203)
                                            else 62
                                        )
                                        if state == 61:
                                            state = (
                                                83
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.663452446)
                                                else 84
                                            )
                                            if state == 83:
                                                state = (
                                                    103
                                                    if x["col_peak"] < 0.239075661
                                                    else 104
                                                )
                                                if state == 103:
                                                    return -0.00487481616
                                                if state == 104:
                                                    state = (
                                                        115
                                                        if np.isnan(x["distnr_med"])
                                                        or (
                                                            x["distnr_med"]
                                                            < 0.523185194
                                                        )
                                                        else 116
                                                    )
                                                    if state == 115:
                                                        return 0.0976433828
                                                    if state == 116:
                                                        state = (
                                                            125
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.977750003
                                                            )
                                                            else 126
                                                        )
                                                        if state == 125:
                                                            return 0.0536496267
                                                        if state == 126:
                                                            return -0.0901585221
                                            if state == 84:
                                                return -0.0487781838
                                        if state == 62:
                                            state = (
                                                85
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.836071551)
                                                else 86
                                            )
                                            if state == 85:
                                                return -0.176286623
                                            if state == 86:
                                                return 0.0132082673
                        if state == 10:
                            return -0.104939543
                    if state == 6:
                        return 0.0315555483
                if state == 4:
                    state = 7 if x["col_last"] < 1.05046225 else 8
                    if state == 7:
                        return 0.213676199
                    if state == 8:
                        return 0.0323837996
    elif num_booster == 78:
        state = 0
        if state == 0:
            state = 1 if x["col_last"] < 0.216013581 else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_last"]) or (x["mag_last"] < 17.8150463) else 4
                )
                if state == 3:
                    return 0.210751221
                if state == 4:
                    state = 7 if x["col_peak"] < -0.120978355 else 8
                    if state == 7:
                        return -0.0452811457
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 0.9427315)
                            else 16
                        )
                        if state == 15:
                            return -0.0717971921
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.96097231)
                                else 26
                            )
                            if state == 25:
                                return 0.0723676309
                            if state == 26:
                                state = 41 if x["col_last"] < 0.120317459 else 42
                                if state == 41:
                                    state = (
                                        55
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.53374958)
                                        else 56
                                    )
                                    if state == 55:
                                        return 0.0380314477
                                    if state == 56:
                                        return -0.0815930739
                                if state == 42:
                                    return 0.0218937807
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0384121) else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.45635128)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 2.98047447)
                            else 18
                        )
                        if state == 17:
                            state = (
                                27
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.0431828499)
                                else 28
                            )
                            if state == 27:
                                return -0.0328373648
                            if state == 28:
                                state = (
                                    43
                                    if np.isnan(x["col_last"])
                                    or (x["col_last"] < 0.566111565)
                                    else 44
                                )
                                if state == 43:
                                    state = 59 if x["col_det"] < -0.317011356 else 60
                                    if state == 59:
                                        return -0.0471367389
                                    if state == 60:
                                        state = (
                                            71
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < 0.347614288)
                                            else 72
                                        )
                                        if state == 71:
                                            state = (
                                                87
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0627025515)
                                                else 88
                                            )
                                            if state == 87:
                                                return 0.0145603977
                                            if state == 88:
                                                state = (
                                                    101
                                                    if x["maggaia_med"] < 17.0650349
                                                    else 102
                                                )
                                                if state == 101:
                                                    return 0.00340158376
                                                if state == 102:
                                                    state = (
                                                        115
                                                        if np.isnan(x["col_det"])
                                                        or (x["col_det"] < -0.101070404)
                                                        else 116
                                                    )
                                                    if state == 115:
                                                        state = (
                                                            123
                                                            if np.isnan(
                                                                x["distpsnr1_med"]
                                                            )
                                                            or (
                                                                x["distpsnr1_med"]
                                                                < 0.330653608
                                                            )
                                                            else 124
                                                        )
                                                        if state == 123:
                                                            return -0.0413943902
                                                        if state == 124:
                                                            return 0.16859594
                                                    if state == 116:
                                                        return 0.0276313964
                                        if state == 72:
                                            return -0.00385515019
                                if state == 44:
                                    return 0.000386000029
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 6.0197916)
                                else 30
                            )
                            if state == 29:
                                return -0.0606127083
                            if state == 30:
                                return 0.0240342636
                    if state == 10:
                        return -0.216398999
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < 0.326630592)
                        else 12
                    )
                    if state == 11:
                        state = (
                            19
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 4.04718781)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.03188086)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    47
                                    if np.isnan(x["col_last"])
                                    or (x["col_last"] < 0.601377487)
                                    else 48
                                )
                                if state == 47:
                                    state = (
                                        63
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.0352582932)
                                        else 64
                                    )
                                    if state == 63:
                                        return -0.0396975987
                                    if state == 64:
                                        return 0.0556385517
                                if state == 48:
                                    return 0.0805034861
                            if state == 32:
                                return 0.0580238812
                        if state == 20:
                            state = (
                                33
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 5.03724527)
                                else 34
                            )
                            if state == 33:
                                return -0.125894889
                            if state == 34:
                                state = 49 if x["col_last"] < 0.443576336 else 50
                                if state == 49:
                                    return -0.0543293543
                                if state == 50:
                                    state = 65 if x["col_det"] < -0.230899811 else 66
                                    if state == 65:
                                        return 0.0889262334
                                    if state == 66:
                                        state = (
                                            81 if x["col_det"] < -0.0132198334 else 82
                                        )
                                        if state == 81:
                                            return -0.0902719051
                                        if state == 82:
                                            state = (
                                                97
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 5.92399883)
                                                else 98
                                            )
                                            if state == 97:
                                                return 0.121088587
                                            if state == 98:
                                                state = (
                                                    113
                                                    if x["maggaia_med"] < 15.9789343
                                                    else 114
                                                )
                                                if state == 113:
                                                    return 0.0843971968
                                                if state == 114:
                                                    state = (
                                                        121
                                                        if x["col_det"] < 0.147988319
                                                        else 122
                                                    )
                                                    if state == 121:
                                                        return 0.0851029456
                                                    if state == 122:
                                                        state = (
                                                            131
                                                            if x["distpsnr1_med"]
                                                            < 1.23333895
                                                            else 132
                                                        )
                                                        if state == 131:
                                                            return 0.0295115188
                                                        if state == 132:
                                                            return -0.104112424
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 5.96873283)
                            else 22
                        )
                        if state == 21:
                            state = (
                                35
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.051898)
                                else 36
                            )
                            if state == 35:
                                return 0.0890575796
                            if state == 36:
                                return -0.114710197
                        if state == 22:
                            return 0.141109034
    elif num_booster == 79:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.00481249997 else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 8.87357616) else 4
                if state == 3:
                    return -0.0155735482
                if state == 4:
                    state = 7 if x["mag_peak"] < 18.6954308 else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.950161815)
                            else 14
                        )
                        if state == 13:
                            state = (
                                23
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.637327671)
                                else 24
                            )
                            if state == 23:
                                return 0.103734836
                            if state == 24:
                                return -0.0898486525
                        if state == 14:
                            return 0.136357635
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.368710339)
                            else 16
                        )
                        if state == 15:
                            return -0.0581432804
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.15471816)
                                else 26
                            )
                            if state == 25:
                                return 0.0887534991
                            if state == 26:
                                state = (
                                    41
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.979750037)
                                    else 42
                                )
                                if state == 41:
                                    return -0.0880085081
                                if state == 42:
                                    return 0.0793303996
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 37.0471268) else 6
                if state == 5:
                    state = 9 if x["mag_peak"] < 17.7877331 else 10
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.746828616)
                            else 18
                        )
                        if state == 17:
                            state = (
                                27
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.711905003)
                                else 28
                            )
                            if state == 27:
                                return -0.0182658173
                            if state == 28:
                                state = (
                                    45
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.978500009)
                                    else 46
                                )
                                if state == 45:
                                    return -0.368861586
                                if state == 46:
                                    return -0.0070279059
                        if state == 18:
                            return -0.056777738
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.798732221)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.658872008)
                                else 32
                            )
                            if state == 31:
                                state = (
                                    49
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.94174999)
                                    else 50
                                )
                                if state == 49:
                                    return -0.102880552
                                if state == 50:
                                    state = 67 if x["maggaia_med"] < 14.8557167 else 68
                                    if state == 67:
                                        return 0.084096536
                                    if state == 68:
                                        state = (
                                            89
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.17551057)
                                            else 90
                                        )
                                        if state == 89:
                                            return -0.0971779898
                                        if state == 90:
                                            state = (
                                                99
                                                if x["maggaia_med"] < 19.0867729
                                                else 100
                                            )
                                            if state == 99:
                                                state = (
                                                    107
                                                    if np.isnan(x["col_det"])
                                                    or (x["col_det"] < 0.145395279)
                                                    else 108
                                                )
                                                if state == 107:
                                                    state = (
                                                        123
                                                        if x["mag_peak"] < 18.6095848
                                                        else 124
                                                    )
                                                    if state == 123:
                                                        return 0.0863148719
                                                    if state == 124:
                                                        return -0.0564688109
                                                if state == 108:
                                                    return -0.090849407
                                            if state == 100:
                                                return 0.0309413578
                            if state == 32:
                                state = (
                                    51
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.972249985)
                                    else 52
                                )
                                if state == 51:
                                    return 0.00674295938
                                if state == 52:
                                    state = (
                                        69
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 19.460022)
                                        else 70
                                    )
                                    if state == 69:
                                        return 0.167000964
                                    if state == 70:
                                        return -0.0388534442
                        if state == 20:
                            state = (
                                33
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.07776356)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    53
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.97724998)
                                    else 54
                                )
                                if state == 53:
                                    return -0.0241033714
                                if state == 54:
                                    state = 73 if x["maggaia_med"] < 19.1376114 else 74
                                    if state == 73:
                                        return -0.198469222
                                    if state == 74:
                                        return 0.00844210479
                            if state == 34:
                                state = (
                                    55
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.907249987)
                                    else 56
                                )
                                if state == 55:
                                    state = 75 if x["maggaia_med"] < 18.2508659 else 76
                                    if state == 75:
                                        return 0.118126348
                                    if state == 76:
                                        return -0.0485446677
                                if state == 56:
                                    state = 77 if x["maggaia_med"] < 15.6013489 else 78
                                    if state == 77:
                                        return -0.108492374
                                    if state == 78:
                                        state = (
                                            93
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 1.43481064)
                                            else 94
                                        )
                                        if state == 93:
                                            return 0.0529034957
                                        if state == 94:
                                            state = (
                                                103
                                                if x["maggaia_med"] < 17.6489105
                                                else 104
                                            )
                                            if state == 103:
                                                return 0.0466913767
                                            if state == 104:
                                                state = (
                                                    117
                                                    if x["col_det"] < -0.00176382065
                                                    else 118
                                                )
                                                if state == 117:
                                                    return -0.0588410497
                                                if state == 118:
                                                    state = (
                                                        135
                                                        if np.isnan(x["mag_peak"])
                                                        or (x["mag_peak"] < 18.5468731)
                                                        else 136
                                                    )
                                                    if state == 135:
                                                        state = (
                                                            145
                                                            if np.isnan(x["t_lc"])
                                                            or (x["t_lc"] < 20.9642143)
                                                            else 146
                                                        )
                                                        if state == 145:
                                                            return -0.0238622241
                                                        if state == 146:
                                                            return 0.0821549967
                                                    if state == 136:
                                                        return -0.0579388477
                if state == 6:
                    state = 11 if x["mag_peak"] < 18.9517002 else 12
                    if state == 11:
                        state = (
                            21
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.718286335)
                            else 22
                        )
                        if state == 21:
                            state = (
                                35
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 0.711315215)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    57
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.976750016)
                                    else 58
                                )
                                if state == 57:
                                    return -0.0712889209
                                if state == 58:
                                    return 0.0527370833
                            if state == 36:
                                return -0.0685247034
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["distnr_med"])
                                or (x["distnr_med"] < 1.17833257)
                                else 38
                            )
                            if state == 37:
                                return 0.219924152
                            if state == 38:
                                return 0.0315942355
                    if state == 12:
                        return -0.112235337
    elif num_booster == 80:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 4.896348) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distpsnr1_med"])
                    or (x["distpsnr1_med"] < 0.394204319)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.88395262)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 0.200723678)
                            else 14
                        )
                        if state == 13:
                            state = (
                                23
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.0425752476)
                                else 24
                            )
                            if state == 23:
                                return -0.0726891607
                            if state == 24:
                                state = (
                                    39
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.469554245)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        67
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.226907879)
                                        else 68
                                    )
                                    if state == 67:
                                        return -0.0286945906
                                    if state == 68:
                                        return 0.120459273
                                if state == 40:
                                    return -0.0877184495
                        if state == 14:
                            return -0.110979937
                    if state == 8:
                        return 0.0353023335
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.98611689)
                        else 10
                    )
                    if state == 9:
                        state = 17 if x["distpsnr1_med"] < 0.688057125 else 18
                        if state == 17:
                            return 0.100906439
                        if state == 18:
                            state = (
                                29
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.96984386)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    49
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.9443475)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        69
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 1.74182725)
                                        else 70
                                    )
                                    if state == 69:
                                        state = (
                                            91
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.883030057)
                                            else 92
                                        )
                                        if state == 91:
                                            return -0.07916563
                                        if state == 92:
                                            state = (
                                                109
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.0445080996)
                                                else 110
                                            )
                                            if state == 109:
                                                state = (
                                                    123
                                                    if x["distpsnr1_med"] < 1.58061314
                                                    else 124
                                                )
                                                if state == 123:
                                                    return -0.15062429
                                                if state == 124:
                                                    return 0.0255936328
                                            if state == 110:
                                                state = (
                                                    125
                                                    if x["distpsnr1_med"] < 0.889256835
                                                    else 126
                                                )
                                                if state == 125:
                                                    return -0.017418839
                                                if state == 126:
                                                    state = (
                                                        141
                                                        if x["sgscore1_med"]
                                                        < 0.292064011
                                                        else 142
                                                    )
                                                    if state == 141:
                                                        return 0.136610687
                                                    if state == 142:
                                                        return -0.0632078573
                                    if state == 70:
                                        return -0.0984299928
                                if state == 50:
                                    state = (
                                        71
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 3.01376104)
                                        else 72
                                    )
                                    if state == 71:
                                        return 0.151816249
                                    if state == 72:
                                        state = (
                                            93
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 4.53333235)
                                            else 94
                                        )
                                        if state == 93:
                                            state = (
                                                111
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 0.947430551)
                                                else 112
                                            )
                                            if state == 111:
                                                return -0.102928147
                                            if state == 112:
                                                state = (
                                                    129
                                                    if x["distpsnr1_med"] < 4.55559731
                                                    else 130
                                                )
                                                if state == 129:
                                                    return -0.120734759
                                                if state == 130:
                                                    return 0.118245713
                                        if state == 94:
                                            state = (
                                                113
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 1.01870942)
                                                else 114
                                            )
                                            if state == 113:
                                                return 0.105115585
                                            if state == 114:
                                                state = (
                                                    131
                                                    if x["distpsnr1_med"] < 6.13072968
                                                    else 132
                                                )
                                                if state == 131:
                                                    return -0.110105254
                                                if state == 132:
                                                    return 0.0460843071
                            if state == 30:
                                state = (
                                    51
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.47674823)
                                    else 52
                                )
                                if state == 51:
                                    return 0.108852185
                                if state == 52:
                                    return -0.158700958
                    if state == 10:
                        state = 19 if x["distpsnr1_med"] < 1.22268581 else 20
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.99192142)
                                else 32
                            )
                            if state == 31:
                                return 0.219210118
                            if state == 32:
                                return 0.0167726744
                        if state == 20:
                            state = (
                                33
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.00293398)
                                else 34
                            )
                            if state == 33:
                                return -0.106582075
                            if state == 34:
                                state = (
                                    57
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.41236353)
                                    else 58
                                )
                                if state == 57:
                                    return -0.0849027708
                                if state == 58:
                                    state = (
                                        75
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 5.80105257)
                                        else 76
                                    )
                                    if state == 75:
                                        return 0.156972498
                                    if state == 76:
                                        return -0.0887388736
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distpsnr1_med"]) or (x["distpsnr1_med"] < 11.4957047)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 4.96322346)
                        else 12
                    )
                    if state == 11:
                        return -0.164412677
                    if state == 12:
                        state = (
                            21
                            if np.isnan(x["distpsnr1_med"])
                            or (x["distpsnr1_med"] < 0.665186286)
                            else 22
                        )
                        if state == 21:
                            state = (
                                35
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 8.03910828)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    59
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.241752267)
                                    else 60
                                )
                                if state == 59:
                                    return -0.0673566535
                                if state == 60:
                                    state = (
                                        79
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.706340551)
                                        else 80
                                    )
                                    if state == 79:
                                        return 0.121984676
                                    if state == 80:
                                        state = (
                                            97
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.718643665)
                                            else 98
                                        )
                                        if state == 97:
                                            return -0.19838348
                                        if state == 98:
                                            return 0.100044295
                            if state == 36:
                                return -0.092954427
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 8.99973392)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    63
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.743889332)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        83
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.512534022)
                                        else 84
                                    )
                                    if state == 83:
                                        return 0.0218530297
                                    if state == 84:
                                        return -0.214850992
                                if state == 64:
                                    state = (
                                        85
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.744617581)
                                        else 86
                                    )
                                    if state == 85:
                                        return 0.130506992
                                    if state == 86:
                                        state = (
                                            101
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.888788879)
                                            else 102
                                        )
                                        if state == 101:
                                            return -0.218395099
                                        if state == 102:
                                            state = (
                                                119
                                                if np.isnan(x["t_predetect"])
                                                or (x["t_predetect"] < 7.95743036)
                                                else 120
                                            )
                                            if state == 119:
                                                state = (
                                                    135
                                                    if x["distpsnr1_med"] < 9.15412617
                                                    else 136
                                                )
                                                if state == 135:
                                                    state = (
                                                        149
                                                        if x["sgscore1_med"]
                                                        < 0.00237499992
                                                        else 150
                                                    )
                                                    if state == 149:
                                                        return -0.106820732
                                                    if state == 150:
                                                        state = (
                                                            159
                                                            if np.isnan(x["mag_peak"])
                                                            or (
                                                                x["mag_peak"]
                                                                < 18.6305084
                                                            )
                                                            else 160
                                                        )
                                                        if state == 159:
                                                            return 0.102079548
                                                        if state == 160:
                                                            return -0.00697695045
                                                if state == 136:
                                                    return -0.11423333
                                            if state == 120:
                                                state = (
                                                    137
                                                    if x["distpsnr1_med"] < 1.30946827
                                                    else 138
                                                )
                                                if state == 137:
                                                    return 0.00648192549
                                                if state == 138:
                                                    state = (
                                                        151
                                                        if np.isnan(x["sgscore1_med"])
                                                        or (
                                                            x["sgscore1_med"]
                                                            < 0.0701383948
                                                        )
                                                        else 152
                                                    )
                                                    if state == 151:
                                                        return -0.177715957
                                                    if state == 152:
                                                        return 0.0104498519
                            if state == 38:
                                return 0.0666612238
                if state == 6:
                    return 0.12524429
    elif num_booster == 81:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 2.96975136)
                else 2
            )
            if state == 1:
                state = 3 if x["distpsnr1_med"] < 1.85735273 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.25113916)
                        else 8
                    )
                    if state == 7:
                        state = 15 if x["sgscore1_med"] < 0.0723958015 else 16
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.5366344)
                                else 30
                            )
                            if state == 29:
                                return 0.0923270881
                            if state == 30:
                                state = (
                                    57
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.300766766)
                                    else 58
                                )
                                if state == 57:
                                    return 0.0968566015
                                if state == 58:
                                    return -0.0605588593
                        if state == 16:
                            return -0.08673089
                    if state == 8:
                        return -0.07849738
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 3.41665506)
                        else 10
                    )
                    if state == 9:
                        state = 19 if x["sgscore1_med"] < 0.0167083517 else 20
                        if state == 19:
                            return -0.035198614
                        if state == 20:
                            return 0.1043915
                    if state == 10:
                        state = 21 if x["sgscore1_med"] < 0.00737500004 else 22
                        if state == 21:
                            return -0.0868676007
                        if state == 22:
                            state = (
                                41
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.1223774)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    73
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 3.70408344)
                                    else 74
                                )
                                if state == 73:
                                    return -0.0169114769
                                if state == 74:
                                    state = (
                                        107
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 6.1882515)
                                        else 108
                                    )
                                    if state == 107:
                                        state = (
                                            129
                                            if x["maggaia_med"] < 19.5787411
                                            else 130
                                        )
                                        if state == 129:
                                            return -0.0964602455
                                        if state == 130:
                                            return 0.101136014
                                    if state == 108:
                                        return 0.112494953
                            if state == 42:
                                return -0.0479102731
            if state == 2:
                state = 5 if x["distpsnr1_med"] < 0.671603084 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.633916259)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0036249999)
                            else 24
                        )
                        if state == 23:
                            return 0.090630047
                        if state == 24:
                            return -0.11807631
                    if state == 12:
                        state = 25 if x["sgscore1_med"] < 0.332499981 else 26
                        if state == 25:
                            state = (
                                47
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.0433102)
                                else 48
                            )
                            if state == 47:
                                return 0.0270933136
                            if state == 48:
                                return 0.148449585
                        if state == 26:
                            return -0.0315436274
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.3400774)
                        else 14
                    )
                    if state == 13:
                        return 0.090983443
                    if state == 14:
                        state = 27 if x["sgscore1_med"] < 0.342750013 else 28
                        if state == 27:
                            state = (
                                51
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 18.1732578)
                                else 52
                            )
                            if state == 51:
                                state = (
                                    87
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.48959196)
                                    else 88
                                )
                                if state == 87:
                                    return -0.205845773
                                if state == 88:
                                    return -0.0169439148
                            if state == 52:
                                state = (
                                    89
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 3.02896261)
                                    else 90
                                )
                                if state == 89:
                                    state = (
                                        113 if x["distpsnr1_med"] < 1.49681842 else 114
                                    )
                                    if state == 113:
                                        state = (
                                            131
                                            if np.isnan(x["maggaia_med"])
                                            or (x["maggaia_med"] < 17.3015232)
                                            else 132
                                        )
                                        if state == 131:
                                            return 0.0969352797
                                        if state == 132:
                                            state = (
                                                147
                                                if x["distpsnr1_med"] < 1.46498144
                                                else 148
                                            )
                                            if state == 147:
                                                state = (
                                                    161
                                                    if x["maggaia_med"] < 17.9363766
                                                    else 162
                                                )
                                                if state == 161:
                                                    state = (
                                                        173
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.460865)
                                                        else 174
                                                    )
                                                    if state == 173:
                                                        return 0.0903763995
                                                    if state == 174:
                                                        state = (
                                                            181
                                                            if x["maggaia_med"]
                                                            < 17.3821468
                                                            else 182
                                                        )
                                                        if state == 181:
                                                            return -0.109249748
                                                        if state == 182:
                                                            return 0.0868131295
                                                if state == 162:
                                                    state = (
                                                        175
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 19.0264854)
                                                        else 176
                                                    )
                                                    if state == 175:
                                                        return 0.0132234404
                                                    if state == 176:
                                                        return -0.194299266
                                            if state == 148:
                                                return 0.065158397
                                    if state == 114:
                                        state = (
                                            133
                                            if x["maggaia_med"] < 19.2801056
                                            else 134
                                        )
                                        if state == 133:
                                            state = (
                                                149
                                                if x["distpsnr1_med"] < 1.71192658
                                                else 150
                                            )
                                            if state == 149:
                                                return -0.0282247197
                                            if state == 150:
                                                state = (
                                                    163
                                                    if x["maggaia_med"] < 15.0782757
                                                    else 164
                                                )
                                                if state == 163:
                                                    return -0.00418108469
                                                if state == 164:
                                                    state = (
                                                        177
                                                        if np.isnan(x["mag_last"])
                                                        or (x["mag_last"] < 18.6164093)
                                                        else 178
                                                    )
                                                    if state == 177:
                                                        return 0.0237555578
                                                    if state == 178:
                                                        return -0.208332986
                                        if state == 134:
                                            state = (
                                                151
                                                if x["distpsnr1_med"] < 1.87396455
                                                else 152
                                            )
                                            if state == 151:
                                                return -0.139804423
                                            if state == 152:
                                                return 0.0342808999
                                if state == 90:
                                    return 0.0213115066
                        if state == 28:
                            state = (
                                53
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.1665039)
                                else 54
                            )
                            if state == 53:
                                state = (
                                    91
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 2.19417286)
                                    else 92
                                )
                                if state == 91:
                                    state = (
                                        117 if x["distpsnr1_med"] < 0.997087955 else 118
                                    )
                                    if state == 117:
                                        return -0.0299427453
                                    if state == 118:
                                        return 0.161089271
                                if state == 92:
                                    state = (
                                        119
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 2.2902298)
                                        else 120
                                    )
                                    if state == 119:
                                        return -0.109531723
                                    if state == 120:
                                        return 0.0470965914
                            if state == 54:
                                return -0.0184356458
    elif num_booster == 82:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.8141708) else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.697500229) else 4
                if state == 3:
                    return -0.0162272137
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.983250022)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.761428595)
                            else 20
                        )
                        if state == 19:
                            state = (
                                37
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 8.97600174)
                                else 38
                            )
                            if state == 37:
                                return -0.106873326
                            if state == 38:
                                state = (
                                    63
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 7.88331032)
                                    else 64
                                )
                                if state == 63:
                                    state = (
                                        93
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.756666541)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            123
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 28.9960709)
                                            else 124
                                        )
                                        if state == 123:
                                            return 0.03616504
                                        if state == 124:
                                            state = (
                                                147
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 0.738005161)
                                                else 148
                                            )
                                            if state == 147:
                                                return 0.171565846
                                            if state == 148:
                                                return 0.00836032536
                                    if state == 94:
                                        return 0.0109997848
                                if state == 64:
                                    return -0.0341609418
                        if state == 20:
                            state = (
                                39
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 22.0284042)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    65
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.0306192003)
                                    else 66
                                )
                                if state == 65:
                                    return -0.0401839428
                                if state == 66:
                                    return 0.166358396
                            if state == 40:
                                return -0.0243056044
                    if state == 10:
                        return -0.0186979119
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.663928449) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.974250019)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.654285669)
                            else 24
                        )
                        if state == 23:
                            state = (
                                43
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 6.06869221)
                                else 44
                            )
                            if state == 43:
                                return 0.0248947181
                            if state == 44:
                                state = (
                                    69
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 6.99215317)
                                    else 70
                                )
                                if state == 69:
                                    return -0.0976748243
                                if state == 70:
                                    return 0.0332680084
                        if state == 24:
                            return 0.0253606383
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.561071396)
                            else 26
                        )
                        if state == 25:
                            state = (
                                45
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 27.9372749)
                                else 46
                            )
                            if state == 45:
                                return -0.0726910904
                            if state == 46:
                                state = (
                                    73
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 8.92022514)
                                    else 74
                                )
                                if state == 73:
                                    state = (
                                        99
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.516904712)
                                        else 100
                                    )
                                    if state == 99:
                                        return 0.119054936
                                    if state == 100:
                                        return -0.0476507321
                                if state == 74:
                                    return -0.0520043634
                        if state == 26:
                            state = (
                                47
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 25.0450859)
                                else 48
                            )
                            if state == 47:
                                state = (
                                    75
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.99418402)
                                    else 76
                                )
                                if state == 75:
                                    state = (
                                        101
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.586666822)
                                        else 102
                                    )
                                    if state == 101:
                                        return 0.296894282
                                    if state == 102:
                                        return 0.0344626233
                                if state == 76:
                                    return 0.0423738286
                            if state == 48:
                                return 0.032593973
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["classtar_med"])
                        or (x["classtar_med"] < 0.979750037)
                        else 14
                    )
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.742023706)
                            else 28
                        )
                        if state == 27:
                            state = (
                                49
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 37.9166107)
                                else 50
                            )
                            if state == 49:
                                state = (
                                    79
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.0461226478)
                                    else 80
                                )
                                if state == 79:
                                    return 0.0922007784
                                if state == 80:
                                    return -0.0770393312
                            if state == 50:
                                state = (
                                    81
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.96034145)
                                    else 82
                                )
                                if state == 81:
                                    return -0.0153551046
                                if state == 82:
                                    state = (
                                        111
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.73309499)
                                        else 112
                                    )
                                    if state == 111:
                                        return -0.0804912001
                                    if state == 112:
                                        return -0.291627109
                        if state == 28:
                            state = (
                                51
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 43.9653931)
                                else 52
                            )
                            if state == 51:
                                state = (
                                    83
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.0215856005)
                                    else 84
                                )
                                if state == 83:
                                    return 0.0799355656
                                if state == 84:
                                    state = (
                                        113
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.753333151)
                                        else 114
                                    )
                                    if state == 113:
                                        return -0.179401979
                                    if state == 114:
                                        state = (
                                            137
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 18.9678345)
                                            else 138
                                        )
                                        if state == 137:
                                            return -0.0860996842
                                        if state == 138:
                                            return 0.0161190666
                            if state == 52:
                                return 0.0364236832
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.955357075)
                            else 30
                        )
                        if state == 29:
                            state = (
                                53
                                if np.isnan(x["t_lc"]) or (x["t_lc"] < 24.0645313)
                                else 54
                            )
                            if state == 53:
                                state = (
                                    87
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 2.95380783)
                                    else 88
                                )
                                if state == 87:
                                    return 0.063008666
                                if state == 88:
                                    return -0.0487928875
                            if state == 54:
                                return 0.050746128
                        if state == 30:
                            return -0.0787837356
    elif num_booster == 83:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["maggaia_med"]) or (x["maggaia_med"] < 20.0852966)
                else 2
            )
            if state == 1:
                state = 3 if x["neargaia_med"] < 0.648653567 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.0236875005)
                        else 8
                    )
                    if state == 7:
                        return 0.0852810442
                    if state == 8:
                        state = 17 if x["maggaia_med"] < 17.3877583 else 18
                        if state == 17:
                            return -0.179057509
                        if state == 18:
                            state = 27 if x["maggaia_med"] < 17.4241295 else 28
                            if state == 27:
                                return 0.0721065998
                            if state == 28:
                                return -0.0857686326
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["sgscore1_med"])
                        or (x["sgscore1_med"] < 0.0799582973)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["maggaia_med"])
                            or (x["maggaia_med"] < 19.4574184)
                            else 20
                        )
                        if state == 19:
                            state = (
                                29
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 19.2804947)
                                else 30
                            )
                            if state == 29:
                                state = 37 if x["col_peak"] < -0.195209026 else 38
                                if state == 37:
                                    return 0.0677861199
                                if state == 38:
                                    state = 51 if x["mag_peak"] < 17.8844604 else 52
                                    if state == 51:
                                        return 0.0797164291
                                    if state == 52:
                                        state = (
                                            65 if x["col_det"] < 0.0748500824 else 66
                                        )
                                        if state == 65:
                                            state = (
                                                75
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.1845016)
                                                else 76
                                            )
                                            if state == 75:
                                                return -0.0115676522
                                            if state == 76:
                                                return -0.145249426
                                        if state == 66:
                                            state = (
                                                77
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 19.9273491)
                                                else 78
                                            )
                                            if state == 77:
                                                return -0.02529121
                                            if state == 78:
                                                state = (
                                                    93
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.974750042)
                                                    else 94
                                                )
                                                if state == 93:
                                                    return -0.0455680043
                                                if state == 94:
                                                    return 0.08017575
                            if state == 30:
                                return 0.0715950206
                        if state == 20:
                            state = 31 if x["maggaia_med"] < 19.8120365 else 32
                            if state == 31:
                                return -0.0988671631
                            if state == 32:
                                state = (
                                    41
                                    if np.isnan(x["col_peak"])
                                    or (x["col_peak"] < 0.070189476)
                                    else 42
                                )
                                if state == 41:
                                    state = (
                                        55
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 17.9045753)
                                        else 56
                                    )
                                    if state == 55:
                                        state = 67 if x["col_det"] < 0.117400169 else 68
                                        if state == 67:
                                            return 0.100142933
                                        if state == 68:
                                            return -0.086005345
                                    if state == 56:
                                        return 0.104469568
                                if state == 42:
                                    return -0.0529766791
                    if state == 10:
                        state = 21 if x["maggaia_med"] < 17.9378872 else 22
                        if state == 21:
                            state = 33 if x["maggaia_med"] < 16.5610313 else 34
                            if state == 33:
                                return -0.0372874252
                            if state == 34:
                                return 0.139324069
                        if state == 22:
                            state = (
                                35
                                if np.isnan(x["maggaia_med"])
                                or (x["maggaia_med"] < 19.2755814)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    45
                                    if np.isnan(x["col_peak"])
                                    or (x["col_peak"] < 0.478089333)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        59
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 17.7129059)
                                        else 60
                                    )
                                    if state == 59:
                                        state = (
                                            69 if x["col_det"] < 0.0969724655 else 70
                                        )
                                        if state == 69:
                                            return -0.100744709
                                        if state == 70:
                                            state = (
                                                81
                                                if np.isnan(x["mag_det"])
                                                or (x["mag_det"] < 20.1945)
                                                else 82
                                            )
                                            if state == 81:
                                                return 0.0778793171
                                            if state == 82:
                                                return -0.076185599
                                    if state == 60:
                                        return -0.0775848031
                                if state == 46:
                                    return 0.0623550415
                            if state == 36:
                                return 0.0712983534
            if state == 2:
                state = 5 if x["neargaia_med"] < 38.1114044 else 6
                if state == 5:
                    return -0.0911388248
                if state == 6:
                    return 0.0826741681
    elif num_booster == 84:
        state = 0
        if state == 0:
            state = 1 if x["mag_peak"] < 18.9933681 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.716328382)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.5192089)
                        else 8
                    )
                    if state == 7:
                        return -0.0448229201
                    if state == 8:
                        state = 17 if x["sgscore1_med"] < 0.116583496 else 18
                        if state == 17:
                            state = 29 if x["sgscore1_med"] < 0.00834821537 else 30
                            if state == 29:
                                return 0.0150040658
                            if state == 30:
                                state = (
                                    53
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.710782468)
                                    else 54
                                )
                                if state == 53:
                                    state = 85 if x["col_det"] < 0.228973389 else 86
                                    if state == 85:
                                        return 0.0158257689
                                    if state == 86:
                                        state = (
                                            119
                                            if x["neargaia_med"] < 55.9164581
                                            else 120
                                        )
                                        if state == 119:
                                            return 0.142261341
                                        if state == 120:
                                            return -0.0400451459
                                if state == 54:
                                    return 0.185960844
                        if state == 18:
                            return -0.0565356612
                if state == 4:
                    state = (
                        9 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.993) else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0382410996)
                            else 20
                        )
                        if state == 19:
                            state = (
                                33
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0286041498)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    59
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 3.20374727)
                                    else 60
                                )
                                if state == 59:
                                    return 0.130867362
                                if state == 60:
                                    return -0.0469993278
                            if state == 34:
                                return 0.00589534827
                        if state == 20:
                            state = 35 if x["sgscore1_med"] < 0.695366025 else 36
                            if state == 35:
                                state = (
                                    61
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.718070269)
                                    else 62
                                )
                                if state == 61:
                                    return -0.195579171
                                if state == 62:
                                    state = 89 if x["col_det"] < 0.236206055 else 90
                                    if state == 89:
                                        state = (
                                            121
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 0.64962709)
                                            else 122
                                        )
                                        if state == 121:
                                            return 0.226800382
                                        if state == 122:
                                            return -0.0105067007
                                    if state == 90:
                                        state = (
                                            123
                                            if x["neargaia_med"] < 1.00974929
                                            else 124
                                        )
                                        if state == 123:
                                            return -0.31208387
                                        if state == 124:
                                            state = (
                                                161
                                                if x["sgscore1_med"] < 0.117996998
                                                else 162
                                            )
                                            if state == 161:
                                                return 0.110648185
                                            if state == 162:
                                                return -0.0359854549
                            if state == 36:
                                return -0.0980723426
                    if state == 10:
                        state = 21 if x["sgscore1_med"] < 0.00737500004 else 22
                        if state == 21:
                            state = 37 if x["sgscore1_med"] < 0.00322916498 else 38
                            if state == 37:
                                state = (
                                    63
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 2.3050909)
                                    else 64
                                )
                                if state == 63:
                                    return -0.0414587073
                                if state == 64:
                                    return 0.112539537
                            if state == 38:
                                return -0.109249972
                        if state == 22:
                            state = 39 if x["sgscore1_med"] < 0.165413499 else 40
                            if state == 39:
                                state = (
                                    67
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 2.69877005)
                                    else 68
                                )
                                if state == 67:
                                    return 0.0980029553
                                if state == 68:
                                    state = (
                                        93
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.0744752884)
                                        else 94
                                    )
                                    if state == 93:
                                        state = (
                                            129
                                            if x["neargaia_med"] < 17.0784798
                                            else 130
                                        )
                                        if state == 129:
                                            return 0.0657583848
                                        if state == 130:
                                            return -0.0660051629
                                    if state == 94:
                                        return 0.0542218648
                            if state == 40:
                                state = (
                                    69
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 2.65175962)
                                    else 70
                                )
                                if state == 69:
                                    state = 95 if x["col_det"] < 0.33194828 else 96
                                    if state == 95:
                                        return 0.140864983
                                    if state == 96:
                                        state = (
                                            133
                                            if np.isnan(x["neargaia_med"])
                                            or (x["neargaia_med"] < 42.0987625)
                                            else 134
                                        )
                                        if state == 133:
                                            state = (
                                                169
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.190318495)
                                                else 170
                                            )
                                            if state == 169:
                                                return -0.0586953796
                                            if state == 170:
                                                return 0.0807519034
                                        if state == 134:
                                            return -0.0559209101
                                if state == 70:
                                    state = (
                                        97
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < 0.137179062)
                                        else 98
                                    )
                                    if state == 97:
                                        state = (
                                            135
                                            if x["neargaia_med"] < 15.9380875
                                            else 136
                                        )
                                        if state == 135:
                                            return -0.146968052
                                        if state == 136:
                                            return 0.0482966453
                                    if state == 98:
                                        return 0.0721516833
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.5043447)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.8139496)
                        else 12
                    )
                    if state == 11:
                        return -0.227104768
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0422291495)
                            else 24
                        )
                        if state == 23:
                            state = (
                                41
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.0381875001)
                                else 42
                            )
                            if state == 41:
                                state = (
                                    71
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 0.285452008)
                                    else 72
                                )
                                if state == 71:
                                    return 0.0307267569
                                if state == 72:
                                    state = 101 if x["col_det"] < -0.0301346779 else 102
                                    if state == 101:
                                        return 0.0472851135
                                    if state == 102:
                                        state = (
                                            141
                                            if x["neargaia_med"] < 53.3455505
                                            else 142
                                        )
                                        if state == 141:
                                            return -0.12402112
                                        if state == 142:
                                            return 0.103518225
                            if state == 42:
                                return 0.0824523345
                        if state == 24:
                            return -0.0397933163
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.7808495)
                        else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.37441051)
                            else 26
                        )
                        if state == 25:
                            state = 45 if x["sgscore1_med"] < 0.0530952513 else 46
                            if state == 45:
                                return 0.0504744463
                            if state == 46:
                                return -0.0803862512
                        if state == 26:
                            return 0.0756852999
                    if state == 14:
                        state = (
                            27
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0043958351)
                            else 28
                        )
                        if state == 27:
                            return 0.034756802
                        if state == 28:
                            state = 49 if x["sgscore1_med"] < 0.055544652 else 50
                            if state == 49:
                                return -0.102628075
                            if state == 50:
                                state = (
                                    81
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 3.06807184)
                                    else 82
                                )
                                if state == 81:
                                    state = 111 if x["col_det"] < 0.230106354 else 112
                                    if state == 111:
                                        return -0.0573666058
                                    if state == 112:
                                        return 0.0782680884
                                if state == 82:
                                    state = (
                                        113
                                        if np.isnan(x["col_det"])
                                        or (x["col_det"] < -0.00125026703)
                                        else 114
                                    )
                                    if state == 113:
                                        return -0.145743236
                                    if state == 114:
                                        return 0.0445038229
    elif num_booster == 85:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.9933681) else 2
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.4783001) else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.3513851)
                        else 8
                    )
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["col_last"]) or (x["col_last"] < -0.086309433)
                            else 14
                        )
                        if state == 13:
                            state = (
                                21
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 6.0189352)
                                else 22
                            )
                            if state == 21:
                                state = (
                                    35
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 14.5545731)
                                    else 36
                                )
                                if state == 35:
                                    return 0.026880594
                                if state == 36:
                                    state = (
                                        51
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 18.7125492)
                                        else 52
                                    )
                                    if state == 51:
                                        return -0.232620776
                                    if state == 52:
                                        return 0.000312405056
                            if state == 22:
                                return 0.0616462864
                        if state == 14:
                            return 0.00315971719
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["col_last"]) or (x["col_last"] < 0.0919322968)
                            else 16
                        )
                        if state == 15:
                            state = (
                                25
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 5.99483776)
                                else 26
                            )
                            if state == 25:
                                state = (
                                    37
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 18.6382427)
                                    else 38
                                )
                                if state == 37:
                                    state = (
                                        53
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.3333015)
                                        else 54
                                    )
                                    if state == 53:
                                        state = (
                                            69 if x["maggaia_med"] < 19.3957748 else 70
                                        )
                                        if state == 69:
                                            state = (
                                                97
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 20.6585007)
                                                else 98
                                            )
                                            if state == 97:
                                                state = (
                                                    121
                                                    if x["col_peak"] < -0.102334976
                                                    else 122
                                                )
                                                if state == 121:
                                                    return 0.0530308485
                                                if state == 122:
                                                    state = (
                                                        139
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 18.4039993)
                                                        else 140
                                                    )
                                                    if state == 139:
                                                        return -0.0188334566
                                                    if state == 140:
                                                        state = (
                                                            149
                                                            if x["maggaia_med"]
                                                            < 17.8822517
                                                            else 150
                                                        )
                                                        if state == 149:
                                                            return -0.0741854534
                                                        if state == 150:
                                                            return 0.100002915
                                            if state == 98:
                                                return -0.0871603414
                                        if state == 70:
                                            return -0.0714521483
                                    if state == 54:
                                        return 0.0677995831
                                if state == 38:
                                    return 0.0545116626
                            if state == 26:
                                state = (
                                    39
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 18.6794777)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        57
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.7813988)
                                        else 58
                                    )
                                    if state == 57:
                                        return 0.0794246644
                                    if state == 58:
                                        state = (
                                            79 if x["maggaia_med"] < 18.8381462 else 80
                                        )
                                        if state == 79:
                                            return 0.0921495929
                                        if state == 80:
                                            return -0.0707323328
                                if state == 40:
                                    state = (
                                        59
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.663662)
                                        else 60
                                    )
                                    if state == 59:
                                        return -0.0683927983
                                    if state == 60:
                                        return 0.0803334787
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.06298614)
                                else 28
                            )
                            if state == 27:
                                return 0.0332316272
                            if state == 28:
                                state = 43 if x["mag_peak"] < 17.8699455 else 44
                                if state == 43:
                                    return 0.0524152927
                                if state == 44:
                                    state = (
                                        63
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.3046989)
                                        else 64
                                    )
                                    if state == 63:
                                        return -0.0769900084
                                    if state == 64:
                                        return 0.0676585957
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.8178864)
                        else 10
                    )
                    if state == 9:
                        return 0.0340505838
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["col_last"]) or (x["col_last"] < 0.29603672)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.0791783035)
                                else 32
                            )
                            if state == 31:
                                return -0.0249547306
                            if state == 32:
                                state = 47 if x["mag_peak"] < 18.7418442 else 48
                                if state == 47:
                                    return 0.0681105703
                                if state == 48:
                                    return -0.129873157
                        if state == 20:
                            return 0.00926532224
            if state == 2:
                return -0.103951573
    elif num_booster == 86:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 0.0166088007)
                else 2
            )
            if state == 1:
                state = (
                    3 if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3309002) else 4
                )
                if state == 3:
                    return -0.127646163
                if state == 4:
                    return 0.0375101641
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.0250549) else 6
                )
                if state == 5:
                    state = (
                        7 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.759642839) else 8
                    )
                    if state == 7:
                        state = (
                            11
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 17.7356739)
                            else 12
                        )
                        if state == 11:
                            state = (
                                19
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 16.1520004)
                                else 20
                            )
                            if state == 19:
                                return -0.0717150494
                            if state == 20:
                                return 0.096191138
                        if state == 12:
                            state = (
                                21
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 18.5655003)
                                else 22
                            )
                            if state == 21:
                                return -0.0835136399
                            if state == 22:
                                state = (
                                    37
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < -0.137498856)
                                    else 38
                                )
                                if state == 37:
                                    return 0.0951113328
                                if state == 38:
                                    return -0.058682628
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.2462883)
                            else 14
                        )
                        if state == 13:
                            state = (
                                23
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.9020004)
                                else 24
                            )
                            if state == 23:
                                return 0.197573453
                            if state == 24:
                                return -0.0515622869
                        if state == 14:
                            return -0.0883562565
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.808571458)
                        else 10
                    )
                    if state == 9:
                        state = 15 if x["mag_peak"] < 17.8480263 else 16
                        if state == 15:
                            return 0.0809737369
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 17.7024994)
                                else 28
                            )
                            if state == 27:
                                state = 41 if x["col_det"] < 0.597143173 else 42
                                if state == 41:
                                    return 0.0307374932
                                if state == 42:
                                    return -0.122607313
                            if state == 28:
                                state = 43 if x["col_det"] < -0.209130287 else 44
                                if state == 43:
                                    state = (
                                        59
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 11.7091866)
                                        else 60
                                    )
                                    if state == 59:
                                        return -0.101077117
                                    if state == 60:
                                        state = (
                                            69
                                            if x["distpsnr1_med"] < 0.876866102
                                            else 70
                                        )
                                        if state == 69:
                                            return 0.0518259108
                                        if state == 70:
                                            state = (
                                                81
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 3.64549351)
                                                else 82
                                            )
                                            if state == 81:
                                                return -0.105865076
                                            if state == 82:
                                                return 0.0769951567
                                if state == 44:
                                    state = (
                                        61
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 1.47886324)
                                        else 62
                                    )
                                    if state == 61:
                                        state = (
                                            71
                                            if np.isnan(x["distpsnr1_med"])
                                            or (x["distpsnr1_med"] < 0.0985629037)
                                            else 72
                                        )
                                        if state == 71:
                                            return -0.0748463199
                                        if state == 72:
                                            state = (
                                                83
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.67528462)
                                                else 84
                                            )
                                            if state == 83:
                                                return 0.11277017
                                            if state == 84:
                                                return -0.0115961516
                                    if state == 62:
                                        state = (
                                            73 if x["distpsnr1_med"] < 1.8238796 else 74
                                        )
                                        if state == 73:
                                            state = (
                                                85
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 1.2718637)
                                                else 86
                                            )
                                            if state == 85:
                                                return -0.00137274805
                                            if state == 86:
                                                state = (
                                                    97
                                                    if x["neargaia_med"] < 54.0305176
                                                    else 98
                                                )
                                                if state == 97:
                                                    return -0.129415467
                                                if state == 98:
                                                    return 0.0961241946
                                        if state == 74:
                                            state = (
                                                87
                                                if np.isnan(x["distnr_med"])
                                                or (x["distnr_med"] < 2.00764084)
                                                else 88
                                            )
                                            if state == 87:
                                                state = (
                                                    99
                                                    if x["neargaia_med"] < 14.1098442
                                                    else 100
                                                )
                                                if state == 99:
                                                    return 0.142951265
                                                if state == 100:
                                                    state = (
                                                        111
                                                        if np.isnan(x["distpsnr1_med"])
                                                        or (
                                                            x["distpsnr1_med"]
                                                            < 2.17283702
                                                        )
                                                        else 112
                                                    )
                                                    if state == 111:
                                                        return 0.0863042921
                                                    if state == 112:
                                                        return -0.0506188013
                                            if state == 88:
                                                state = (
                                                    101
                                                    if x["neargaia_med"] < 13.6543045
                                                    else 102
                                                )
                                                if state == 101:
                                                    return -0.0820042863
                                                if state == 102:
                                                    state = (
                                                        115
                                                        if x["distpsnr1_med"]
                                                        < 4.25543785
                                                        else 116
                                                    )
                                                    if state == 115:
                                                        state = (
                                                            129
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 5.93246508
                                                            )
                                                            else 130
                                                        )
                                                        if state == 129:
                                                            return 0.120419376
                                                        if state == 130:
                                                            return -0.096828416
                                                    if state == 116:
                                                        state = (
                                                            131
                                                            if np.isnan(
                                                                x["t_predetect"]
                                                            )
                                                            or (
                                                                x["t_predetect"]
                                                                < 3.02028942
                                                            )
                                                            else 132
                                                        )
                                                        if state == 131:
                                                            return 0.0621054694
                                                        if state == 132:
                                                            return -0.087473087
                    if state == 10:
                        state = (
                            17
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.5659771)
                            else 18
                        )
                        if state == 17:
                            state = (
                                29
                                if np.isnan(x["magnr_med"])
                                or (x["magnr_med"] < 22.0212498)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    45
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.368899822)
                                    else 46
                                )
                                if state == 45:
                                    return 0.092140235
                                if state == 46:
                                    return -0.062271826
                            if state == 30:
                                return 0.0077488916
                        if state == 18:
                            return -0.00205032201
    elif num_booster == 87:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_last"]) or (x["col_last"] < 0.177940369) else 2
            if state == 1:
                state = 3 if x["neargaia_med"] < 1.00920534 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 6.96859932)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.72066462)
                            else 16
                        )
                        if state == 15:
                            return -0.00372699345
                        if state == 16:
                            return -0.168005154
                    if state == 8:
                        return 0.0611094348
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.9640336)
                        else 10
                    )
                    if state == 9:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 3.01763058)
                            else 18
                        )
                        if state == 17:
                            state = (
                                29
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.102082253)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    45
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 18.5183487)
                                    else 46
                                )
                                if state == 45:
                                    state = (
                                        65
                                        if np.isnan(x["maggaia_med"])
                                        or (x["maggaia_med"] < 16.9691467)
                                        else 66
                                    )
                                    if state == 65:
                                        state = (
                                            87
                                            if np.isnan(x["col_last"])
                                            or (x["col_last"] < 0.0177965164)
                                            else 88
                                        )
                                        if state == 87:
                                            state = (
                                                103
                                                if np.isnan(x["t_lc"])
                                                or (x["t_lc"] < 48.8901138)
                                                else 104
                                            )
                                            if state == 103:
                                                return 0.0732514933
                                            if state == 104:
                                                return -0.0646238551
                                        if state == 88:
                                            return -0.00956154056
                                    if state == 66:
                                        return 0.161220074
                                if state == 46:
                                    state = 67 if x["maggaia_med"] < 18.7079124 else 68
                                    if state == 67:
                                        return -0.109064817
                                    if state == 68:
                                        return 0.0315844566
                            if state == 30:
                                return -0.00744083198
                        if state == 18:
                            return -0.0213228744
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 2.93143368)
                            else 20
                        )
                        if state == 19:
                            state = (
                                33
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.117774963)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    53
                                    if np.isnan(x["maggaia_med"])
                                    or (x["maggaia_med"] < 17.481966)
                                    else 54
                                )
                                if state == 53:
                                    return 0.0167611651
                                if state == 54:
                                    return -0.0693678632
                            if state == 34:
                                return 0.00246410724
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.0760245323)
                                else 36
                            )
                            if state == 35:
                                state = 55 if x["maggaia_med"] < 18.4969788 else 56
                                if state == 55:
                                    return -0.0584895201
                                if state == 56:
                                    return 0.099231258
                            if state == 36:
                                return -0.0271681882
            if state == 2:
                state = (
                    5
                    if np.isnan(x["neargaia_med"]) or (x["neargaia_med"] < 0.908918142)
                    else 6
                )
                if state == 5:
                    return -0.0547055788
                if state == 6:
                    return 0.0483685955
    elif num_booster == 88:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["col_det"]) or (x["col_det"] < 0.0746240616) else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.115367629)
                    else 4
                )
                if state == 3:
                    return 0.0711009428
                if state == 4:
                    state = (
                        7
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.160405993)
                        else 8
                    )
                    if state == 7:
                        return -0.101061143
                    if state == 8:
                        state = (
                            13
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.2889595)
                            else 14
                        )
                        if state == 13:
                            state = 21 if x["neargaia_med"] < 18.0235786 else 22
                            if state == 21:
                                state = (
                                    35
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.9257317)
                                    else 36
                                )
                                if state == 35:
                                    state = (
                                        49
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.733333468)
                                        else 50
                                    )
                                    if state == 49:
                                        state = (
                                            67
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 17.473999)
                                            else 68
                                        )
                                        if state == 67:
                                            return -0.0113947056
                                        if state == 68:
                                            state = (
                                                89
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.1106892)
                                                else 90
                                            )
                                            if state == 89:
                                                return -0.130315319
                                            if state == 90:
                                                return 0.0287127793
                                    if state == 50:
                                        return 0.0251584034
                                if state == 36:
                                    return 0.0332687721
                            if state == 22:
                                state = (
                                    37
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.208149)
                                    else 38
                                )
                                if state == 37:
                                    return -0.017694084
                                if state == 38:
                                    state = (
                                        55
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.942857325)
                                        else 56
                                    )
                                    if state == 55:
                                        state = (
                                            75
                                            if np.isnan(x["magnr_med"])
                                            or (x["magnr_med"] < 19.3365002)
                                            else 76
                                        )
                                        if state == 75:
                                            return -0.0136222867
                                        if state == 76:
                                            state = (
                                                95
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 18.9482765)
                                                else 96
                                            )
                                            if state == 95:
                                                return 0.136382625
                                            if state == 96:
                                                return 0.0129642449
                                    if state == 56:
                                        return 0.122983873
                        if state == 14:
                            state = 23 if x["neargaia_med"] < 46.1478729 else 24
                            if state == 23:
                                state = (
                                    39
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.4092503)
                                    else 40
                                )
                                if state == 39:
                                    return -0.0343442038
                                if state == 40:
                                    state = (
                                        59
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.653928638)
                                        else 60
                                    )
                                    if state == 59:
                                        return -0.0517872684
                                    if state == 60:
                                        return 0.0697253421
                            if state == 24:
                                state = (
                                    41
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 20.1230507)
                                    else 42
                                )
                                if state == 41:
                                    return -0.119886659
                                if state == 42:
                                    return 0.020200219
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.709594488)
                    else 6
                )
                if state == 5:
                    state = (
                        9
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.704973459)
                        else 10
                    )
                    if state == 9:
                        return 0.00222045369
                    if state == 10:
                        return -0.14313446
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 1.07179475)
                        else 12
                    )
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.2566986)
                            else 18
                        )
                        if state == 17:
                            return -0.00930381007
                        if state == 18:
                            state = (
                                31
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 1.0079298)
                                else 32
                            )
                            if state == 31:
                                return 0.185237601
                            if state == 32:
                                return -0.0202826448
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 17.3707962)
                            else 20
                        )
                        if state == 19:
                            return -0.07100977
                        if state == 20:
                            state = (
                                33
                                if np.isnan(x["neargaia_med"])
                                or (x["neargaia_med"] < 4.58774233)
                                else 34
                            )
                            if state == 33:
                                return -0.0603877008
                            if state == 34:
                                return 0.0402356498
    elif num_booster == 89:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.00204166491 else 2
            if state == 1:
                return 0.0592921749
            if state == 2:
                state = (
                    5
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.866750002)
                    else 6
                )
                if state == 5:
                    return -0.134196967
                if state == 6:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.042345)
                        else 10
                    )
                    if state == 9:
                        state = (
                            13
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.6743507)
                            else 14
                        )
                        if state == 13:
                            state = 19 if x["sgscore1_med"] < 0.112758502 else 20
                            if state == 19:
                                state = 29 if x["col_det"] < -0.317011356 else 30
                                if state == 29:
                                    return -0.0324757211
                                if state == 30:
                                    state = (
                                        41
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.759999931)
                                        else 42
                                    )
                                    if state == 41:
                                        state = (
                                            59
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 3.03725696)
                                            else 60
                                        )
                                        if state == 59:
                                            return 0.0824563429
                                        if state == 60:
                                            state = (
                                                85
                                                if np.isnan(x["classtar_med"])
                                                or (x["classtar_med"] < 0.979250014)
                                                else 86
                                            )
                                            if state == 85:
                                                state = (
                                                    117
                                                    if x["maggaia_med"] < 19.3136063
                                                    else 118
                                                )
                                                if state == 117:
                                                    state = (
                                                        151
                                                        if x["col_det"] < 0.257873535
                                                        else 152
                                                    )
                                                    if state == 151:
                                                        state = (
                                                            167
                                                            if np.isnan(x["mag_last"])
                                                            or (
                                                                x["mag_last"]
                                                                < 18.808136
                                                            )
                                                            else 168
                                                        )
                                                        if state == 167:
                                                            return -0.0810087919
                                                        if state == 168:
                                                            return 0.0771389678
                                                    if state == 152:
                                                        return -0.0836338997
                                                if state == 118:
                                                    return 0.0851405486
                                            if state == 86:
                                                return -0.0270036031
                                    if state == 42:
                                        state = (
                                            61
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 5.98121548)
                                            else 62
                                        )
                                        if state == 61:
                                            return 0.0218322836
                                        if state == 62:
                                            return 0.172903463
                            if state == 20:
                                state = (
                                    31
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.297832012)
                                    else 32
                                )
                                if state == 31:
                                    state = (
                                        43
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.725595236)
                                        else 44
                                    )
                                    if state == 43:
                                        state = (
                                            63
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 5.96041679)
                                            else 64
                                        )
                                        if state == 63:
                                            return -0.0413600653
                                        if state == 64:
                                            return 0.0717412904
                                    if state == 44:
                                        return 0.0513265915
                                if state == 32:
                                    return -0.13917084
                        if state == 14:
                            return 0.153209269
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 17.7857819)
                            else 16
                        )
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["sgscore1_med"])
                                or (x["sgscore1_med"] < 0.153351009)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    33
                                    if np.isnan(x["col_det"])
                                    or (x["col_det"] < 0.188009262)
                                    else 34
                                )
                                if state == 33:
                                    return -0.0815301239
                                if state == 34:
                                    state = (
                                        49
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.755476058)
                                        else 50
                                    )
                                    if state == 49:
                                        return -0.416220725
                                    if state == 50:
                                        return -0.059040729
                            if state == 24:
                                return -0.0425118208
                        if state == 16:
                            return 0.0108468616
    elif num_booster == 90:
        state = 0
        if state == 0:
            state = 1 if x["sgscore1_med"] < 0.00204166491 else 2
            if state == 1:
                return 0.0345881842
            if state == 2:
                state = (
                    5
                    if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.5165005)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.734719515)
                        else 12
                    )
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.72066462)
                            else 18
                        )
                        if state == 17:
                            return -0.0226901062
                        if state == 18:
                            return -0.265800208
                    if state == 12:
                        state = (
                            19
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.745402932)
                            else 20
                        )
                        if state == 19:
                            return 0.0915594473
                        if state == 20:
                            state = 27 if x["col_peak"] < 1.20294952 else 28
                            if state == 27:
                                return 0.0030789976
                            if state == 28:
                                state = (
                                    41
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 5.95445633)
                                    else 42
                                )
                                if state == 41:
                                    return -0.0152717819
                                if state == 42:
                                    return -0.232557759
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 5.35740376)
                        else 14
                    )
                    if state == 13:
                        state = (
                            21
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 4.40177441)
                            else 22
                        )
                        if state == 21:
                            state = (
                                29
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.00563001633)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    43
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 0.0632580966)
                                    else 44
                                )
                                if state == 43:
                                    state = (
                                        51
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 0.0215856005)
                                        else 52
                                    )
                                    if state == 51:
                                        state = (
                                            59
                                            if np.isnan(x["sgscore1_med"])
                                            or (x["sgscore1_med"] < 0.0193333495)
                                            else 60
                                        )
                                        if state == 59:
                                            return -0.0865528062
                                        if state == 60:
                                            return 0.0794748813
                                    if state == 52:
                                        return -0.0935395509
                                if state == 44:
                                    state = (
                                        53
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 9.88910294)
                                        else 54
                                    )
                                    if state == 53:
                                        state = (
                                            63
                                            if x["sgscore1_med"] < 0.0140565503
                                            else 64
                                        )
                                        if state == 63:
                                            state = (
                                                79 if x["mag_peak"] < 18.7381859 else 80
                                            )
                                            if state == 79:
                                                state = (
                                                    87
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.982749999)
                                                    else 88
                                                )
                                                if state == 87:
                                                    state = (
                                                        97
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 3.99515629
                                                        )
                                                        else 98
                                                    )
                                                    if state == 97:
                                                        return -0.0493711419
                                                    if state == 98:
                                                        return 0.137004942
                                                if state == 88:
                                                    return -0.0421158895
                                            if state == 80:
                                                state = (
                                                    89
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.922749996)
                                                    else 90
                                                )
                                                if state == 89:
                                                    return 0.00966636837
                                                if state == 90:
                                                    state = (
                                                        99
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 1.49865746
                                                        )
                                                        else 100
                                                    )
                                                    if state == 99:
                                                        return 0.0307024382
                                                    if state == 100:
                                                        state = (
                                                            111
                                                            if x["sgscore1_med"]
                                                            < 0.00387499994
                                                            else 112
                                                        )
                                                        if state == 111:
                                                            return 0.0151364114
                                                        if state == 112:
                                                            return -0.134908319
                                        if state == 64:
                                            state = (
                                                81
                                                if np.isnan(x["mag_peak"])
                                                or (x["mag_peak"] < 18.7904663)
                                                else 82
                                            )
                                            if state == 81:
                                                state = (
                                                    91
                                                    if np.isnan(x["classtar_med"])
                                                    or (x["classtar_med"] < 0.980250001)
                                                    else 92
                                                )
                                                if state == 91:
                                                    return 0.007928323
                                                if state == 92:
                                                    state = (
                                                        103
                                                        if np.isnan(x["t_predetect"])
                                                        or (
                                                            x["t_predetect"]
                                                            < 2.97797441
                                                        )
                                                        else 104
                                                    )
                                                    if state == 103:
                                                        return 0.147626936
                                                    if state == 104:
                                                        state = (
                                                            117
                                                            if np.isnan(
                                                                x["sgscore1_med"]
                                                            )
                                                            or (
                                                                x["sgscore1_med"]
                                                                < 0.123357505
                                                            )
                                                            else 118
                                                        )
                                                        if state == 117:
                                                            return 0.10327699
                                                        if state == 118:
                                                            return -0.0330315605
                                            if state == 82:
                                                return -0.04567606
                                    if state == 54:
                                        return 0.0966256633
                            if state == 30:
                                return -0.0369820148
                        if state == 22:
                            return 0.0541921295
                    if state == 14:
                        state = (
                            23
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 10.1402502)
                            else 24
                        )
                        if state == 23:
                            state = (
                                31
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < -0.114287376)
                                else 32
                            )
                            if state == 31:
                                return -0.113368325
                            if state == 32:
                                return 0.0719663575
                        if state == 24:
                            return 0.0164557155
    elif num_booster == 91:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.4193001) else 2
            if state == 1:
                state = 3 if np.isnan(x["t_lc"]) or (x["t_lc"] < 57.8465919) else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["col_det"]) or (x["col_det"] < 0.400136471)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0516458005)
                            else 16
                        )
                        if state == 15:
                            state = 25 if x["col_last"] < -0.0840291977 else 26
                            if state == 25:
                                return -0.0399945863
                            if state == 26:
                                state = (
                                    37
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 18.7186394)
                                    else 38
                                )
                                if state == 37:
                                    state = (
                                        53
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.875357151)
                                        else 54
                                    )
                                    if state == 53:
                                        state = (
                                            75
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.535714149)
                                            else 76
                                        )
                                        if state == 75:
                                            return 0.0167353619
                                        if state == 76:
                                            state = (
                                                99
                                                if x["col_det"] < 0.0150728226
                                                else 100
                                            )
                                            if state == 99:
                                                return -0.0283394344
                                            if state == 100:
                                                return 0.138884708
                                    if state == 54:
                                        return -0.0494479835
                                if state == 38:
                                    return -0.0389359295
                        if state == 16:
                            state = (
                                27
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.2322402)
                                else 28
                            )
                            if state == 27:
                                state = 39 if x["mag_peak"] < 18.9880562 else 40
                                if state == 39:
                                    state = (
                                        57
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.743809581)
                                        else 58
                                    )
                                    if state == 57:
                                        state = (
                                            79
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.712857008)
                                            else 80
                                        )
                                        if state == 79:
                                            state = (
                                                101
                                                if x["col_det"] < 0.262747288
                                                else 102
                                            )
                                            if state == 101:
                                                return 0.0324464962
                                            if state == 102:
                                                state = (
                                                    125
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 18.143486)
                                                    else 126
                                                )
                                                if state == 125:
                                                    return 0.0719720945
                                                if state == 126:
                                                    return -0.0825949982
                                        if state == 80:
                                            return -0.14699094
                                    if state == 58:
                                        state = (
                                            81
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.806190491)
                                            else 82
                                        )
                                        if state == 81:
                                            return 0.0737520978
                                        if state == 82:
                                            return -0.0708310008
                                if state == 40:
                                    state = (
                                        59
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.779166698)
                                        else 60
                                    )
                                    if state == 59:
                                        return -0.129442289
                                    if state == 60:
                                        return 0.0432560332
                            if state == 28:
                                return 0.0366075896
                    if state == 8:
                        return 0.0690397322
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["col_det"]) or (x["col_det"] < 0.0165185928)
                        else 10
                    )
                    if state == 9:
                        return 0.00604611728
                    if state == 10:
                        return 0.271637648
            if state == 2:
                state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 7.04276037) else 6
                if state == 5:
                    return 0.0845676437
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["col_det"]) or (x["col_det"] < -0.0932941437)
                        else 14
                    )
                    if state == 13:
                        state = 21 if x["sgscore1_med"] < 0.0031458349 else 22
                        if state == 21:
                            return 0.0545845293
                        if state == 22:
                            state = (
                                31
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.109936714)
                                else 32
                            )
                            if state == 31:
                                state = 45 if x["mag_peak"] < 18.0795784 else 46
                                if state == 45:
                                    return 0.0669139102
                                if state == 46:
                                    state = (
                                        65
                                        if np.isnan(x["rb_med"])
                                        or (x["rb_med"] < 0.570357323)
                                        else 66
                                    )
                                    if state == 65:
                                        return 0.00471529365
                                    if state == 66:
                                        state = (
                                            87
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.678333282)
                                            else 88
                                        )
                                        if state == 87:
                                            state = (
                                                107
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.262662411)
                                                else 108
                                            )
                                            if state == 107:
                                                state = (
                                                    129
                                                    if np.isnan(x["maggaia_med"])
                                                    or (x["maggaia_med"] < 19.5787926)
                                                    else 130
                                                )
                                                if state == 129:
                                                    state = (
                                                        137
                                                        if x["col_det"] < -0.28623867
                                                        else 138
                                                    )
                                                    if state == 137:
                                                        return -0.00936251134
                                                    if state == 138:
                                                        state = (
                                                            141
                                                            if np.isnan(
                                                                x["classtar_med"]
                                                            )
                                                            or (
                                                                x["classtar_med"]
                                                                < 0.973749995
                                                            )
                                                            else 142
                                                        )
                                                        if state == 141:
                                                            return 0.0333422944
                                                        if state == 142:
                                                            return -0.114196807
                                                if state == 130:
                                                    return -0.00411243038
                                            if state == 108:
                                                return 0.00413854653
                                        if state == 88:
                                            state = (
                                                109
                                                if np.isnan(x["col_det"])
                                                or (x["col_det"] < -0.146849632)
                                                else 110
                                            )
                                            if state == 109:
                                                return -0.0272797905
                                            if state == 110:
                                                return 0.114885665
                            if state == 32:
                                return -0.0414825082
                    if state == 14:
                        state = (
                            23
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.153351009)
                            else 24
                        )
                        if state == 23:
                            state = (
                                33
                                if np.isnan(x["col_last"])
                                or (x["col_last"] < 0.697959542)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    49
                                    if np.isnan(x["mag_peak"])
                                    or (x["mag_peak"] < 18.1014023)
                                    else 50
                                )
                                if state == 49:
                                    return -0.113053575
                                if state == 50:
                                    return 0.00989045668
                            if state == 34:
                                return 0.00488917576
                        if state == 24:
                            return -0.00539209321
    elif num_booster == 92:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.699285567) else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.575000048) else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["t_predetect"])
                        or (x["t_predetect"] < 0.114652753)
                        else 8
                    )
                    if state == 7:
                        return -0.0769548789
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.6210003)
                            else 18
                        )
                        if state == 17:
                            return -0.0672885105
                        if state == 18:
                            state = (
                                33
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 2.92727423)
                                else 34
                            )
                            if state == 33:
                                state = (
                                    53
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 21.4305)
                                    else 54
                                )
                                if state == 53:
                                    return 0.157001376
                                if state == 54:
                                    return -0.0256183166
                            if state == 34:
                                state = (
                                    55
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 19.5844994)
                                    else 56
                                )
                                if state == 55:
                                    return 0.0853767991
                                if state == 56:
                                    state = (
                                        75 if x["distpsnr1_med"] < 2.61348391 else 76
                                    )
                                    if state == 75:
                                        state = (
                                            103
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 19.5835743)
                                            else 104
                                        )
                                        if state == 103:
                                            return 0.0879536569
                                        if state == 104:
                                            return -0.0800623074
                                    if state == 76:
                                        return -0.0364713296
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 6.98230362)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.8212509)
                            else 20
                        )
                        if state == 19:
                            return -0.162020817
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 3.95989585)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    57
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 21.1875)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        77
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 3.26656723)
                                        else 78
                                    )
                                    if state == 77:
                                        state = (
                                            107
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.9436455)
                                            else 108
                                        )
                                        if state == 107:
                                            return 0.0686472282
                                        if state == 108:
                                            state = (
                                                127
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 20.793499)
                                                else 128
                                            )
                                            if state == 127:
                                                state = (
                                                    137
                                                    if x["mag_peak"] < 18.9102402
                                                    else 138
                                                )
                                                if state == 137:
                                                    return 0.0492030382
                                                if state == 138:
                                                    return -0.116621137
                                            if state == 128:
                                                return 0.0366402417
                                    if state == 78:
                                        return 0.110435352
                                if state == 58:
                                    return -0.0826946422
                            if state == 36:
                                state = (
                                    59
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 21.0100002)
                                    else 60
                                )
                                if state == 59:
                                    state = (
                                        81 if x["distpsnr1_med"] < 0.114037648 else 82
                                    )
                                    if state == 81:
                                        return 0.0803874508
                                    if state == 82:
                                        return -0.122331023
                                if state == 60:
                                    return -0.00916925818
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.1345005)
                            else 22
                        )
                        if state == 21:
                            return -0.0543612912
                        if state == 22:
                            return 0.106724977
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.768571496) else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 5.94441509)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 17.8465004)
                            else 24
                        )
                        if state == 23:
                            return 0.0697325617
                        if state == 24:
                            state = (
                                41
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.0222279988)
                                else 42
                            )
                            if state == 41:
                                return 0.0970065668
                            if state == 42:
                                state = (
                                    63
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 18.1704998)
                                    else 64
                                )
                                if state == 63:
                                    return -0.114089012
                                if state == 64:
                                    state = (
                                        87
                                        if np.isnan(x["distpsnr1_med"])
                                        or (x["distpsnr1_med"] < 3.98557806)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            113
                                            if np.isnan(x["mag_last"])
                                            or (x["mag_last"] < 18.8228855)
                                            else 114
                                        )
                                        if state == 113:
                                            return 0.0828742385
                                        if state == 114:
                                            state = (
                                                129
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.3585014)
                                                else 130
                                            )
                                            if state == 129:
                                                return 0.0696801171
                                            if state == 130:
                                                state = (
                                                    139
                                                    if x["mag_peak"] < 18.9288731
                                                    else 140
                                                )
                                                if state == 139:
                                                    return 0.03783115
                                                if state == 140:
                                                    return -0.116416022
                                    if state == 88:
                                        return -0.0773613453
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.4780006)
                            else 26
                        )
                        if state == 25:
                            return 0.121334486
                        if state == 26:
                            return -0.0371390171
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 3.86057854)
                        else 14
                    )
                    if state == 13:
                        state = (
                            27
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.2075005)
                            else 28
                        )
                        if state == 27:
                            return 0.0922813416
                        if state == 28:
                            state = (
                                49
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 0.00181709998)
                                else 50
                            )
                            if state == 49:
                                return 0.0283557437
                            if state == 50:
                                state = (
                                    67
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 20.5855007)
                                    else 68
                                )
                                if state == 67:
                                    return -0.136882782
                                if state == 68:
                                    return 0.0110122338
                    if state == 14:
                        state = (
                            29
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.4054985)
                            else 30
                        )
                        if state == 29:
                            state = (
                                51
                                if np.isnan(x["t_predetect"])
                                or (x["t_predetect"] < 5.87118626)
                                else 52
                            )
                            if state == 51:
                                return 0.112612635
                            if state == 52:
                                return -0.045273032
                        if state == 30:
                            return -0.0542381555
    elif num_booster == 93:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["mag_last"]) or (x["mag_last"] < 17.9402313) else 2
            if state == 1:
                return 0.0601250231
            if state == 2:
                state = (
                    3
                    if np.isnan(x["classtar_med"]) or (x["classtar_med"] < 0.978500009)
                    else 4
                )
                if state == 3:
                    state = 5 if np.isnan(x["t_lc"]) or (x["t_lc"] < 55.8127823) else 6
                    if state == 5:
                        state = (
                            9
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0876190513)
                            else 10
                        )
                        if state == 9:
                            state = 17 if x["col_peak"] < 0.349781036 else 18
                            if state == 17:
                                state = (
                                    31
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 5.94273186)
                                    else 32
                                )
                                if state == 31:
                                    return -0.0264146756
                                if state == 32:
                                    return -0.189064682
                            if state == 18:
                                state = (
                                    33
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 4.97234964)
                                    else 34
                                )
                                if state == 33:
                                    return -0.0498192385
                                if state == 34:
                                    state = (
                                        59
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.717028081)
                                        else 60
                                    )
                                    if state == 59:
                                        return 0.140560582
                                    if state == 60:
                                        return -0.153284654
                        if state == 10:
                            state = 19 if x["col_peak"] < -0.0354995728 else 20
                            if state == 19:
                                return 0.0867573544
                            if state == 20:
                                state = (
                                    35
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 1.94385409)
                                    else 36
                                )
                                if state == 35:
                                    return -0.0419363305
                                if state == 36:
                                    state = (
                                        63
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.639334202)
                                        else 64
                                    )
                                    if state == 63:
                                        return -0.0587713122
                                    if state == 64:
                                        state = (
                                            89
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 1.07252562)
                                            else 90
                                        )
                                        if state == 89:
                                            return 0.118648291
                                        if state == 90:
                                            state = (
                                                111
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 17.5569992)
                                                else 112
                                            )
                                            if state == 111:
                                                return -0.0282616969
                                            if state == 112:
                                                state = (
                                                    133
                                                    if np.isnan(x["distnr_med"])
                                                    or (x["distnr_med"] < 4.37316418)
                                                    else 134
                                                )
                                                if state == 133:
                                                    state = (
                                                        151
                                                        if np.isnan(x["magnr_med"])
                                                        or (x["magnr_med"] < 20.2200012)
                                                        else 152
                                                    )
                                                    if state == 151:
                                                        return 0.0957581252
                                                    if state == 152:
                                                        return -0.0418406986
                                                if state == 134:
                                                    return -0.0221560989
                    if state == 6:
                        state = 11 if x["sgscore1_med"] < 0.00455356995 else 12
                        if state == 11:
                            return 0.0457030423
                        if state == 12:
                            return -0.140287563
                if state == 4:
                    state = 7 if np.isnan(x["t_lc"]) or (x["t_lc"] < 31.0696239) else 8
                    if state == 7:
                        state = (
                            13
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.0103749996)
                            else 14
                        )
                        if state == 13:
                            state = (
                                23
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < -0.0914802551)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    39
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 7.00134277)
                                    else 40
                                )
                                if state == 39:
                                    state = (
                                        65
                                        if np.isnan(x["distnr_med"])
                                        or (x["distnr_med"] < 0.275643378)
                                        else 66
                                    )
                                    if state == 65:
                                        return 0.0814766586
                                    if state == 66:
                                        state = (
                                            91
                                            if np.isnan(x["distnr_med"])
                                            or (x["distnr_med"] < 0.829340577)
                                            else 92
                                        )
                                        if state == 91:
                                            return -0.0813092962
                                        if state == 92:
                                            state = (
                                                115
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 19.8195)
                                                else 116
                                            )
                                            if state == 115:
                                                return 0.0832253247
                                            if state == 116:
                                                return -0.0622644946
                                if state == 40:
                                    return 0.0881425142
                            if state == 24:
                                return 0.0703742728
                        if state == 14:
                            state = 25 if x["col_peak"] < -0.120340824 else 26
                            if state == 25:
                                return -0.0870898962
                            if state == 26:
                                state = (
                                    45
                                    if np.isnan(x["t_predetect"])
                                    or (x["t_predetect"] < 3.50066566)
                                    else 46
                                )
                                if state == 45:
                                    return 0.0260928757
                                if state == 46:
                                    return -0.0594349243
                    if state == 8:
                        state = (
                            15
                            if np.isnan(x["sgscore1_med"])
                            or (x["sgscore1_med"] < 0.124116004)
                            else 16
                        )
                        if state == 15:
                            state = 27 if x["col_peak"] < 0.194297314 else 28
                            if state == 27:
                                return 0.000661147409
                            if state == 28:
                                return 0.131092548
                        if state == 16:
                            return 0.00319099892
    elif num_booster == 94:
        state = 0
        if state == 0:
            state = 1 if x["distpsnr1_med"] < 0.656493902 else 2
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.712781191)
                    else 4
                )
                if state == 3:
                    state = 7 if x["mag_peak"] < 17.7894173 else 8
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.1520004)
                            else 16
                        )
                        if state == 15:
                            return -0.360361964
                        if state == 16:
                            return 0.0410405286
                    if state == 8:
                        state = (
                            17
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 20.6070004)
                            else 18
                        )
                        if state == 17:
                            state = (
                                29
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < 0.149558067)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    43
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.968000054)
                                    else 44
                                )
                                if state == 43:
                                    return 0.0116800796
                                if state == 44:
                                    state = (
                                        61
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 20.2610512)
                                        else 62
                                    )
                                    if state == 61:
                                        state = (
                                            79 if x["col_det"] < -0.0118360519 else 80
                                        )
                                        if state == 79:
                                            return -0.0593499281
                                        if state == 80:
                                            state = (
                                                93
                                                if np.isnan(x["sgscore1_med"])
                                                or (x["sgscore1_med"] < 0.00270833494)
                                                else 94
                                            )
                                            if state == 93:
                                                return 0.11975462
                                            if state == 94:
                                                state = (
                                                    103
                                                    if np.isnan(x["col_last"])
                                                    or (x["col_last"] < 0.232531548)
                                                    else 104
                                                )
                                                if state == 103:
                                                    state = (
                                                        117
                                                        if x["distpsnr1_med"]
                                                        < 0.31738922
                                                        else 118
                                                    )
                                                    if state == 117:
                                                        return -0.147379592
                                                    if state == 118:
                                                        return 0.064277038
                                                if state == 104:
                                                    return 0.0506752171
                                    if state == 62:
                                        return -0.115649179
                            if state == 30:
                                return -0.119055957
                        if state == 18:
                            return 0.0427244008
                if state == 4:
                    return 0.0739387348
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.7442168)
                    else 6
                )
                if state == 5:
                    state = 11 if x["mag_peak"] < 18.0525475 else 12
                    if state == 11:
                        return 0.212498263
                    if state == 12:
                        return -0.0179480892
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_peak"]) or (x["mag_peak"] < 18.5600853)
                        else 14
                    )
                    if state == 13:
                        state = (
                            23
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.8260002)
                            else 24
                        )
                        if state == 23:
                            return 0.13422437
                        if state == 24:
                            state = (
                                37
                                if np.isnan(x["col_det"])
                                or (x["col_det"] < -0.034070015)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    49
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.982249975)
                                    else 50
                                )
                                if state == 49:
                                    state = (
                                        63
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.1491508)
                                        else 64
                                    )
                                    if state == 63:
                                        return -0.05576865
                                    if state == 64:
                                        state = (
                                            83
                                            if np.isnan(x["col_det"])
                                            or (x["col_det"] < -0.161915779)
                                            else 84
                                        )
                                        if state == 83:
                                            return -0.000071
                                        if state == 84:
                                            return 0.0919667333
                                if state == 50:
                                    state = (
                                        65
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 17.3040504)
                                        else 66
                                    )
                                    if state == 65:
                                        return -0.0707595497
                                    if state == 66:
                                        return 0.0897813588
                            if state == 38:
                                state = (
                                    51
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.981750011)
                                    else 52
                                )
                                if state == 51:
                                    return -0.0593429431
                                if state == 52:
                                    state = (
                                        69
                                        if np.isnan(x["mag_det"])
                                        or (x["mag_det"] < 19.7938499)
                                        else 70
                                    )
                                    if state == 69:
                                        state = (
                                            87 if x["col_det"] < 0.0147066116 else 88
                                        )
                                        if state == 87:
                                            return -0.0821050629
                                        if state == 88:
                                            return 0.0940048695
                                    if state == 70:
                                        return 0.0849695057
                    if state == 14:
                        state = (
                            25
                            if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 18.7502499)
                            else 26
                        )
                        if state == 25:
                            state = 39 if x["col_det"] < -0.103403091 else 40
                            if state == 39:
                                return 0.0195881519
                            if state == 40:
                                state = (
                                    53
                                    if np.isnan(x["classtar_med"])
                                    or (x["classtar_med"] < 0.976750016)
                                    else 54
                                )
                                if state == 53:
                                    return 0.0107918903
                                if state == 54:
                                    return -0.137563795
                        if state == 26:
                            return -0.00152405072
    elif num_booster == 95:
        state = 0
        if state == 0:
            state = (
                1
                if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 4.89207172)
                else 2
            )
            if state == 1:
                state = 3 if x["neargaia_med"] < 5.1648078 else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["col_det"]) or (x["col_det"] < 0.458903313)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.579285741)
                            else 16
                        )
                        if state == 15:
                            return -0.0371001028
                        if state == 16:
                            state = (
                                29
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.581666589)
                                else 30
                            )
                            if state == 29:
                                return 0.215562165
                            if state == 30:
                                return 0.0358483382
                    if state == 8:
                        return -0.0148435878
                if state == 4:
                    state = 9 if x["col_det"] < 0.296112061 else 10
                    if state == 9:
                        return 0.0517009608
                    if state == 10:
                        state = (
                            19
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.604642928)
                            else 20
                        )
                        if state == 19:
                            return -0.071048677
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.726190507)
                                else 36
                            )
                            if state == 35:
                                return 0.024351757
                            if state == 36:
                                state = 55 if x["col_peak"] < 0.738098145 else 56
                                if state == 55:
                                    return 0.104871199
                                if state == 56:
                                    state = (
                                        85
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 3.07001734)
                                        else 86
                                    )
                                    if state == 85:
                                        return -0.0971586928
                                    if state == 86:
                                        return 0.0869704932
            if state == 2:
                state = 5 if x["neargaia_med"] < 0.672370434 else 6
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["col_det"]) or (x["col_det"] < 0.0232744217)
                        else 12
                    )
                    if state == 11:
                        return -0.0107832542
                    if state == 12:
                        state = (
                            23
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.739166677)
                            else 24
                        )
                        if state == 23:
                            return -0.284441054
                        if state == 24:
                            state = (
                                39
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.741666794)
                                else 40
                            )
                            if state == 39:
                                return 0.0604974702
                            if state == 40:
                                return -0.126227215
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["col_det"]) or (x["col_det"] < 0.161698341)
                        else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.660714328)
                            else 26
                        )
                        if state == 25:
                            state = (
                                41
                                if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.556666672)
                                else 42
                            )
                            if state == 41:
                                state = 59 if x["col_peak"] < -0.17522049 else 60
                                if state == 59:
                                    return 0.0505979396
                                if state == 60:
                                    state = (
                                        87
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 9.0395546)
                                        else 88
                                    )
                                    if state == 87:
                                        state = (
                                            117
                                            if np.isnan(x["rb_med"])
                                            or (x["rb_med"] < 0.482261837)
                                            else 118
                                        )
                                        if state == 117:
                                            state = (
                                                133
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.336666822)
                                                else 134
                                            )
                                            if state == 133:
                                                return -0.0749507174
                                            if state == 134:
                                                return 0.0839212313
                                        if state == 118:
                                            return -0.12804319
                                    if state == 88:
                                        return 0.0504862256
                            if state == 42:
                                state = 61 if x["col_peak"] < -0.0524320602 else 62
                                if state == 61:
                                    return -0.00172588893
                                if state == 62:
                                    state = (
                                        91
                                        if np.isnan(x["t_predetect"])
                                        or (x["t_predetect"] < 5.97777748)
                                        else 92
                                    )
                                    if state == 91:
                                        return -0.040389996
                                    if state == 92:
                                        return 0.121674754
                        if state == 26:
                            return -0.0488221757
                    if state == 14:
                        return 0.0624721833
    elif num_booster == 96:
        state = 0
        if state == 0:
            state = 1 if x["neargaia_med"] < 0.536017239 else 2
            if state == 1:
                return -0.0566992573
            if state == 2:
                state = (
                    5 if np.isnan(x["mag_det"]) or (x["mag_det"] < 18.6673737) else 6
                )
                if state == 5:
                    return -0.0437003002
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.0425339)
                        else 12
                    )
                    if state == 11:
                        state = 19 if x["distpsnr1_med"] < 0.23389262 else 20
                        if state == 19:
                            return -0.0527810194
                        if state == 20:
                            state = (
                                29
                                if np.isnan(x["mag_peak"])
                                or (x["mag_peak"] < 17.8700447)
                                else 30
                            )
                            if state == 29:
                                return 0.0893092006
                            if state == 30:
                                return -0.0608239025
                    if state == 12:
                        state = 21 if x["distpsnr1_med"] < 1.51394773 else 22
                        if state == 21:
                            state = 31 if x["mag_peak"] < 19.0332069 else 32
                            if state == 31:
                                state = 41 if x["sgscore1_med"] < 0.509500027 else 42
                                if state == 41:
                                    state = 55 if x["mag_peak"] < 18.6012917 else 56
                                    if state == 55:
                                        state = (
                                            71 if x["col_peak"] < 0.146361828 else 72
                                        )
                                        if state == 71:
                                            return 0.0978401154
                                        if state == 72:
                                            state = (
                                                83
                                                if x["sgscore1_med"] < 0.099931702
                                                else 84
                                            )
                                            if state == 83:
                                                state = (
                                                    91
                                                    if x["distpsnr1_med"] < 0.663879395
                                                    else 92
                                                )
                                                if state == 91:
                                                    return 0.0671026334
                                                if state == 92:
                                                    return -0.0634412915
                                            if state == 84:
                                                return -0.0452574231
                                    if state == 56:
                                        return 0.087024197
                                if state == 42:
                                    return -0.00594275352
                            if state == 32:
                                return -0.049479831
                        if state == 22:
                            state = 33 if x["mag_peak"] < 18.9869461 else 34
                            if state == 33:
                                state = (
                                    45
                                    if np.isnan(x["sgscore1_med"])
                                    or (x["sgscore1_med"] < 0.0231041498)
                                    else 46
                                )
                                if state == 45:
                                    return -0.0014705694
                                if state == 46:
                                    state = 61 if x["mag_peak"] < 18.8882599 else 62
                                    if state == 61:
                                        return 0.074329026
                                    if state == 62:
                                        return -0.0537218675
                            if state == 34:
                                return -0.0932800397
    elif num_booster == 97:
        state = 0
        if state == 0:
            state = 1 if np.isnan(x["t_lc"]) or (x["t_lc"] < 42.9200516) else 2
            if state == 1:
                state = 3 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.579999983) else 4
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["col_last"]) or (x["col_last"] < 0.674713612)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 1.04782009)
                            else 16
                        )
                        if state == 15:
                            return -0.0989603475
                        if state == 16:
                            return 0.0320289694
                    if state == 8:
                        return -0.252380013
                if state == 4:
                    state = 9 if x["col_last"] < 0.365611076 else 10
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 2.79066205)
                            else 20
                        )
                        if state == 19:
                            state = (
                                31
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 19.5364685)
                                else 32
                            )
                            if state == 31:
                                return 0.0294538513
                            if state == 32:
                                return -0.100108296
                        if state == 20:
                            return -0.0387694091
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 1.29070663)
                            else 22
                        )
                        if state == 21:
                            state = (
                                35
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 20.106741)
                                else 36
                            )
                            if state == 35:
                                state = (
                                    57
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.0105515)
                                    else 58
                                )
                                if state == 57:
                                    state = (
                                        79
                                        if np.isnan(x["neargaia_med"])
                                        or (x["neargaia_med"] < 0.664475739)
                                        else 80
                                    )
                                    if state == 79:
                                        return -0.0454276875
                                    if state == 80:
                                        state = (
                                            99
                                            if np.isnan(x["t_lc"])
                                            or (x["t_lc"] < 20.9125977)
                                            else 100
                                        )
                                        if state == 99:
                                            return -0.00634494796
                                        if state == 100:
                                            state = (
                                                119
                                                if np.isnan(x["rb_med"])
                                                or (x["rb_med"] < 0.756666899)
                                                else 120
                                            )
                                            if state == 119:
                                                return 0.265822828
                                            if state == 120:
                                                return -0.0475668013
                                if state == 58:
                                    return 0.037219204
                            if state == 36:
                                return -0.0383713804
                        if state == 22:
                            state = (
                                37
                                if np.isnan(x["mag_last"])
                                or (x["mag_last"] < 20.1836128)
                                else 38
                            )
                            if state == 37:
                                state = (
                                    59
                                    if np.isnan(x["mag_det"])
                                    or (x["mag_det"] < 19.7817001)
                                    else 60
                                )
                                if state == 59:
                                    return 0.0314506106
                                if state == 60:
                                    return -0.0681992099
                            if state == 38:
                                return 0.0413460843
            if state == 2:
                state = 5 if np.isnan(x["rb_med"]) or (x["rb_med"] < 0.734999895) else 6
                if state == 5:
                    return 0.0254748445
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["col_last"]) or (x["col_last"] < -0.0349836349)
                        else 14
                    )
                    if state == 13:
                        state = (
                            25
                            if np.isnan(x["distnr_med"])
                            or (x["distnr_med"] < 0.738145411)
                            else 26
                        )
                        if state == 25:
                            return -0.149547011
                        if state == 26:
                            return 0.0500213467
                    if state == 14:
                        return -0.00356365158
    elif num_booster == 98:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.862344027) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 6.00270844)
                    else 4
                )
                if state == 3:
                    state = (
                        7
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7429695)
                        else 8
                    )
                    if state == 7:
                        state = (
                            15
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.2318268)
                            else 16
                        )
                        if state == 15:
                            state = (
                                29
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.000227928162)
                                else 30
                            )
                            if state == 29:
                                state = (
                                    51
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 18.0900002)
                                    else 52
                                )
                                if state == 51:
                                    return -0.0436106063
                                if state == 52:
                                    state = (
                                        77
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 20.0114994)
                                        else 78
                                    )
                                    if state == 77:
                                        return 0.0625578761
                                    if state == 78:
                                        state = (
                                            99
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.95039368)
                                            else 100
                                        )
                                        if state == 99:
                                            return 0.0799944103
                                        if state == 100:
                                            return -0.0676944479
                            if state == 30:
                                return -0.0561122
                        if state == 16:
                            return -0.0711198524
                    if state == 8:
                        return 0.0290638916
                if state == 4:
                    state = (
                        9
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.8896179)
                        else 10
                    )
                    if state == 9:
                        state = (
                            19
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 18.2047958)
                            else 20
                        )
                        if state == 19:
                            state = (
                                33
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.167644978)
                                else 34
                            )
                            if state == 33:
                                return -0.212700471
                            if state == 34:
                                return 0.179262415
                        if state == 20:
                            state = (
                                35
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.140319347)
                                else 36
                            )
                            if state == 35:
                                return -0.004985129
                            if state == 36:
                                return -0.367315888
                    if state == 10:
                        state = (
                            21
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.2017746)
                            else 22
                        )
                        if state == 21:
                            return 0.0696715266
                        if state == 22:
                            return -0.0709857121
            if state == 2:
                state = (
                    5
                    if np.isnan(x["t_predetect"]) or (x["t_predetect"] < 4.02077007)
                    else 6
                )
                if state == 5:
                    state = (
                        11
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.7438469)
                        else 12
                    )
                    if state == 11:
                        state = (
                            23
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 19.4350052)
                            else 24
                        )
                        if state == 23:
                            state = (
                                39
                                if np.isnan(x["col_peak"])
                                or (x["col_peak"] < 0.368918419)
                                else 40
                            )
                            if state == 39:
                                state = (
                                    55
                                    if np.isnan(x["magnr_med"])
                                    or (x["magnr_med"] < 18.0849991)
                                    else 56
                                )
                                if state == 55:
                                    return 0.105899446
                                if state == 56:
                                    state = (
                                        81
                                        if np.isnan(x["magnr_med"])
                                        or (x["magnr_med"] < 20.9905014)
                                        else 82
                                    )
                                    if state == 81:
                                        state = (
                                            101
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.945185184)
                                            else 102
                                        )
                                        if state == 101:
                                            return -0.0281772781
                                        if state == 102:
                                            state = (
                                                113
                                                if np.isnan(x["mag_last"])
                                                or (x["mag_last"] < 19.207365)
                                                else 114
                                            )
                                            if state == 113:
                                                state = (
                                                    125
                                                    if np.isnan(x["mag_last"])
                                                    or (x["mag_last"] < 18.9963951)
                                                    else 126
                                                )
                                                if state == 125:
                                                    return 0.0822020024
                                                if state == 126:
                                                    return -0.0648149699
                                            if state == 114:
                                                return 0.0932101682
                                    if state == 82:
                                        state = (
                                            103
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.95900464)
                                            else 104
                                        )
                                        if state == 103:
                                            return -0.101303257
                                        if state == 104:
                                            return 0.0528875999
                            if state == 40:
                                return 0.234021142
                        if state == 24:
                            return 0.0152240768
                    if state == 12:
                        state = (
                            25
                            if np.isnan(x["mag_last"]) or (x["mag_last"] < 20.0715504)
                            else 26
                        )
                        if state == 25:
                            state = 43 if x["col_peak"] < 0.117539406 else 44
                            if state == 43:
                                return 0.0136134187
                            if state == 44:
                                return -0.174275994
                        if state == 26:
                            return 0.0130647793
                if state == 6:
                    state = (
                        13
                        if np.isnan(x["mag_last"]) or (x["mag_last"] < 17.4167671)
                        else 14
                    )
                    if state == 13:
                        return -0.204858571
                    if state == 14:
                        return -0.00703703379
    elif num_booster == 99:
        state = 0
        if state == 0:
            state = (
                1 if np.isnan(x["magnr_med"]) or (x["magnr_med"] < 16.1334991) else 2
            )
            if state == 1:
                state = (
                    3
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 0.745402932)
                    else 4
                )
                if state == 3:
                    return -0.0921612978
                if state == 4:
                    return 0.16082117
            if state == 2:
                state = (
                    5
                    if np.isnan(x["distnr_med"]) or (x["distnr_med"] < 2.22051001)
                    else 6
                )
                if state == 5:
                    state = 9 if x["col_peak"] < -0.128970146 else 10
                    if state == 9:
                        return -0.0345860086
                    if state == 10:
                        state = (
                            15
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 7.97642374)
                            else 16
                        )
                        if state == 15:
                            state = (
                                23
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.2192001)
                                else 24
                            )
                            if state == 23:
                                state = (
                                    35
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.48959196)
                                    else 36
                                )
                                if state == 35:
                                    state = 53 if x["mag_peak"] < 18.72575 else 54
                                    if state == 53:
                                        return 0.0893708915
                                    if state == 54:
                                        return -0.0721603334
                                if state == 36:
                                    return 0.225948006
                            if state == 24:
                                state = (
                                    37
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 1.10087562)
                                    else 38
                                )
                                if state == 37:
                                    state = 57 if x["mag_peak"] < 18.9672203 else 58
                                    if state == 57:
                                        state = (
                                            79
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 5.87229729)
                                            else 80
                                        )
                                        if state == 79:
                                            state = (
                                                99
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.9825001)
                                                else 100
                                            )
                                            if state == 99:
                                                return -0.00752359256
                                            if state == 100:
                                                state = (
                                                    119
                                                    if np.isnan(x["col_peak"])
                                                    or (x["col_peak"] < 0.0848855972)
                                                    else 120
                                                )
                                                if state == 119:
                                                    return 0.126600102
                                                if state == 120:
                                                    return -0.0487103797
                                        if state == 80:
                                            return -0.0180186518
                                    if state == 58:
                                        return -0.0329779498
                                if state == 38:
                                    state = 59 if x["mag_peak"] < 18.8106995 else 60
                                    if state == 59:
                                        return -0.0649658367
                                    if state == 60:
                                        state = (
                                            85
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 0.0203356501)
                                            else 86
                                        )
                                        if state == 85:
                                            return -0.0311444011
                                        if state == 86:
                                            state = (
                                                107
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 21.1817513)
                                                else 108
                                            )
                                            if state == 107:
                                                return 0.108463354
                                            if state == 108:
                                                return -0.0208451506
                        if state == 16:
                            state = (
                                25
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 19.3971481)
                                else 26
                            )
                            if state == 25:
                                return 0.0420121066
                            if state == 26:
                                return -0.0840417892
                if state == 6:
                    state = (
                        11
                        if np.isnan(x["col_peak"]) or (x["col_peak"] < -0.282077134)
                        else 12
                    )
                    if state == 11:
                        state = (
                            17
                            if np.isnan(x["t_predetect"])
                            or (x["t_predetect"] < 8.91857719)
                            else 18
                        )
                        if state == 17:
                            state = (
                                27
                                if np.isnan(x["mag_det"]) or (x["mag_det"] < 20.3042488)
                                else 28
                            )
                            if state == 27:
                                state = (
                                    43
                                    if np.isnan(x["distnr_med"])
                                    or (x["distnr_med"] < 3.3314867)
                                    else 44
                                )
                                if state == 43:
                                    return -0.0948065296
                                if state == 44:
                                    state = (
                                        65
                                        if np.isnan(x["mag_peak"])
                                        or (x["mag_peak"] < 18.7217636)
                                        else 66
                                    )
                                    if state == 65:
                                        state = (
                                            91
                                            if np.isnan(x["t_predetect"])
                                            or (x["t_predetect"] < 2.98050356)
                                            else 92
                                        )
                                        if state == 91:
                                            return 0.00912237354
                                        if state == 92:
                                            state = (
                                                113
                                                if np.isnan(x["magnr_med"])
                                                or (x["magnr_med"] < 18.9445)
                                                else 114
                                            )
                                            if state == 113:
                                                return 0.0354287922
                                            if state == 114:
                                                return -0.129641891
                                    if state == 66:
                                        return 0.0718123913
                            if state == 28:
                                return 0.0237703416
                        if state == 18:
                            return 0.0817505866
                    if state == 12:
                        return 0.0218653325
